package devmgr.api.model;

import devmgr.api.symbol.LUNMapping;
import devmgr.api.symbol.VolumeCache;
import io.swagger.annotations.ApiModelProperty;

import javax.xml.bind.annotation.XmlRootElement;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * Created with IntelliJ IDEA.
 * User: masonb
 * Date: 11/26/13
 * Time: 3:50 PM
 * To change this template use File | Settings | File Templates.
 */
@XmlRootElement
public class VolumeEx extends devmgr.api.symbol.Volume implements Identifiable, UserVolume, CopyableObject {

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof VolumeEx)) {
            return false;
        }

        VolumeEx volumeEx = (VolumeEx) o;

        if (!Objects.equals(getVolumeRef(),volumeEx.getId())) {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode() {
        final String volumeRef = getVolumeRef();
        return volumeRef != null ? volumeRef.hashCode() : 0;
    }

    private VolumeUse volumeUse;
    //indicates if the volume (or it sometimes its underlying repository is full or not
    private boolean volumeFull;

    private List<LUNMapping>mappings = new ArrayList<>();

    //TODO FIELDS
    //poolName;
    //is Volume Copy Target
    //Mirror Status
    //is built on crush pool (Probably need to handle raid better)
    //is Pit Base

    /**
     * The underlying volume type of the MappableObject
     *
     * @return
     */
    @Override
    public ObjectType getObjectType() {
        return ObjectType.volume;
    }

    /**
     * Name/label of the volume.
     * @return
     */
    @Override
    public String getName() {
        return super.getLabel();
    }

    /**
     * Capacity of the volume in bytes.
     * @return
     */
    @Override
    public Long getTotalSizeInBytes() {
        return super.getCapacity();
    }

    /**
     * "True" if the volume is in use as a repository and is full.
     * @return
     */
    public boolean isVolumeFull() {
        return volumeFull;
    }

    public void setVolumeFull(boolean volumeFull) {
        this.volumeFull = volumeFull;
    }

    /**
     * Indicates if the volume is a volume copy target
     * @return
     */
    @Override
    @ApiModelProperty("This value is true if the volume is currently the target of a volume copy pair.")
    public boolean isVolumeCopyTarget() {
        return volumeCopyTarget;
    }

    @Override
    public void setVolumeCopyTarget(boolean isVolumeCopyTarget) {
        this.volumeCopyTarget = isVolumeCopyTarget;
    }

    /**
     * Indicates if the volume is a base volume for a PIT
     * @return
     */
    @Override
    public boolean isPitBaseVolume() {
        return pitBaseVolume;
    }

    @Override
    public void setPitBaseVolume(boolean isPitBaseVolume) {
        this.pitBaseVolume = isPitBaseVolume;
    }

    /**
     * Defines the use for this volume
     * @return
     */
    public VolumeUse getVolumeUse() {
        return volumeUse;
    }

    /**
     * Sets the use for the volume
     * @param volumeUse
     */
    public void setVolumeUse(VolumeUse volumeUse) {
        this.volumeUse = volumeUse;
    }

    /**
     * Mappings for the volume.
     * @return
     */
    @Override
    public List<LUNMapping> getListOfMappings() {
        return mappings;
    }

    public void setMapping(LUNMapping mapping) {
        this.mappings.add(mapping);
    }

    @Override
    public void setMappings(List<LUNMapping> mappings) {
        this.mappings=mappings;
    }

    /**
     * "True" if the volume has at least one mapping.
     * @return
     */
    @Override
    public boolean isMapped() {
        return !mappings.isEmpty();
    }


    /**
     * Id of the volume
     * @return
     */
    @Override
    public String getId() {
        return getVolumeRef();
    }

    /**
     * The unique World Wide Name (WWN) for the volume.
     * @return
     */
    @Override
    public String getWwn() {
        return getWorldWideName();
    }

    /**
     * The current owning controller.
     * @return
     */
    @Override
    public String getCurrentControllerId() {
        return getCurrentManager();
    }

    /**
     * The preferred controller.
     * @return
     */
    @Override
    public String getPreferredControllerId() {
        return getPreferredManager();
    }

    private boolean volumeCopyTarget;
    private boolean cloneCopy;
    private boolean volumeCopySource;
    private boolean pitBaseVolume;
    private boolean asyncMirrorTarget;
    private boolean asyncMirrorSource;

    @Override
    public void setVolumeCopySource(boolean v) {
        this.volumeCopySource = v;
    }

    @Override
    public void setOnlineVolumeCopy(boolean c) {
        this.cloneCopy = c;
    }

    @Override
    @ApiModelProperty("This value is true if the volume is currently the source in a volume copy pair.")
    public boolean isVolumeCopySource() {
        return volumeCopySource;
    }

    @Override
    public boolean isOnlineVolumeCopy() {
        return cloneCopy;
    }

    /**
     * @API_Spec_Description True if the volume is a source in an Asynchronous Mirror relationship.
     */
    @Override
    @ApiModelProperty("This value is true if the volume is currently the source in an Asynchronous Mirror relationship.")
    public boolean isAsyncMirrorSource() {
        return asyncMirrorSource;  //To change body of implemented methods use File | Settings | File Templates.
    }

    /**
     * @API_Spec_Description True if the volume is a target in an Asynchronous Mirror relationship.
     */
    @Override
    @ApiModelProperty("This value is true if the volume is currently the target in an Asynchronous Mirror relationship.")
    public boolean isAsyncMirrorTarget() {
        return asyncMirrorTarget;  //To change body of implemented methods use File | Settings | File Templates.
    }

    /**
     * @API_Spec_Description Set to true if this volume is local in an AMG that is secondary.
     */
    @Override
    public void setAsyncMirrorTarget(boolean v) {
        this.asyncMirrorTarget = v;
    }

    /**
     * @API_Spec_Description Set to true if this volume is local in an AMG that is primary.
     */
    @Override
    public void setAsyncMirrorSource(boolean v) {
        this.asyncMirrorSource = v;
    }

    private boolean remoteMirrorSource;

    @Override
    public void setRemoteMirrorTarget(boolean remoteMirrorTarget) {
        this.remoteMirrorTarget = remoteMirrorTarget;
    }

    @Override
    @ApiModelProperty("True if the volume is a source (primary), in an Remote Volume Mirror relationship.")
    public boolean isRemoteMirrorSource() {
        return this.remoteMirrorSource;
    }

    @Override
    @ApiModelProperty("True if the volume is a target (secondary), in an Remote Volume Mirror relationship.")
    public boolean isRemoteMirrorTarget() {
        return this.remoteMirrorTarget;
    }

    @Override
    public void setRemoteMirrorSource(boolean remoteMirrorSource) {
        this.remoteMirrorSource = remoteMirrorSource;
    }

    private boolean remoteMirrorTarget;

    @Override
    @ApiModelProperty("True if the volume was defined on a DiskPool.")
    public boolean isDiskPool() {
        return diskPool;
    }

    public void setDiskPool(boolean diskPool) {
        this.diskPool = diskPool;
    }

    private boolean diskPool;

    @Override
    public VolumeCache getCacheSettings() {
        return super.getCache();
    }

    @Override
    @ApiModelProperty("True if this volume is added to a flashCache.")
    public boolean isFlashCached() {
        return flashCached;
    }

    public void setFlashCached(boolean flashCached) {
        this.flashCached = flashCached;
    }

    private boolean flashCached;

    /**
     * The amount that a volume is currently being increased by.
     *
     * @return If a volume expansion is in progress, the total it's being increased by, otherwise zero.
     */
    public long getIncreasingBy() {
        return increasingBy;
    }

    @ApiModelProperty("If a Dynamic Volume Expansion (DVE) is in progress, the total capacity the volume is being increased by, otherwise zero.")
    private long increasingBy;

    public void setIncreasingBy(final long increasingBy){
        this.increasingBy = increasingBy;
    }


    @ApiModelProperty(value = "Metadata associated with the volume")
    private List<VolumeMetadataItem> metadata=new ArrayList<>();

    @Override
    public List<VolumeMetadataItem> getMetadata() {
        return metadata;
    }

    @Override
    public boolean isThinProvisioned() {
        return false;
    }

    public void setDataAssurance(boolean dataAssurance) {
        this.dataAssurance = dataAssurance;
    }

    private boolean dataAssurance;

    @Override
    public boolean isDataAssurance() {
        return this.dataAssurance;
    }

    public void setMetadata(List<VolumeMetadataItem> metadata) {
        this.metadata = metadata;
    }

}
