package devmgr.api.model.ldap;

import io.swagger.annotations.ApiModelProperty;
import javax.xml.bind.annotation.XmlType;

/**
 * Model to hold information about a bind lookup user
 */
@XmlType
public class BindLookupUser {

   private String password;

   private String user;

   public BindLookupUser() {
      password = null;
      user = null;
   }

   public BindLookupUser(String user, String password) {
      this.user = user;
      this.password = password;
   }

   public static BindLookupUser make(String user, String password) {
      BindLookupUser blu = new BindLookupUser(user, password);
      return blu;
   }

   public final String getPassword() {
      return password;
   }

   public final String getUser() {
      return user;
   }

   @ApiModelProperty(
         value = "The password for the bind user",
         required = true)
   public final void setPassword(String password) {
      this.password = password;
   }

   @ApiModelProperty(
         value = "The full DN for the bind user account",
         example = "cn=BindUser,ou=system-accounts,dc=example,dc=com",
         required = true)
   public final void setUser(String user) {
      this.user = user;
   }

   @Override
   public boolean equals(Object o) {
      if (this == o) {
         return true;
      }
      if (!(o instanceof BindLookupUser)) {
         return false;
      }
      BindLookupUser bindLookupUser = (BindLookupUser) o;

      boolean passwordMatches = bindLookupUser.getPassword() == null ?
              password == null : bindLookupUser.getPassword().equals(password);
      boolean userMatches = bindLookupUser.getUser() == null ? user == null : bindLookupUser.getUser().equals(user);

      if(!passwordMatches || !userMatches) {
         return false;
      }

      return true;
   }

   @Override
   public int hashCode() {
      int userHash = user != null ? user.hashCode() : 0;
      int passHash = password != null ? password.hashCode() : 0;
      return 67 * (userHash + passHash);
   }
}