/*******************************************************************************
 * Copyright (c) 2016 of NetApp, Inc. All Rights Reserved.                     *
 *                                                                             *
 ******************************************************************************/
package devmgr.api.model.ldap;

import javax.xml.bind.annotation.adapters.XmlAdapter;

/**
 * Used to convert a boolean string into a {@link Boolean} value. It is case
 * insensitive, but it will also throw an exception if it is unable to convert
 * the boolean (instead of defaulting to false).
 * 
 * @author vtroy
 *
 */
public class BooleanXMLAdapter extends XmlAdapter<String, Boolean> {
    @Override
    public String marshal(Boolean boolVal) throws Exception {
        return boolVal.toString();
    }

    @Override
    public Boolean unmarshal(String boolVal) throws Exception {
        if(boolVal != null && boolVal.compareToIgnoreCase(Boolean.TRUE.toString()) != 0
              && boolVal.compareToIgnoreCase(Boolean.FALSE.toString()) != 0) {
            throw new NumberFormatException(boolVal + " is not a valid boolean.");
        }
        return Boolean.parseBoolean(boolVal);
    }
}
