package devmgr.api.model.ldap;

import io.swagger.annotations.ApiModelProperty;

import java.util.regex.Pattern;

/**
 * Specifies the group mappings for an LDAP configuration
 *
 * @author vtroy
 */
public class GroupMapping {
    public static final String VAL_SECURITYADMIN = "security.admin";
    public static final String VAL_STORAGEADMIN = "storage.admin";
    public static final String VAL_STORAGEMONITOR = "storage.monitor";
    public static final String VAL_SUPPORTADMIN = "support.admin";
    public static final String VAL_STORAGENONE = "none";

    /**
     * @TODO: Make it a {@link Pattern} object instead of a String
     */
    @ApiModelProperty(value = "specifies the DN of the group. The wildcard .* can optionally be "
          + "used to allow specifying only a partial DN.", example = ".*cn=data-admin.*")
    private String groupRegex;

    @ApiModelProperty(name = "ignorecase", required = false, value = "Whether or not to ignore case for the group mappings", example = "false")
    private boolean ignoreCase;

    @ApiModelProperty(name = "name", required = true, value = "Specifies the role of the group", example = "storage.monitor")
    private Role name;

    private boolean hasIgnoreCaseBeenSet = false;

    public GroupMapping() {
    }

    private GroupMapping(Role name, String groupRegex, boolean ignoreCase) {
        super();
        this.name = name;
        this.groupRegex = groupRegex;
        this.ignoreCase = ignoreCase;
    }

    public final String getGroupRegex() {
        return this.groupRegex == null ? "" : this.groupRegex;
    }

    public final Role getName() {
        return name;
    }

    public final Boolean isIgnoreCase() {
        return ignoreCase;
    }

    public final void setGroupRegex(String groupRegex) {
        this.groupRegex = groupRegex;
    }

    public final void setIgnoreCase(Boolean ignoreCase) {
        hasIgnoreCaseBeenSet = true;
        this.ignoreCase = ignoreCase;
    }

    public final void setName(Role name) {
        this.name = name;
    }

    @Override
    public String toString() {
        return "RoleMap [groupRegex=" + groupRegex + ", name=" + name + ", ignoreCase=" + ignoreCase + "]";
    }

    @Override
    public boolean equals(Object o) {
        if(this == o) {
            return true;
        }
        if(!(o instanceof GroupMapping)) {
            return false;
        }
        GroupMapping mapping = (GroupMapping) o;

        if(mapping.getGroupRegex().equals(groupRegex) && mapping.getName().equals(name) &&
                mapping.isIgnoreCase().equals(ignoreCase)) {
            return true;
        }

        return false;
    }

    @Override
    public int hashCode() {
        int nameHash = name != null ? name.hashCode() : 0;
        int groupHash = groupRegex != null ? groupRegex.hashCode() : 0;
        int ignoreHash = ignoreCase ? 113 : 151;
        return 59 * (nameHash + groupHash + ignoreHash);
    }
}
