/*******************************************************************************
 * Copyright (c) 2016 of NetApp, Inc. All Rights Reserved.                     *
 *                                                                             *
 ******************************************************************************/
package devmgr.api.model.ldap;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.ArrayList;
import java.util.List;

/**
 * Represents a root XML and JSON element of a LDAP configuration.
 *
 * @author vtroy
 */
@ApiModel(description = "Structure that contains information about an LDAP Configuration")
public class LdapConfiguration {

    @ApiModelProperty(value = "The defined LDAP domains", required = true)
    private List<LdapDomain> ldapDomains;

    @ApiModelProperty(value = "LDAP Configuration version to use", hidden = true)
    private String version;

    public final List<LdapDomain> getLdapDomains() {
        if (ldapDomains == null) {
            ldapDomains = new ArrayList<>();
        }
        return ldapDomains;
    }

    public String getVersion() {
        return version;
    }

    public final void setLdapDomains(List<LdapDomain> ldapDomains) {
        this.ldapDomains = ldapDomains;
    }

    public final void setVersion(String version) {
        this.version = version;
    }

    @Override
    public String toString() {
        String domains;

        if(ldapDomains == null) {
            domains = "0";
        } else {
            domains = String.valueOf(ldapDomains.size());
        }

        return "LdapConfiguration (v" + getVersion() + ") [ldapDomains=" + domains + "]";
    }

    @Override
    public boolean equals(Object o) {
        if(this == o) {
            return true;
        }
        if(!(o instanceof LdapConfiguration)) {
            return false;
        }

        LdapConfiguration config = (LdapConfiguration) o;
        boolean versionMatches = config.getVersion() == null ? version == null : config.getVersion().equals(version);
        if(!versionMatches) {
            return false;
        }

        if(config.getLdapDomains().size() != getLdapDomains().size()) {
            return false;
        }

        for(int i = 0, size = config.getLdapDomains().size(); i < size; i++) {
            if(!config.getLdapDomains().get(i).equals(ldapDomains.get(i))) {
                return false;
            }
        }

        return true;
    }

    @Override
    public int hashCode() {
        int versionHash = version != null ? version.hashCode() : 0;
        int domainsHash = ldapDomains != null ? ldapDomains.hashCode() : 0;
        return 83 * (versionHash + domainsHash);
    }
}
