package devmgr.api.rpc;

import devmgr.api.runtime.Decoder;

/**
 * Represents an abstract connection to the storage system
 */
public interface SymbolClient extends AutoCloseable {

    void setTypeOverrides(Decoder.TypeOverrideTable typeOverrides);

    /**
     * Identical to {@link #call(int, Object)} where the {@code proc} string is
     * first mapped to its matching procedure id.
     */
    <T> T call(String proc, Object args) throws Exception;

    /**
     * Send a call to the remote host synchronously (blocking).
     *
     * @param proc the procedure id
     * @param args the procedure arguments
     * @param <T> result type of the return
     * @return the procedure call return value
     * @throws Exception if there's an error
     */
    <T> T call(int proc, Object args) throws Exception;

    /**
     * Identical to {@link #call(int, Object, NIOClientCallback)} where the {@code proc} string is
     * first mapped to its matching procedure id.
     */
    Object call(String proc, Object args, NIOClientCallback callback);

    /**
     * Send a call to the server asynchronously (non-blocking).
     *
     * @param proc the symbol procedure id
     * @param args arguments for the procedure
     * @param callback the callback used to communicate success or failure
     * @return the xid of the last transaction
     */
    int call(int proc, Object args, NIOClientCallback callback);

}
