package devmgr.api.runtime;

@SuppressWarnings("serial")
public class EncodeException
extends Exception
{
    public EncodeException(String msg)
    {
        super(msg);
    }
    
    /**
     * Construct a new EncodeException, referencing an original cause.
     * @param msg Message for the exception.
     * @param original Original exception that caused the problem.
     */
    private EncodeException(String msg, Exception original)
    {
        super(msg, original);
    }
    
    /**
     * Build a new exception to be thrown.
     * @param fmt Format string for message construction.
     * @param args Format arguments.
     * @return A EncodeException object to be thrown.
     */
    public static EncodeException build(String fmt, Object... args)
    {
        String msg = String.format(fmt, args);
        return new EncodeException(msg);
    }
    
    /**
     * Build an exception to be thrown, referencing the specified 
     * original as its cause.
     * @param original Original exception that caused the problem.
     * @param fmt Format string for message construction.
     * @param args Format arguments.
     * @return A EncodeException object to be thrown.
     */
    public static EncodeException build(Exception original, 
                                        String fmt, Object... args)
    {
        String msg = String.format(fmt, args);
        return new EncodeException(msg, original);
    }
}