package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure contains information about an accessible controller. Objects of this type are contained in a DiscoveryResponse object and returned to the client via a discoverControllers procedure call. In general, if a discoverControllers request is directed to a SYMbol agent that acts as a proxy for multiple I/O-attached controllers, then the DiscoveryResponse object will contain one AccessibleController object for each I/O-attached controller that is reachable through the proxy. However, for requests that are directed to network-attached controllers, the DiscoveryResponse will contain only one AccessibleController object, which represents the responding controller itself. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(731)
public class AccessibleController implements Serializable {
	public AccessibleController() {
	}

	/** The ID value of the tray in which this controller resides. */
	@io.swagger.annotations.ApiModelProperty(value ="The ID value of the tray in which this controller resides." , required = true)
	@XmlElement(required = true)
	private int trayId;

	/** @return The ID value of the tray in which this controller resides. */
	public int getTrayId() {
		return this.trayId;
	}
	/** @param x The ID value of the tray in which this controller resides. */
	public void setTrayId(int x) {
		this.trayId = x;
	}

	/** The slot within its tray where this controller resides. */
	@io.swagger.annotations.ApiModelProperty(value ="The slot within its tray where this controller resides." , required = true)
	@XmlElement(required = true)
	private int slot;

	/** @return The slot within its tray where this controller resides. */
	public int getSlot() {
		return this.slot;
	}
	/** @param x The slot within its tray where this controller resides. */
	public void setSlot(int x) {
		this.slot = x;
	}

	/** The world-wide unique identifier of the storage array in which this controller resides. */
	@io.swagger.annotations.ApiModelProperty(value ="The world-wide unique identifier of the storage array in which this controller resides." , required = true)
	@XmlElement(required = true)
	private SAIdentifier saId;

	/** @return The world-wide unique identifier of the storage array in which this controller resides. */
	public SAIdentifier getSaId() {
		return this.saId;
	}
	/** @param x The world-wide unique identifier of the storage array in which this controller resides. */
	public void setSaId(SAIdentifier x) {
		this.saId = x;
	}

	/** The SYMbol reference value that uniquely identifies this controller. */
	@io.swagger.annotations.ApiModelProperty(value ="The SYMbol reference value that uniquely identifies this controller." , required = true)
	@XmlElement(required = true)
	private String thisController;

	/** @return The SYMbol reference value that uniquely identifies this controller. */
	public String getThisController() {
		return this.thisController;
	}
	/** @param x The SYMbol reference value that uniquely identifies this controller. */
	public void setThisController(String x) {
		this.thisController = x;
	}

	/** An array of SYMbol reference values for all of the controllers that are present in the storage array where this controller resides. */
	@io.swagger.annotations.ApiModelProperty(value ="An array of SYMbol reference values for all of the controllers that are present in the storage array where this controller resides." , required = true)
	@XmlElement(required = true)
	private String[] allControllers;

	/** @return An array of SYMbol reference values for all of the controllers that are present in the storage array where this controller resides. */
	public String[] getAllControllers() {
		return this.allControllers;
	}
	/** @param x An array of SYMbol reference values for all of the controllers that are present in the storage array where this controller resides. */
	public void setAllControllers(String[] x) {
		this.allControllers = x;
	}
}
