package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration defines the different types of components that may be reported within a storage array. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(118)
public enum ComponentType implements Serializable {
		/** The component type is not known. */
		unknown(0),
		/** The component is a cooling fan. */
		fan(1),
		/** The component is a cache hold-up battery. */
		battery(2),
		/** The component is a power supply. */
		powerSupply(3),
		/** The component is a thermal sensor module. */
		thermalSensor(4),
		/** The component is an enclosure services module. */
		esm(5),
		/** The component is an uninterruptible power supply. */
		ups(6),
		/** The component is a Fibre Channel mini-hub module. */
		minihub(7),
		/** The component is a Fibre Channel GBIC module. */
		gbic(8),
		/** The component is an SFP. */
		sfp(9),
		/** The component is an Interconnect CRU. */
		interconnectCru(10),
		/** The component is a Support CRU. */
		supportCru(11),
		/** The component is an alarm. */
		alarm(12),
		/** The component is a host board. */
		hostboard(13),
		/** The component is a SAS expander integrated circuit. */
		icSasExpander(14),
		/** This component type is numerically equivalent to COMP_TYPE_HOSTBOARD. It has been added so that the component type terminology for host cards lines up with the major event log location terminology. Either one of the two enumeration values may be used. */
		hostIoCard(15),
		/** The component is a non-volatile storage device for preserving the contents of the controller cache memory in the event of a power loss. */
		cacheBackupDevice(16),
		/** The component is a cache memory DIMM. */
		cacheMemDimm(17),
		/** The component is a processor memory DIMM. */
		procMemDimm(18),
		/** The component is a channel port. Note that ChannelPorts are not included in the component bundle. */
		channelPort(20),
		/** The component is a disk drive. Note that Drives are not included in the component bundle. */
		drive(21),
		/** The component is a controller. Note that Controllers are not included in the component bundle. */
		controller(22),
		/** The component is an Ethernet interface. Note that interfaces are not included in the component bundle. */
		ethernetInterface(23),
		/** The component is a Fibre Channel interface. Note that interfaces are not included in the component bundle. */
		fibreInterface(24),
		/** The component is an Infiniband interface. Note that interfaces are not included in the component bundle. */
		ibInterface(25),
		/** The component is an iSCSI interface. Note that interfaces are not included in the component bundle. */
		iscsiInterface(26),
		/** The component is a SAS interface. Note that interfaces are not included in the component bundle. */
		sasInterface(27),
		/** The component is a Tray. Note that Trays are not included in the component bundle. */
		tray(28),
		/** The component is a StorageArray. Note that Storage Arrays are not included in the component bundle. */
		storageArray(29),
		/** The component is a drive drawer. */
		drawer(30),
		__UNDEFINED(464378545);

		public final int value;

		private ComponentType(int v) {
			this.value = v;
		}
}
