package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure reports the statistical information for controller-related fields. These include the CPU utilization, total read and write counter, number of IOs, cache hit information. Some of the information in this group, such as the CPU utilization, was reported in earlier releases as part of the Discrete Time Series management. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(596)
public class ControllerCounterGroup implements Serializable {
	public ControllerCounterGroup() {
	}

	/** Controller that generated this group. */
	@io.swagger.annotations.ApiModelProperty(value ="Controller that generated this group." , required = true)
	@XmlElement(required = true)
	private String controllerRef;

	/** @return Controller that generated this group. */
	public String getControllerRef() {
		return this.controllerRef;
	}
	/** @param x Controller that generated this group. */
	public void setControllerRef(String x) {
		this.controllerRef = x;
	}

	/** Time the counters were last reset. Time is the number of seconds since midnight, January 1, 1970. */
	@io.swagger.annotations.ApiModelProperty(value ="Time the counters were last reset. Time is the number of seconds since midnight, January 1, 1970." , required = true)
	@XmlElement(required = true)
	private long baseTime;

	/** @return Time the counters were last reset. Time is the number of seconds since midnight, January 1, 1970. */
	public long getBaseTime() {
		return this.baseTime;
	}
	/** @param x Time the counters were last reset. Time is the number of seconds since midnight, January 1, 1970. */
	public void setBaseTime(long x) {
		this.baseTime = x;
	}

	/** Start time for this collection as measured by the number of seconds since baseTime. */
	@io.swagger.annotations.ApiModelProperty(value ="Start time for this collection as measured by the number of seconds since baseTime." , required = true)
	@XmlElement(required = true)
	private long startTime;

	/** @return Start time for this collection as measured by the number of seconds since baseTime. */
	public long getStartTime() {
		return this.startTime;
	}
	/** @param x Start time for this collection as measured by the number of seconds since baseTime. */
	public void setStartTime(long x) {
		this.startTime = x;
	}

	/** End time for this collection as measured by the number of seconds since baseTime. */
	@io.swagger.annotations.ApiModelProperty(value ="End time for this collection as measured by the number of seconds since baseTime." , required = true)
	@XmlElement(required = true)
	private long observedTime;

	/** @return End time for this collection as measured by the number of seconds since baseTime. */
	public long getObservedTime() {
		return this.observedTime;
	}
	/** @param x End time for this collection as measured by the number of seconds since baseTime. */
	public void setObservedTime(long x) {
		this.observedTime = x;
	}

	/** CPU utilization statistics structure. */
	@io.swagger.annotations.ApiModelProperty(value ="CPU utilization statistics structure." , required = true)
	@XmlElement(required = true)
	private CpuUtilizationStats[] cpuUtilizationStats;

	/** @return CPU utilization statistics structure. */
	public CpuUtilizationStats[] getCpuUtilizationStats() {
		return this.cpuUtilizationStats;
	}
	/** @param x CPU utilization statistics structure. */
	public void setCpuUtilizationStats(CpuUtilizationStats[] x) {
		this.cpuUtilizationStats = x;
	}

	/** Total number of IO operations serviced by the controller. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of IO operations serviced by the controller." , required = true)
	@XmlElement(required = true)
	private long totalIopsServiced;

	/** @return Total number of IO operations serviced by the controller. */
	public long getTotalIopsServiced() {
		return this.totalIopsServiced;
	}
	/** @param x Total number of IO operations serviced by the controller. */
	public void setTotalIopsServiced(long x) {
		this.totalIopsServiced = x;
	}

	/** Total number of Bytes serviced by the controller. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of Bytes serviced by the controller." , required = true)
	@XmlElement(required = true)
	private long totalBytesServiced;

	/** @return Total number of Bytes serviced by the controller. */
	public long getTotalBytesServiced() {
		return this.totalBytesServiced;
	}
	/** @param x Total number of Bytes serviced by the controller. */
	public void setTotalBytesServiced(long x) {
		this.totalBytesServiced = x;
	}

	/** Total number of IO operations that hit cache. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of IO operations that hit cache." , required = true)
	@XmlElement(required = true)
	private long cacheHitsIopsTotal;

	/** @return Total number of IO operations that hit cache. */
	public long getCacheHitsIopsTotal() {
		return this.cacheHitsIopsTotal;
	}
	/** @param x Total number of IO operations that hit cache. */
	public void setCacheHitsIopsTotal(long x) {
		this.cacheHitsIopsTotal = x;
	}

	/** Total number of bytes that hit cache. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of bytes that hit cache." , required = true)
	@XmlElement(required = true)
	private long cacheHitsBytesTotal;

	/** @return Total number of bytes that hit cache. */
	public long getCacheHitsBytesTotal() {
		return this.cacheHitsBytesTotal;
	}
	/** @param x Total number of bytes that hit cache. */
	public void setCacheHitsBytesTotal(long x) {
		this.cacheHitsBytesTotal = x;
	}

	/** Total number of IOs that are categorized as random. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of IOs that are categorized as random." , required = true)
	@XmlElement(required = true)
	private long randomIosTotal;

	/** @return Total number of IOs that are categorized as random. */
	public long getRandomIosTotal() {
		return this.randomIosTotal;
	}
	/** @param x Total number of IOs that are categorized as random. */
	public void setRandomIosTotal(long x) {
		this.randomIosTotal = x;
	}

	/** Total number of Bytes that are categorized as random. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of Bytes that are categorized as random." , required = true)
	@XmlElement(required = true)
	private long randomBytesTotal;

	/** @return Total number of Bytes that are categorized as random. */
	public long getRandomBytesTotal() {
		return this.randomBytesTotal;
	}
	/** @param x Total number of Bytes that are categorized as random. */
	public void setRandomBytesTotal(long x) {
		this.randomBytesTotal = x;
	}

	/** Total number of Read IO operations. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of Read IO operations." , required = true)
	@XmlElement(required = true)
	private long readIopsTotal;

	/** @return Total number of Read IO operations. */
	public long getReadIopsTotal() {
		return this.readIopsTotal;
	}
	/** @param x Total number of Read IO operations. */
	public void setReadIopsTotal(long x) {
		this.readIopsTotal = x;
	}

	/** Total number of Bytes read. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of Bytes read." , required = true)
	@XmlElement(required = true)
	private long readBytesTotal;

	/** @return Total number of Bytes read. */
	public long getReadBytesTotal() {
		return this.readBytesTotal;
	}
	/** @param x Total number of Bytes read. */
	public void setReadBytesTotal(long x) {
		this.readBytesTotal = x;
	}

	/** Total number of Write IO operations. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of Write IO operations." , required = true)
	@XmlElement(required = true)
	private long writeIopsTotal;

	/** @return Total number of Write IO operations. */
	public long getWriteIopsTotal() {
		return this.writeIopsTotal;
	}
	/** @param x Total number of Write IO operations. */
	public void setWriteIopsTotal(long x) {
		this.writeIopsTotal = x;
	}

	/** Total number of Bytes written. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of Bytes written." , required = true)
	@XmlElement(required = true)
	private long writeBytesTotal;

	/** @return Total number of Bytes written. */
	public long getWriteBytesTotal() {
		return this.writeBytesTotal;
	}
	/** @param x Total number of Bytes written. */
	public void setWriteBytesTotal(long x) {
		this.writeBytesTotal = x;
	}

	/** Total number of IO operations serviced by the controller that are characterized as cache mirroring related. If cache mirroring is disabled, this counter will not have any value. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of IO operations serviced by the controller that are characterized as cache mirroring related. If cache mirroring is disabled, this counter will not have any value." , required = true)
	@XmlElement(required = true)
	private long mirrorIopsTotal;

	/** @return Total number of IO operations serviced by the controller that are characterized as cache mirroring related. If cache mirroring is disabled, this counter will not have any value. */
	public long getMirrorIopsTotal() {
		return this.mirrorIopsTotal;
	}
	/** @param x Total number of IO operations serviced by the controller that are characterized as cache mirroring related. If cache mirroring is disabled, this counter will not have any value. */
	public void setMirrorIopsTotal(long x) {
		this.mirrorIopsTotal = x;
	}

	/** Total number of Bytes serviced by the controller that are characterized as cache mirroring related. If cache mirroring is disabled, this counter will not have any value. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of Bytes serviced by the controller that are characterized as cache mirroring related. If cache mirroring is disabled, this counter will not have any value." , required = true)
	@XmlElement(required = true)
	private long mirrorBytesTotal;

	/** @return Total number of Bytes serviced by the controller that are characterized as cache mirroring related. If cache mirroring is disabled, this counter will not have any value. */
	public long getMirrorBytesTotal() {
		return this.mirrorBytesTotal;
	}
	/** @param x Total number of Bytes serviced by the controller that are characterized as cache mirroring related. If cache mirroring is disabled, this counter will not have any value. */
	public void setMirrorBytesTotal(long x) {
		this.mirrorBytesTotal = x;
	}

	/** Bytes written that are categorized as Full stripe writes. */
	@io.swagger.annotations.ApiModelProperty(value ="Bytes written that are categorized as Full stripe writes." , required = true)
	@XmlElement(required = true)
	private long fullStripeWritesBytes;

	/** @return Bytes written that are categorized as Full stripe writes. */
	public long getFullStripeWritesBytes() {
		return this.fullStripeWritesBytes;
	}
	/** @param x Bytes written that are categorized as Full stripe writes. */
	public void setFullStripeWritesBytes(long x) {
		this.fullStripeWritesBytes = x;
	}

	/** Bytes transferred that are categorized as RAID 0 transfers. */
	@io.swagger.annotations.ApiModelProperty(value ="Bytes transferred that are categorized as RAID 0 transfers." , required = true)
	@XmlElement(required = true)
	private long raid0BytesTransferred;

	/** @return Bytes transferred that are categorized as RAID 0 transfers. */
	public long getRaid0BytesTransferred() {
		return this.raid0BytesTransferred;
	}
	/** @param x Bytes transferred that are categorized as RAID 0 transfers. */
	public void setRaid0BytesTransferred(long x) {
		this.raid0BytesTransferred = x;
	}

	/** Bytes transferred that are categorized as RAID 1 transfers. */
	@io.swagger.annotations.ApiModelProperty(value ="Bytes transferred that are categorized as RAID 1 transfers." , required = true)
	@XmlElement(required = true)
	private long raid1BytesTransferred;

	/** @return Bytes transferred that are categorized as RAID 1 transfers. */
	public long getRaid1BytesTransferred() {
		return this.raid1BytesTransferred;
	}
	/** @param x Bytes transferred that are categorized as RAID 1 transfers. */
	public void setRaid1BytesTransferred(long x) {
		this.raid1BytesTransferred = x;
	}

	/** Bytes transferred that are categorized as RAID 5 transfers. */
	@io.swagger.annotations.ApiModelProperty(value ="Bytes transferred that are categorized as RAID 5 transfers." , required = true)
	@XmlElement(required = true)
	private long raid5BytesTransferred;

	/** @return Bytes transferred that are categorized as RAID 5 transfers. */
	public long getRaid5BytesTransferred() {
		return this.raid5BytesTransferred;
	}
	/** @param x Bytes transferred that are categorized as RAID 5 transfers. */
	public void setRaid5BytesTransferred(long x) {
		this.raid5BytesTransferred = x;
	}

	/** Bytes transferred that are categorized as RAID 6 transfers. */
	@io.swagger.annotations.ApiModelProperty(value ="Bytes transferred that are categorized as RAID 6 transfers." , required = true)
	@XmlElement(required = true)
	private long raid6BytesTransferred;

	/** @return Bytes transferred that are categorized as RAID 6 transfers. */
	public long getRaid6BytesTransferred() {
		return this.raid6BytesTransferred;
	}
	/** @param x Bytes transferred that are categorized as RAID 6 transfers. */
	public void setRaid6BytesTransferred(long x) {
		this.raid6BytesTransferred = x;
	}

	/** Bytes transferred that are categorized as DDP transfers. */
	@io.swagger.annotations.ApiModelProperty(value ="Bytes transferred that are categorized as DDP transfers." , required = true)
	@XmlElement(required = true)
	private long ddpBytesTransferred;

	/** @return Bytes transferred that are categorized as DDP transfers. */
	public long getDdpBytesTransferred() {
		return this.ddpBytesTransferred;
	}
	/** @param x Bytes transferred that are categorized as DDP transfers. */
	public void setDdpBytesTransferred(long x) {
		this.ddpBytesTransferred = x;
	}

	/** Theoretical maximum possible Bytes per second under current load. */
	@io.swagger.annotations.ApiModelProperty(value ="Theoretical maximum possible Bytes per second under current load." , required = true)
	@XmlElement(required = true)
	private long maxPossibleBpsUnderCurrentLoad;

	/** @return Theoretical maximum possible Bytes per second under current load. */
	public long getMaxPossibleBpsUnderCurrentLoad() {
		return this.maxPossibleBpsUnderCurrentLoad;
	}
	/** @param x Theoretical maximum possible Bytes per second under current load. */
	public void setMaxPossibleBpsUnderCurrentLoad(long x) {
		this.maxPossibleBpsUnderCurrentLoad = x;
	}

	/** Theoretical maximum possible IO per second under current load. */
	@io.swagger.annotations.ApiModelProperty(value ="Theoretical maximum possible IO per second under current load." , required = true)
	@XmlElement(required = true)
	private long maxPossibleIopsUnderCurrentLoad;

	/** @return Theoretical maximum possible IO per second under current load. */
	public long getMaxPossibleIopsUnderCurrentLoad() {
		return this.maxPossibleIopsUnderCurrentLoad;
	}
	/** @param x Theoretical maximum possible IO per second under current load. */
	public void setMaxPossibleIopsUnderCurrentLoad(long x) {
		this.maxPossibleIopsUnderCurrentLoad = x;
	}
}
