package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration defines the different failure types that can be returned from a logical or block level consistency check on the Database Manager (DBM) file system. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(64)
public enum DbmValidationStatus implements Serializable {
		/** Validation finished without any detected problems. */
		ok(0),
		/** Memory allocation failed. */
		noHeap(1),
		/** I/O error occurred to all native drives. */
		ioError(2),
		/** Dependent singleton instance not available (most likely too early in Start of Day). */
		earlyExecution(3),
		/** Fatal error, file system detected to be invalid. */
		fatalFsInvalid(4),
		/** Fatal error, block number in root directory found to be unrealistic. */
		fatalRootOutOfBounds(5),
		/** Fatal error, block number found to be referenced multiple times. */
		fatalDupBlockPointers(6),
		/** Fatal error, block number in file system directory found to be unrealistic. */
		fatalDirOutOfBounds(7),
		/** Fatal error, metadata structure with invalid field. */
		fatalCorruptMetadata(8),
		/** Fatal error, expected metadata structure missing. */
		fatalMissingMetadata(9),
		/** Fatal error, record number found to be unrealistic. */
		fatalRecOutOfBounds(10),
		/** Fatal error, record number found to be referenced multiple times. */
		fatalDupRecPointers(11),
		/** Fatal error, record number refers to no allocated block. */
		fatalRecordUnallocated(12),
		/** Fatal error, allocated file system block not referenced by database. */
		fatalOrphanBlock(13),
		/** Fatal error, file system offline (no corruptions found but the file system is offline). */
		fatalFsOffline(14),
		/** Stable storage capacity is zero (no drives), could be discovered at the beginning or during a block read (special I/O error). */
		noDrives(15),
		/** A lock (mutex resource) could not be obtained. */
		lockError(16),
		/** The primary and backup databases do not match. */
		fatalMirrorMismatch(17),
		/** The backup database is not supported on this platform, the backup database is not instantiated, the backup database is not yet synchronized with the primary database, or the backup database is locked (in database recovery mode). */
		mirrorNotReady(18),
		__UNDEFINED(464378545);

		public final int value;

		private DbmValidationStatus(int v) {
			this.value = v;
		}
}
