package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure provides information about a drawer that is part of a high density drive enclosure. One such object is reported for each drawer in the information returned by the getObjectGraph operation. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(908)
public class Drawer implements Serializable,devmgr.api.model.Identifiable {
	public Drawer() {
	}

	/** The component reference associated with the drawer. */
	@io.swagger.annotations.ApiModelProperty(value ="The component reference associated with the drawer." , required = true)
	@XmlElement(required = true)
	private String drawerRef;

	/** @return The component reference associated with the drawer. */
	public String getDrawerRef() {
		return this.drawerRef;
	}
	/** @param x The component reference associated with the drawer. */
	public void setDrawerRef(String x) {
		this.drawerRef = x;
	}

	/** This value is set to true when the drawer is open; otherwise it is set to false. */
	@io.swagger.annotations.ApiModelProperty(value ="This value is set to true when the drawer is open; otherwise it is set to false." , required = true)
	@XmlElement(required = true)
	private boolean isOpen;

	/** @return This value is set to true when the drawer is open; otherwise it is set to false. */
	public boolean isIsOpen() {
		return this.isOpen;
	}
	/** @param x This value is set to true when the drawer is open; otherwise it is set to false. */
	public void setIsOpen(boolean x) {
		this.isOpen = x;
	}

	/** This field contains the drawer status. */
	@io.swagger.annotations.ApiModelProperty(value ="This field contains the drawer status." , required = true)
	@XmlElement(required = true)
	private DrawerStatus status = DrawerStatus.__UNDEFINED;

	/** @return This field contains the drawer status. */
	public DrawerStatus getStatus() {
		return this.status;
	}
	/** @param x This field contains the drawer status. */
	public void setStatus(DrawerStatus x) {
		this.status = x;
	}

	/** This field contains the drawer location. This will be a tray reference to the tray containing the drawer. */
	@io.swagger.annotations.ApiModelProperty(value ="This field contains the drawer location. This will be a tray reference to the tray containing the drawer." , required = true)
	@XmlElement(required = true)
	private Location physicalLocation;

	/** @return This field contains the drawer location. This will be a tray reference to the tray containing the drawer. */
	public Location getPhysicalLocation() {
		return this.physicalLocation;
	}
	/** @param x This field contains the drawer location. This will be a tray reference to the tray containing the drawer. */
	public void setPhysicalLocation(Location x) {
		this.physicalLocation = x;
	}

	/** This field contains the repair policy for the drawer component. */
	@io.swagger.annotations.ApiModelProperty(value ="This field contains the repair policy for the drawer component." , required = true)
	@XmlElement(required = true)
	private RepairPolicy repairPolicy;

	/** @return This field contains the repair policy for the drawer component. */
	public RepairPolicy getRepairPolicy() {
		return this.repairPolicy;
	}
	/** @param x This field contains the repair policy for the drawer component. */
	public void setRepairPolicy(RepairPolicy x) {
		this.repairPolicy = x;
	}

	/** This data is a variable length ASCII text string. It contains the firmware version for the DCM (Drawer Control and Monitor) chip on the drawer component. */
	@io.swagger.annotations.ApiModelProperty(value ="This data is a variable length ASCII text string. It contains the firmware version for the DCM (Drawer Control and Monitor) chip on the drawer component." , required = true)
	@XmlElement(required = true)
	private String softwareVersion;

	/** @return This data is a variable length ASCII text string. It contains the firmware version for the DCM (Drawer Control and Monitor) chip on the drawer component. */
	public String getSoftwareVersion() {
		return this.softwareVersion;
	}
	/** @param x This data is a variable length ASCII text string. It contains the firmware version for the DCM (Drawer Control and Monitor) chip on the drawer component. */
	public void setSoftwareVersion(String x) {
		this.softwareVersion = x;
	}

	/** This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) chip part number on the drawer component. This part number is from VPD data. */
	@io.swagger.annotations.ApiModelProperty(value ="This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) chip part number on the drawer component. This part number is from VPD data." , required = true)
	@XmlElement(required = true)
	private String partNumber;

	/** @return This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) chip part number on the drawer component. This part number is from VPD data. */
	public String getPartNumber() {
		return this.partNumber;
	}
	/** @param x This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) chip part number on the drawer component. This part number is from VPD data. */
	public void setPartNumber(String x) {
		this.partNumber = x;
	}

	/** This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) chip serial number on the drawer component. This serial number is from VPD data. */
	@io.swagger.annotations.ApiModelProperty(value ="This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) chip serial number on the drawer component. This serial number is from VPD data." , required = true)
	@XmlElement(required = true)
	private String serialNumber;

	/** @return This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) chip serial number on the drawer component. This serial number is from VPD data. */
	public String getSerialNumber() {
		return this.serialNumber;
	}
	/** @param x This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) chip serial number on the drawer component. This serial number is from VPD data. */
	public void setSerialNumber(String x) {
		this.serialNumber = x;
	}

	/** This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) chip manufacturer name, obtained from VPD data. */
	@io.swagger.annotations.ApiModelProperty(value ="This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) chip manufacturer name, obtained from VPD data." , required = true)
	@XmlElement(required = true)
	private String vendorName;

	/** @return This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) chip manufacturer name, obtained from VPD data. */
	public String getVendorName() {
		return this.vendorName;
	}
	/** @param x This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) chip manufacturer name, obtained from VPD data. */
	public void setVendorName(String x) {
		this.vendorName = x;
	}

	/** This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) manufacture date, obtained from VPD data. */
	@io.swagger.annotations.ApiModelProperty(value ="This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) manufacture date, obtained from VPD data." , required = true)
	@XmlElement(required = true)
	private long manufactureDate;

	/** @return This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) manufacture date, obtained from VPD data. */
	public long getManufactureDate() {
		return this.manufactureDate;
	}
	/** @param x This data is a variable length ASCII text string. It contains the DCM (Drawer Control and Monitor) manufacture date, obtained from VPD data. */
	public void setManufactureDate(long x) {
		this.manufactureDate = x;
	}

	/** This data is a variable length ASCII text string. It contains the Field Replaceable Unit (FRU) type, obtained from VPD data. */
	@io.swagger.annotations.ApiModelProperty(value ="This data is a variable length ASCII text string. It contains the Field Replaceable Unit (FRU) type, obtained from VPD data." , required = true)
	@XmlElement(required = true)
	private String fruType;

	/** @return This data is a variable length ASCII text string. It contains the Field Replaceable Unit (FRU) type, obtained from VPD data. */
	public String getFruType() {
		return this.fruType;
	}
	/** @param x This data is a variable length ASCII text string. It contains the Field Replaceable Unit (FRU) type, obtained from VPD data. */
	public void setFruType(String x) {
		this.fruType = x;
	}

	/** This data is a variable length ASCII text string describing the type of drawer. */
	@io.swagger.annotations.ApiModelProperty(value ="This data is a variable length ASCII text string describing the type of drawer." , required = true)
	@XmlElement(required = true)
	private String drawerType;

	/** @return This data is a variable length ASCII text string describing the type of drawer. */
	public String getDrawerType() {
		return this.drawerType;
	}
	/** @param x This data is a variable length ASCII text string describing the type of drawer. */
	public void setDrawerType(String x) {
		this.drawerType = x;
	}
	@Override
	public String getId(){
		return drawerRef;
	}
}
