package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration is used to identify the reason for the current status of the drive. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(183)
public enum DriveStatusCause implements Serializable {
		/** There is no relevant cause value to report. This value will be reported, for example, if the drive's status is optimal. */
		none(1),
		/** The drive is in its current state because of a user-initiated action. */
		userOp(2),
		/** The drive is in its current state because a write operation failed. */
		writeOp(3),
		/** The drive is in its current state because it is not a properly certified drive for use in the storage array. */
		uncertified(4),
		/** The drive is in its current state because it was bypassed due to a mismatch between the drive's speed and the ESM's speed. */
		speedMismatch(5),
		/** The drive is in its current state because it was bypassed and the cause is unknown. */
		bypassUnknown(6),
		/** A failed drive has been replaced by the wrong type of drive. */
		wrongDriveType(7),
		/** The DACStore on the drive is unrecognizable because it was written by up-rev firmware. */
		incompatibleUprevDacstore(8),
		/** The DACStore on the drive is unrecognizable because it was written by down-rev firmware. */
		incompatibleDownrevDacstore(9),
		/** The drive is considered incompatible because the firmware encountered an internal error while trying to use it. */
		incompatibleInternalError(10),
		/** The drive is considered incompatible because its formatted sector size differs from the other drives in the array. */
		incompatibleSectorSizeMismatch(11),
		/** Either (1) A foreign, unassigned drive is present, but a partial volume group in the storage array refers to the drive as assigned to that volume group, or (2) a partial volume group in the storage array refers to the foreign drive as missing from that volume group and the foreign drive is referring to itself as assigned to a different volume group. */
		incompatibleNativeVgRefersToForeignDrive(12),
		/** Incompatible native drive */
		incompatibleForeignVgRefersToNativeDrive(13),
		/** A partial volume group in the storage array refers to a foreign drive as missing from that volume group and the foreign drive is referring to itself as assigned to that volume group. The problem is that the drive is foreign so it cannot be treated as missing from the volume group (in which case it would be native). */
		incompatibleNativeVgForeignDriveMutualRef(14),
		/** The drives of a missing volume group in the storage array are inserted but their configuration is now changed, i.e., the volume group was (1) removed without exporting it first, (2) imported into another array, (3) subjected to a configuration change, and (4) moved back to the original array. Each drive will have this drive status cause. */
		incompatibleVgCloned(15),
		/** A foreign drive refers to itself as assigned to a complete volume group in the storage array (but obviously the complete volume group is not referring to the foreign drive). */
		incompatibleForeignDriveInconsistent(16),
		/** A partial volume group in the storage array is referring to a drive in another, exported, volume group as missing, i.e., both the volume group in the storage array and the volume group in the exported state are referring to the same drive as being assigned to them. All the drives of the exported volume group have this drive status cause including the drive causing the conflict. */
		incompatibleVgHasDrivePartOfMultipleVgs(17),
		/** An unassigned foreign drive reports its state as unassigned, but a contingent volume group in the storage array refers to the drive as a member of that volume group */
		incompatibleForeignDriveHasInconsistentRole(18),
		/** A drive is assigned to two different volume groups, one that is contingent and another which was just inserted. The drives of the second volume group are also in an incompatible state, but with the cause of DRIVE_CAUSE_INCOMPATIBLE_VG_HAS_DRIVE_PART_OF_MULTIPLE_VGS. The second volume group is not created. */
		incompatibleVgDrivePartOfMultipleVgs(19),
		/** A drive is part of a legacy volume group that contains a failed drive and/or an in-use hot-spare. */
		incompatibleFailedLegacyDrive(20),
		/** The SNIA Disk Data Format (DDF) anchor header on the drive has a T10 vendor other than LSI-Engenio. */
		incompatibleDdfOtherVendor(21),
		/** The drive was found to be incompatible during a database adoption process, causing the adoption to fail.. */
		incompatibleDbAdoptionFailure(22),
		/** The Full-Disk-Encryption drive could not be security unlocked. */
		locked(23),
		/** The inserted drive does not have sufficient capacity for the user data of the failed drive. */
		insufficientDriveCapacity(24),
		/** The drive failed because of a super-capacitor failure. */
		supercapacitorFailure(25),
		/** The drive has an unsupported protocol connection. */
		unsupportedProtocolConnection(27),
		/** The drive capacity is not supported. */
		unsupportedCapacity(28),
		/** An invalid lock key was presented to unlock the FDE drive. */
		invalidLockKeyPresented(29),
		/** The drive has in incompatible Protection Information type . */
		incompatiblePiType(30),
		/** Drives are locked out due to a failed database validation during SOD, after a change in the HIC configuration has been detected. */
		incompatibleDatabaseValidationFailure(31),
		/** A drive interposer has an unsupported firmware version. */
		incompatibleUnsupportedInterposerFwVersion(32),
		/** The SATA drive is not supported because it does not support SMART Command Transfer (SCT) commands. */
		incompatibleSataDriveSctUnsupported(33),
		/** The drive is not supported based on the model number. */
		incompatibleModelNumberUnsupported(34),
		/** The lowest aligned LBA for the physical sector of an emulation was found to be non-zero and is therefore not supported. */
		incompatibleAlignmentForEmulationDrive(35),
		/** The drive is a source of a data relocation operation. */
		srcRelocation(36),
		/** The drive is a destination of a data relocation operation. */
		dstRelocation(37),
		/** The drive is incompatible because the configuration metadata on the drive is either corrupt or otherwise unusable by the controller. The drive will need to be initialized before it can be integrated into the array. */
		incompatibleDriveMetadataUnusable(38),
		/** The drive failed due to PFA condition. */
		pfa(39),
		/** The drive failed due to SPFA condition. */
		spfa(40),
		__UNDEFINED(464378545);

		public final int value;

		private DriveStatusCause(int v) {
			this.value = v;
		}
}
