package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** An enumeration that includes the possible Chassis ID TLV sub-types as specified in IEEE specification 802.1ab. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(60)
public enum EnhEthChassisIDSubtype implements Serializable {
		/** The Chassis ID TLV sub-type is unknown. */
		unk(0),
		/** (IETF RFC 2737). */
		component(1),
		/** The Chassis ID TLV sub-type is the Interface Alias - If Alias (IETF RFC 2863). */
		intfAlias(2),
		/** The Chassis ID TLV sub-type is the Port Component - EntPhysicalAlias when entPhysicalClass has a value 'port(10)' or 'backplane(4)' (IETF RFC 2737). */
		portComp(3),
		/** The Chassis ID TLV sub-type is the MAC Address - IEEE Std 802-2001. */
		macAddr(4),
		/** The Chassis ID TLV sub-type is the Network Address - an octet string that identifies a particular network address family and an associated network address that are encoded in network octet order. An IP address, for example, would be encoded with the first octet containing the IANA Address Family Numbers enumeration value for the specific address type and octets 2 through n containing the address value (for example, the encoding for C0-A8-FE-0A would indicate the IP version 4 address 192.168.254.10).. */
		ntwkAddr(5),
		/** The Chassis ID TLV sub-type is the Interface Name - if Name (IETF RFC 2863). */
		intfName(6),
		/** The Chassis ID TLV sub-type is Locally Assigned - an alpha-numeric string and is locally assigned. */
		local(7),
		__UNDEFINED(464378545);

		public final int value;

		private EnhEthChassisIDSubtype(int v) {
			this.value = v;
		}
}
