package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used to convey information about a controller's Ethernet network interface. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(1030)
public class EthernetInterface implements Serializable {
	public EthernetInterface() {
	}

	/** Name of the Ethernet port, as reported by the controller. */
	@io.swagger.annotations.ApiModelProperty(value ="Name of the Ethernet port, as reported by the controller." , required = true)
	@XmlElement(required = true)
	private String interfaceName;

	/** @return Name of the Ethernet port, as reported by the controller. */
	public String getInterfaceName() {
		return this.interfaceName;
	}
	/** @param x Name of the Ethernet port, as reported by the controller. */
	public void setInterfaceName(String x) {
		this.interfaceName = x;
	}

	/** The channel number of this Ethernet interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The channel number of this Ethernet interface." , required = true)
	@XmlElement(required = true)
	private int channel;

	/** @return The channel number of this Ethernet interface. */
	public int getChannel() {
		return this.channel;
	}
	/** @param x The channel number of this Ethernet interface. */
	public void setChannel(int x) {
		this.channel = x;
	}

	/** The speed of the interface, as currently configured, in Mbit/sec. */
	@io.swagger.annotations.ApiModelProperty(value ="The speed of the interface, as currently configured, in Mbit/sec." , required = true)
	@XmlElement(required = true)
	private int speed;

	/** @return The speed of the interface, as currently configured, in Mbit/sec. */
	public int getSpeed() {
		return this.speed;
	}
	/** @param x The speed of the interface, as currently configured, in Mbit/sec. */
	public void setSpeed(int x) {
		this.speed = x;
	}

	/** The 32-bit IP protocol address assigned to the interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The 32-bit IP protocol address assigned to the interface." , required = true)
	@XmlElement(required = true)
	private int ip;

	/** @return The 32-bit IP protocol address assigned to the interface. */
	public int getIp() {
		return this.ip;
	}
	/** @param x The 32-bit IP protocol address assigned to the interface. */
	public void setIp(int x) {
		this.ip = x;
	}

	/** An ASCII string that identifies the alias name for the interface; this name is presumed to be associated with the IP protocol address. */
	@io.swagger.annotations.ApiModelProperty(value ="An ASCII string that identifies the alias name for the interface; this name is presumed to be associated with the IP protocol address." , required = true)
	@XmlElement(required = true)
	private String alias;

	/** @return An ASCII string that identifies the alias name for the interface; this name is presumed to be associated with the IP protocol address. */
	public String getAlias() {
		return this.alias;
	}
	/** @param x An ASCII string that identifies the alias name for the interface; this name is presumed to be associated with the IP protocol address. */
	public void setAlias(String x) {
		this.alias = x;
	}

	/** An ASCII string representation of the globally-unique 48-bit MAC address assigned to the Ethernet interface. */
	@io.swagger.annotations.ApiModelProperty(value ="An ASCII string representation of the globally-unique 48-bit MAC address assigned to the Ethernet interface." , required = true)
	@XmlElement(required = true)
	private String macAddr;

	/** @return An ASCII string representation of the globally-unique 48-bit MAC address assigned to the Ethernet interface. */
	public String getMacAddr() {
		return this.macAddr;
	}
	/** @param x An ASCII string representation of the globally-unique 48-bit MAC address assigned to the Ethernet interface. */
	public void setMacAddr(String x) {
		this.macAddr = x;
	}

	/** IP address of the gateway. */
	@io.swagger.annotations.ApiModelProperty(value ="IP address of the gateway." , required = true)
	@XmlElement(required = true)
	private int gatewayIp;

	/** @return IP address of the gateway. */
	public int getGatewayIp() {
		return this.gatewayIp;
	}
	/** @param x IP address of the gateway. */
	public void setGatewayIp(int x) {
		this.gatewayIp = x;
	}

	/** Network subnet mask. */
	@io.swagger.annotations.ApiModelProperty(value ="Network subnet mask." , required = true)
	@XmlElement(required = true)
	private int subnetMask;

	/** @return Network subnet mask. */
	public int getSubnetMask() {
		return this.subnetMask;
	}
	/** @param x Network subnet mask. */
	public void setSubnetMask(int x) {
		this.subnetMask = x;
	}

	/** Bootpserver used to get network parameters. */
	@io.swagger.annotations.ApiModelProperty(value ="Bootpserver used to get network parameters." , required = true)
	@XmlElement(required = true)
	private boolean bootpUsed;

	/** @return Bootpserver used to get network parameters. */
	public boolean isBootpUsed() {
		return this.bootpUsed;
	}
	/** @param x Bootpserver used to get network parameters. */
	public void setBootpUsed(boolean x) {
		this.bootpUsed = x;
	}

	/** True if rlogin sessions are allowed. */
	@io.swagger.annotations.ApiModelProperty(value ="True if rlogin sessions are allowed." , required = true)
	@XmlElement(required = true)
	private boolean rloginEnabled;

	/** @return True if rlogin sessions are allowed. */
	public boolean isRloginEnabled() {
		return this.rloginEnabled;
	}
	/** @param x True if rlogin sessions are allowed. */
	public void setRloginEnabled(boolean x) {
		this.rloginEnabled = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private String reserved1;

	/** @return Reserved for future use. */
	public String getReserved1() {
		return this.reserved1;
	}
	/** @param x Reserved for future use. */
	public void setReserved1(String x) {
		this.reserved1 = x;
	}

	/** Set to true if there is a configuration error. */
	@io.swagger.annotations.ApiModelProperty(value ="Set to true if there is a configuration error." , required = true)
	@XmlElement(required = true)
	private boolean setupError;

	/** @return Set to true if there is a configuration error. */
	public boolean isSetupError() {
		return this.setupError;
	}
	/** @param x Set to true if there is a configuration error. */
	public void setSetupError(boolean x) {
		this.setupError = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private String reserved2;

	/** @return Reserved for future use. */
	public String getReserved2() {
		return this.reserved2;
	}
	/** @param x Reserved for future use. */
	public void setReserved2(String x) {
		this.reserved2 = x;
	}

	/** The unique identifier for a given instance of this structure. */
	@io.swagger.annotations.ApiModelProperty(value ="The unique identifier for a given instance of this structure." , required = true)
	@XmlElement(required = true)
	private String interfaceRef;

	/** @return The unique identifier for a given instance of this structure. */
	public String getInterfaceRef() {
		return this.interfaceRef;
	}
	/** @param x The unique identifier for a given instance of this structure. */
	public void setInterfaceRef(String x) {
		this.interfaceRef = x;
	}

	/** The status of the network link for this interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The status of the network link for this interface." , required = true)
	@XmlElement(required = true)
	private LinkStatus linkStatus = LinkStatus.__UNDEFINED;

	/** @return The status of the network link for this interface. */
	public LinkStatus getLinkStatus() {
		return this.linkStatus;
	}
	/** @param x The status of the network link for this interface. */
	public void setLinkStatus(LinkStatus x) {
		this.linkStatus = x;
	}

	/** True if IPV4 is enabled for this interface; otherwise false. */
	@io.swagger.annotations.ApiModelProperty(value ="True if IPV4 is enabled for this interface; otherwise false." , required = true)
	@XmlElement(required = true)
	private boolean ipv4Enabled;

	/** @return True if IPV4 is enabled for this interface; otherwise false. */
	public boolean isIpv4Enabled() {
		return this.ipv4Enabled;
	}
	/** @param x True if IPV4 is enabled for this interface; otherwise false. */
	public void setIpv4Enabled(boolean x) {
		this.ipv4Enabled = x;
	}

	/** The IPV4 address for the interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The IPV4 address for the interface." , required = true)
	@XmlElement(required = true)
	private String ipv4Address;

	/** @return The IPV4 address for the interface. */
	public String getIpv4Address() {
		return this.ipv4Address;
	}
	/** @param x The IPV4 address for the interface. */
	public void setIpv4Address(String x) {
		this.ipv4Address = x;
	}

	/** The IPV4 subnet mask for the interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The IPV4 subnet mask for the interface." , required = true)
	@XmlElement(required = true)
	private String ipv4SubnetMask;

	/** @return The IPV4 subnet mask for the interface. */
	public String getIpv4SubnetMask() {
		return this.ipv4SubnetMask;
	}
	/** @param x The IPV4 subnet mask for the interface. */
	public void setIpv4SubnetMask(String x) {
		this.ipv4SubnetMask = x;
	}

	/** The method by which the IPV4 address information is configured. */
	@io.swagger.annotations.ApiModelProperty(value ="The method by which the IPV4 address information is configured." , required = true)
	@XmlElement(required = true)
	private IpV4ConfigMethod ipv4AddressConfigMethod = IpV4ConfigMethod.__UNDEFINED;

	/** @return The method by which the IPV4 address information is configured. */
	public IpV4ConfigMethod getIpv4AddressConfigMethod() {
		return this.ipv4AddressConfigMethod;
	}
	/** @param x The method by which the IPV4 address information is configured. */
	public void setIpv4AddressConfigMethod(IpV4ConfigMethod x) {
		this.ipv4AddressConfigMethod = x;
	}

	/** True if IPV6 is enabled for this interface; otherwise false. */
	@io.swagger.annotations.ApiModelProperty(value ="True if IPV6 is enabled for this interface; otherwise false." , required = true)
	@XmlElement(required = true)
	private boolean ipv6Enabled;

	/** @return True if IPV6 is enabled for this interface; otherwise false. */
	public boolean isIpv6Enabled() {
		return this.ipv6Enabled;
	}
	/** @param x True if IPV6 is enabled for this interface; otherwise false. */
	public void setIpv6Enabled(boolean x) {
		this.ipv6Enabled = x;
	}

	/** The IPV6 local address for the interface and associated data. */
	@io.swagger.annotations.ApiModelProperty(value ="The IPV6 local address for the interface and associated data." , required = true)
	@XmlElement(required = true)
	private IpV6AddressData ipv6LocalAddress;

	/** @return The IPV6 local address for the interface and associated data. */
	public IpV6AddressData getIpv6LocalAddress() {
		return this.ipv6LocalAddress;
	}
	/** @param x The IPV6 local address for the interface and associated data. */
	public void setIpv6LocalAddress(IpV6AddressData x) {
		this.ipv6LocalAddress = x;
	}

	/** The IPV6 static routable address for the interface and associated data. */
	@io.swagger.annotations.ApiModelProperty(value ="The IPV6 static routable address for the interface and associated data." , required = true)
	@XmlElement(required = true)
	private IpV6AddressData ipv6PortStaticRoutableAddress;

	/** @return The IPV6 static routable address for the interface and associated data. */
	public IpV6AddressData getIpv6PortStaticRoutableAddress() {
		return this.ipv6PortStaticRoutableAddress;
	}
	/** @param x The IPV6 static routable address for the interface and associated data. */
	public void setIpv6PortStaticRoutableAddress(IpV6AddressData x) {
		this.ipv6PortStaticRoutableAddress = x;
	}

	/** The set of IPV6 port routable addresses for the interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The set of IPV6 port routable addresses for the interface." , required = true)
	@XmlElement(required = true)
	private IpV6AddressData[] ipv6PortRoutableAddresses;

	/** @return The set of IPV6 port routable addresses for the interface. */
	public IpV6AddressData[] getIpv6PortRoutableAddresses() {
		return this.ipv6PortRoutableAddresses;
	}
	/** @param x The set of IPV6 port routable addresses for the interface. */
	public void setIpv6PortRoutableAddresses(IpV6AddressData[] x) {
		this.ipv6PortRoutableAddresses = x;
	}

	/** The method by which the IPV6 address information is configured for the interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The method by which the IPV6 address information is configured for the interface." , required = true)
	@XmlElement(required = true)
	private IpV6ConfigMethod ipv6AddressConfigMethod = IpV6ConfigMethod.__UNDEFINED;

	/** @return The method by which the IPV6 address information is configured for the interface. */
	public IpV6ConfigMethod getIpv6AddressConfigMethod() {
		return this.ipv6AddressConfigMethod;
	}
	/** @param x The method by which the IPV6 address information is configured for the interface. */
	public void setIpv6AddressConfigMethod(IpV6ConfigMethod x) {
		this.ipv6AddressConfigMethod = x;
	}

	/** If set to true, the interface is operating in full duplex mode; otherwise, it is operating in half-duplex mode. */
	@io.swagger.annotations.ApiModelProperty(value ="If set to true, the interface is operating in full duplex mode; otherwise, it is operating in half-duplex mode." , required = true)
	@XmlElement(required = true)
	private boolean fullDuplex;

	/** @return If set to true, the interface is operating in full duplex mode; otherwise, it is operating in half-duplex mode. */
	public boolean isFullDuplex() {
		return this.fullDuplex;
	}
	/** @param x If set to true, the interface is operating in full duplex mode; otherwise, it is operating in half-duplex mode. */
	public void setFullDuplex(boolean x) {
		this.fullDuplex = x;
	}

	/** Support speed setting for interface */
	@io.swagger.annotations.ApiModelProperty(value ="Support speed setting for interface" , required = true)
	@XmlElement(required = true)
	private EthernetSpeedSetting[] supportedSpeedSettings;

	/** @return Support speed setting for interface */
	public EthernetSpeedSetting[] getSupportedSpeedSettings() {
		return this.supportedSpeedSettings;
	}
	/** @param x Support speed setting for interface */
	public void setSupportedSpeedSettings(EthernetSpeedSetting[] x) {
		this.supportedSpeedSettings = x;
	}

	/** Configured setting for the interface. */
	@io.swagger.annotations.ApiModelProperty(value ="Configured setting for the interface." , required = true)
	@XmlElement(required = true)
	private EthernetSpeedSetting configuredSpeedSetting = EthernetSpeedSetting.__UNDEFINED;

	/** @return Configured setting for the interface. */
	public EthernetSpeedSetting getConfiguredSpeedSetting() {
		return this.configuredSpeedSetting;
	}
	/** @param x Configured setting for the interface. */
	public void setConfiguredSpeedSetting(EthernetSpeedSetting x) {
		this.configuredSpeedSetting = x;
	}

	/** Current speed of the interface. */
	@io.swagger.annotations.ApiModelProperty(value ="Current speed of the interface." , required = true)
	@XmlElement(required = true)
	private InterfaceSpeed currentSpeed = InterfaceSpeed.__UNDEFINED;

	/** @return Current speed of the interface. */
	public InterfaceSpeed getCurrentSpeed() {
		return this.currentSpeed;
	}
	/** @param x Current speed of the interface. */
	public void setCurrentSpeed(InterfaceSpeed x) {
		this.currentSpeed = x;
	}

	/** The physical location of the Ethernet interface. The parent reference in Location identifies the physical component (e.g., controller or host card) where the interface circuitry is located, and the position field is a firmware-assigned 1-relative number signifying "1st ethernet interface relative to the parent," "2nd ethernet interface relative to the parent," etc. This "interface number" is independent of the interface's channel association. */
	@io.swagger.annotations.ApiModelProperty(value ="The physical location of the Ethernet interface. The parent reference in Location identifies the physical component (e.g., controller or host card) where the interface circuitry is located, and the position field is a firmware-assigned 1-relative number signifying \"1st ethernet interface relative to the parent,\" \"2nd ethernet interface relative to the parent,\" etc. This \"interface number\" is independent of the interface's channel association." , required = true)
	@XmlElement(required = true)
	private Location physicalLocation;

	/** @return The physical location of the Ethernet interface. The parent reference in Location identifies the physical component (e.g., controller or host card) where the interface circuitry is located, and the position field is a firmware-assigned 1-relative number signifying "1st ethernet interface relative to the parent," "2nd ethernet interface relative to the parent," etc. This "interface number" is independent of the interface's channel association. */
	public Location getPhysicalLocation() {
		return this.physicalLocation;
	}
	/** @param x The physical location of the Ethernet interface. The parent reference in Location identifies the physical component (e.g., controller or host card) where the interface circuitry is located, and the position field is a firmware-assigned 1-relative number signifying "1st ethernet interface relative to the parent," "2nd ethernet interface relative to the parent," etc. This "interface number" is independent of the interface's channel association. */
	public void setPhysicalLocation(Location x) {
		this.physicalLocation = x;
	}
}
