package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration object is used to specify the different component types that can be associated with entries in the Major Event Log. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(165)
public enum EventComponentType implements Serializable {
		/** The component type is not known. */
		unknown(0),
		/** The component is a physical drive. */
		drive(1),
		/** The component is a power supply. */
		powerSply(2),
		/** The component is a cooling fan. */
		fan(3),
		/** The component is a Minihub. */
		minihub(4),
		/** The component is a temperature sensor. */
		tempSensor(5),
		/** The component is a channel. */
		channel(6),
		/** The component is an ESM (Environment Services Module) card. */
		esm(7),
		/** The component is a physical controller. */
		controller(8),
		/** The component is a cache-holdup battery. */
		battery(9),
		/** The component is an enclosure (or tray). */
		enclosure(10),
		/** The component is a UPS (Uninterruptible Power Supply). */
		ups(11),
		/** The component is a chip on a controller board. */
		chip(12),
		/** The component is volume. */
		volume(13),
		/** The component is a volume group. */
		volumeGrp(14),
		/** The component is a Fibre Channel port CRU. This value is deprecated. */
		portCru(15),
		/** The component is an interconnect CRU. */
		interconnectCru(16),
		/** The component is a support CRU. */
		supportCru(17),
		/** The component is an alarm. */
		alarm(18),
		/** The component is a channel port. */
		channelPort(19),
		/** The component is an SFP port. */
		sfpPort(20),
		/** The component is a host board (XBB architecture only). */
		hostBoard(21),
		/** The component is a new "type." */
		newFormat(22),
		/** The component is a controller SFP (XBB architecture only). */
		ctlrSfp(23),
		/** The component is a SOC Fibre Channel Switch chip on the controller (XBB architecture only). */
		ctlrSoc(24),
		/** The component is an iSCSI initiator. */
		initiator(25),
		/** The component is an iSCSI target. */
		target(26),
		/** The component is a controller host I/O card. A "host I/O card" is the same thing as a "host board," the difference being that this particular event component type provides explicit location information for the card to which the event applies. */
		isnsServer(27),
		/** The component is a controller host I/O card. A "host I/O card" is the same thing as a "host board," the difference being that this particular event component type provides explicit location information for the card to which the event applies. */
		hostIoCard(28),
		/** The component is a cache backup device. */
		cacheBackupDevice(29),
		/** The component is a cache memory DIMM. */
		cacheMemDimm(30),
		/** The component is a host defined in the storage partitions topology database. */
		host(31),
		/** The component is a host port. */
		hostPort(32),
		/** The component is a drawer. */
		drawer(33),
		/** The component is either a drive or a temperature sensor in a drawer within a Wembley enclosure. */
		relative(34),
		/** The component is a schedule. */
		schedule(35),
		/** The component is an Async Mirror Group. */
		asyncMirrorGroup(36),
		/** The component is a disk pool. */
		diskPool(37),
		/** The component is a PiT. */
		pit(38),
		/** The component is a PiT Consistency Group. */
		pitConsistencyGroup(39),
		/** The component is a Consistency Group PIT. */
		cgpit(40),
		/** The component is a Consistency Group View. */
		cgview(41),
		/** The component is a flash cache. */
		flashCache(42),
		/** The component is an SNMP community. */
		snmpCommunity(43),
		/** The component is an SNMP trap destination. */
		snmpTrapDestination(44),
		/** The component is a Fibre Channel target. */
		fcTarget(45),
		/** Blank event component type to maintain backward compatibility within the enumeration. */
		blankOne(46),
		/** Blank event component type to maintain backward compatibility within the enumeration. */
		blankTwo(47),
		/** Event component type for a fan only CRU. */
		fanOnlyCru(48),
		/** MEL component type for power supply CRU. */
		psuCru(49),
		/** MEL component type for NVMe initiator. */
		nvmeInitiator(50),
		__UNDEFINED(464378545);

		public final int value;

		private EventComponentType(int v) {
			this.value = v;
		}
}
