package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure provides information about a number of internal parameters that describe the features and capabilities supported by the controller firmware and/or hardware. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(305)
public class FeatureParams implements Serializable {
	public FeatureParams() {
	}

	/** The maximum number of hot spare drives that can be assigned. If the value in this field is '0xFFFFFFFF' it means there is no limit to the number of hot spares. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of hot spare drives that can be assigned. If the value in this field is '0xFFFFFFFF' it means there is no limit to the number of hot spares." , required = true)
	@XmlElement(required = true)
	private int maxHotSpares;

	/** @return The maximum number of hot spare drives that can be assigned. If the value in this field is '0xFFFFFFFF' it means there is no limit to the number of hot spares. */
	public int getMaxHotSpares() {
		return this.maxHotSpares;
	}
	/** @param x The maximum number of hot spare drives that can be assigned. If the value in this field is '0xFFFFFFFF' it means there is no limit to the number of hot spares. */
	public void setMaxHotSpares(int x) {
		this.maxHotSpares = x;
	}

	/** A variable-length array in which each element specifies one of the supported cache block sizes that can be set on the controller. Cache block sizes are reported in bytes. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array in which each element specifies one of the supported cache block sizes that can be set on the controller. Cache block sizes are reported in bytes." , required = true)
	@XmlElement(required = true)
	private int[] cacheBlockSizes;

	/** @return A variable-length array in which each element specifies one of the supported cache block sizes that can be set on the controller. Cache block sizes are reported in bytes. */
	public int[] getCacheBlockSizes() {
		return this.cacheBlockSizes;
	}
	/** @param x A variable-length array in which each element specifies one of the supported cache block sizes that can be set on the controller. Cache block sizes are reported in bytes. */
	public void setCacheBlockSizes(int[] x) {
		this.cacheBlockSizes = x;
	}

	/** The maximum number of drives that can be added, in a given operation, to an existing volume group to expand the capacity of the volume group. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of drives that can be added, in a given operation, to an existing volume group to expand the capacity of the volume group." , required = true)
	@XmlElement(required = true)
	private int maxDCEDrives;

	/** @return The maximum number of drives that can be added, in a given operation, to an existing volume group to expand the capacity of the volume group. */
	public int getMaxDCEDrives() {
		return this.maxDCEDrives;
	}
	/** @param x The maximum number of drives that can be added, in a given operation, to an existing volume group to expand the capacity of the volume group. */
	public void setMaxDCEDrives(int x) {
		this.maxDCEDrives = x;
	}

	/** The maximum multiplier value that can be specified when configuring cache the read-ahead parameter for a volume. (Realize, however, that the volume read-ahead parameter is no longer treated as a quantify, but as a simple on (non-zero) / off (zero) indicator. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum multiplier value that can be specified when configuring cache the read-ahead parameter for a volume. (Realize, however, that the volume read-ahead parameter is no longer treated as a quantify, but as a simple on (non-zero) / off (zero) indicator." , required = true)
	@XmlElement(required = true)
	private int maxReadAheadMultiplier;

	/** @return The maximum multiplier value that can be specified when configuring cache the read-ahead parameter for a volume. (Realize, however, that the volume read-ahead parameter is no longer treated as a quantify, but as a simple on (non-zero) / off (zero) indicator. */
	public int getMaxReadAheadMultiplier() {
		return this.maxReadAheadMultiplier;
	}
	/** @param x The maximum multiplier value that can be specified when configuring cache the read-ahead parameter for a volume. (Realize, however, that the volume read-ahead parameter is no longer treated as a quantify, but as a simple on (non-zero) / off (zero) indicator. */
	public void setMaxReadAheadMultiplier(int x) {
		this.maxReadAheadMultiplier = x;
	}

	/** The minimum supported period over which a complete media scan can be set to occur (measured in days). */
	@io.swagger.annotations.ApiModelProperty(value ="The minimum supported period over which a complete media scan can be set to occur (measured in days)." , required = true)
	@XmlElement(required = true)
	private int minMediaScanPeriod;

	/** @return The minimum supported period over which a complete media scan can be set to occur (measured in days). */
	public int getMinMediaScanPeriod() {
		return this.minMediaScanPeriod;
	}
	/** @param x The minimum supported period over which a complete media scan can be set to occur (measured in days). */
	public void setMinMediaScanPeriod(int x) {
		this.minMediaScanPeriod = x;
	}

	/** The maximum supported period over which a complete media scan can be set to occur (measured in days). */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum supported period over which a complete media scan can be set to occur (measured in days)." , required = true)
	@XmlElement(required = true)
	private int maxMediaScanPeriod;

	/** @return The maximum supported period over which a complete media scan can be set to occur (measured in days). */
	public int getMaxMediaScanPeriod() {
		return this.maxMediaScanPeriod;
	}
	/** @param x The maximum supported period over which a complete media scan can be set to occur (measured in days). */
	public void setMaxMediaScanPeriod(int x) {
		this.maxMediaScanPeriod = x;
	}

	/** A variable-length array in which each element specifies one of the supported segment size values, in bytes. This array should be consulted prior to attempting to create a volume modify a volume's segment size via the startVolumeSegmentSizing procedure. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array in which each element specifies one of the supported segment size values, in bytes. This array should be consulted prior to attempting to create a volume modify a volume's segment size via the startVolumeSegmentSizing procedure." , required = true)
	@XmlElement(required = true)
	private int[] supportedSegSizes;

	/** @return A variable-length array in which each element specifies one of the supported segment size values, in bytes. This array should be consulted prior to attempting to create a volume modify a volume's segment size via the startVolumeSegmentSizing procedure. */
	public int[] getSupportedSegSizes() {
		return this.supportedSegSizes;
	}
	/** @param x A variable-length array in which each element specifies one of the supported segment size values, in bytes. This array should be consulted prior to attempting to create a volume modify a volume's segment size via the startVolumeSegmentSizing procedure. */
	public void setSupportedSegSizes(int[] x) {
		this.supportedSegSizes = x;
	}

	/** The number of standard segment size values (at beginning of list). */
	@io.swagger.annotations.ApiModelProperty(value ="The number of standard segment size values (at beginning of list)." , required = true)
	@XmlElement(required = true)
	private int numStandardSegSizes;

	/** @return The number of standard segment size values (at beginning of list). */
	public int getNumStandardSegSizes() {
		return this.numStandardSegSizes;
	}
	/** @param x The number of standard segment size values (at beginning of list). */
	public void setNumStandardSegSizes(int x) {
		this.numStandardSegSizes = x;
	}

	/** A variable-length array in which each element specifies one of the supported segment size transition options. The user of the SYMbol interface should consult this list to determine a valid new segment size for a volume before attempting to use the startVolumeSegmentSizing procedure. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array in which each element specifies one of the supported segment size transition options. The user of the SYMbol interface should consult this list to determine a valid new segment size for a volume before attempting to use the startVolumeSegmentSizing procedure." , required = true)
	@XmlElement(required = true)
	private SegmentSizeTransition[] segTransitions;

	/** @return A variable-length array in which each element specifies one of the supported segment size transition options. The user of the SYMbol interface should consult this list to determine a valid new segment size for a volume before attempting to use the startVolumeSegmentSizing procedure. */
	public SegmentSizeTransition[] getSegTransitions() {
		return this.segTransitions;
	}
	/** @param x A variable-length array in which each element specifies one of the supported segment size transition options. The user of the SYMbol interface should consult this list to determine a valid new segment size for a volume before attempting to use the startVolumeSegmentSizing procedure. */
	public void setSegTransitions(SegmentSizeTransition[] x) {
		this.segTransitions = x;
	}

	/** The maximum number of LUN addresses that are available for volume mapping operations. The range of supported LUN values is thus 0 through mappableLUNCoun-1. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of LUN addresses that are available for volume mapping operations. The range of supported LUN values is thus 0 through mappableLUNCoun-1." , required = true)
	@XmlElement(required = true)
	private int mappableLUNCount;

	/** @return The maximum number of LUN addresses that are available for volume mapping operations. The range of supported LUN values is thus 0 through mappableLUNCoun-1. */
	public int getMappableLUNCount() {
		return this.mappableLUNCount;
	}
	/** @param x The maximum number of LUN addresses that are available for volume mapping operations. The range of supported LUN values is thus 0 through mappableLUNCoun-1. */
	public void setMappableLUNCount(int x) {
		this.mappableLUNCount = x;
	}

	/** The number of partitions supported by the controller. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of partitions supported by the controller." , required = true)
	@XmlElement(required = true)
	private int maxPartitionCount;

	/** @return The number of partitions supported by the controller. */
	public int getMaxPartitionCount() {
		return this.maxPartitionCount;
	}
	/** @param x The number of partitions supported by the controller. */
	public void setMaxPartitionCount(int x) {
		this.maxPartitionCount = x;
	}

	/** The number of mappings allowed per volume. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of mappings allowed per volume." , required = true)
	@XmlElement(required = true)
	private int maxMappingsPerVolume;

	/** @return The number of mappings allowed per volume. */
	public int getMaxMappingsPerVolume() {
		return this.maxMappingsPerVolume;
	}
	/** @param x The number of mappings allowed per volume. */
	public void setMaxMappingsPerVolume(int x) {
		this.maxMappingsPerVolume = x;
	}

	/** The maximum number of standard volumes allowed per array. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of standard volumes allowed per array." , required = true)
	@XmlElement(required = true)
	private int maxVolumes;

	/** @return The maximum number of standard volumes allowed per array. */
	public int getMaxVolumes() {
		return this.maxVolumes;
	}
	/** @param x The maximum number of standard volumes allowed per array. */
	public void setMaxVolumes(int x) {
		this.maxVolumes = x;
	}

	/** The maximum number of snapshot volumes allowed per array. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of snapshot volumes allowed per array." , required = true)
	@XmlElement(required = true)
	private int maxSnapshots;

	/** @return The maximum number of snapshot volumes allowed per array. */
	public int getMaxSnapshots() {
		return this.maxSnapshots;
	}
	/** @param x The maximum number of snapshot volumes allowed per array. */
	public void setMaxSnapshots(int x) {
		this.maxSnapshots = x;
	}

	/** The maximum number of snapshots allowed on any given base volume. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of snapshots allowed on any given base volume." , required = true)
	@XmlElement(required = true)
	private int maxSnapshotsPerBase;

	/** @return The maximum number of snapshots allowed on any given base volume. */
	public int getMaxSnapshotsPerBase() {
		return this.maxSnapshotsPerBase;
	}
	/** @param x The maximum number of snapshots allowed on any given base volume. */
	public void setMaxSnapshotsPerBase(int x) {
		this.maxSnapshotsPerBase = x;
	}

	/** The minimum size of a repository volume in bytes. */
	@io.swagger.annotations.ApiModelProperty(value ="The minimum size of a repository volume in bytes." , required = true)
	@XmlElement(required = true)
	private int minRepositorySize;

	/** @return The minimum size of a repository volume in bytes. */
	public int getMinRepositorySize() {
		return this.minRepositorySize;
	}
	/** @param x The minimum size of a repository volume in bytes. */
	public void setMinRepositorySize(int x) {
		this.minRepositorySize = x;
	}

	/** The maximum number of mirrored volumes allowed per array assuming full size repositories. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of mirrored volumes allowed per array assuming full size repositories." , required = true)
	@XmlElement(required = true)
	private int maxMirrors;

	/** @return The maximum number of mirrored volumes allowed per array assuming full size repositories. */
	public int getMaxMirrors() {
		return this.maxMirrors;
	}
	/** @param x The maximum number of mirrored volumes allowed per array assuming full size repositories. */
	public void setMaxMirrors(int x) {
		this.maxMirrors = x;
	}

	/** The maximum number of volume copies allowed per array. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of volume copies allowed per array." , required = true)
	@XmlElement(required = true)
	private int maxVolCopys;

	/** @return The maximum number of volume copies allowed per array. */
	public int getMaxVolCopys() {
		return this.maxVolCopys;
	}
	/** @param x The maximum number of volume copies allowed per array. */
	public void setMaxVolCopys(int x) {
		this.maxVolCopys = x;
	}

	/** The maximum number of background copies that can be active at any one time. This maximum number applies to the entire array, not just one controller. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of background copies that can be active at any one time. This maximum number applies to the entire array, not just one controller." , required = true)
	@XmlElement(required = true)
	private int maxConcurrentBackgroundCopys;

	/** @return The maximum number of background copies that can be active at any one time. This maximum number applies to the entire array, not just one controller. */
	public int getMaxConcurrentBackgroundCopys() {
		return this.maxConcurrentBackgroundCopys;
	}
	/** @param x The maximum number of background copies that can be active at any one time. This maximum number applies to the entire array, not just one controller. */
	public void setMaxConcurrentBackgroundCopys(int x) {
		this.maxConcurrentBackgroundCopys = x;
	}

	/** The maximum value a UTM LUN can be set to. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum value a UTM LUN can be set to." , required = true)
	@XmlElement(required = true)
	private int maxUtmLunValue;

	/** @return The maximum value a UTM LUN can be set to. */
	public int getMaxUtmLunValue() {
		return this.maxUtmLunValue;
	}
	/** @param x The maximum value a UTM LUN can be set to. */
	public void setMaxUtmLunValue(int x) {
		this.maxUtmLunValue = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private String reserved1;

	/** @return Reserved for future use. */
	public String getReserved1() {
		return this.reserved1;
	}
	/** @param x Reserved for future use. */
	public void setReserved1(String x) {
		this.reserved1 = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private String reserved2;

	/** @return Reserved for future use. */
	public String getReserved2() {
		return this.reserved2;
	}
	/** @param x Reserved for future use. */
	public void setReserved2(String x) {
		this.reserved2 = x;
	}

	/** The NVSRAM setting for optional controller battery. */
	@io.swagger.annotations.ApiModelProperty(value ="The NVSRAM setting for optional controller battery." , required = true)
	@XmlElement(required = true)
	private boolean battery_not_in_configuration;

	/** @return The NVSRAM setting for optional controller battery. */
	public boolean isBattery_not_in_configuration() {
		return this.battery_not_in_configuration;
	}
	/** @param x The NVSRAM setting for optional controller battery. */
	public void setBattery_not_in_configuration(boolean x) {
		this.battery_not_in_configuration = x;
	}

	/** A list of supported drive types. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of supported drive types." , required = true)
	@XmlElement(required = true)
	private PhysicalDriveType[] supportedDriveTypes;

	/** @return A list of supported drive types. */
	public PhysicalDriveType[] getSupportedDriveTypes() {
		return this.supportedDriveTypes;
	}
	/** @param x A list of supported drive types. */
	public void setSupportedDriveTypes(PhysicalDriveType[] x) {
		this.supportedDriveTypes = x;
	}

	/** The maximum number of mirrored volumes allowed per array for existing repositories. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of mirrored volumes allowed per array for existing repositories." , required = true)
	@XmlElement(required = true)
	private int currentMaxMirrors;

	/** @return The maximum number of mirrored volumes allowed per array for existing repositories. */
	public int getCurrentMaxMirrors() {
		return this.currentMaxMirrors;
	}
	/** @param x The maximum number of mirrored volumes allowed per array for existing repositories. */
	public void setCurrentMaxMirrors(int x) {
		this.currentMaxMirrors = x;
	}

	/** The maximum number of volumes allowed per volume group. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of volumes allowed per volume group." , required = true)
	@XmlElement(required = true)
	private int maxVolumesPerGroup;

	/** @return The maximum number of volumes allowed per volume group. */
	public int getMaxVolumesPerGroup() {
		return this.maxVolumesPerGroup;
	}
	/** @param x The maximum number of volumes allowed per volume group. */
	public void setMaxVolumesPerGroup(int x) {
		this.maxVolumesPerGroup = x;
	}

	/** The maximum number of drive download files permitted. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of drive download files permitted." , required = true)
	@XmlElement(required = true)
	private int maxDriveDownloadFiles;

	/** @return The maximum number of drive download files permitted. */
	public int getMaxDriveDownloadFiles() {
		return this.maxDriveDownloadFiles;
	}
	/** @param x The maximum number of drive download files permitted. */
	public void setMaxDriveDownloadFiles(int x) {
		this.maxDriveDownloadFiles = x;
	}

	/** The maximum number of records allowed in the client data storage area. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of records allowed in the client data storage area." , required = true)
	@XmlElement(required = true)
	private int maxMgmtClientRecords;

	/** @return The maximum number of records allowed in the client data storage area. */
	public int getMaxMgmtClientRecords() {
		return this.maxMgmtClientRecords;
	}
	/** @param x The maximum number of records allowed in the client data storage area. */
	public void setMaxMgmtClientRecords(int x) {
		this.maxMgmtClientRecords = x;
	}

	/** The maximum record size of a client data record. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum record size of a client data record." , required = true)
	@XmlElement(required = true)
	private int maxMgmtClientRecordSize;

	/** @return The maximum record size of a client data record. */
	public int getMaxMgmtClientRecordSize() {
		return this.maxMgmtClientRecordSize;
	}
	/** @param x The maximum record size of a client data record. */
	public void setMaxMgmtClientRecordSize(int x) {
		this.maxMgmtClientRecordSize = x;
	}

	/** Indicates whether the system is Simplex or Duplex. */
	@io.swagger.annotations.ApiModelProperty(value ="Indicates whether the system is Simplex or Duplex." , required = true)
	@XmlElement(required = true)
	private ControllerRedundancyMode redundancyMode = ControllerRedundancyMode.__UNDEFINED;

	/** @return Indicates whether the system is Simplex or Duplex. */
	public ControllerRedundancyMode getRedundancyMode() {
		return this.redundancyMode;
	}
	/** @param x Indicates whether the system is Simplex or Duplex. */
	public void setRedundancyMode(ControllerRedundancyMode x) {
		this.redundancyMode = x;
	}

	/** The maximum number of expansion drive trays allowed for this storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of expansion drive trays allowed for this storage array." , required = true)
	@XmlElement(required = true)
	private int maxExpansionDriveTrays;

	/** @return The maximum number of expansion drive trays allowed for this storage array. */
	public int getMaxExpansionDriveTrays() {
		return this.maxExpansionDriveTrays;
	}
	/** @param x The maximum number of expansion drive trays allowed for this storage array. */
	public void setMaxExpansionDriveTrays(int x) {
		this.maxExpansionDriveTrays = x;
	}

	/** The iSCSI authentication methods supported by the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="The iSCSI authentication methods supported by the storage array." , required = true)
	@XmlElement(required = true)
	private AuthenticationMethod[] supportedAuthMethods;

	/** @return The iSCSI authentication methods supported by the storage array. */
	public AuthenticationMethod[] getSupportedAuthMethods() {
		return this.supportedAuthMethods;
	}
	/** @param x The iSCSI authentication methods supported by the storage array. */
	public void setSupportedAuthMethods(AuthenticationMethod[] x) {
		this.supportedAuthMethods = x;
	}

	/** Max number of iSCSI IPV6 local addresses */
	@io.swagger.annotations.ApiModelProperty(value ="Max number of iSCSI IPV6 local addresses" , required = true)
	@XmlElement(required = true)
	private int maxIscsiIpv6LocalAddressesPerPort;

	/** @return Max number of iSCSI IPV6 local addresses */
	public int getMaxIscsiIpv6LocalAddressesPerPort() {
		return this.maxIscsiIpv6LocalAddressesPerPort;
	}
	/** @param x Max number of iSCSI IPV6 local addresses */
	public void setMaxIscsiIpv6LocalAddressesPerPort(int x) {
		this.maxIscsiIpv6LocalAddressesPerPort = x;
	}

	/** Max number of iSCSI IPV6 routable addresses */
	@io.swagger.annotations.ApiModelProperty(value ="Max number of iSCSI IPV6 routable addresses" , required = true)
	@XmlElement(required = true)
	private int maxIscsiIpv6RoutableAddressesPerPort;

	/** @return Max number of iSCSI IPV6 routable addresses */
	public int getMaxIscsiIpv6RoutableAddressesPerPort() {
		return this.maxIscsiIpv6RoutableAddressesPerPort;
	}
	/** @param x Max number of iSCSI IPV6 routable addresses */
	public void setMaxIscsiIpv6RoutableAddressesPerPort(int x) {
		this.maxIscsiIpv6RoutableAddressesPerPort = x;
	}

	/** The global upper bound, expressed in bytes, on the new segment size that may be requested on the startVolumeSegmentSizing procedure. */
	@io.swagger.annotations.ApiModelProperty(value ="The global upper bound, expressed in bytes, on the new segment size that may be requested on the startVolumeSegmentSizing procedure." , required = true)
	@XmlElement(required = true)
	private int absoluteMaxDssSegmentSize;

	/** @return The global upper bound, expressed in bytes, on the new segment size that may be requested on the startVolumeSegmentSizing procedure. */
	public int getAbsoluteMaxDssSegmentSize() {
		return this.absoluteMaxDssSegmentSize;
	}
	/** @param x The global upper bound, expressed in bytes, on the new segment size that may be requested on the startVolumeSegmentSizing procedure. */
	public void setAbsoluteMaxDssSegmentSize(int x) {
		this.absoluteMaxDssSegmentSize = x;
	}

	/** This field is set to true if the storage array uses smart battery technology, and false otherwise. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is set to true if the storage array uses smart battery technology, and false otherwise." , required = true)
	@XmlElement(required = true)
	private boolean smartBatteryTechnology;

	/** @return This field is set to true if the storage array uses smart battery technology, and false otherwise. */
	public boolean isSmartBatteryTechnology() {
		return this.smartBatteryTechnology;
	}
	/** @param x This field is set to true if the storage array uses smart battery technology, and false otherwise. */
	public void setSmartBatteryTechnology(boolean x) {
		this.smartBatteryTechnology = x;
	}

	/** This field, which is only applicable if smartBatteryTechnology is true, is set to true if the charge level on a smart battery unit is expected to remain above the minimum level needed to support write caching. */
	@io.swagger.annotations.ApiModelProperty(value ="This field, which is only applicable if smartBatteryTechnology is true, is set to true if the charge level on a smart battery unit is expected to remain above the minimum level needed to support write caching." , required = true)
	@XmlElement(required = true)
	private boolean writeCachingEnabledDuringLearnCycle;

	/** @return This field, which is only applicable if smartBatteryTechnology is true, is set to true if the charge level on a smart battery unit is expected to remain above the minimum level needed to support write caching. */
	public boolean isWriteCachingEnabledDuringLearnCycle() {
		return this.writeCachingEnabledDuringLearnCycle;
	}
	/** @param x This field, which is only applicable if smartBatteryTechnology is true, is set to true if the charge level on a smart battery unit is expected to remain above the minimum level needed to support write caching. */
	public void setWriteCachingEnabledDuringLearnCycle(boolean x) {
		this.writeCachingEnabledDuringLearnCycle = x;
	}

	/** The maximum number of SSDs supported on the array. If SSDs are not supported this value is 0. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of SSDs supported on the array. If SSDs are not supported this value is 0." , required = true)
	@XmlElement(required = true)
	private int maxSSDsSupported;

	/** @return The maximum number of SSDs supported on the array. If SSDs are not supported this value is 0. */
	public int getMaxSSDsSupported() {
		return this.maxSSDsSupported;
	}
	/** @param x The maximum number of SSDs supported on the array. If SSDs are not supported this value is 0. */
	public void setMaxSSDsSupported(int x) {
		this.maxSSDsSupported = x;
	}

	/** True if different SSD interface types (e.g. Fibre Channel, SAS) can be used in the same volume group. */
	@io.swagger.annotations.ApiModelProperty(value ="True if different SSD interface types (e.g. Fibre Channel, SAS) can be used in the same volume group." , required = true)
	@XmlElement(required = true)
	private boolean ssdInterfaceTypeMixingSupported;

	/** @return True if different SSD interface types (e.g. Fibre Channel, SAS) can be used in the same volume group. */
	public boolean isSsdInterfaceTypeMixingSupported() {
		return this.ssdInterfaceTypeMixingSupported;
	}
	/** @param x True if different SSD interface types (e.g. Fibre Channel, SAS) can be used in the same volume group. */
	public void setSsdInterfaceTypeMixingSupported(boolean x) {
		this.ssdInterfaceTypeMixingSupported = x;
	}

	/** The maximum number of drive slots supported on the array. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of drive slots supported on the array." , required = true)
	@XmlElement(required = true)
	private int maxDriveSlots;

	/** @return The maximum number of drive slots supported on the array. */
	public int getMaxDriveSlots() {
		return this.maxDriveSlots;
	}
	/** @param x The maximum number of drive slots supported on the array. */
	public void setMaxDriveSlots(int x) {
		this.maxDriveSlots = x;
	}

	/** The protection types supported by the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="The protection types supported by the storage array." , required = true)
	@XmlElement(required = true)
	private ProtectionType[] supportedProtectionTypes;

	/** @return The protection types supported by the storage array. */
	public ProtectionType[] getSupportedProtectionTypes() {
		return this.supportedProtectionTypes;
	}
	/** @param x The protection types supported by the storage array. */
	public void setSupportedProtectionTypes(ProtectionType[] x) {
		this.supportedProtectionTypes = x;
	}

	/** An array listing the MEL event priorities that are configured for use in the current controller firmware build. */
	@io.swagger.annotations.ApiModelProperty(value ="An array listing the MEL event priorities that are configured for use in the current controller firmware build." , required = true)
	@XmlElement(required = true)
	private EventPriority[] supportedEventPriorities;

	/** @return An array listing the MEL event priorities that are configured for use in the current controller firmware build. */
	public EventPriority[] getSupportedEventPriorities() {
		return this.supportedEventPriorities;
	}
	/** @param x An array listing the MEL event priorities that are configured for use in the current controller firmware build. */
	public void setSupportedEventPriorities(EventPriority[] x) {
		this.supportedEventPriorities = x;
	}

	/** The maximum flash cache repository size measured in bytes. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum flash cache repository size measured in bytes." , required = true)
	@XmlElement(required = true)
	private long maxFlashCacheSize;

	/** @return The maximum flash cache repository size measured in bytes. */
	public long getMaxFlashCacheSize() {
		return this.maxFlashCacheSize;
	}
	/** @param x The maximum flash cache repository size measured in bytes. */
	public void setMaxFlashCacheSize(long x) {
		this.maxFlashCacheSize = x;
	}

	/** The default media scan period stored in the controller's NVSRAM. Units are days. */
	@io.swagger.annotations.ApiModelProperty(value ="The default media scan period stored in the controller's NVSRAM. Units are days." , required = true)
	@XmlElement(required = true)
	private int defaultMediaScanPeriod;

	/** @return The default media scan period stored in the controller's NVSRAM. Units are days. */
	public int getDefaultMediaScanPeriod() {
		return this.defaultMediaScanPeriod;
	}
	/** @param x The default media scan period stored in the controller's NVSRAM. Units are days. */
	public void setDefaultMediaScanPeriod(int x) {
		this.defaultMediaScanPeriod = x;
	}
}
