package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration identifies the FRU diagnostic test. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(280)
public enum FruDiagTestIdentifier implements Serializable {
		/** No diagnostic status is available. */
		none(0),
		/** This test will include writing patterns for a single 8-byte word. A single byte of the pattern will be cleared and compared to a mask to ensure that the correct byte was successfully cleared. This will be repeated for all bytes in the 8-byte word. */
		dimmByteEnable(1),
		/** This test will verify single bit and multi-bit ECC errors on specified regions within the cache memory. It will also attempt to correct the ECC errors. If the ECC errors are not correctable, it will perform a self-lockdown indicating an ECC error. */
		dimmEcc(2),
		/** This will perform a March C- test on specified regions within the RPA memory. It will test for only one set of inverse patterns. */
		dimmMarchC(3),
		/** This is a typical DRAM word pattern test where the test sequence proceeds with a series of read/write operations for all locations within the specified memory region using a set of special patterns. The test writes and verifies several patterns at 32 bit widths. */
		dimmPatterns(4),
		/** This test will generate a non-repetitive pattern for the double word length and write to the entire region specified. The pattern will be read back and verified. */
		dimmPseudorandom(5),
		/** This test will checked the capability of DMA copy operations across various regions within the cache memory. This will use the RPA hardware capabilities to move the data from one region to another. */
		dimmDmaCopy(6),
		/** This diagnostic tests if the USB flash device is write protected. */
		usbflashWriteProtect(7),
		/** This diagnostic indicates whether a USB flash drive is approaching its write cycle limit. */
		usbflashWriteCycle(8),
		/** This diagnostic will write a pattern to the entire USB flash drive in quantum of blocks. Each block written will be read back and the data verified. */
		usbflashWritePatterns(9),
		/** This diagnostic will write a random pattern to each flash block. The written pattern will be read back and the data verified. */
		usbflashRandom(10),
		/** HIC Read Write. */
		hicReadWrite(11),
		/** HIC Data Lines. */
		hicDataLines(12),
		/** HIC Interrupt. */
		hicInterrupt(13),
		/** HIC Loopback. */
		hicLoopback(14),
		/** HIC T10 Protection Information. */
		hicT10pi(15),
		/** HIC DMA. */
		hicDma(16),
		/** HIC Context Memory. */
		hicContextMemory(17),
		/** HIC Extended Memory. */
		hicExtMemory(18),
		/** Controller Register Address. */
		ctlrRegisterAddress(19),
		/** Controller Data Lines. */
		ctlrDataLines(20),
		/** Controller APC SRAM. */
		ctlrApcSram(21),
		/** Controller APC FIFO. */
		ctlrApcFifo(22),
		/** Controller Data Copy. */
		ctlrDataCopy(23),
		/** Controller RAID 5. */
		ctlrRaid5(24),
		/** Controller RAID 6. */
		ctlrRaid6(25),
		/** Used for HIC RAM read/write tests. */
		hicRamReadWrite(26),
		__UNDEFINED(464378545);

		public final int value;

		private FruDiagTestIdentifier(int v) {
			this.value = v;
		}
}
