package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure represents a host system that accesses the storage array via the I/O path for data access. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(699)
public class Host implements Serializable,devmgr.api.model.Identifiable,devmgr.api.model.Named {
	public Host() {
	}

	/** The unique identification value for this object. Other objects may use this reference value to refer to the host. */
	@io.swagger.annotations.ApiModelProperty(value ="The unique identification value for this object. Other objects may use this reference value to refer to the host." , required = true)
	@XmlElement(required = true)
	private String hostRef;

	/** @return The unique identification value for this object. Other objects may use this reference value to refer to the host. */
	public String getHostRef() {
		return this.hostRef;
	}
	/** @param x The unique identification value for this object. Other objects may use this reference value to refer to the host. */
	public void setHostRef(String x) {
		this.hostRef = x;
	}

	/** The cluster reference value of the cluster in which this host resides. A NULL reference value indicates that the host has not been assigned to a cluster. */
	@io.swagger.annotations.ApiModelProperty(value ="The cluster reference value of the cluster in which this host resides. A NULL reference value indicates that the host has not been assigned to a cluster." , required = true)
	@XmlElement(required = true)
	private String clusterRef;

	/** @return The cluster reference value of the cluster in which this host resides. A NULL reference value indicates that the host has not been assigned to a cluster. */
	public String getClusterRef() {
		return this.clusterRef;
	}
	/** @param x The cluster reference value of the cluster in which this host resides. A NULL reference value indicates that the host has not been assigned to a cluster. */
	public void setClusterRef(String x) {
		this.clusterRef = x;
	}

	/** The user-assigned, descriptive label string for the host. */
	@io.swagger.annotations.ApiModelProperty(value ="The user-assigned, descriptive label string for the host." , required = true)
	@XmlElement(required = true)
	private String label;

	/** @return The user-assigned, descriptive label string for the host. */
	public String getLabel() {
		return this.label;
	}
	/** @param x The user-assigned, descriptive label string for the host. */
	public void setLabel(String x) {
		this.label = x;
	}

	/** If true, indicates that I/O accesses from this host are subject to the storage array's default LUN-to-volume mappings. If false, indicates that I/O accesses from the host are subject to host-specific or cluster-specific LUN-to-volume mappings. */
	@io.swagger.annotations.ApiModelProperty(value ="If true, indicates that I/O accesses from this host are subject to the storage array's default LUN-to-volume mappings. If false, indicates that I/O accesses from the host are subject to host-specific or cluster-specific LUN-to-volume mappings." , required = true)
	@XmlElement(required = true)
	private boolean isSAControlled;

	/** @return If true, indicates that I/O accesses from this host are subject to the storage array's default LUN-to-volume mappings. If false, indicates that I/O accesses from the host are subject to host-specific or cluster-specific LUN-to-volume mappings. */
	public boolean isIsSAControlled() {
		return this.isSAControlled;
	}
	/** @param x If true, indicates that I/O accesses from this host are subject to the storage array's default LUN-to-volume mappings. If false, indicates that I/O accesses from the host are subject to host-specific or cluster-specific LUN-to-volume mappings. */
	public void setIsSAControlled(boolean x) {
		this.isSAControlled = x;
	}

	/** If true, indicates that creation of LUN-to-volume mappings should require careful confirmation from the end-user, since such a mapping will alter the volume access rights of other hosts, in addition to this one. */
	@io.swagger.annotations.ApiModelProperty(value ="If true, indicates that creation of LUN-to-volume mappings should require careful confirmation from the end-user, since such a mapping will alter the volume access rights of other hosts, in addition to this one." , required = true)
	@XmlElement(required = true)
	private boolean confirmLUNMappingCreation;

	/** @return If true, indicates that creation of LUN-to-volume mappings should require careful confirmation from the end-user, since such a mapping will alter the volume access rights of other hosts, in addition to this one. */
	public boolean isConfirmLUNMappingCreation() {
		return this.confirmLUNMappingCreation;
	}
	/** @param x If true, indicates that creation of LUN-to-volume mappings should require careful confirmation from the end-user, since such a mapping will alter the volume access rights of other hosts, in addition to this one. */
	public void setConfirmLUNMappingCreation(boolean x) {
		this.confirmLUNMappingCreation = x;
	}

	/** An integer index indicating the type of host. */
	@io.swagger.annotations.ApiModelProperty(value ="An integer index indicating the type of host." , required = true)
	@XmlElement(required = true)
	private int hostTypeIndex;

	/** @return An integer index indicating the type of host. */
	public int getHostTypeIndex() {
		return this.hostTypeIndex;
	}
	/** @param x An integer index indicating the type of host. */
	public void setHostTypeIndex(int x) {
		this.hostTypeIndex = x;
	}

	/** This field is true if the host has a PI capable access method. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is true if the host has a PI capable access method." , required = true)
	@XmlElement(required = true)
	private boolean protectionInformationCapableAccessMethod;

	/** @return This field is true if the host has a PI capable access method. */
	public boolean isProtectionInformationCapableAccessMethod() {
		return this.protectionInformationCapableAccessMethod;
	}
	/** @param x This field is true if the host has a PI capable access method. */
	public void setProtectionInformationCapableAccessMethod(boolean x) {
		this.protectionInformationCapableAccessMethod = x;
	}

	/** If true, the host is capable of supporting large block formats. */
	@io.swagger.annotations.ApiModelProperty(value ="If true, the host is capable of supporting large block formats." , required = true)
	@XmlElement(required = true)
	private boolean isLargeBlockFormatHost;

	/** @return If true, the host is capable of supporting large block formats. */
	public boolean isIsLargeBlockFormatHost() {
		return this.isLargeBlockFormatHost;
	}
	/** @param x If true, the host is capable of supporting large block formats. */
	public void setIsLargeBlockFormatHost(boolean x) {
		this.isLargeBlockFormatHost = x;
	}

	/** Provides an indication as to whether LUN 0 is restricted (i.e., disallowed) for the associated host. */
	@io.swagger.annotations.ApiModelProperty(value ="Provides an indication as to whether LUN 0 is restricted (i.e., disallowed) for the associated host." , required = true)
	@XmlElement(required = true)
	private boolean isLun0Restricted;

	/** @return Provides an indication as to whether LUN 0 is restricted (i.e., disallowed) for the associated host. */
	public boolean isIsLun0Restricted() {
		return this.isLun0Restricted;
	}
	/** @param x Provides an indication as to whether LUN 0 is restricted (i.e., disallowed) for the associated host. */
	public void setIsLun0Restricted(boolean x) {
		this.isLun0Restricted = x;
	}
	@Override
	public String getId(){
		return hostRef;
	}
	@Override
	public String getName(){
		return label;
	}
}
