package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure models the critical aspects of a host board component. Instances of this structure are included in the object graph according to the following rules: (1) if the controller does not have a host card slot, then there is never a corresponding HostBoard structure; (2) if the controller model is defined so as to always have a host card installed, then a corresponding HostBoard structure is always present; (3) if a controller model is defined such that it may receive a host card upgrade in the field, then a HostBoard structure is always present, but its status may indicate "not present." */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(998)
public class HostBoard implements Serializable,devmgr.api.model.Identifiable {
	public HostBoard() {
	}

	/** The controller associated with the host board. */
	@io.swagger.annotations.ApiModelProperty(value ="The controller associated with the host board." , required = true)
	@XmlElement(required = true)
	private String parentController;

	/** @return The controller associated with the host board. */
	public String getParentController() {
		return this.parentController;
	}
	/** @param x The controller associated with the host board. */
	public void setParentController(String x) {
		this.parentController = x;
	}

	/** The host board's part number, from VPD. */
	@io.swagger.annotations.ApiModelProperty(value ="The host board's part number, from VPD." , required = true)
	@XmlElement(required = true)
	private String partNumber;

	/** @return The host board's part number, from VPD. */
	public String getPartNumber() {
		return this.partNumber;
	}
	/** @param x The host board's part number, from VPD. */
	public void setPartNumber(String x) {
		this.partNumber = x;
	}

	/** The host board's serial number, from VPD. */
	@io.swagger.annotations.ApiModelProperty(value ="The host board's serial number, from VPD." , required = true)
	@XmlElement(required = true)
	private String serialNumber;

	/** @return The host board's serial number, from VPD. */
	public String getSerialNumber() {
		return this.serialNumber;
	}
	/** @param x The host board's serial number, from VPD. */
	public void setSerialNumber(String x) {
		this.serialNumber = x;
	}

	/** The host board's vendor name, from VPD. */
	@io.swagger.annotations.ApiModelProperty(value ="The host board's vendor name, from VPD." , required = true)
	@XmlElement(required = true)
	private String vendorName;

	/** @return The host board's vendor name, from VPD. */
	public String getVendorName() {
		return this.vendorName;
	}
	/** @param x The host board's vendor name, from VPD. */
	public void setVendorName(String x) {
		this.vendorName = x;
	}

	/** The host board's date of manufacture, from VPD. */
	@io.swagger.annotations.ApiModelProperty(value ="The host board's date of manufacture, from VPD." , required = true)
	@XmlElement(required = true)
	private long manufacturerDate;

	/** @return The host board's date of manufacture, from VPD. */
	public long getManufacturerDate() {
		return this.manufacturerDate;
	}
	/** @param x The host board's date of manufacture, from VPD. */
	public void setManufacturerDate(long x) {
		this.manufacturerDate = x;
	}

	/** The field replaceable unit type string, from VPD. */
	@io.swagger.annotations.ApiModelProperty(value ="The field replaceable unit type string, from VPD." , required = true)
	@XmlElement(required = true)
	private String fruType;

	/** @return The field replaceable unit type string, from VPD. */
	public String getFruType() {
		return this.fruType;
	}
	/** @param x The field replaceable unit type string, from VPD. */
	public void setFruType(String x) {
		this.fruType = x;
	}

	/** The board ID of the controller's host card. */
	@io.swagger.annotations.ApiModelProperty(value ="The board ID of the controller's host card." , required = true)
	@XmlElement(required = true)
	private String hostBoardId;

	/** @return The board ID of the controller's host card. */
	public String getHostBoardId() {
		return this.hostBoardId;
	}
	/** @param x The board ID of the controller's host card. */
	public void setHostBoardId(String x) {
		this.hostBoardId = x;
	}

	/** The host board's status. */
	@io.swagger.annotations.ApiModelProperty(value ="The host board's status." , required = true)
	@XmlElement(required = true)
	private HostBoardStatus status = HostBoardStatus.__UNDEFINED;

	/** @return The host board's status. */
	public HostBoardStatus getStatus() {
		return this.status;
	}
	/** @param x The host board's status. */
	public void setStatus(HostBoardStatus x) {
		this.status = x;
	}

	/** The host board's type. */
	@io.swagger.annotations.ApiModelProperty(value ="The host board's type." , required = true)
	@XmlElement(required = true)
	private HostBoardType type = HostBoardType.__UNDEFINED;

	/** @return The host board's type. */
	public HostBoardType getType() {
		return this.type;
	}
	/** @param x The host board's type. */
	public void setType(HostBoardType x) {
		this.type = x;
	}

	/** The reference for this physical host board. */
	@io.swagger.annotations.ApiModelProperty(value ="The reference for this physical host board." , required = true)
	@XmlElement(required = true)
	private String hostBoardRef;

	/** @return The reference for this physical host board. */
	public String getHostBoardRef() {
		return this.hostBoardRef;
	}
	/** @param x The reference for this physical host board. */
	public void setHostBoardRef(String x) {
		this.hostBoardRef = x;
	}

	/** The number of ports provided by the host board. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of ports provided by the host board." , required = true)
	@XmlElement(required = true)
	private int numberOfPorts;

	/** @return The number of ports provided by the host board. */
	public int getNumberOfPorts() {
		return this.numberOfPorts;
	}
	/** @param x The number of ports provided by the host board. */
	public void setNumberOfPorts(int x) {
		this.numberOfPorts = x;
	}

	/** Data that is specific to the type of host board. */
	@io.swagger.annotations.ApiModelProperty(value ="Data that is specific to the type of host board." , required = true)
	@XmlElement(required = true)
	private HostBoardTypeData hbTypeData;

	/** @return Data that is specific to the type of host board. */
	public HostBoardTypeData getHbTypeData() {
		return this.hbTypeData;
	}
	/** @param x Data that is specific to the type of host board. */
	public void setHbTypeData(HostBoardTypeData x) {
		this.hbTypeData = x;
	}

	/** The OEM part number of the host board. */
	@io.swagger.annotations.ApiModelProperty(value ="The OEM part number of the host board." , required = true)
	@XmlElement(required = true)
	private String oemPartNumber;

	/** @return The OEM part number of the host board. */
	public String getOemPartNumber() {
		return this.oemPartNumber;
	}
	/** @param x The OEM part number of the host board. */
	public void setOemPartNumber(String x) {
		this.oemPartNumber = x;
	}

	/** The number of the slot on the controller where the host board resides. Host board slots are numbered starting at one, independent of other types of slots (e.g., cache backup device slots) on the controller. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of the slot on the controller where the host board resides. Host board slots are numbered starting at one, independent of other types of slots (e.g., cache backup device slots) on the controller." , required = true)
	@XmlElement(required = true)
	private int hostBoardControllerSlot;

	/** @return The number of the slot on the controller where the host board resides. Host board slots are numbered starting at one, independent of other types of slots (e.g., cache backup device slots) on the controller. */
	public int getHostBoardControllerSlot() {
		return this.hostBoardControllerSlot;
	}
	/** @param x The number of the slot on the controller where the host board resides. Host board slots are numbered starting at one, independent of other types of slots (e.g., cache backup device slots) on the controller. */
	public void setHostBoardControllerSlot(int x) {
		this.hostBoardControllerSlot = x;
	}

	/** The repair policy for the host board component. */
	@io.swagger.annotations.ApiModelProperty(value ="The repair policy for the host board component." , required = true)
	@XmlElement(required = true)
	private RepairPolicy repairPolicy;

	/** @return The repair policy for the host board component. */
	public RepairPolicy getRepairPolicy() {
		return this.repairPolicy;
	}
	/** @param x The repair policy for the host board component. */
	public void setRepairPolicy(RepairPolicy x) {
		this.repairPolicy = x;
	}

	/** The physical location of the host board. The parent reference in Location identifies the controller where the host board is physically located, and the position field is the parent-relative/like-component relative slot number of the host card, starting at 1. */
	@io.swagger.annotations.ApiModelProperty(value ="The physical location of the host board. The parent reference in Location identifies the controller where the host board is physically located, and the position field is the parent-relative/like-component relative slot number of the host card, starting at 1." , required = true)
	@XmlElement(required = true)
	private Location physicalLocation;

	/** @return The physical location of the host board. The parent reference in Location identifies the controller where the host board is physically located, and the position field is the parent-relative/like-component relative slot number of the host card, starting at 1. */
	public Location getPhysicalLocation() {
		return this.physicalLocation;
	}
	/** @param x The physical location of the host board. The parent reference in Location identifies the controller where the host board is physically located, and the position field is the parent-relative/like-component relative slot number of the host card, starting at 1. */
	public void setPhysicalLocation(Location x) {
		this.physicalLocation = x;
	}
	@Override
	public String getId(){
		return hostBoardRef;
	}
}
