package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure represents a host-resident I/O port used to access storage array data via the I/O path. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(1144)
public class HostPort implements Serializable,devmgr.api.model.Identifiable {
	public HostPort() {
	}

	/** The unique identification value for this object. Other objects may use this reference value to refer to the host port. */
	@io.swagger.annotations.ApiModelProperty(value ="The unique identification value for this object. Other objects may use this reference value to refer to the host port." , required = true)
	@XmlElement(required = true)
	private String hostPortRef;

	/** @return The unique identification value for this object. Other objects may use this reference value to refer to the host port. */
	public String getHostPortRef() {
		return this.hostPortRef;
	}
	/** @param x The unique identification value for this object. Other objects may use this reference value to refer to the host port. */
	public void setHostPortRef(String x) {
		this.hostPortRef = x;
	}

	/** The unique, externally-defined identifier for this object. For example, for a Fibre Channel host port, this field contains the value of the Fibre Channel world-wide name for the port. */
	@io.swagger.annotations.ApiModelProperty(value ="The unique, externally-defined identifier for this object. For example, for a Fibre Channel host port, this field contains the value of the Fibre Channel world-wide name for the port." , required = true)
	@XmlElement(required = true)
	private String hostPortName;

	/** @return The unique, externally-defined identifier for this object. For example, for a Fibre Channel host port, this field contains the value of the Fibre Channel world-wide name for the port. */
	public String getHostPortName() {
		return this.hostPortName;
	}
	/** @param x The unique, externally-defined identifier for this object. For example, for a Fibre Channel host port, this field contains the value of the Fibre Channel world-wide name for the port. */
	public void setHostPortName(String x) {
		this.hostPortName = x;
	}

	/** The user-assigned, descriptive label string for the host port. */
	@io.swagger.annotations.ApiModelProperty(value ="The user-assigned, descriptive label string for the host port." , required = true)
	@XmlElement(required = true)
	private String label;

	/** @return The user-assigned, descriptive label string for the host port. */
	public String getLabel() {
		return this.label;
	}
	/** @param x The user-assigned, descriptive label string for the host port. */
	public void setLabel(String x) {
		this.label = x;
	}

	/** The host reference value of the host in which this port resides. */
	@io.swagger.annotations.ApiModelProperty(value ="The host reference value of the host in which this port resides." , required = true)
	@XmlElement(required = true)
	private String hostRef;

	/** @return The host reference value of the host in which this port resides. */
	public String getHostRef() {
		return this.hostRef;
	}
	/** @param x The host reference value of the host in which this port resides. */
	public void setHostRef(String x) {
		this.hostRef = x;
	}

	/** An index value that indicates the type of host port. This value is used to reference the appropriate entry in the hostPortType field of the associated StorageArray object. */
	@io.swagger.annotations.ApiModelProperty(value ="An index value that indicates the type of host port. This value is used to reference the appropriate entry in the hostPortType field of the associated StorageArray object." , required = true)
	@XmlElement(required = true)
	private int hostPortTypeIndex;

	/** @return An index value that indicates the type of host port. This value is used to reference the appropriate entry in the hostPortType field of the associated StorageArray object. */
	public int getHostPortTypeIndex() {
		return this.hostPortTypeIndex;
	}
	/** @param x An index value that indicates the type of host port. This value is used to reference the appropriate entry in the hostPortType field of the associated StorageArray object. */
	public void setHostPortTypeIndex(int x) {
		this.hostPortTypeIndex = x;
	}

	/** If true, indicates that I/O accesses from this host port are subject to the storage array's default LUN-to-volume mappings. If false, indicates that I/O accesses from the host port are subject to host-specific or cluster-specific LUN-to-volume mappings. */
	@io.swagger.annotations.ApiModelProperty(value ="If true, indicates that I/O accesses from this host port are subject to the storage array's default LUN-to-volume mappings. If false, indicates that I/O accesses from the host port are subject to host-specific or cluster-specific LUN-to-volume mappings." , required = true)
	@XmlElement(required = true)
	private boolean isSAControlled;

	/** @return If true, indicates that I/O accesses from this host port are subject to the storage array's default LUN-to-volume mappings. If false, indicates that I/O accesses from the host port are subject to host-specific or cluster-specific LUN-to-volume mappings. */
	public boolean isIsSAControlled() {
		return this.isSAControlled;
	}
	/** @param x If true, indicates that I/O accesses from this host port are subject to the storage array's default LUN-to-volume mappings. If false, indicates that I/O accesses from the host port are subject to host-specific or cluster-specific LUN-to-volume mappings. */
	public void setIsSAControlled(boolean x) {
		this.isSAControlled = x;
	}

	/** If true, indicates that creation of LUN-to-volume mappings should require careful confirmation from the end-user, since such a mapping will alter the volume access rights of other host ports, in addition to this one. */
	@io.swagger.annotations.ApiModelProperty(value ="If true, indicates that creation of LUN-to-volume mappings should require careful confirmation from the end-user, since such a mapping will alter the volume access rights of other host ports, in addition to this one." , required = true)
	@XmlElement(required = true)
	private boolean confirmLUNMappingCreation;

	/** @return If true, indicates that creation of LUN-to-volume mappings should require careful confirmation from the end-user, since such a mapping will alter the volume access rights of other host ports, in addition to this one. */
	public boolean isConfirmLUNMappingCreation() {
		return this.confirmLUNMappingCreation;
	}
	/** @param x If true, indicates that creation of LUN-to-volume mappings should require careful confirmation from the end-user, since such a mapping will alter the volume access rights of other host ports, in addition to this one. */
	public void setConfirmLUNMappingCreation(boolean x) {
		this.confirmLUNMappingCreation = x;
	}

	/** The I/O-protocol-based unique port identifier. This field replaces the deprecated hostPortName field. */
	@io.swagger.annotations.ApiModelProperty(value ="The I/O-protocol-based unique port identifier. This field replaces the deprecated hostPortName field." , required = true)
	@XmlElement(required = true)
	private SCSIInitiatorPortId portId;

	/** @return The I/O-protocol-based unique port identifier. This field replaces the deprecated hostPortName field. */
	public SCSIInitiatorPortId getPortId() {
		return this.portId;
	}
	/** @param x The I/O-protocol-based unique port identifier. This field replaces the deprecated hostPortName field. */
	public void setPortId(SCSIInitiatorPortId x) {
		this.portId = x;
	}

	/** The host port has been marked inactive */
	@io.swagger.annotations.ApiModelProperty(value ="The host port has been marked inactive" , required = true)
	@XmlElement(required = true)
	private boolean portInactive;

	/** @return The host port has been marked inactive */
	public boolean isPortInactive() {
		return this.portInactive;
	}
	/** @param x The host port has been marked inactive */
	public void setPortInactive(boolean x) {
		this.portInactive = x;
	}
	@Override
	public String getId(){
		return hostPortRef;
	}
}
