package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration specifies the types of dependencies that may be identified for a volume belonging to a group that is a candidate to be imported. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(233)
public enum ImportDependencyType implements Serializable {
		/** The dependent volume and the referenced volume participate in the same snapshot. */
		snapshot(1),
		/** The dependent volume and the referenced volume comprise a volume copy pair. */
		volumeCopy(2),
		/** The dependent volume provides metadata for the referenced higher-level volume. */
		metadata(3),
		/** The dependent volume is one of the volumes in a remote mirror pair. */
		mirrorPair(4),
		/** The dependent volume has a mapping to a host system */
		hostMapping(5),
		/** The dependent volume has a persistent reservation. */
		persistentReservation(6),
		/** The dependent volume depends on RAID 6 hardware support. */
		raid6Support(7),
		/** The dependent volume is an Async Mirror Group Member (could be either primary or secondary). */
		asyncMirrorGroupMember(8),
		/** The dependent volume is an ERV/ConcatVolume member. */
		concatMember(9),
		/** The dependent volume is a PiT Group base. */
		pitGroup(10),
		/** The dependent volume is a PiT View base. */
		pitView(11),
		__UNDEFINED(464378545);

		public final int value;

		private ImportDependencyType(int v) {
			this.value = v;
		}
}
