package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure identifies the protocol endpoints of an iSCSI connection. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(1138)
public class IscsiConnection implements Serializable {
	public IscsiConnection() {
	}

	/** The unique identifier of the connection within the scope of the parent session. */
	@io.swagger.annotations.ApiModelProperty(value ="The unique identifier of the connection within the scope of the parent session." , required = true)
	@XmlElement(required = true)
	private int connectionId;

	/** @return The unique identifier of the connection within the scope of the parent session. */
	public int getConnectionId() {
		return this.connectionId;
	}
	/** @param x The unique identifier of the connection within the scope of the parent session. */
	public void setConnectionId(int x) {
		this.connectionId = x;
	}

	/** A reference to the physical interface to which this connection is bound. */
	@io.swagger.annotations.ApiModelProperty(value ="A reference to the physical interface to which this connection is bound." , required = true)
	@XmlElement(required = true)
	private String iscsiInterface;

	/** @return A reference to the physical interface to which this connection is bound. */
	public String getIscsiInterface() {
		return this.iscsiInterface;
	}
	/** @param x A reference to the physical interface to which this connection is bound. */
	public void setIscsiInterface(String x) {
		this.iscsiInterface = x;
	}

	/** The maximum data payload size supported for command or data PDUs to be sent on this connection. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum data payload size supported for command or data PDUs to be sent on this connection." , required = true)
	@XmlElement(required = true)
	private int maxTransmitDataSegmentLength;

	/** @return The maximum data payload size supported for command or data PDUs to be sent on this connection. */
	public int getMaxTransmitDataSegmentLength() {
		return this.maxTransmitDataSegmentLength;
	}
	/** @param x The maximum data payload size supported for command or data PDUs to be sent on this connection. */
	public void setMaxTransmitDataSegmentLength(int x) {
		this.maxTransmitDataSegmentLength = x;
	}

	/** True if this connection is inserting markers in in its outgoing data stream. */
	@io.swagger.annotations.ApiModelProperty(value ="True if this connection is inserting markers in in its outgoing data stream." , required = true)
	@XmlElement(required = true)
	private boolean sendingMarkers;

	/** @return True if this connection is inserting markers in in its outgoing data stream. */
	public boolean isSendingMarkers() {
		return this.sendingMarkers;
	}
	/** @param x True if this connection is inserting markers in in its outgoing data stream. */
	public void setSendingMarkers(boolean x) {
		this.sendingMarkers = x;
	}

	/** The active version number of the iSCSI specification negotiated on this connection. */
	@io.swagger.annotations.ApiModelProperty(value ="The active version number of the iSCSI specification negotiated on this connection." , required = true)
	@XmlElement(required = true)
	private char activeIscsiVersion;

	/** @return The active version number of the iSCSI specification negotiated on this connection. */
	public char getActiveIscsiVersion() {
		return this.activeIscsiVersion;
	}
	/** @param x The active version number of the iSCSI specification negotiated on this connection. */
	public void setActiveIscsiVersion(char x) {
		this.activeIscsiVersion = x;
	}

	/** True if the target is required to authenticate itself to the Initiator, in addition to the Initiator authenticating itself to the target. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the target is required to authenticate itself to the Initiator, in addition to the Initiator authenticating itself to the target." , required = true)
	@XmlElement(required = true)
	private boolean mutualAuthentication;

	/** @return True if the target is required to authenticate itself to the Initiator, in addition to the Initiator authenticating itself to the target. */
	public boolean isMutualAuthentication() {
		return this.mutualAuthentication;
	}
	/** @param x True if the target is required to authenticate itself to the Initiator, in addition to the Initiator authenticating itself to the target. */
	public void setMutualAuthentication(boolean x) {
		this.mutualAuthentication = x;
	}

	/** A collection of connection-level settings that are subject to initiator-target negotiation. */
	@io.swagger.annotations.ApiModelProperty(value ="A collection of connection-level settings that are subject to initiator-target negotiation." , required = true)
	@XmlElement(required = true)
	private IscsiNegotiableConnectionSettings negotiatedSettings;

	/** @return A collection of connection-level settings that are subject to initiator-target negotiation. */
	public IscsiNegotiableConnectionSettings getNegotiatedSettings() {
		return this.negotiatedSettings;
	}
	/** @param x A collection of connection-level settings that are subject to initiator-target negotiation. */
	public void setNegotiatedSettings(IscsiNegotiableConnectionSettings x) {
		this.negotiatedSettings = x;
	}

	/** The TCP protocol endpoints of the connection. */
	@io.swagger.annotations.ApiModelProperty(value ="The TCP protocol endpoints of the connection." , required = true)
	@XmlElement(required = true)
	private IscsiConnectionEndpoints endpoints;

	/** @return The TCP protocol endpoints of the connection. */
	public IscsiConnectionEndpoints getEndpoints() {
		return this.endpoints;
	}
	/** @param x The TCP protocol endpoints of the connection. */
	public void setEndpoints(IscsiConnectionEndpoints x) {
		this.endpoints = x;
	}
}
