package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure contains information about the storage array in its role as "iSCSI entity." (An iSCSI entity is a system that contains and exposes iSCSI nodes.) */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(636)
public class IscsiEntityData implements Serializable {
	public IscsiEntityData() {
	}

	/** True if the storage array is enabled to respond to ICMP ping messages. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the storage array is enabled to respond to ICMP ping messages." , required = true)
	@XmlElement(required = true)
	private boolean icmpPingResponseEnabled;

	/** @return True if the storage array is enabled to respond to ICMP ping messages. */
	public boolean isIcmpPingResponseEnabled() {
		return this.icmpPingResponseEnabled;
	}
	/** @param x True if the storage array is enabled to respond to ICMP ping messages. */
	public void setIcmpPingResponseEnabled(boolean x) {
		this.icmpPingResponseEnabled = x;
	}

	/** True if the storage array is enabled to participate in unnamed discovery sessions. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the storage array is enabled to participate in unnamed discovery sessions." , required = true)
	@XmlElement(required = true)
	private boolean unnamedDiscoverySessionsEnabled;

	/** @return True if the storage array is enabled to participate in unnamed discovery sessions. */
	public boolean isUnnamedDiscoverySessionsEnabled() {
		return this.unnamedDiscoverySessionsEnabled;
	}
	/** @param x True if the storage array is enabled to participate in unnamed discovery sessions. */
	public void setUnnamedDiscoverySessionsEnabled(boolean x) {
		this.unnamedDiscoverySessionsEnabled = x;
	}

	/** The number of the TCP port on which the iSNS server listens for incoming connections. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of the TCP port on which the iSNS server listens for incoming connections." , required = true)
	@XmlElement(required = true)
	private int isnsServerTcpListenPort;

	/** @return The number of the TCP port on which the iSNS server listens for incoming connections. */
	public int getIsnsServerTcpListenPort() {
		return this.isnsServerTcpListenPort;
	}
	/** @param x The number of the TCP port on which the iSNS server listens for incoming connections. */
	public void setIsnsServerTcpListenPort(int x) {
		this.isnsServerTcpListenPort = x;
	}

	/** The method by which the storage array determines the IPV4 address of the iSNS server. */
	@io.swagger.annotations.ApiModelProperty(value ="The method by which the storage array determines the IPV4 address of the iSNS server." , required = true)
	@XmlElement(required = true)
	private IpV4ConfigMethod ipv4IsnsServerAddressConfigMethod = IpV4ConfigMethod.__UNDEFINED;

	/** @return The method by which the storage array determines the IPV4 address of the iSNS server. */
	public IpV4ConfigMethod getIpv4IsnsServerAddressConfigMethod() {
		return this.ipv4IsnsServerAddressConfigMethod;
	}
	/** @param x The method by which the storage array determines the IPV4 address of the iSNS server. */
	public void setIpv4IsnsServerAddressConfigMethod(IpV4ConfigMethod x) {
		this.ipv4IsnsServerAddressConfigMethod = x;
	}

	/** The method by which the storage array determines the IPV4 address of the iSNS server. */
	@io.swagger.annotations.ApiModelProperty(value ="The method by which the storage array determines the IPV4 address of the iSNS server." , required = true)
	@XmlElement(required = true)
	private String ipv4IsnsServerAddress;

	/** @return The method by which the storage array determines the IPV4 address of the iSNS server. */
	public String getIpv4IsnsServerAddress() {
		return this.ipv4IsnsServerAddress;
	}
	/** @param x The method by which the storage array determines the IPV4 address of the iSNS server. */
	public void setIpv4IsnsServerAddress(String x) {
		this.ipv4IsnsServerAddress = x;
	}

	/** The method by which the storage array determines the IPV6 address of the iSNS server. This is always set to "static" and cannot be changed. */
	@io.swagger.annotations.ApiModelProperty(value ="The method by which the storage array determines the IPV6 address of the iSNS server. This is always set to \"static\" and cannot be changed." , required = true)
	@XmlElement(required = true)
	private IpV6ConfigMethod ipv6IsnsServerAddressConfigMethod = IpV6ConfigMethod.__UNDEFINED;

	/** @return The method by which the storage array determines the IPV6 address of the iSNS server. This is always set to "static" and cannot be changed. */
	public IpV6ConfigMethod getIpv6IsnsServerAddressConfigMethod() {
		return this.ipv6IsnsServerAddressConfigMethod;
	}
	/** @param x The method by which the storage array determines the IPV6 address of the iSNS server. This is always set to "static" and cannot be changed. */
	public void setIpv6IsnsServerAddressConfigMethod(IpV6ConfigMethod x) {
		this.ipv6IsnsServerAddressConfigMethod = x;
	}

	/** The method by which the storage array determines the IPV6 address of the iSNS server. This is always set to "static" and cannot be changed. */
	@io.swagger.annotations.ApiModelProperty(value ="The method by which the storage array determines the IPV6 address of the iSNS server. This is always set to \"static\" and cannot be changed." , required = true)
	@XmlElement(required = true)
	private String ipv6IsnsServerAddress;

	/** @return The method by which the storage array determines the IPV6 address of the iSNS server. This is always set to "static" and cannot be changed. */
	public String getIpv6IsnsServerAddress() {
		return this.ipv6IsnsServerAddress;
	}
	/** @param x The method by which the storage array determines the IPV6 address of the iSNS server. This is always set to "static" and cannot be changed. */
	public void setIpv6IsnsServerAddress(String x) {
		this.ipv6IsnsServerAddress = x;
	}

	/** The state of the iSCSI entity with respect to iSNS server registration. */
	@io.swagger.annotations.ApiModelProperty(value ="The state of the iSCSI entity with respect to iSNS server registration." , required = true)
	@XmlElement(required = true)
	private IsnsRegistrationState isnsRegistrationState = IsnsRegistrationState.__UNDEFINED;

	/** @return The state of the iSCSI entity with respect to iSNS server registration. */
	public IsnsRegistrationState getIsnsRegistrationState() {
		return this.isnsRegistrationState;
	}
	/** @param x The state of the iSCSI entity with respect to iSNS server registration. */
	public void setIsnsRegistrationState(IsnsRegistrationState x) {
		this.isnsRegistrationState = x;
	}

	/** True if the storage array is enabled to register with the iSNS (Internet Storage Name Service) server. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the storage array is enabled to register with the iSNS (Internet Storage Name Service) server." , required = true)
	@XmlElement(required = true)
	private boolean isnsServerRegistrationEnabled;

	/** @return True if the storage array is enabled to register with the iSNS (Internet Storage Name Service) server. */
	public boolean isIsnsServerRegistrationEnabled() {
		return this.isnsServerRegistrationEnabled;
	}
	/** @param x True if the storage array is enabled to register with the iSNS (Internet Storage Name Service) server. */
	public void setIsnsServerRegistrationEnabled(boolean x) {
		this.isnsServerRegistrationEnabled = x;
	}

	/** True if all the host ports have DHCP enabled, regardless of the configuration state. */
	@io.swagger.annotations.ApiModelProperty(value ="True if all the host ports have DHCP enabled, regardless of the configuration state." , required = true)
	@XmlElement(required = true)
	private boolean hostPortsConfiguredDHCP;

	/** @return True if all the host ports have DHCP enabled, regardless of the configuration state. */
	public boolean isHostPortsConfiguredDHCP() {
		return this.hostPortsConfiguredDHCP;
	}
	/** @param x True if all the host ports have DHCP enabled, regardless of the configuration state. */
	public void setHostPortsConfiguredDHCP(boolean x) {
		this.hostPortsConfiguredDHCP = x;
	}
}
