package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure contains information about session-level settings that are subject to initiator-target negotiation. It is used in two contexts: (1) reporting controller default settings (i.e., those that are the starting point for negotiation), and (2) reporting the current active settings. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(301)
public class IscsiNegotiableSessionSettings implements Serializable {
	public IscsiNegotiableSessionSettings() {
	}

	/** True indicates that the initiator must wait for an R2T before sending to the target. False indicates the initiator may send data immediately. */
	@io.swagger.annotations.ApiModelProperty(value ="True indicates that the initiator must wait for an R2T before sending to the target. False indicates the initiator may send data immediately." , required = true)
	@XmlElement(required = true)
	private boolean initialR2t;

	/** @return True indicates that the initiator must wait for an R2T before sending to the target. False indicates the initiator may send data immediately. */
	public boolean isInitialR2t() {
		return this.initialR2t;
	}
	/** @param x True indicates that the initiator must wait for an R2T before sending to the target. False indicates the initiator may send data immediately. */
	public void setInitialR2t(boolean x) {
		this.initialR2t = x;
	}

	/** True indicates that the initiator and target have agreed to support immediate data on this session. */
	@io.swagger.annotations.ApiModelProperty(value ="True indicates that the initiator and target have agreed to support immediate data on this session." , required = true)
	@XmlElement(required = true)
	private boolean immediateData;

	/** @return True indicates that the initiator and target have agreed to support immediate data on this session. */
	public boolean isImmediateData() {
		return this.immediateData;
	}
	/** @param x True indicates that the initiator and target have agreed to support immediate data on this session. */
	public void setImmediateData(boolean x) {
		this.immediateData = x;
	}

	/** The maximum number of outstanding request-to-transmit (R2T)s per iSCSI task within this session. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of outstanding request-to-transmit (R2T)s per iSCSI task within this session." , required = true)
	@XmlElement(required = true)
	private int maxOutstandingR2t;

	/** @return The maximum number of outstanding request-to-transmit (R2T)s per iSCSI task within this session. */
	public int getMaxOutstandingR2t() {
		return this.maxOutstandingR2t;
	}
	/** @param x The maximum number of outstanding request-to-transmit (R2T)s per iSCSI task within this session. */
	public void setMaxOutstandingR2t(int x) {
		this.maxOutstandingR2t = x;
	}

	/** The maximum length supported for unsolicited data sent within this session. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum length supported for unsolicited data sent within this session." , required = true)
	@XmlElement(required = true)
	private int maxUnsolicitedFirstDataBurstLength;

	/** @return The maximum length supported for unsolicited data sent within this session. */
	public int getMaxUnsolicitedFirstDataBurstLength() {
		return this.maxUnsolicitedFirstDataBurstLength;
	}
	/** @param x The maximum length supported for unsolicited data sent within this session. */
	public void setMaxUnsolicitedFirstDataBurstLength(int x) {
		this.maxUnsolicitedFirstDataBurstLength = x;
	}

	/** The maximum number of bytes which can be sent within a single sequence of Data-In or Data-Out PDUs. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of bytes which can be sent within a single sequence of Data-In or Data-Out PDUs." , required = true)
	@XmlElement(required = true)
	private int maxDataBurstLength;

	/** @return The maximum number of bytes which can be sent within a single sequence of Data-In or Data-Out PDUs. */
	public int getMaxDataBurstLength() {
		return this.maxDataBurstLength;
	}
	/** @param x The maximum number of bytes which can be sent within a single sequence of Data-In or Data-Out PDUs. */
	public void setMaxDataBurstLength(int x) {
		this.maxDataBurstLength = x;
	}

	/** True indicates that data PDU sequences must be transferred using continuously increasing offsets, except during error recovery False indicates that iSCSI data PDU sequences may be transferred in any order. */
	@io.swagger.annotations.ApiModelProperty(value ="True indicates that data PDU sequences must be transferred using continuously increasing offsets, except during error recovery False indicates that iSCSI data PDU sequences may be transferred in any order." , required = true)
	@XmlElement(required = true)
	private boolean dataSequenceInOrder;

	/** @return True indicates that data PDU sequences must be transferred using continuously increasing offsets, except during error recovery False indicates that iSCSI data PDU sequences may be transferred in any order. */
	public boolean isDataSequenceInOrder() {
		return this.dataSequenceInOrder;
	}
	/** @param x True indicates that data PDU sequences must be transferred using continuously increasing offsets, except during error recovery False indicates that iSCSI data PDU sequences may be transferred in any order. */
	public void setDataSequenceInOrder(boolean x) {
		this.dataSequenceInOrder = x;
	}

	/** True indicates that data PDUs within sequences must be at continuously increasing addresses, with no gaps or overlay between PDUs. False indicates that iSCSI data PDUs within sequences may be in any order. */
	@io.swagger.annotations.ApiModelProperty(value ="True indicates that data PDUs within sequences must be at continuously increasing addresses, with no gaps or overlay between PDUs. False indicates that iSCSI data PDUs within sequences may be in any order." , required = true)
	@XmlElement(required = true)
	private boolean dataPduInOrder;

	/** @return True indicates that data PDUs within sequences must be at continuously increasing addresses, with no gaps or overlay between PDUs. False indicates that iSCSI data PDUs within sequences may be in any order. */
	public boolean isDataPduInOrder() {
		return this.dataPduInOrder;
	}
	/** @param x True indicates that data PDUs within sequences must be at continuously increasing addresses, with no gaps or overlay between PDUs. False indicates that iSCSI data PDUs within sequences may be in any order. */
	public void setDataPduInOrder(boolean x) {
		this.dataPduInOrder = x;
	}

	/** The level of error recovery negotiated between the initiator and the target. */
	@io.swagger.annotations.ApiModelProperty(value ="The level of error recovery negotiated between the initiator and the target." , required = true)
	@XmlElement(required = true)
	private int errorRecoveryLevel;

	/** @return The level of error recovery negotiated between the initiator and the target. */
	public int getErrorRecoveryLevel() {
		return this.errorRecoveryLevel;
	}
	/** @param x The level of error recovery negotiated between the initiator and the target. */
	public void setErrorRecoveryLevel(int x) {
		this.errorRecoveryLevel = x;
	}

	/** The maximum number of connections allowed in this session. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum number of connections allowed in this session." , required = true)
	@XmlElement(required = true)
	private int maxConnectionsPerSession;

	/** @return The maximum number of connections allowed in this session. */
	public int getMaxConnectionsPerSession() {
		return this.maxConnectionsPerSession;
	}
	/** @param x The maximum number of connections allowed in this session. */
	public void setMaxConnectionsPerSession(int x) {
		this.maxConnectionsPerSession = x;
	}

	/** The minimum time, in seconds, to wait before attempting an explicit/implicit logout or active iSCSI task reassignment after an unexpected connection termination or a connection reset. */
	@io.swagger.annotations.ApiModelProperty(value ="The minimum time, in seconds, to wait before attempting an explicit/implicit logout or active iSCSI task reassignment after an unexpected connection termination or a connection reset." , required = true)
	@XmlElement(required = true)
	private int defaultTimeToWait;

	/** @return The minimum time, in seconds, to wait before attempting an explicit/implicit logout or active iSCSI task reassignment after an unexpected connection termination or a connection reset. */
	public int getDefaultTimeToWait() {
		return this.defaultTimeToWait;
	}
	/** @param x The minimum time, in seconds, to wait before attempting an explicit/implicit logout or active iSCSI task reassignment after an unexpected connection termination or a connection reset. */
	public void setDefaultTimeToWait(int x) {
		this.defaultTimeToWait = x;
	}

	/** The maximum time, in seconds after an initial wait, before which an active iSCSI task reassignment is still possible after an unexpected connection. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum time, in seconds after an initial wait, before which an active iSCSI task reassignment is still possible after an unexpected connection." , required = true)
	@XmlElement(required = true)
	private int defaultTimeToRetain;

	/** @return The maximum time, in seconds after an initial wait, before which an active iSCSI task reassignment is still possible after an unexpected connection. */
	public int getDefaultTimeToRetain() {
		return this.defaultTimeToRetain;
	}
	/** @param x The maximum time, in seconds after an initial wait, before which an active iSCSI task reassignment is still possible after an unexpected connection. */
	public void setDefaultTimeToRetain(int x) {
		this.defaultTimeToRetain = x;
	}
}
