package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure describes a pending host that appears to be the same as a host in the configured topology. The data in the structure indicates what differences exist between the pending host and the configured host. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(1162)
public class MatchedPendingHost implements Serializable {
	public MatchedPendingHost() {
	}

	/** A description of the pending host as it was submitted by the host context agent. */
	@io.swagger.annotations.ApiModelProperty(value ="A description of the pending host as it was submitted by the host context agent." , required = true)
	@XmlElement(required = true)
	private PendingHost pendingHost;

	/** @return A description of the pending host as it was submitted by the host context agent. */
	public PendingHost getPendingHost() {
		return this.pendingHost;
	}
	/** @param x A description of the pending host as it was submitted by the host context agent. */
	public void setPendingHost(PendingHost x) {
		this.pendingHost = x;
	}

	/** A reference to the configured host with which the pending host is matched. */
	@io.swagger.annotations.ApiModelProperty(value ="A reference to the configured host with which the pending host is matched." , required = true)
	@XmlElement(required = true)
	private String matchingConfiguredHost;

	/** @return A reference to the configured host with which the pending host is matched. */
	public String getMatchingConfiguredHost() {
		return this.matchingConfiguredHost;
	}
	/** @param x A reference to the configured host with which the pending host is matched. */
	public void setMatchingConfiguredHost(String x) {
		this.matchingConfiguredHost = x;
	}

	/** An indication of the host properties on which the match is based. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of the host properties on which the match is based." , required = true)
	@XmlElement(required = true)
	private PendingHostMatchType matchType = PendingHostMatchType.__UNDEFINED;

	/** @return An indication of the host properties on which the match is based. */
	public PendingHostMatchType getMatchType() {
		return this.matchType;
	}
	/** @param x An indication of the host properties on which the match is based. */
	public void setMatchType(PendingHostMatchType x) {
		this.matchType = x;
	}

	/** True if the name of the pending host is different than the configured host. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the name of the pending host is different than the configured host." , required = true)
	@XmlElement(required = true)
	private boolean hostNameChange;

	/** @return True if the name of the pending host is different than the configured host. */
	public boolean isHostNameChange() {
		return this.hostNameChange;
	}
	/** @param x True if the name of the pending host is different than the configured host. */
	public void setHostNameChange(boolean x) {
		this.hostNameChange = x;
	}

	/** True if the type of the pending host is different than the configured host. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the type of the pending host is different than the configured host." , required = true)
	@XmlElement(required = true)
	private boolean hostTypeChange;

	/** @return True if the type of the pending host is different than the configured host. */
	public boolean isHostTypeChange() {
		return this.hostTypeChange;
	}
	/** @param x True if the type of the pending host is different than the configured host. */
	public void setHostTypeChange(boolean x) {
		this.hostTypeChange = x;
	}

	/** yet been created in the configured topology. */
	@io.swagger.annotations.ApiModelProperty(value ="yet been created in the configured topology." , required = true)
	@XmlElement(required = true)
	private SCSIInitiatorPortId[] unconfiguredPorts;

	/** @return yet been created in the configured topology. */
	public SCSIInitiatorPortId[] getUnconfiguredPorts() {
		return this.unconfiguredPorts;
	}
	/** @param x yet been created in the configured topology. */
	public void setUnconfiguredPorts(SCSIInitiatorPortId[] x) {
		this.unconfiguredPorts = x;
	}

	/** A list of HostPortRef structures representing configured ports that are common between this pending host and the configured host identified by the matchingConfiguredHost field. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of HostPortRef structures representing configured ports that are common between this pending host and the configured host identified by the matchingConfiguredHost field." , required = true)
	@XmlElement(required = true)
	private String[] matchingPorts;

	/** @return A list of HostPortRef structures representing configured ports that are common between this pending host and the configured host identified by the matchingConfiguredHost field. */
	public String[] getMatchingPorts() {
		return this.matchingPorts;
	}
	/** @param x A list of HostPortRef structures representing configured ports that are common between this pending host and the configured host identified by the matchingConfiguredHost field. */
	public void setMatchingPorts(String[] x) {
		this.matchingPorts = x;
	}

	/** A list of HostPortRef structures representing configured ports belonging to the pending host that conflict with ports in the configured topology. The definition of a port conflict for a matched pending host is any port belonging to the pending host that (1) is not identified in matchingPorts and (2) matches a port in the configured topology. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of HostPortRef structures representing configured ports belonging to the pending host that conflict with ports in the configured topology. The definition of a port conflict for a matched pending host is any port belonging to the pending host that (1) is not identified in matchingPorts and (2) matches a port in the configured topology." , required = true)
	@XmlElement(required = true)
	private String[] conflictingPorts;

	/** @return A list of HostPortRef structures representing configured ports belonging to the pending host that conflict with ports in the configured topology. The definition of a port conflict for a matched pending host is any port belonging to the pending host that (1) is not identified in matchingPorts and (2) matches a port in the configured topology. */
	public String[] getConflictingPorts() {
		return this.conflictingPorts;
	}
	/** @param x A list of HostPortRef structures representing configured ports belonging to the pending host that conflict with ports in the configured topology. The definition of a port conflict for a matched pending host is any port belonging to the pending host that (1) is not identified in matchingPorts and (2) matches a port in the configured topology. */
	public void setConflictingPorts(String[] x) {
		this.conflictingPorts = x;
	}

	/** A list of HostPortRef structures representing configured ports belonging to the host identified by matchingConfiguredHost, which are not present in the pending host ports. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of HostPortRef structures representing configured ports belonging to the host identified by matchingConfiguredHost, which are not present in the pending host ports." , required = true)
	@XmlElement(required = true)
	private String[] missingPorts;

	/** @return A list of HostPortRef structures representing configured ports belonging to the host identified by matchingConfiguredHost, which are not present in the pending host ports. */
	public String[] getMissingPorts() {
		return this.missingPorts;
	}
	/** @param x A list of HostPortRef structures representing configured ports belonging to the host identified by matchingConfiguredHost, which are not present in the pending host ports. */
	public void setMissingPorts(String[] x) {
		this.missingPorts = x;
	}

	/** A list of ScsiNodeRef elements representing configured initiators that are common between this pending host and the configured host identified by the matchingConfiguredHost field. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of ScsiNodeRef elements representing configured initiators that are common between this pending host and the configured host identified by the matchingConfiguredHost field." , required = true)
	@XmlElement(required = true)
	private String[] matchingInitiators;

	/** @return A list of ScsiNodeRef elements representing configured initiators that are common between this pending host and the configured host identified by the matchingConfiguredHost field. */
	public String[] getMatchingInitiators() {
		return this.matchingInitiators;
	}
	/** @param x A list of ScsiNodeRef elements representing configured initiators that are common between this pending host and the configured host identified by the matchingConfiguredHost field. */
	public void setMatchingInitiators(String[] x) {
		this.matchingInitiators = x;
	}

	/** A list of ScsiNodeRef elements representing configured initiators belonging to the pending host that conflict with ports or initiators in the configured topology. The definition of an initiator conflict for a matched pending host is any initiator belonging to the pending host that (1) is not identified in matching Initiators and (2) matches an initiator in the configured topology. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of ScsiNodeRef elements representing configured initiators belonging to the pending host that conflict with ports or initiators in the configured topology. The definition of an initiator conflict for a matched pending host is any initiator belonging to the pending host that (1) is not identified in matching Initiators and (2) matches an initiator in the configured topology." , required = true)
	@XmlElement(required = true)
	private String[] conflictingInitiators;

	/** @return A list of ScsiNodeRef elements representing configured initiators belonging to the pending host that conflict with ports or initiators in the configured topology. The definition of an initiator conflict for a matched pending host is any initiator belonging to the pending host that (1) is not identified in matching Initiators and (2) matches an initiator in the configured topology. */
	public String[] getConflictingInitiators() {
		return this.conflictingInitiators;
	}
	/** @param x A list of ScsiNodeRef elements representing configured initiators belonging to the pending host that conflict with ports or initiators in the configured topology. The definition of an initiator conflict for a matched pending host is any initiator belonging to the pending host that (1) is not identified in matching Initiators and (2) matches an initiator in the configured topology. */
	public void setConflictingInitiators(String[] x) {
		this.conflictingInitiators = x;
	}

	/** A list of ScsiNodeRef elements representing configured initiators belonging to the host identified by matchingConfiguredHost, which are not present in the pending host initiators. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of ScsiNodeRef elements representing configured initiators belonging to the host identified by matchingConfiguredHost, which are not present in the pending host initiators." , required = true)
	@XmlElement(required = true)
	private String[] missingInitiators;

	/** @return A list of ScsiNodeRef elements representing configured initiators belonging to the host identified by matchingConfiguredHost, which are not present in the pending host initiators. */
	public String[] getMissingInitiators() {
		return this.missingInitiators;
	}
	/** @param x A list of ScsiNodeRef elements representing configured initiators belonging to the host identified by matchingConfiguredHost, which are not present in the pending host initiators. */
	public void setMissingInitiators(String[] x) {
		this.missingInitiators = x;
	}
}
