package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used to return information associated with a particular MEL entry. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(1139)
public class MelEntry implements Serializable {
	public MelEntry() {
	}

	/** The sequence number of the MEL entry. The controller maintains a unique, monotonically increasing 64-bit sequence number value and stamps each MEL entry with the next value of this counter. */
	@io.swagger.annotations.ApiModelProperty(value ="The sequence number of the MEL entry. The controller maintains a unique, monotonically increasing 64-bit sequence number value and stamps each MEL entry with the next value of this counter." , required = true)
	@XmlElement(required = true)
	private long sequenceNumber;

	/** @return The sequence number of the MEL entry. The controller maintains a unique, monotonically increasing 64-bit sequence number value and stamps each MEL entry with the next value of this counter. */
	public long getSequenceNumber() {
		return this.sequenceNumber;
	}
	/** @param x The sequence number of the MEL entry. The controller maintains a unique, monotonically increasing 64-bit sequence number value and stamps each MEL entry with the next value of this counter. */
	public void setSequenceNumber(long x) {
		this.sequenceNumber = x;
	}

	/** An integer value that indicates the specific type of event being reported. */
	@io.swagger.annotations.ApiModelProperty(value ="An integer value that indicates the specific type of event being reported." , required = true)
	@XmlElement(required = true)
	private int eventType;

	/** @return An integer value that indicates the specific type of event being reported. */
	public int getEventType() {
		return this.eventType;
	}
	/** @param x An integer value that indicates the specific type of event being reported. */
	public void setEventType(int x) {
		this.eventType = x;
	}

	/** The time at which the MEL entry was generated. This value is defined in terms of the number of seconds since midnight GMT on January 1, 1970. */
	@io.swagger.annotations.ApiModelProperty(value ="The time at which the MEL entry was generated. This value is defined in terms of the number of seconds since midnight GMT on January 1, 1970." , required = true)
	@XmlElement(required = true)
	private long timeStamp;

	/** @return The time at which the MEL entry was generated. This value is defined in terms of the number of seconds since midnight GMT on January 1, 1970. */
	public long getTimeStamp() {
		return this.timeStamp;
	}
	/** @param x The time at which the MEL entry was generated. This value is defined in terms of the number of seconds since midnight GMT on January 1, 1970. */
	public void setTimeStamp(long x) {
		this.timeStamp = x;
	}

	/** The category into which this event falls. This value identifies the general type of activity or event that occurred and caused the entry to be generated. */
	@io.swagger.annotations.ApiModelProperty(value ="The category into which this event falls. This value identifies the general type of activity or event that occurred and caused the entry to be generated." , required = true)
	@XmlElement(required = true)
	private EventCategory category = EventCategory.__UNDEFINED;

	/** @return The category into which this event falls. This value identifies the general type of activity or event that occurred and caused the entry to be generated. */
	public EventCategory getCategory() {
		return this.category;
	}
	/** @param x The category into which this event falls. This value identifies the general type of activity or event that occurred and caused the entry to be generated. */
	public void setCategory(EventCategory x) {
		this.category = x;
	}

	/** The type of component that is associated with this entry. */
	@io.swagger.annotations.ApiModelProperty(value ="The type of component that is associated with this entry." , required = true)
	@XmlElement(required = true)
	private EventComponentType componentType = EventComponentType.__UNDEFINED;

	/** @return The type of component that is associated with this entry. */
	public EventComponentType getComponentType() {
		return this.componentType;
	}
	/** @param x The type of component that is associated with this entry. */
	public void setComponentType(EventComponentType x) {
		this.componentType = x;
	}

	/** The location, or other identifying value, of the component associated with this entry. */
	@io.swagger.annotations.ApiModelProperty(value ="The location, or other identifying value, of the component associated with this entry." , required = true)
	@XmlElement(required = true)
	private ComponentLocation componentLocation;

	/** @return The location, or other identifying value, of the component associated with this entry. */
	public ComponentLocation getComponentLocation() {
		return this.componentLocation;
	}
	/** @param x The location, or other identifying value, of the component associated with this entry. */
	public void setComponentLocation(ComponentLocation x) {
		this.componentLocation = x;
	}

	/** A true/false indication of whether the ComponentLocation field is valid for this entry. */
	@io.swagger.annotations.ApiModelProperty(value ="A true/false indication of whether the ComponentLocation field is valid for this entry." , required = true)
	@XmlElement(required = true)
	private boolean locationValid;

	/** @return A true/false indication of whether the ComponentLocation field is valid for this entry. */
	public boolean isLocationValid() {
		return this.locationValid;
	}
	/** @param x A true/false indication of whether the ComponentLocation field is valid for this entry. */
	public void setLocationValid(boolean x) {
		this.locationValid = x;
	}

	/** The priority code associated with this event. */
	@io.swagger.annotations.ApiModelProperty(value ="The priority code associated with this event." , required = true)
	@XmlElement(required = true)
	private EventPriority priority = EventPriority.__UNDEFINED;

	/** @return The priority code associated with this event. */
	public EventPriority getPriority() {
		return this.priority;
	}
	/** @param x The priority code associated with this event. */
	public void setPriority(EventPriority x) {
		this.priority = x;
	}

	/** The controller that is the source of the event (Controller 1 or 2). */
	@io.swagger.annotations.ApiModelProperty(value ="The controller that is the source of the event (Controller 1 or 2)." , required = true)
	@XmlElement(required = true)
	private int eventSourceController;

	/** @return The controller that is the source of the event (Controller 1 or 2). */
	public int getEventSourceController() {
		return this.eventSourceController;
	}
	/** @param x The controller that is the source of the event (Controller 1 or 2). */
	public void setEventSourceController(int x) {
		this.eventSourceController = x;
	}

	/** The Additional Sense Code value associated with this event. */
	@io.swagger.annotations.ApiModelProperty(value ="The Additional Sense Code value associated with this event." , required = true)
	@XmlElement(required = true)
	private int ASC;

	/** @return The Additional Sense Code value associated with this event. */
	public int getASC() {
		return this.ASC;
	}
	/** @param x The Additional Sense Code value associated with this event. */
	public void setASC(int x) {
		this.ASC = x;
	}

	/** The Additional Sense Code Qualifier associated with this event. */
	@io.swagger.annotations.ApiModelProperty(value ="The Additional Sense Code Qualifier associated with this event." , required = true)
	@XmlElement(required = true)
	private int ASCQ;

	/** @return The Additional Sense Code Qualifier associated with this event. */
	public int getASCQ() {
		return this.ASCQ;
	}
	/** @param x The Additional Sense Code Qualifier associated with this event. */
	public void setASCQ(int x) {
		this.ASCQ = x;
	}

	/** The Sense Key value associated with this event, or zero if no key is applicable. */
	@io.swagger.annotations.ApiModelProperty(value ="The Sense Key value associated with this event, or zero if no key is applicable." , required = true)
	@XmlElement(required = true)
	private int senseKey;

	/** @return The Sense Key value associated with this event, or zero if no key is applicable. */
	public int getSenseKey() {
		return this.senseKey;
	}
	/** @param x The Sense Key value associated with this event, or zero if no key is applicable. */
	public void setSenseKey(int x) {
		this.senseKey = x;
	}

	/** The raw data stored for this event. This information may be useful for debugging or troubleshooting problems with the assistance of a field support or development representative. */
	@io.swagger.annotations.ApiModelProperty(value ="The raw data stored for this event. This information may be useful for debugging or troubleshooting problems with the assistance of a field support or development representative." , required = true)
	@XmlElement(required = true)
	private String rawData;

	/** @return The raw data stored for this event. This information may be useful for debugging or troubleshooting problems with the assistance of a field support or development representative. */
	public String getRawData() {
		return this.rawData;
	}
	/** @param x The raw data stored for this event. This information may be useful for debugging or troubleshooting problems with the assistance of a field support or development representative. */
	public void setRawData(String x) {
		this.rawData = x;
	}

	/** Extended component location information for this entry. This data type of this field is a union with discriminator extLocType. If the discriminator is set to something other than EXT_COMP_LOCTYPE_UNKNOWN, then the location information in this field overrides what is in the componentLocation field. */
	@io.swagger.annotations.ApiModelProperty(value ="Extended component location information for this entry. This data type of this field is a union with discriminator extLocType. If the discriminator is set to something other than EXT_COMP_LOCTYPE_UNKNOWN, then the location information in this field overrides what is in the componentLocation field." , required = true)
	@XmlElement(required = true)
	private ExtendedComponentLocation extComponentLocation;

	/** @return Extended component location information for this entry. This data type of this field is a union with discriminator extLocType. If the discriminator is set to something other than EXT_COMP_LOCTYPE_UNKNOWN, then the location information in this field overrides what is in the componentLocation field. */
	public ExtendedComponentLocation getExtComponentLocation() {
		return this.extComponentLocation;
	}
	/** @param x Extended component location information for this entry. This data type of this field is a union with discriminator extLocType. If the discriminator is set to something other than EXT_COMP_LOCTYPE_UNKNOWN, then the location information in this field overrides what is in the componentLocation field. */
	public void setExtComponentLocation(ExtendedComponentLocation x) {
		this.extComponentLocation = x;
	}

	/** This field allows customized control over the handling of MEL events. */
	@io.swagger.annotations.ApiModelProperty(value ="This field allows customized control over the handling of MEL events." , required = true)
	@XmlElement(required = true)
	private EventControl controlParams;

	/** @return This field allows customized control over the handling of MEL events. */
	public EventControl getControlParams() {
		return this.controlParams;
	}
	/** @param x This field allows customized control over the handling of MEL events. */
	public void setControlParams(EventControl x) {
		this.controlParams = x;
	}
}
