package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure contains information about a PiT Group. If the PITGroup is part of a consistency group, some of the attributes (noted below) will actually be controlled by the consistency group itself and the fields in the PITGroup will reflect the consistency group settings. NOTE: A PiT group may have a schedule associated with it. In that case, the targetObject field in the ScheduleInstance object will contain the PitGroupRef. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(995)
public class PITGroup implements Serializable,devmgr.api.model.Identifiable,devmgr.api.model.Named {
	public PITGroup() {
	}

	/** The reference (key) for the PiT Group. */
	@io.swagger.annotations.ApiModelProperty(value ="The reference (key) for the PiT Group." , required = true)
	@XmlElement(required = true)
	private String pitGroupRef;

	/** @return The reference (key) for the PiT Group. */
	public String getPitGroupRef() {
		return this.pitGroupRef;
	}
	/** @param x The reference (key) for the PiT Group. */
	public void setPitGroupRef(String x) {
		this.pitGroupRef = x;
	}

	/** The name of the PiT Group. If this PiT group is part of a consistency group, then this label does not have to be present or unique as the parent consistency group label will be used. */
	@io.swagger.annotations.ApiModelProperty(value ="The name of the PiT Group. If this PiT group is part of a consistency group, then this label does not have to be present or unique as the parent consistency group label will be used." , required = true)
	@XmlElement(required = true)
	private String label;

	/** @return The name of the PiT Group. If this PiT group is part of a consistency group, then this label does not have to be present or unique as the parent consistency group label will be used. */
	public String getLabel() {
		return this.label;
	}
	/** @param x The name of the PiT Group. If this PiT group is part of a consistency group, then this label does not have to be present or unique as the parent consistency group label will be used. */
	public void setLabel(String x) {
		this.label = x;
	}

	/** The status of the PiT Group. */
	@io.swagger.annotations.ApiModelProperty(value ="The status of the PiT Group." , required = true)
	@XmlElement(required = true)
	private PITGroupStatus status = PITGroupStatus.__UNDEFINED;

	/** @return The status of the PiT Group. */
	public PITGroupStatus getStatus() {
		return this.status;
	}
	/** @param x The status of the PiT Group. */
	public void setStatus(PITGroupStatus x) {
		this.status = x;
	}

	/** The base volume for this PiT Group. */
	@io.swagger.annotations.ApiModelProperty(value ="The base volume for this PiT Group." , required = true)
	@XmlElement(required = true)
	private String baseVolume;

	/** @return The base volume for this PiT Group. */
	public String getBaseVolume() {
		return this.baseVolume;
	}
	/** @param x The base volume for this PiT Group. */
	public void setBaseVolume(String x) {
		this.baseVolume = x;
	}

	/** The copy-on-write (CoW) Repository for this PiT group. */
	@io.swagger.annotations.ApiModelProperty(value ="The copy-on-write (CoW) Repository for this PiT group." , required = true)
	@XmlElement(required = true)
	private String repositoryVolume;

	/** @return The copy-on-write (CoW) Repository for this PiT group. */
	public String getRepositoryVolume() {
		return this.repositoryVolume;
	}
	/** @param x The copy-on-write (CoW) Repository for this PiT group. */
	public void setRepositoryVolume(String x) {
		this.repositoryVolume = x;
	}

	/** The cluster size (in bytes). */
	@io.swagger.annotations.ApiModelProperty(value ="The cluster size (in bytes)." , required = true)
	@XmlElement(required = true)
	private int clusterSize;

	/** @return The cluster size (in bytes). */
	public int getClusterSize() {
		return this.clusterSize;
	}
	/** @param x The cluster size (in bytes). */
	public void setClusterSize(int x) {
		this.clusterSize = x;
	}

	/** The maximum allowable repository size (in bytes) based on current cluster size. Only applicable if there is at least one PiT in the PiT group. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum allowable repository size (in bytes) based on current cluster size. Only applicable if there is at least one PiT in the PiT group." , required = true)
	@XmlElement(required = true)
	private long maxRepositoryCapacity;

	/** @return The maximum allowable repository size (in bytes) based on current cluster size. Only applicable if there is at least one PiT in the PiT group. */
	public long getMaxRepositoryCapacity() {
		return this.maxRepositoryCapacity;
	}
	/** @param x The maximum allowable repository size (in bytes) based on current cluster size. Only applicable if there is at least one PiT in the PiT group. */
	public void setMaxRepositoryCapacity(long x) {
		this.maxRepositoryCapacity = x;
	}

	/** The maximum allowable base volume size (in bytes) based on current cluster size. Only applicable if there is at least one PiT in the PiT group. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum allowable base volume size (in bytes) based on current cluster size. Only applicable if there is at least one PiT in the PiT group." , required = true)
	@XmlElement(required = true)
	private long maxBaseCapacity;

	/** @return The maximum allowable base volume size (in bytes) based on current cluster size. Only applicable if there is at least one PiT in the PiT group. */
	public long getMaxBaseCapacity() {
		return this.maxBaseCapacity;
	}
	/** @param x The maximum allowable base volume size (in bytes) based on current cluster size. Only applicable if there is at least one PiT in the PiT group. */
	public void setMaxBaseCapacity(long x) {
		this.maxBaseCapacity = x;
	}

	/** The amount of repository capacity that is unusable due to limited addressability of the current cluster size. */
	@io.swagger.annotations.ApiModelProperty(value ="The amount of repository capacity that is unusable due to limited addressability of the current cluster size." , required = true)
	@XmlElement(required = true)
	private long unusableRepositoryCapacity;

	/** @return The amount of repository capacity that is unusable due to limited addressability of the current cluster size. */
	public long getUnusableRepositoryCapacity() {
		return this.unusableRepositoryCapacity;
	}
	/** @param x The amount of repository capacity that is unusable due to limited addressability of the current cluster size. */
	public void setUnusableRepositoryCapacity(long x) {
		this.unusableRepositoryCapacity = x;
	}

	/** The behavior on repository full condition. Overridden by consistency group setting if this PITGroup is associated with a consistency group. */
	@io.swagger.annotations.ApiModelProperty(value ="The behavior on repository full condition. Overridden by consistency group setting if this PITGroup is associated with a consistency group." , required = true)
	@XmlElement(required = true)
	private PITRepositoryFullPolicy repFullPolicy = PITRepositoryFullPolicy.__UNDEFINED;

	/** @return The behavior on repository full condition. Overridden by consistency group setting if this PITGroup is associated with a consistency group. */
	public PITRepositoryFullPolicy getRepFullPolicy() {
		return this.repFullPolicy;
	}
	/** @param x The behavior on repository full condition. Overridden by consistency group setting if this PITGroup is associated with a consistency group. */
	public void setRepFullPolicy(PITRepositoryFullPolicy x) {
		this.repFullPolicy = x;
	}

	/** The repository utilization warning threshold percentage. */
	@io.swagger.annotations.ApiModelProperty(value ="The repository utilization warning threshold percentage." , required = true)
	@XmlElement(required = true)
	private int fullWarnThreshold;

	/** @return The repository utilization warning threshold percentage. */
	public int getFullWarnThreshold() {
		return this.fullWarnThreshold;
	}
	/** @param x The repository utilization warning threshold percentage. */
	public void setFullWarnThreshold(int x) {
		this.fullWarnThreshold = x;
	}

	/** The auto-delete indicator. If non-zero, the oldest PiT will be automatically deleted when creating a new one to keep the total number of PiTs limited to the number specified. This value is overridden by the consistency group setting if this PITGroup is associated with a consistency group. */
	@io.swagger.annotations.ApiModelProperty(value ="The auto-delete indicator. If non-zero, the oldest PiT will be automatically deleted when creating a new one to keep the total number of PiTs limited to the number specified. This value is overridden by the consistency group setting if this PITGroup is associated with a consistency group." , required = true)
	@XmlElement(required = true)
	private int autoDeleteLimit;

	/** @return The auto-delete indicator. If non-zero, the oldest PiT will be automatically deleted when creating a new one to keep the total number of PiTs limited to the number specified. This value is overridden by the consistency group setting if this PITGroup is associated with a consistency group. */
	public int getAutoDeleteLimit() {
		return this.autoDeleteLimit;
	}
	/** @param x The auto-delete indicator. If non-zero, the oldest PiT will be automatically deleted when creating a new one to keep the total number of PiTs limited to the number specified. This value is overridden by the consistency group setting if this PITGroup is associated with a consistency group. */
	public void setAutoDeleteLimit(int x) {
		this.autoDeleteLimit = x;
	}

	/** Long running operation. */
	@io.swagger.annotations.ApiModelProperty(value ="Long running operation." , required = true)
	@XmlElement(required = true)
	private VolumeAction action = VolumeAction.__UNDEFINED;

	/** @return Long running operation. */
	public VolumeAction getAction() {
		return this.action;
	}
	/** @param x Long running operation. */
	public void setAction(VolumeAction x) {
		this.action = x;
	}

	/** The status of the rollback (if rollback is indicated in VolumeAction above). */
	@io.swagger.annotations.ApiModelProperty(value ="The status of the rollback (if rollback is indicated in VolumeAction above)." , required = true)
	@XmlElement(required = true)
	private PITRollbackStatus rollbackStatus = PITRollbackStatus.__UNDEFINED;

	/** @return The status of the rollback (if rollback is indicated in VolumeAction above). */
	public PITRollbackStatus getRollbackStatus() {
		return this.rollbackStatus;
	}
	/** @param x The status of the rollback (if rollback is indicated in VolumeAction above). */
	public void setRollbackStatus(PITRollbackStatus x) {
		this.rollbackStatus = x;
	}

	/** The importance of the rollback operation. */
	@io.swagger.annotations.ApiModelProperty(value ="The importance of the rollback operation." , required = true)
	@XmlElement(required = true)
	private RollbackPriority rollbackPriority = RollbackPriority.__UNDEFINED;

	/** @return The importance of the rollback operation. */
	public RollbackPriority getRollbackPriority() {
		return this.rollbackPriority;
	}
	/** @param x The importance of the rollback operation. */
	public void setRollbackPriority(RollbackPriority x) {
		this.rollbackPriority = x;
	}

	/** If true, this PiT group is part of a consistency group. */
	@io.swagger.annotations.ApiModelProperty(value ="If true, this PiT group is part of a consistency group." , required = true)
	@XmlElement(required = true)
	private boolean consistencyGroup;

	/** @return If true, this PiT group is part of a consistency group. */
	public boolean isConsistencyGroup() {
		return this.consistencyGroup;
	}
	/** @param x If true, this PiT group is part of a consistency group. */
	public void setConsistencyGroup(boolean x) {
		this.consistencyGroup = x;
	}

	/** A reference to the parent consistency group, if applicable. This value will be NULL if this PiT group is not part of a consistency group. */
	@io.swagger.annotations.ApiModelProperty(value ="A reference to the parent consistency group, if applicable. This value will be NULL if this PiT group is not part of a consistency group." , required = true)
	@XmlElement(required = true)
	private String consistencyGroupRef;

	/** @return A reference to the parent consistency group, if applicable. This value will be NULL if this PiT group is not part of a consistency group. */
	public String getConsistencyGroupRef() {
		return this.consistencyGroupRef;
	}
	/** @param x A reference to the parent consistency group, if applicable. This value will be NULL if this PiT group is not part of a consistency group. */
	public void setConsistencyGroupRef(String x) {
		this.consistencyGroupRef = x;
	}

	/** The status of Pending PiT Creation. */
	@io.swagger.annotations.ApiModelProperty(value ="The status of Pending PiT Creation." , required = true)
	@XmlElement(required = true)
	private PITCreationPendingStatus creationPendingStatus = PITCreationPendingStatus.__UNDEFINED;

	/** @return The status of Pending PiT Creation. */
	public PITCreationPendingStatus getCreationPendingStatus() {
		return this.creationPendingStatus;
	}
	/** @param x The status of Pending PiT Creation. */
	public void setCreationPendingStatus(PITCreationPendingStatus x) {
		this.creationPendingStatus = x;
	}

	/** The PiT group SSID. This is provided primarily for debug purposes. */
	@io.swagger.annotations.ApiModelProperty(value ="The PiT group SSID. This is provided primarily for debug purposes." , required = true)
	@XmlElement(required = true)
	private int volumeHandle;

	/** @return The PiT group SSID. This is provided primarily for debug purposes. */
	public int getVolumeHandle() {
		return this.volumeHandle;
	}
	/** @param x The PiT group SSID. This is provided primarily for debug purposes. */
	public void setVolumeHandle(int x) {
		this.volumeHandle = x;
	}
	@Override
	public String getId(){
		return pitGroupRef;
	}
	@Override
	public String getName(){
		return label;
	}
}
