package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration object is used to describe the physical interface of the drive. This is not necessarily the same as the I/O protocol interface used by the controller to communicate with the drive (DriveType). In addition, the supportedDriveTypes array in the FeatureParams structure will contain values from this enumeration identifying which drive types are supported on the storage array. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(21)
public enum PhysicalDriveType implements Serializable {
		/** All drive types, for volume candidates. */
		all(0),
		/** SCSI drive type. */
		scsi(1),
		/** Fibre Channel drive type. */
		fibre(2),
		/** Serial ATA drive type. */
		sata(3),
		/** Parallel ATA drive type. */
		pata(4),
		/** Fibre Channel drive type with 520-byte sectors for data availability protection */
		fibre520b(5),
		/** Serial-attached SCSI drive type. */
		sas(6),
		/** The physical drive type is unknown (e.g., as in the case where the drive is dual-bypassed). */
		unknown(7),
		/** The physical drive type is a serial-attached SCSI drive where the drive has a logical sector size of 4KB. */
		sas4k(8),
		__UNDEFINED(464378545);

		public final int value;

		private PhysicalDriveType(int v) {
			this.value = v;
		}
}
