package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration object is used to represent the product capabilities supported by the RAID controller firmware. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(191)
public enum ProductCapability implements Serializable {
		/** The array has no capabilities. */
		capabilityNone(0),
		/** Cache backup is supported. */
		capabilityCacheBackup(1),
		/** Core iSCSI is supported. */
		capabilityCoreIscsi(2),
		/** DAP 520B is supported. */
		capabilityDap520b(3),
		/** Dual-ported SATA is supported. */
		capabilityDualPortedSata(4),
		/** FDE is supported. */
		capabilityFdeDriveSupport(5),
		/** Field replaceable cache memory is supported */
		capabilityFieldRepCacheMem(6),
		/** Gb Ethernet management port is supported. */
		capabilityGbEthMgmtPort(7),
		/** Infiniband is supported. */
		capabilityInfinibandSupport(8),
		/** IPV6 management port is supported. */
		capabilityIpv6MgmtPortIpv6(9),
		/** iSCSI IPV6 is supported. */
		capabilityIscsiIpv6(10),
		/** SAS is supported. */
		capabilitySasSupport(11),
		/** Simplex controller. */
		capabilitySimplex(12),
		/** Smart battery management is supported. */
		capabilitySmartBatteryMgmt(13),
		/** Caliber 6141 is supported. */
		capabilityCal6141(14),
		/** Caliber 6334 is supported. */
		capabilityCal6334(15),
		/** Configure database adoption is supported. */
		capabilityCfgDbAdoption(16),
		/** Controller lockdown is supported. */
		capabilityCtrlLockdown(17),
		/** Controller state capture is supported. */
		capabilityCtrlStateCapture(18),
		/** Diagnostic data capture is supported. */
		capabilityDiagDataCapture(19),
		/** Drive data relocation is supported. */
		capabilityDriveDataRelocation(20),
		/** Drive enclosure miswires is supported. */
		capabilityDriveEnclosureMiswires(21),
		/** Drive management is supported. */
		capabilityDriveMgmt(22),
		/** Mixed drives within a tray are supported. */
		capabilityDriveMixWithinTray(23),
		/** Drive channel diagnostics are supported. */
		capabilityDrvChannelDiags(24),
		/** Feature bundles are supported. */
		capabilityFeatureBundles(25),
		/** Host context agent is supported. */
		capabilityHostContextAgent(26),
		/** Immediate host topology is supported. */
		capabilityImmediateHostTopology(27),
		/** Online drive firmware download is supported. */
		capabilityOnlineDrvFwDwnld(28),
		/** Parent relative location is supported. */
		capabilityParentRelativeLocation(29),
		/** Parent relative status is supported. */
		capabilityParentRelativeStatus(30),
		/** Pompano is supported. */
		capabilityPompanoSupport(31),
		/** RAID 6 is supported. */
		capabilityRaid6(32),
		/** SOC statistics are supported. */
		capabilitySocStatistics(33),
		/** Virtualization is supported. */
		capabilitySupportsVirtualization(34),
		/** T10 Protection Information is supported. */
		capabilityT10(35),
		/** Infusion is supported. */
		capabilityInfusion(36),
		/** Drive limit management is supported. */
		capabilityDriveLimitManagement(37),
		/** SFP Plus is supported. */
		capabilitySfpPlus(38),
		/** iSCSI 10 Gb host card is supported. */
		capabilityIscsi10gbHostCard(39),
		/** Enhanced LUN 0 is supported. */
		capabilityEnhancedLun0Support(40),
		/** Enhanced format unit is supported. */
		capabilityEnhancedFormatUnitSupport(41),
		/** Drive side trunking is supported. */
		capabilityDriveSideTrunkSupport(42),
		/** Solid state disks are supported. */
		capabilitySsdSupport(43),
		/** The base controller diagnostics feature is supported. */
		capabilityBaseControllerDiags(44),
		/** The cache memory diagnostics feature is supported. */
		capabilityCacheMemoryDiags(45),
		/** The drive slot limit feature is supported. */
		capabilityDriveSlotLimit(46),
		/** The FDE proxy key management feature is supported. */
		capabilityFdeProxyKeyMgmt(47),
		/** The iOS feature is supported. */
		capabilityIosSupport(48),
		/** The Lockout 2TB Drives feature is supported. */
		capabilityLockout2tbDrives(49),
		/** The parent relative MEL component location reporting feature is supported. */
		capabilityParentRelativeMel(50),
		/** The RAID 6 pre-read redundancy check feature is supported. */
		capabilityRaid6PrereadRedCheck(51),
		/** The SATA drive lockout feature is supported. */
		capabilitySataDriveLockout(52),
		/** The Sys Log Messages feature is supported. */
		capabilitySyslogMsgs(53),
		/** The Wembley enclosure is supported. */
		capabilityWembleyEnclosure(54),
		/** The Cache Backup Device Diagnostics feature is supported. */
		capabilityCacheBackupDeviceDiags(55),
		/** The HIC Diagnostics feature is supported. */
		capabilityHicDiags(56),
		/** The enclosure is a Camden/Ebbets or a Mercury Devil enclosure. */
		capabilitySetTrayAttributes(57),
		/** The array supports iSCSI Target Mode. */
		capabilityIscsiTarget(58),
		/** The array supports iSCSI MultiMirror. */
		capabilityIscsiInitiator(59),
		/** The Power Supply Firmware Update capability is supported. */
		capabilityPsuFirmwareUpdate(60),
		/** DPL Core Dump capability is supported. */
		capabilityDplCoreDump(61),
		/** Disk Pools are supported. */
		capabilityDiskPools(62),
		/** The Autosupport feature is supported. */
		capabilityAsupSupport(63),
		/** The Embedded SNMP Agent is supported. */
		capabilityEmbeddedSnmpAgent(64),
		/** The FTDC trace history feature is supported. */
		capabilityFtdcTraceHistory(65),
		/** Generic advanced format drive support is provided including support for 512e drives. */
		capabilityAdvancedFormatSupport(66),
		/** Support for 4Kn drives is provided in addition to generic support. */
		capability4knativeAdvancedFormatSupport(67),
		/** The Autosupport On Demand feature is supported. */
		capabilityAsupOnDemandSupport(68),
		/** IOC Dump capability is supported. */
		capabilityIocDump(69),
		/** The drive power cycle feature is supported. */
		capabilityDrivePowerCycle(70),
		/** The low and high resolution statistical sampling is supported. */
		capabilityLowAndHighSampling(71),
		/** This array supports the auto load balancing capability. */
		capabilityAutoLoadBalancing(72),
		/** This enumeration value is present if the array supports the WLC Improvements feature. */
		capabilityWlcLogging(73),
		/** This product capability is in the Product Capabilities list if the CFW supports FIPS drives */
		capabilityFipsDriveSupport(75),
		/** When set, this indicates the CFW supports persisting application awareness data. */
		capabilityApplicationAwareness(76),
		/** This array supports the embedded external key management feature. */
		capabilityEmbeddedEkms(77),
		/** Checking protection information during cache mirroring is supported. */
		capabilityCacheMirroringProtectionInformation(78),
		__UNDEFINED(464378545);

		public final int value;

		private ProductCapability(int v) {
			this.value = v;
		}
}
