package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration defines the Storage Array attributes. It is used to fill in the "attribute" part of the attribute-value pairs in the arrayAttributes field of the SAData structure. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(16)
public enum SAAttributeID implements Serializable {
		/** Unused. */
		unused(0),
		/** The following values should be used to specify the OEM in the SAData arrayAttributes key/value pair: 0 = Generic/Catera OEM 1 = Apollo OEM 2 = Accent OEM 3 = Mercury OEM 4 = NetApp OEM This must only be visible in the Internal Master spec.. */
		oemSpecificArrayType(1),
		/** The attribute indicates the type of management applications allowed for this array. Values for the attribute are specified by the MgmtApplicationType enumeration. */
		mgmtApplicationType(2),
		/** The attribute indicates whether or not the array is locked down. The value of the attribute is set to 1 if a controller in the array is locked down, otherwise the value is set to 0. */
		controllerLockedDown(3),
		/** The attribute indicates whether or not the database is recovery mode. The value of the attribute is set to 1 if the database is in recovery mode, otherwise the value is set to 0. */
		databaseRecoveryMode(4),
		/** This attribute key is added to the attribute list and the value is set to 1 (TRUE) if the controller is currently operating in T10 PI Analysis Lockdown mode. */
		t10PiAnalysisLockdown(5),
		/** Designates an array running vEOS. */
		veosArray(6),
		/** This indicates that the controller is able to accept message authentication using SHA256 message authentication code in messages with the auth flavor set to SYMBOL_AUTH_HMAC256. */
		symbolAuthHmac256Support(7),
		__UNDEFINED(464378545);

		public final int value;

		private SAAttributeID(int v) {
			this.value = v;
		}
}
