package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure provides information about caching parameters that are maintained for the storage array as a whole, as opposed to per-volume caching parameters. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(445)
public class SACache implements Serializable {
	public SACache() {
	}

	/** The characteristic size, in bytes, of a cache block. */
	@io.swagger.annotations.ApiModelProperty(value ="The characteristic size, in bytes, of a cache block." , required = true)
	@XmlElement(required = true)
	private int cacheBlkSize;

	/** @return The characteristic size, in bytes, of a cache block. */
	public int getCacheBlkSize() {
		return this.cacheBlkSize;
	}
	/** @param x The characteristic size, in bytes, of a cache block. */
	public void setCacheBlkSize(int x) {
		this.cacheBlkSize = x;
	}

	/** Specifies the amount of cache data that will be flushed to disk when a cache flush operation is initiated. This value is specified as an integer in the range 0-100 that represents the percentage of the controller's write cache data that can remain in the "dirty", or unflushed state. When demand flush operations are started, data will be flushed from cache to disk until the overall amount of dirty data drops to or below the percentage specified by this value. */
	@io.swagger.annotations.ApiModelProperty(value ="Specifies the amount of cache data that will be flushed to disk when a cache flush operation is initiated. This value is specified as an integer in the range 0-100 that represents the percentage of the controller's write cache data that can remain in the \"dirty\", or unflushed state. When demand flush operations are started, data will be flushed from cache to disk until the overall amount of dirty data drops to or below the percentage specified by this value." , required = true)
	@XmlElement(required = true)
	private int demandFlushAmount;

	/** @return Specifies the amount of cache data that will be flushed to disk when a cache flush operation is initiated. This value is specified as an integer in the range 0-100 that represents the percentage of the controller's write cache data that can remain in the "dirty", or unflushed state. When demand flush operations are started, data will be flushed from cache to disk until the overall amount of dirty data drops to or below the percentage specified by this value. */
	public int getDemandFlushAmount() {
		return this.demandFlushAmount;
	}
	/** @param x Specifies the amount of cache data that will be flushed to disk when a cache flush operation is initiated. This value is specified as an integer in the range 0-100 that represents the percentage of the controller's write cache data that can remain in the "dirty", or unflushed state. When demand flush operations are started, data will be flushed from cache to disk until the overall amount of dirty data drops to or below the percentage specified by this value. */
	public void setDemandFlushAmount(int x) {
		this.demandFlushAmount = x;
	}

	/** Specifies the "level of fullness" of "dirty" data in the controller's write cache which, when reached, will cause the controller to begin flushing data from cache to disk. This value is specified as a percentage, in the range 0-100, of the overall write cache capacity of the controller. After flushing begins, it will continue until enough data has been flushed to drop the percentage of dirty data to or below the value specified in the demandFlushAmount parameter described above. */
	@io.swagger.annotations.ApiModelProperty(value ="Specifies the \"level of fullness\" of \"dirty\" data in the controller's write cache which, when reached, will cause the controller to begin flushing data from cache to disk. This value is specified as a percentage, in the range 0-100, of the overall write cache capacity of the controller. After flushing begins, it will continue until enough data has been flushed to drop the percentage of dirty data to or below the value specified in the demandFlushAmount parameter described above." , required = true)
	@XmlElement(required = true)
	private int demandFlushThreshold;

	/** @return Specifies the "level of fullness" of "dirty" data in the controller's write cache which, when reached, will cause the controller to begin flushing data from cache to disk. This value is specified as a percentage, in the range 0-100, of the overall write cache capacity of the controller. After flushing begins, it will continue until enough data has been flushed to drop the percentage of dirty data to or below the value specified in the demandFlushAmount parameter described above. */
	public int getDemandFlushThreshold() {
		return this.demandFlushThreshold;
	}
	/** @param x Specifies the "level of fullness" of "dirty" data in the controller's write cache which, when reached, will cause the controller to begin flushing data from cache to disk. This value is specified as a percentage, in the range 0-100, of the overall write cache capacity of the controller. After flushing begins, it will continue until enough data has been flushed to drop the percentage of dirty data to or below the value specified in the demandFlushAmount parameter described above. */
	public void setDemandFlushThreshold(int x) {
		this.demandFlushThreshold = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private String reserved1;

	/** @return Reserved for future use. */
	public String getReserved1() {
		return this.reserved1;
	}
	/** @param x Reserved for future use. */
	public void setReserved1(String x) {
		this.reserved1 = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private String reserved2;

	/** @return Reserved for future use. */
	public String getReserved2() {
		return this.reserved2;
	}
	/** @param x Reserved for future use. */
	public void setReserved2(String x) {
		this.reserved2 = x;
	}

	/** True if checking of protection information during cache mirroring is enabled, false otherwise. */
	@io.swagger.annotations.ApiModelProperty(value ="True if checking of protection information during cache mirroring is enabled, false otherwise." , required = true)
	@XmlElement(required = true)
	private boolean cacheMirroringProtectionInformation;

	/** @return True if checking of protection information during cache mirroring is enabled, false otherwise. */
	public boolean isCacheMirroringProtectionInformation() {
		return this.cacheMirroringProtectionInformation;
	}
	/** @param x True if checking of protection information during cache mirroring is enabled, false otherwise. */
	public void setCacheMirroringProtectionInformation(boolean x) {
		this.cacheMirroringProtectionInformation = x;
	}
}
