package devmgr.api.symbol;

import devmgr.api.runtime.*;
import devmgr.api.rpc.*;

public class SYMbolAPIClientV1 extends RPCClient {
	public SYMbolAPIClientV1() {
		super(new SYMbolAPI());
	}
	 public static final String SYMBOL_VERSION="181";
	/** Returns a DiscoveryResponse object that identifies the storage arrays and controllers known to the RPC server that handles this request. Response also indicates if RPC server is RAID controller or SYMbol RPC UTM agent.
	 * @return A DiscoveryResponse object that identifies the storage arrays and controllers known to the RPC server that handles this request. The response also indicates if the RPC server is a true RAID controller or a SYMbol RPC/UTM agent. In cases where the response comes from a controller, only one AccessibleController object will be identified, although it will contain the reference values of all controllers present in the storage array. If the response is from an agent, it will contain one AccessibleController for each controller that is accessible through the agent. Furthermore, each such object will identify the storage array to which it belongs, plus all other controllers present in the array.
	 */
	public DiscoveryResponse discoverControllers( ) throws Exception {
		return (DiscoveryResponse) call(1, null);
	}

	/** This function is used to bind a new connection to a particular controller. If the server is actually a controller itself, the controller will just ensure that its CONTROLLER REF is the same as the one passed in as an argument. If the server is an agent, it will use the CONTROLLER REF argument to determine which locally-attached controller should be used for all further interactions over the RPC connection.
	 * @param x A descriptor value that identifies the controller to which all further requests on this RPC connection should be routed.
	 */
	public ReturnCode bindToController(ControllerDescriptor x) throws Exception {
		return (ReturnCode) call(2, x);
	}

	/** Instructs the SYMbol Server's controller to transfer ownership of a volume group and its associated volumes to another controller.
	 * @param x A descriptor that specifies the volume group being modified, and the controller that is to take ownership of the volume group, and thus all volumes defined on the volume group.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode assignVolumeGroupOwnership(VolumeGroupOwnershipUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(3, x);
	}

	/** This procedure causes the controller to automatically assign the specified number of drives as hot spares, in addition to any previously assigned hot spares.
	 * @param x The number of new hot spare drives to be added to the array's pool of hot spares.
	 */
	public ReturnCode assignDrivesAsHotSpares(int x) throws Exception {
		return (ReturnCode) call(4, x);
	}

	/** Instructs the SYMbol Server's controller to create hot spare drives out of the given drives.
	 * @param x A list of drive reference values, which identifies the drives to be assigned as hot spares.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode assignSpecificDrivesAsHotSpares(DriveRefList x) throws Exception {
		return (ReturnCode) call(5, x);
	}

	/** This procedure returns a list of volume candidates that can be used in an ensuing volume creation request.
	 * @param x A VolumeCandidateRequest descriptor that specifies the type of volume candidates to be returned to the caller.
	 * @return A list of volume candidates that conform to the parameters specified in the request. If no such candidates exist, an empty list is returned. Possible return codes are:
	 */
	public VolumeCandidateList getVolumeCandidates(VolumeCandidateRequest x) throws Exception {
		return (VolumeCandidateList) call(6, x);
	}

	/** This procedure causes a new volume to be created based on parameters provided by the caller in the argument structure. Note that a key parameter is a VolumeCandidate object that was previously returned by the controller as the result of a getVolumeCandidates operation. The user must select one such candidate, and then supply further information about the desired attributes of the volume when calling this procedure.
	 * @param x A VolumeCreationDescriptor object that provides attributes and properties of the volume to be created.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode createVolume(VolumeCreationDescriptor x) throws Exception {
		return (ReturnCode) call(7, x);
	}

	/** This procedure causes the drives specified by the argument to be deassigned as hot spares. They will be returned to the pool of unassigned drives, and thus be added to the unconfigured capacity pool of the storage array. Note that a hot spare drive cannot be deassigned if it is currently in use, sparing for a failed drive.
	 * @param x A list of DriveRef values that identifies all drives to be affected by this operation.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deassignDrivesAsHotSpares(DriveRefList x) throws Exception {
		return (ReturnCode) call(8, x);
	}

	/** This procedure is used to delete a Thin Volume. The procedure has been deprecated for deleting RAID Volumes - it has been replaced by the procedure deleteVolumeFromGroup.
	 * @param x The value of the AbstractVolRef for the volume to be deleted.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteVolume(String x) throws Exception {
		return (ReturnCode) call(9, x);
	}

	/** This procedure marks the specified controller as being failed. Furthermore, the alternate of the specified controller will force the failed controller into a reset state (if possible).
	 * @param x The value of the controller reference for the controller that is to be marked failed.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setControllerToFailed(String x) throws Exception {
		return (ReturnCode) call(10, x);
	}

	/** This procedure marks the specified drive as being failed. In general, this will also impact the operational state of the volume group to which the drive is assigned, plus all volumes defined on that volume group. The precise impact on the states of these other objects may vary, as it depends on the RAID level of the volumes, as well as the states of the other drives in the volume group.
	 * @param x The value of the drive reference for the drive that is to be marked failed.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setDriveToFailed(String x) throws Exception {
		return (ReturnCode) call(11, x);
	}

	/** This procedure causes the specified volume to be formatted. All data that is currently present on the volume will be irretrievably lost as a result of this operation. Once a format operation starts, the volume's action field will be changed to VOL_ACTION_INITIALIZING; the getVolumeActionProgress procedure can then be used to monitor the progress of the operation. Volume format operations are typically required only when reviving a volume that has been marked failed for some reason. Newly-created volumes need not be explicitly formatted using this procedure.
	 * @param x The value of the volume reference for the volume that is to be reformatted.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startVolumeFormat(String x) throws Exception {
		return (ReturnCode) call(12, x);
	}

	/** This procedure causes the specified drive object to be initialized for use in the system. All data on the drive is irretrievably lost as a result of this operation. Only offline drives or drives whose status is DRIVE_STAT_INCOMPATIBLE are candidates for initialization. This procedure implicitly transitions the drive to the online state.
	 * @param x The value of the drive reference for the drive that is to be initialized.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode initializeDrive(String x) throws Exception {
		return (ReturnCode) call(13, x);
	}

	/** To indicate the end of the iterative download sequence, call this procedure with a zero-length segment size. When the controller receives this end indicator, the controller writes the accumulated firmware image to stable storage (typically flash memory). The controller responds to this procedure call with the appropriate return code, delays for a short period, and then reboots to load and execute the new firmware.
	 * @param x A FirmwareUpdateDescriptor object that indicates, among other things, the offset and size of the firmware segment being transferred.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode loadControllerFirmware(FirmwareUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(14, x);
	}

	/** To indicate the end of the iterative download sequence, call this procedure with a zero-length segment size. When the controller receives this end indicator, the controller writes the accumulated NVSRAM image to stable storage (typically flash memory). The controller responds to this procedure call with the appropriate return code, delays for a short period, and then reboots to load and execute the new NVSRAM.
	 * @param x A FirmwareUpdateDescriptor object that specifies the size and content of the NVSRAM data to be loaded by the controller.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode loadControllerNVSRAM(FirmwareUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(15, x);
	}

	/** This procedure clears all entries from the Major Events Log.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode resetMel( ) throws Exception {
		return (ReturnCode) call(16, null);
	}

	/** This procedure marks a volume group offline. When this operation completes, all volumes in the volume group will be inaccessible for I/O operations. The drives that comprise the volume group can be removed from the storage array and, if desired, inserted into a different storage array.
	 * @param x The value of the volume group reference for the volume group to be placed offline.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setVolumeGroupToOffline(String x) throws Exception {
		return (ReturnCode) call(17, x);
	}

	/** This procedure marks a volume group online. It is typically used when the drives assigned to a volume group have been transported from one storage array to another. After the last such drive has been inserted into the new storage array, it is necessary to manually mark the volume group online. When this operation completes, assuming the drives are all functioning properly, the volumes defined in the volume group will become accessible for I/O operations.
	 * @param x The value of the volume group reference for the volume group to be placed online.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setVolumeGroupToOnline(String x) throws Exception {
		return (ReturnCode) call(18, x);
	}

	/** This procedure initiates the reconstruction of a failed drive in a degraded RAID volume. The procedure returns once the reconstruction has started. If the indicated failed drive has an integrated hot spare serving in its place, then this procedure will initiate the copyback from the hot spare to the failed drive.
	 * @param x The value of the drive reference for the drive on which reconstruction is to begin.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startDriveReconstruction(String x) throws Exception {
		return (ReturnCode) call(19, x);
	}

	/** This procedure initiates a long-running operation to defragment a volume group by shifting the physical storage location of each volume in the volume group to eliminate any free extents that reside between defined volumes. Note that all volumes remain fully accessible and online during this transition. While the operation is in progress, the client can make calls to the getVolumeActionProgress procedure to determine how much progress has been made in completing the operation for each affected volume. The end result of a volume group defragment operation is that free extents that existed between defined volumes will be eliminated, and a single large free extent (if any) will appear at the end of the volume group.
	 * @param x The value of a volume group reference for the volume group that is to be defragmented.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startVolumeGroupDefrag(String x) throws Exception {
		return (ReturnCode) call(20, x);
	}

	/** This procedure initiates a long-running operation to expand the capacity of a volume group by adding one or more drives to it. An expansion of this form requires that the controller transparently move the data of existing volumes within the volume group; volumes remain fully accessible and online during this transition. While the operation is in progress, the client can make calls to the getVolumeActionProgress procedure to determine how much progress has been made in completing the operation for each affected volume. The end result of a volume group expansion is the appearance of a new (or enlarged) free extent at the end of the volume group. The free extent can then be used to create new volumes as desired by the user.
	 * @param x A VolumeGroupExpansionDescriptor object that identifies the volume group to be expanded, plus the drive or drives to be added to the volume group. All drives specified for this operation must be in the unassigned state initially.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startVolumeGroupExpansion(VolumeGroupExpansionDescriptor x) throws Exception {
		return (ReturnCode) call(21, x);
	}

	/** This procedure initiates a long-running operation to change the RAID level of a volume group (and thus all volumes in the volume group) from one supported value to another. While the operation is in progress, the client can make calls to the getVolumeActionProgress procedure to determine how much progress has been made in completing the operation for each affected volume.
	 * @param x A VolumeRAIDMigrationDescriptor object that identifies the volume group and the new RAID level to be used.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startVolumeRAIDMigration(VolumeRAIDMigrationDescriptor x) throws Exception {
		return (ReturnCode) call(22, x);
	}

	/** This procedure initiates a long-running operation to change the segment size (i.e. stripe depth) of a volume from one supported value to another. While the operation is in progress, the client can make calls to the getVolumeActionProgress procedure to determine how much progress has been made in completing the operation.
	 * @param x A VolumeSegmentSizingDescriptor object that identifies the volume and the new segment size to be used.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startVolumeSegmentSizing(VolumeSegmentSizingDescriptor x) throws Exception {
		return (ReturnCode) call(23, x);
	}

	/** This procedure causes the specified controller to be transitioned to the passive state. All volume groups owned by the controller will be transitioned to the alternate controller, which remains in the active state.
	 * @param x The value of the controller reference for the controller that is to be made passive.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setControllerToPassive(String x) throws Exception {
		return (ReturnCode) call(24, x);
	}

	/** This procedure causes the specified controller to be transitioned into the active state. If the controller was previously active, no visible changes will occur as a result of this operation. If it was previously passive or in service mode, it will be made active. After this transition occurs, it will be possible to assign ownership of volume groups to the controller so that it may participate in standard I/O operations.
	 * @param x The value of the controller reference for the controller that is to be made active.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setControllerToActive(String x) throws Exception {
		return (ReturnCode) call(25, x);
	}

	/** This procedure updates the cache parameters that are maintained on a per-array basis, across all controllers in the array.
	 * @param x An SACacheParamsUpdateDescriptor object that provides new values for the storage array cache management parameters.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setSACacheParams(SACacheParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(26, x);
	}

	/** This procedure is used by a client to modify the user-assigned label for the storage array. The label value is stored in non-volatile storage and returned to the client as part of the SAInfo object.
	 * @param x The new user-assigned label for the storage array. This value is presented to the controller as a variable-length opaque byte array. However, the intention is that the byte array will contain a string value in double-byte character set format, with each two bytes representing one character value.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setSAUserLabel(String x) throws Exception {
		return (ReturnCode) call(27, x);
	}

	/** This procedure allows the client to set the clock of the controller to the specified value. Note that the clock value is only set on the controller to which this request is directed. If the client wishes to set the clock value on each controller, then an independent request of this form should be directed to each controller.
	 * @param x A 64-bit integer value that represents the new clock value to be set on the controller. The integer specifies the time value as the number of seconds that have elapsed since 12:00AM GMT on January 1, 1970.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setControllerTime(long x) throws Exception {
		return (ReturnCode) call(28, x);
	}

	/** This procedure updates the caching parameters for a particular volume as specified in the argument structure.
	 * @param x A VolumeCacheParamsUpdateDescriptor object that specifies the volume whose cache parameters are to be updated, as well as the new parameter values themselves.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setVolumeCacheParams(VolumeCacheParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(29, x);
	}

	/** This procedure updates various parameters (outside of cache-related parameters) for a particular volume as specified in the argument structure.
	 * @param x A VolumeParamsUpdateDescriptor object that specifies the volume whose parameters are to be updated, as well as the new parameter values themselves.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setVolumeParams(VolumeParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(30, x);
	}

	/** This procedure is used by a client to modify the user-assigned label for a volume. The label value is stored in non-volatile storage and returned to the client as part of the Volume or SnapshotVolume object when the client requests this information from the controller.
	 * @param x A VolumeLabelUpdateDescriptor object that contains the new user-assigned label for the volume. This value is presented to the controller as a variable-length opaque byte array. However, the intention is that the byte array will contain a string value in double-byte character set format, with each two bytes representing one character value.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setVolumeUserLabel(VolumeLabelUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(31, x);
	}

	/** This procedure causes visual indicators to be activated on the physical storage array unit to allow an end-user to visually identify the storage array. The indicators will remain active until the stopIdentification procedure is invoked.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startSAIdentification( ) throws Exception {
		return (ReturnCode) call(32, null);
	}

	/** This procedure causes visual indicators to be activated on the physical drives specified in the argument list to allow an end-user to visually identify the drives. The indicators will remain active until the stopIdentification procedure is invoked.
	 * @param x A list of drive reference objects that specifies the drives whose visual indicators are to be activated.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startDriveIdentification(DriveRefList x) throws Exception {
		return (ReturnCode) call(33, x);
	}

	/** This procedure cancels the effects of any prior startDriveIdentification, startSAIdentification, startChannelIdentification and/or startTrayIdentification operations by deactivating all visual indicators.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode stopIdentification( ) throws Exception {
		return (ReturnCode) call(34, null);
	}

	/** This procedure updates the I/O interface parameters for the controller to which the request is directed.
	 * @param x An InterfaceUpdateDescriptor object that provides new values for the host I/O interface parameters.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setHostInterfaceParams(InterfaceUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(35, x);
	}

	/** This procedure causes the specified controller's state to be set to optimal. If the controller was previously in the failed state, it will be reactivated. If necessary, the alternate controller will also remove any forced reset signal being applied to the specified controller.
	 * @param x The value of the controller reference for the controller to be set to the optimal state.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setControllerToOptimal(String x) throws Exception {
		return (ReturnCode) call(36, x);
	}

	/** This procedure forces the specified drive to the optimal state, including clearing the PFA condition for the drive, if any. Returning the drive to optimal may cause volumes on the associated volume group to be returned to the optimal state as well. This is a potentially dangerous operation, since a failed drive is usually accompanied by some form of parity inconsistency. Forcing a drive from the failed state to the optimal state may disrupt the controller's normal methods of providing availability in a degraded state, and may thus result in corrupted data being returned on ensuing data transfers to the host system.
	 * @param x The value of the drive reference for the drive to be returned to the optimal state.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setDriveToOptimal(String x) throws Exception {
		return (ReturnCode) call(37, x);
	}

	/** This is a potentially dangerous operation, since it causes data to be made available to the I/O host even though that data may have become corrupted due to device failures that occurred in the past.
	 * @param x The value of the VolumeGroupRef for the volume group that is being restored to the optimal state.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode forceVolumeGroupToOptimal(String x) throws Exception {
		return (ReturnCode) call(38, x);
	}

	/** This procedure is used by clients to query the referenced controller for up-to-date information about its host-side I/O interfaces. Since this interface information is highly volatile, the object graph data contains only a point-in-time snapshot of the interface data. This procedure can be used to obtain current information that may not be reflected in the most recent object graph.
	 * @return A list of elements that describe each host-side I/O interface for the controller to which the request was directed.
	 */
	public IOInterfaceTypeDataList getControllerHostInterfaces( ) throws Exception {
		return (IOInterfaceTypeDataList) call(39, null);
	}

	/** This procedure causes all configuration and state information to be returned to the requester. The information is conveyed in the form of an object graph. The ObjectBundle object contains a set of all known logical and physical components. The reference values within these objects can be analyzed to determine the interrelationships and linkages between the key objects, and thus to establish the true graph-oriented image of the storage array state.
	 * @return An ObjectBundle object that contains all relevant logical and physical objects and their associated state information for the storage array.
	 */
	public ObjectBundle getObjectGraph( ) throws Exception {
		return (ObjectBundle) call(40, null);
	}

	/** This procedure returns an indication of the extent to which a long-running operation on a volume has completed. The set of supported long-running operations is defined by the VolumeAction enumeration. This procedure can also be called for a snapshot volume. The set of supported long-running operations for snapshot volumes is defined by the SnapshotAction enumeration.
	 * @param x The value of the AbstractVolRef for the volume whose long-running operation is being queried.
	 * @return A VolumeActionProgress object that contains the completion percentage of a long running volume oriented operation as well as the estimated elapsed time to completion in minutes. If no operation is running on the given volume then a -1 will be returned for the completion percentage. Estimated time to completion will be -1 if it is unknown.
	 */
	public VolumeActionProgress getVolumeActionProgress(String x) throws Exception {
		return (VolumeActionProgress) call(41, x);
	}

	/** This procedure is used by clients to obtain information about all component or logic failures on the storage array that require some form of recovery action.
	 * @return A FailureTypeList object that contains one element for each type of failure that is currently present in the storage array.
	 */
	public FailureTypeList getRecoveryFailureList( ) throws Exception {
		return (FailureTypeList) call(42, null);
	}

	/** This procedure returns an object that contains high-level status information about the storage array as a whole.
	 * @return An SAData object that contains general status information about the storage array.
	 */
	public SAData getSAData( ) throws Exception {
		return (SAData) call(43, null);
	}

	/** This procedure is used by the client to retrieve performance monitoring data for one or more volumes.
	 * @param x A list of AbstractVolRef values of the volumes for which the caller wishes to obtain performance monitoring information.
	 * @return A list of VolumePerformance objects that contain the desired information. The list contains one such object for each valid volume that was specified in the argument object.
	 */
	public VolumePerformanceList getVolumePerformance(AbstractVolRefList x) throws Exception {
		return (VolumePerformanceList) call(44, x);
	}

	/** This procedure is used by the client to request that the controller store (in nonvolatile storage) a TrayPositionList object that provides information about the relative physical positions of the storage array's trays within their enclosing rack(s) or container(s).
	 * @param x The TrayPositionList object to be stored for future retrieval.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setSATrayPositions(TrayPositionList x) throws Exception {
		return (ReturnCode) call(45, x);
	}

	/** This procedure sets the media scan parameters for a particular volume. Each volume can be configured to either participate in media scans or not. Furthermore, if a volume is configured to participate, it can be further configured so that parity validation either occurs during the media scan or is skipped. The client uses this procedure to set these configuration options on a per-volume basis.
	 * @param x A VolumeMediaScanParamsUpdateDescriptor object that identifies the volume to be modified, as well as the media scan settings to be used for the volume.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setVolumeMediaScanParams(VolumeMediaScanParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(46, x);
	}

	/** This procedure sets the target media scan period for background media scans to the value specified by the caller. The period is specified in units of days, and governs the approximate time required for a complete media scan of all volumes and drives in the system. The allowed period values can be determined by checking the appropriate fields of the FeatureParameters object for the storage array.
	 * @param x The desired media scan period, expressed in units of days. This value must be within the valid range of media scan periods supported the controller.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setSAMediaScanPeriod(int x) throws Exception {
		return (ReturnCode) call(47, x);
	}

	/** This procedure is used by clients to query the controller for indications of state changes that have occurred and which would necessitate that the client refresh its view of the storage array's state. If no state changes need to be reported, the controller will generally hold this request, without responding, for up to the amount of time specified in the argument. If, at any time during the hold period, a state change occurs, the controller will return immediately with the new configuration generation number and/or MEL sequence number. By using this hanging poll approach, the amount of traffic between the client and the server is reduced to an insignificant level, and yet near-immediate notification of changes is still possible.
	 * @param x A ChangeQueryDescriptor object that identifies the caller's current understanding of the storage array's state, along with an indication of the maximum hold time for this request.
	 * @return A ChangeState object that indicates the current configuration of the storage array by providing the array's current configuration generation number, along with key information about the Major Event Log.
	 */
	public ChangeState getChangeState(ChangeQueryDescriptor x) throws Exception {
		return (ChangeState) call(48, x);
	}

	/** Causes the entire configuration of the storage array to be cleared to an initial state.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode clearSAConfiguration( ) throws Exception {
		return (ReturnCode) call(49, null);
	}

	/** Tells the controller to automatically configure the Storage Array.
	 */
	public ReturnCode autoSAConfiguration( ) throws Exception {
		return (ReturnCode) call(50, null);
	}

	/** This procedure is used to determine the head and tail sequence numbers of entries in the storage array's Major Event Log. The client can use these values to manage controlled fetching of log entries.
	 * @return A MelExtent object that contains head and tail sequence numbers of the entries in the storage array's Major Event Log.
	 */
	public MelExtent getMelExtent( ) throws Exception {
		return (MelExtent) call(51, null);
	}

	/** This procedure allows a client to fetch a set of entries from the storage array's Major Event Log for analysis or display. Note that the MEL_MAX_XFER_COUNT constant specifies that maximum number of entries that can be requested in one operation. If more entries are needed, the client must fetch them iteratively, ensuring that no single request exceeds the transfer limit.
	 * @param x A MelExtent object that provides the sequence number of the first and last MEL entries to be retrieved. All entries between these two numbers (inclusive) will be transferred to the caller as a result of this operation.
	 * @return A MelEntryList object containing the desired information.
	 */
	public MelEntryList getMelEntries(MelExtent x) throws Exception {
		return (MelEntryList) call(52, x);
	}

	/** This procedure allows a client to fetch a set of entries with a priority value of EVENT_PRIORITY_CRITICAL from the storage array's Major Event Log for analysis or display. If there are less critical MEL events than MEL_MAX_XFER_COUNT, all the critical events will be displayed on the first call. If the client receives a number of critical MEL events that is equal to MEL_MAX_XFER_COUNT, then the user must increment the first sequence number to be the highest sequence number in the list of entries returned and repeat the procedure. This process must be repeated until the number of entries returned is less than MEL_MAX_XFER_COUNT.
	 * @param x A MelExtent object that provides the sequence number of the first and last MEL entries to be retrieved. All critical entries between these two numbers (inclusive) will be transferred to the caller as the result of the operation.
	 * @return A list of MelEntry objects containing the desired information.
	 */
	public MelEntryList getCriticalMelEntries(MelExtent x) throws Exception {
		return (MelEntryList) call(53, x);
	}

	/** This procedure allows a client to fetch the data that resides within a designated region of the controller's NVSRAM. Note that the NVSRAM data is obtained only from the controller to which this request is directed.
	 * @param x An NVSRAMRegionId value that identifies the region whose data is to be retrieved. The caller is allowed to specify that all NVSRAM regions be obtained, if desired.
	 * @return A list of NVSRAMRegion objects containing the desired information.
	 */
	public NVSRAMRegionList getControllerNVSRAM(NVSRAMRegionId x) throws Exception {
		return (NVSRAMRegionList) call(54, x);
	}

	/** This procedure is used to modify a portion of the controller's NVSRAM. Note that the NVSRAM data is changed only on the controller to which this request is directed.
	 * @param x An NVSRAMUpdateDescriptor object that specifies the region to be modified, the starting byte offset within the region, and the size and value of the new data to be stored into NVSRAM.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setControllerNVSRAM(NVSRAMUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(55, x);
	}

	/** This procedure allows a client to change the administrative password that protects the storage array against unauthorized configuration changes.
	 * @param x An EncryptedPassword object that identifies the new password to be used for further management activities for the storage array.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setSAPassword(EncryptedPassword x) throws Exception {
		return (ReturnCode) call(56, x);
	}

	/** This procedure simply verifies that the controller is responsive and is operating properly.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode pingController( ) throws Exception {
		return (ReturnCode) call(57, null);
	}

	/** Initiates an explicit parity check operation. This is a background task that verifies the correctness of all parity/redundancy data for the volume. Only one such operation may be active at any time on a given controller. After initiating the operation with this procedure, the operation's progress can be checked via the getParityCheckProgress procedure. This procedure is deprecated. The scanVolume procedure should be used instead.
	 * @param x The AbstractVolRef of the volume on which the operation is to be performed.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startVolumeParityCheck(String x) throws Exception {
		return (ReturnCode) call(58, x);
	}

	/** This procedure returns an indication of the progress of an explicit parity check operation on a particular volume. This procedure is deprecated. The scanVolume procedure should be used instead.
	 * @param x The AbstractVolRef value for the volume whose parity check operation is being queried.
	 * @return An integer in the range 0-100 that indicates the percentage of the volume that has been checked for parity inconsistencies, or one of the (negative) PARITY_CHK_* constant values to indicate an error condition or a completed parity check result.
	 */
	public int getParityCheckProgress(String x) throws Exception {
		return (int) call(59, x);
	}

	/** This procedure returns a list of LUN mappings that apply to the object identified by the argument SYMbolRef.
	 * @param x The SYMbolRef value of the entity for which applicable LUN mappings are to be returned. For example, to find all LUN mappings that apply to a particular Cluster object, the associated ClusterRef would be used as the argument.
	 * @return A LUNMappings object that identifies the mappings that apply to the referenced object.
	 */
	public LUNMappings getLUNMappings(String x) throws Exception {
		return (LUNMappings) call(61, x);
	}

	/** Creates a new SAPortGroup & returns its ref. If a group by that name already exists, returns its ref.. OBSOLETE: Any call to createSAPortGroup will get a return status indicating the command is obsolete. No alternative procedure is available.
	 */
	public ReturnCodeWithRef createSAPortGroup(String x) throws Exception {
		return (ReturnCodeWithRef) call(62, x);
	}

	/** Removes all SAPorts from an SAPortGroup, and deletes the group. OBSOLETE: Any call to deleteSAPortGroup will get a return status indicating the command is obsolete. No alternative procedure is available.
	 */
	public ReturnCode deleteSAPortGroup(String x) throws Exception {
		return (ReturnCode) call(63, x);
	}

	/** Removes the SA Port 'itemRef' from any SA Port Group that it might be in, & moves it to the group 'containerRef'. If this leaves the previous SAPortGroup empty, the previous SAPortGroup is deleted. OBSOLETE: Any call to moveSAPort will get a return status indicating the command is obsolete. No alternative procedure is available.
	 */
	public ReturnCode moveSAPort(SYMbolRefPair x) throws Exception {
		return (ReturnCode) call(64, x);
	}

	/** Retrieves a storage array port. OBSOLETE: Any call to getSAPort will get a return status indicating the command is obsolete. No alternative procedure is available.
	 */
	public ReturnCodeWithRef getSAPort(SAPortGetDescriptor x) throws Exception {
		return (ReturnCodeWithRef) call(65, x);
	}

	/** This procedure causes a new Host object to be created using the parameters in the creation descriptor argument. After creating a host, host ports can be added to it, mappings established, etc.
	 * @param x A HostCreationDescriptor object that contains all required attributes for the new Host object.
	 * @return A ReturnCodeWithRef object that indicates the outcome of the operation, and also returns the HostRef of the newly-created object. Valid ReturnCode values are:
	 */
	public ReturnCodeWithRef createHost(HostCreationDescriptor x) throws Exception {
		return (ReturnCodeWithRef) call(66, x);
	}

	/** This procedure causes a new Cluster object to be created and assigned the specified label. After creating a cluster, hosts can be added to it, mappings established, etc.
	 * @param x The user-assigned label to be used for the new cluster.
	 * @return A ReturnCodeWithRef object that indicates the outcome of the operation, and also returns the ClusterRef of the newly-created object. Valid ReturnCode values are:
	 */
	public ReturnCodeWithRef createCluster(String x) throws Exception {
		return (ReturnCodeWithRef) call(67, x);
	}

	/** This procedure causes the Cluster object identified by the argument value to be deleted from the Storage Partitions configuration.
	 * @param x The ClusterRef value for the cluster to be deleted.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteCluster(String x) throws Exception {
		return (ReturnCode) call(68, x);
	}

	/** This procedure changes the user-assigned label for a Cluster object.
	 * @param x A SYMbolRefWithUAL object whose ref field identifies the cluster to be renamed, and whose label field provides the new user-assigned label for the cluster.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode renameCluster(SYMbolRefWithUAL x) throws Exception {
		return (ReturnCode) call(69, x);
	}

	/** This procedure causes the Host object identified by the argument value to be deleted from the Storage Partitions configuration.
	 * @param x The HostRef value for the host to be deleted.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteHost(String x) throws Exception {
		return (ReturnCode) call(70, x);
	}

	/** This procedure changes the user-assigned label for a Host object.
	 * @param x A SYMbolRefWithUAL object whose ref field identifies the host to be renamed, and whose label field provides the new user-assigned label for the host.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode renameHost(SYMbolRefWithUAL x) throws Exception {
		return (ReturnCode) call(71, x);
	}

	/** Changes the Storage Partitions configuration for a Host object by modifying the host's cluster assignment.
	 * @param x A SYMbolRefPair object. The itemRef field of the argument is a HostRef that identifies the host being modified, and the containerRef field is a ClusterRef that identifies the cluster to which the host is to be moved.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode moveHost(SYMbolRefPair x) throws Exception {
		return (ReturnCode) call(72, x);
	}

	/** This procedure causes a new HostPort object to be created using the parameters in the creation descriptor argument. After creating a host, host ports can be added to it, mappings established, etc. This procedure does not work for iSCSI.
	 * @param x A HostPortCreationDescriptor object that contains all required attributes for the new HostPort object.
	 * @return A ReturnCodeWithRef object that indicates the outcome of the operation, and also returns the HostPortRef of the newly-created object. Valid ReturnCode values are:
	 */
	public ReturnCodeWithRef createHostPort(HostPortCreationDescriptor x) throws Exception {
		return (ReturnCodeWithRef) call(73, x);
	}

	/** This procedure causes the HostPort object identified by the argument value to be deleted from the Storage Partitions configuration.
	 * @param x The HostPortRef value for the host port to be deleted.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteHostPort(String x) throws Exception {
		return (ReturnCode) call(74, x);
	}

	/** This procedure changes the user-assigned label for a HostPort object.
	 * @param x A SYMbolRefWithUAL object whose ref field identifies the host port to be renamed, and whose label field provides the new user-assigned label for the host port. This procedure does not apply to iSCSI.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode renameHostPort(HostPortRenameDescriptor x) throws Exception {
		return (ReturnCode) call(75, x);
	}

	/** Changes the Storage Partitions configuration for a HostPort object by modifying the port's host assignment. This procedure does not apply for iSCSI .
	 * @param x A SYMbolRefPair object. The itemRef field of the argument is a HostPortRef that identifies the host port being modified, and the containerRef field is a HostRef that identifies the host to which the port is to be moved.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode moveHostPort(SYMbolRefPair x) throws Exception {
		return (ReturnCode) call(76, x);
	}

	/** This procedure causes a new LUNMapping object to be created using the parameters in the creation descriptor argument. Once this mapping is created, it provides a new LUN-to-volume mapping for I/O accesses from the specified entities to a given volume.
	 * @param x A LUNMappingCreationDescriptor object that contains all required attributes for the new LUNMapping object.
	 * @return A ReturnCodeWithRef object that indicates the outcome of the operation, and also returns the LUNMappingRef of the newly-created object. Valid ReturnCode values are:
	 */
	public ReturnCodeWithRef createLUNMapping(LUNMappingCreationDescriptor x) throws Exception {
		return (ReturnCodeWithRef) call(77, x);
	}

	/** This procedure causes the LUNMapping object identified by the argument value to be deleted from the Storage Partitions configuration.
	 * @param x The LUNMappingRef value for the mapping to be deleted.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteLUNMapping(String x) throws Exception {
		return (ReturnCode) call(78, x);
	}

	/** This procedure returns information about host ports whose world-wide names are known to the controller, but which have not been defined as full HostPort objects via the SYMbol interface. Note that you only need to send the request to one of the controllers, and that the same list of unlabeled host ports are returned, regardless of which controller receives the request. This procedure does not apply to iSCSI. The getUnconfiguredInitiators procedure should be used instead.
	 * @return An UnlabeledHostPorts object that identifies the host ports that are known to the referenced controller, but which have not yet been defined as full HostPort entities.
	 */
	public UnlabeledHostPorts getUnlabeledHostPorts( ) throws Exception {
		return (UnlabeledHostPorts) call(79, null);
	}

	/** Changes the "host port type" attribute of a given HostPort object. Changing an individual host port type will cause all host port types to be changed if SPM is not enabled. This procedure does not apply to iSCSI; for iSCSI, the host type is set at the host level.
	 * @param x A HostPortTypeUpdateDescriptor object that identifies the HostPort to be modified, and also provides the new type index value that specifies the type of the host port.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setHostPortType(HostPortTypeUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(80, x);
	}

	/** Move a LUN mapping.
	 * @param x A LUNMappingUpdateDescriptor that provides the new values for the LUN used to access the mapped value, as well as the host/cluster for which the mapping applies.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode moveLUNMapping(LUNMappingUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(81, x);
	}

	/** This procedure causes the "premium" features identified in the feature keys of the argument to be enabled.
	 * @param x A key for the "premium" feature to be enabled. This key must be obtained from an authorized source in order to be accepted by the array controller.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode enableFeature(FeatureKey x) throws Exception {
		return (ReturnCode) call(82, x);
	}

	/** Disable a single add-on(optional feature
	 * @param x The Capability value for the "premium" feature to be disabled.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode disableFeature(Capability x) throws Exception {
		return (ReturnCode) call(83, x);
	}

	/** This procedure is used to capture current controller conditions as specified by the function being passed through the variable string input.
	 * @param x A character string indicating the function being called and up to 2 function arguments. The individual elements of the string are separated by commas.
	 * @return A pointer to the statePrintBuffer where any output from the function is stored.
	 */
	public ReturnCodeWithOpaqueData stateCapture(String x) throws Exception {
		return (ReturnCodeWithOpaqueData) call(84, x);
	}

	/** Downloads a portion of a new firmware image to a drive in the SYMbol Server. loadDriveFirmware OBSOLETED by implementation of parallel drive firmware download
	 */
	public ReturnCode loadDriveFirmware(DriveFirmwareUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(85, x);
	}

	/** This procedure is used to download some or all of a new firmware image to the ESM cards in a tray. The argument object specifies tray where the ESMs are located, the size of the firmware segment being downloaded, and the offset of the segment within the overall firmware image. Downloads are accomplished using an iterative approach, where the overall image is segmented and each segment transferred to the controller via a call to this procedure. To indicate the end of the iterative download sequence, this procedure should be called with a zero-length segment size. When this end indicator is received by the controller, the accumulated firmware image will be written to the ESM cards.
	 * @param x An ESMFirmwareUpdateDescriptor object that indicates the tray to receive the firmware, the offset and size of the firmware segment being transferred.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode loadESMFirmware(ESMFirmwareUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(86, x);
	}

	/** This procedure allows the Host Specific NVSRAM region to be read to obtain information for a specific host.
	 * @param x An NVSRAMRegionIDAndHostIndex object that specifies the region ID (in this case 0xF2) and the host index for a specific host.
	 * @return The values from the specified region.
	 */
	public NVSRAMRegionList getHostSpecificNVSRAM(NVSRAMRegionIdAndHostIndex x) throws Exception {
		return (NVSRAMRegionList) call(87, x);
	}

	/** This procedure updates the NVSRAM for the Host Specific region.
	 * @param x A HostSpecificNVSRAMUpdateDescriptor object that specifies the region ID (in this case 0xF2), the host index for a specific host, the starting offset within the region, the number of bytes, and the values to be written.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setHostSpecificNVSRAM(HostSpecificNVSRAMUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(88, x);
	}

	/** This procedure sets the battery parameters for the given battery.
	 * @param x A descriptor object that specifies the battery properties.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setBatteryParams(BatteryParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(89, x);
	}

	/** Instructs the SYMbol Server's controller to transfer ownership of a volume to another controller.
	 * @param x A descriptor that specifies the volume being modified and the controller that is to take ownership of the volume.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode assignVolumeOwnership(VolumeOwnershipUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(90, x);
	}

	/** This procedure is used to start the Runtime Diagnostics.
	 * @param x A descriptor that specifies the Runtime Diagnostics tests to run.
	 * @return A RuntimeDiagResults object that indicates the results and the return code for the operation. Valid return code values are:
	 */
	public RuntimeDiagResults issueRuntimeDiagnostics(RuntimeDiagDescriptor x) throws Exception {
		return (RuntimeDiagResults) call(91, x);
	}

	/** This procedure requests a reboot of the given controller.
	 * @param x The value of the controller reference for the controller that is to be rebooted.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode resetController(String x) throws Exception {
		return (ReturnCode) call(92, x);
	}

	/** This procedure is used to put the controller in a quiesced state.
	 * @param x The value of the controller that is to be quiesced.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode quiesceController(String x) throws Exception {
		return (ReturnCode) call(93, x);
	}

	/** This procedure is used to take a controller out of the quiesced state.
	 * @param x A value of the controller to take out of the quiesced state.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode unquiesceController(String x) throws Exception {
		return (ReturnCode) call(94, x);
	}

	/** This procedure checks to make sure the additional capacity is available and then starts a DVE or DCE/DVE operation.
	 * @param x A VolumeExpansionDescriptor object that identifies the volume to be expanded, plus the drive or drives to be added to the volume. All drives specified for this operation must be in the unassigned state initially.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startVolumeExpansion(VolumeExpansionDescriptor x) throws Exception {
		return (ReturnCode) call(95, x);
	}

	/** Create a snapshot volume of a given base.
	 * @param x This object contains information about how a new snapshot volume is to be created including the size of the repository, the repository utilization warning threshold and the REPOSITORY full policy.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid ReturnCode values are:
	 */
	public ReturnCode createSnapshot(SnapshotCreationDescriptor x) throws Exception {
		return (ReturnCode) call(96, x);
	}

	/** This procedure will disable (stop) the indicated snapshot volume.
	 * @param x The SnapshotRef of the snapshot volume on which the operation is to be performed.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode disableSnapshot(String x) throws Exception {
		return (ReturnCode) call(97, x);
	}

	/** This procedure restarts a snapshot volume that was previously created. The snapshot must have been previously disabled for this procedure to succeed.
	 * @param x A descriptor object that specifies the various snapshot parameters.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode recreateSnapshot(SnapshotParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(98, x);
	}

	/** This procedure is used to set various snapshot parameters including the repository warning threshold, the repository full policy, and the rollback operation priority.
	 * @param x A SnapshotParamsUpdateDescriptor object that specifies the various snapshot parameters.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setSnapshotParams(SnapshotParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(99, x);
	}

	/** This procedure is used by clients to obtain information about the utilization of the repository volume for selected snapshots.
	 * @param x A list of snapshot volume reference values.
	 * @return The RepositoryUtilizationList is an array of Repository Utilization objects that contains the number of bytes used in the repository and the associated snapshot volume.
	 */
	public RepositoryUtilizationList getRepositoryUtilization(SnapshotRefList x) throws Exception {
		return (RepositoryUtilizationList) call(100, x);
	}

	/** Calculates the volume's maximum capacity after a DVE operation
	 * @param x This object contains information used for a DVE or DCE/DVE combination.
	 */
	public long calculateDVECapacity(VolumeExpansionDescriptor x) throws Exception {
		return (long) call(101, x);
	}

	/** This procedure returns the Read Link Status information.
	 * @param x A RLS Command Descriptor that provides the type of RLS command.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public RLSResults getReadLinkStatus(RLSCommandDescriptor x) throws Exception {
		return (RLSResults) call(102, x);
	}

	/** This procedure sets the RLS baseline for all devices. The baseline is used to indicate the difference in error counts from when the baseline was established and the time at which the RLS data is requested.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setRLSBaseline( ) throws Exception {
		return (ReturnCode) call(103, null);
	}

	/** This procedure returns the amount of storage required for a metadata volume.
	 * @param x The metadata volume type e.g. remote volume mirror metadata.
	 * @return The size of storage required for a metadata volume.
	 */
	public int getMetadataVolumeCapacity(MetadataVolType x) throws Exception {
		return (int) call(104, x);
	}

	/** Create a metadata volume
	 * @param x A MetadataVolCreationDescriptor object that contains all required attributes for the new MetadataVolume object.
	 * @return A ReturnCode object that indicates the outcome of the operation, and also returns the MetadataVolRef of the newly-created object. Valid ReturnCode values are:
	 */
	public ReturnCode createMetadataVolume(MetadataVolCreationDescriptor x) throws Exception {
		return (ReturnCode) call(105, x);
	}

	/** Activate Remote Mirroring
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode activateMirroring( ) throws Exception {
		return (ReturnCode) call(106, null);
	}

	/** Deactivate Remote Mirroring
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deactivateMirroring( ) throws Exception {
		return (ReturnCode) call(107, null);
	}

	/** Change MirrorProxy Synchronization Priority
	 * @param x This object contains information used for changing the synchronization priority level for a mirror volume.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode changeSynchronizationPriority(MirrorSyncPriorityDescriptor x) throws Exception {
		return (ReturnCode) call(108, x);
	}

	/** This procedure returns a list of mirror volume candidates that can be used in an ensuing mirror volume creation request.
	 * @param x A MirrorVolumeCandidateRequest descriptor that specifies the type of mirror volume candidates to be returned to the caller.
	 * @return A list of mirror volume candidates that conform to the parameters specified in the request.
	 */
	public MirrorVolumeCandidateList getVolumeListForMirroring(MirrorCandidateDescriptor x) throws Exception {
		return (MirrorVolumeCandidateList) call(109, x);
	}

	/** Create a Mirror
	 * @param x A MirrorCreationDescriptor object that contains all required attributes for the new Mirror Volume object.
	 * @return A ReturnCode object that indicates the outcome of the operation, and also returns the MirrorVolRef of the newly-created object. Valid ReturnCode values are:
	 */
	public ReturnCode createMirror(MirrorCreationDescriptor x) throws Exception {
		return (ReturnCode) call(110, x);
	}

	/** This procedure changes the role of the mirror volume.
	 * @param x The MirrorRoleChangeDescriptor object.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode roleChange(MirrorRoleChangeDescriptor x) throws Exception {
		return (ReturnCode) call(111, x);
	}

	/** Deletes a mirror volume.
	 * @param x A MirrorProxyRef object which identifies the Mirror Proxy Volume to be removed.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode removeMirror(String x) throws Exception {
		return (ReturnCode) call(112, x);
	}

	/** This procedure starts the synchronization process on a mirror.
	 * @param x The value of the mirror that is to be synchronized.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startSyncMirror(String x) throws Exception {
		return (ReturnCode) call(113, x);
	}

	/** This procedure causes visual indicators to be activated on the specified channel. The indicators will remain active until the stopIdentification procedure is invoked.
	 * @param x An integer value specifying the channel number.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startChannelIdentification(int x) throws Exception {
		return (ReturnCode) call(114, x);
	}

	/** This procedure causes visual indicators to be activated on the physical storage array unit to allow an end-user to visually identify the trays. The indicators will remain active until the stopIdentification procedure is invoked.
	 * @param x A list of the trays.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startTrayIdentification(TrayRefList x) throws Exception {
		return (ReturnCode) call(115, x);
	}

	/** This procedure gets a list of volumes encroaching the requested Dacstore area.
	 * @param x A number representing the size of a Dacstore in bytes.
	 * @return A list of volumeRef objects representing the volumes encroaching on the desired Dacstore area.
	 */
	public AbstractVolRefList getDacstoreIncompatibleVolumes(long x) throws Exception {
		return (AbstractVolRefList) call(116, x);
	}

	/** This procedure gets the internal clock from the controllers. The time is expressed in seconds since midnight (GMT) on 1/1/1970.
	 * @return The current value of the controller time-of-day clock.
	 */
	public ControllerTime getControllerTime( ) throws Exception {
		return (ControllerTime) call(117, null);
	}

	/** This procedure establishes a volume copy.
	 * @param x The VolumeCopyCreationDescriptor for the volume copy.
	 * @return A ReturnCodewithRef object that indicates the outcome of the operation, and also returns a reference to the newly created copy. Valid ReturnCode values are:
	 */
	public ReturnCodeWithRef establishVolumeCopy(VolumeCopyCreationDescriptor x) throws Exception {
		return (ReturnCodeWithRef) call(118, x);
	}

	/** Removes a volume copy.
	 * @param x A VolumeCopyRef object that identifies the volume copy to be removed.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode removeVolumeCopy(String x) throws Exception {
		return (ReturnCode) call(119, x);
	}

	/** This procedure modifies the parameters of a volume copy.
	 * @param x A VolumeCopyParamsUpdateDescriptor object that identifies the copy request and a set of attributes to be used to update the existing attributes.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setVolumeCopyParams(VolumeCopyParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(120, x);
	}

	/** This procedure takes as its input a VolumeCopyRef and causes a copy operation to be initiated from the beginning of the Source volume. A failure status is returned if the Source and Target volumes do not meet compatibility requirements.
	 * @param x A descriptor object that identifies the volumes to perform the copy operation.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startVolumeCopy(String x) throws Exception {
		return (ReturnCode) call(121, x);
	}

	/** This procedure halts the active copy.
	 * @param x The VolumeCopyRef object to halt the active copy.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode stopVolumeCopy(String x) throws Exception {
		return (ReturnCode) call(122, x);
	}

	/** This procedure returns a list of volume target candidates for creating a volume copy.
	 * @param x An AbstractVolRef descriptor that specifies the source volume for which the target candidates are requested (i.e. the source volume in the candidate copy relationship… the SYMbol client is requesting valid target volumes to use with this source volume).
	 * @return A list of volumes that are valid target volume candidates.
	 */
	public VolumeCopyCandidateList getVolumeCopyTargetCandidates(String x) throws Exception {
		return (VolumeCopyCandidateList) call(123, x);
	}

	/** This procedure returns a list of volume source candidates for creating a volume copy.
	 * @return A list of volumes that are valid source volume candidates.
	 */
	public VolumeCopyCandidateList getVolumeCopySourceCandidates( ) throws Exception {
		return (VolumeCopyCandidateList) call(124, null);
	}

	/** This procedure updates the network parameters.
	 * @param x An EthernetParamsUpdateDescriptor object that specifies the controller IP address, the gateway IP address, the network subnet mask, and bootp enable/disable.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setNetworkParameters(EthernetParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(125, x);
	}

	/** This procedure allows rlogin to the controller to be enabled or disabled.
	 * @param x The RloginUpdateDescriptor object is used for specifying the remote login capability of the controller
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setRloginCapability(RloginUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(126, x);
	}

	/** This procedure is used to set the delay period before a volume transfer alert is issued.
	 * @param x The delay period in seconds from 0 to 3600.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setVolXferAlertDelayPeriod(int x) throws Exception {
		return (ReturnCode) call(127, x);
	}

	/** Get the list of persistent registrations on the array OBSOLETE: Any call to getPersistantReservations will get a return status indicating the command is obsolete. Please use the new command getPRegistrations.
	 */
	public PersistentRegistrationList getPersistentRegistrations( ) throws Exception {
		return (PersistentRegistrationList) call(128, null);
	}

	/** Get the persistent registrations for the specified volume. The list will contain no more than one PersistentRegistration element. OBSOLETE: Any call to getPersistantReservationsForVolume will get a return status indicating the command is obsolete. Please use the new commands getPRegistrationsForVolume.
	 */
	public PersistentRegistrationList getPersistentRegistrationsForVolume(String x) throws Exception {
		return (PersistentRegistrationList) call(129, x);
	}

	/** This procedure clears registrations and reservations for specific volumes. A UNIT ATTENTION, RESERVATIONS PREEMPTED condition is established for the former registrants.
	 * @param x The list AbstractVolRefList of volumes to be cleared.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode clearPersistentRegistrations(AbstractVolRefList x) throws Exception {
		return (ReturnCode) call(130, x);
	}

	/** Change mirror write mode
	 * @param x This object contains information used for changing the mirror write mode.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode changeMirrorWriteMode(MirrorWriteModeDescriptor x) throws Exception {
		return (ReturnCode) call(131, x);
	}

	/** This procedure suspends the communication between a mirror pair.
	 * @param x This object contains information identifying the Mirror Proxy Volume to be removed.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode suspendMirror(String x) throws Exception {
		return (ReturnCode) call(132, x);
	}

	/** This procedure resumes the communication between a mirror pair.
	 * @param x This object contains information identifying the Mirror Proxy Volume to be removed.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode resumeMirror(String x) throws Exception {
		return (ReturnCode) call(133, x);
	}

	/** This procedure sets the allowable options for the auto resynchronization.
	 * @param x This object determines whether auto resynchronization is allowed.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setAutoResync(MirrorAutoResyncDescriptor x) throws Exception {
		return (ReturnCode) call(134, x);
	}

	/** Activate staged controller firmware
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode activateStagedControllerFirmware( ) throws Exception {
		return (ReturnCode) call(135, null);
	}

	/** This procedure invalidates the staged controller firmware.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode invalidateStagedControllerFirmware( ) throws Exception {
		return (ReturnCode) call(136, null);
	}

	/** This procedure gets the drive's log sense pages.
	 * @param x This object contains information identifying all drives that are affected by this operation.
	 * @return A DriveLogData object that indicates the outcome of the operation. Valid values are:
	 */
	public DriveLogData getDriveLogData(String x) throws Exception {
		return (DriveLogData) call(137, x);
	}

	/** This procedure automatically gets the configuration candidates.
	 * @param x This object contains a list of automatic configuration templates.
	 * @return An AutoConfigCandidateList object that indicates the outcome of the operation. Valid values are:
	 */
	public AutoConfigCandidateList getAutoConfigCandidates(AutoConfigTemplateList x) throws Exception {
		return (AutoConfigCandidateList) call(138, x);
	}

	/** Create automatic configuration
	 * @param x This object contains a list of automatic configuration templates.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode createAutoConfig(AutoConfigCandidateList x) throws Exception {
		return (ReturnCode) call(139, x);
	}

	/** Automatically assign hot spares
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode autoAssignHotSpares( ) throws Exception {
		return (ReturnCode) call(140, null);
	}

	/** This procedure returns a list of all hot spare drives and their volume groups.
	 * @return A HotSpareCoverageList object that indicates the outcome of the operation. Valid values are:
	 */
	public HotSpareCoverageList getHotSpareCoverage( ) throws Exception {
		return (HotSpareCoverageList) call(141, null);
	}

	/** This procedure returns a list of hot spare candidates with the volume groups that they potentially cover.
	 * @param x This object contains information describing the physical drive types supported.
	 * @return A HotspareCandidateList object that indicates the outcome of the operation. Valid values are:
	 */
	public HotSpareCandidateList getHotSpareCandidates(PhysicalDriveType x) throws Exception {
		return (HotSpareCandidateList) call(142, x);
	}

	/** This procedure returns a list of the known unreadable sectors for the system.
	 * @return An UnreadableSectorTableInfo object containing the database limit and all known unreadable sectors in the system.
	 */
	public UnreadableSectorTableInfo readUnreadableSectorDatabase( ) throws Exception {
		return (UnreadableSectorTableInfo) call(143, null);
	}

	/** Clears all the unreadable sectors for the given Volume
	 * @param x This object contains information for the specific volume.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode clearUnreadableSectors(String x) throws Exception {
		return (ReturnCode) call(144, x);
	}

	/** Sending an RVM Communication Check command
	 * @param x This object performs a user requested communication check for a remote volume.
	 * @return A RemoteCommunicationCheckSampleList object that indicates the outcome of the operation. Valid values are:
	 */
	public RemoteCommunicationCheckSampleList communicationCheck(RemoteCommunicationCheckDescriptor x) throws Exception {
		return (RemoteCommunicationCheckSampleList) call(145, x);
	}

	/** This procedure starts the parallel drive firmware download process.
	 * @param x This object contains the list of drives to download and an indicator of whether or not to perform the download keeping the volumes online.
	 * @return A DriveFirmwareStatus object that indicates the outcome of the operation. Valid values are:
	 */
	public DriveFirmwareStatus startDriveFirmwareDownload(DriveFirmwareDownload x) throws Exception {
		return (DriveFirmwareStatus) call(146, x);
	}

	/** This procedure sends chunks to the parallel drive firmware download process.
	 * @param x This object contains information about the DriveFirmwareChunkDescriptor.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode sendDriveFirmware(DriveFirmwareChunkDescriptor x) throws Exception {
		return (ReturnCode) call(147, x);
	}

	/** This procedure starts the drive download stage of the parallel drive firmware download process.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode updateDriveFirmware( ) throws Exception {
		return (ReturnCode) call(148, null);
	}

	/** This procedure stops the parallel drive firmware download process.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode stopDriveFirmwareDownload( ) throws Exception {
		return (ReturnCode) call(149, null);
	}

	/** This procedure gets the progress of the firmware download.
	 * @return A DriveFirmwareStatus object that indicates the outcome of the operation. Valid values are:
	 */
	public DriveFirmwareStatus getDriveFirmwareDownloadProgress( ) throws Exception {
		return (DriveFirmwareStatus) call(150, null);
	}

	/** This procedure creates a volume using the parameters of a volume that previously existed. Since no data or parity initialization is performed on the volume, the prior data is preserved resulting in a volume that is identical to the previous volume.
	 * @param x This object contains information on how a recovered volume is to be created.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode recoverVolume(RecoverVolumeDescriptor x) throws Exception {
		return (ReturnCode) call(151, x);
	}

	/** This procedure sets the drive channel state to either degraded or optimal.
	 * @param x This object contains information on how to request a drive channel state change from the array.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setDriveChannelState(DriveChannelStateDescriptor x) throws Exception {
		return (ReturnCode) call(152, x);
	}

	/** This procedure gets statistical information about all of the drive channels.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public DriveChannelList getDriveChannelStatistics( ) throws Exception {
		return (DriveChannelList) call(153, null);
	}

	/** Clear the drive channel cumulative statistic information
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode clearDriveChannelStatistics( ) throws Exception {
		return (ReturnCode) call(154, null);
	}

	/** This procedure suspends the communications for all mirrors in a Write Consistency group with a specified group number.
	 * @param x This object contains information about the write consistency group object.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode suspendConsistencyGroup(String x) throws Exception {
		return (ReturnCode) call(155, x);
	}

	/** This procedure resumes the communication for all mirrors in a Write Consistency group with a specified group number.
	 * @param x This object contains information about the write consistency group object.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are: ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode resumeConsistencyGroup(String x) throws Exception {
		return (ReturnCode) call(156, x);
	}

	/** This procedure places a controller in Service Mode. It replaces the obsolete setControllerToPassive procedure. The command is serviced by the controller opposite to controllerRef.
	 * @param x The value of the controller reference for the controller to be placed in service mode.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setControllerServiceMode(String x) throws Exception {
		return (ReturnCode) call(157, x);
	}

	/** This procedure causes a scan of the specified volume over the specified extent. The scan stops on any media or parity error encountered and reports the error. The procedure can also be used to repair media errors and parity errors.
	 * @param x A VolumeScanDescriptor that specifies the volume and extent to be scanned and contains indicators to enable repairing of media and parity errors.
	 * @return A ParityScanResponse that contains a ReturnCode indicating the status of the scan/repair. If the return code indicates a media error or parity error was encountered the EndingLBA fields specify the location of the error. Valid values for the return code are:
	 */
	public ParityScanResponse scanVolume(VolumeScanDescriptor x) throws Exception {
		return (ParityScanResponse) call(158, x);
	}

	/** This procedure changes the mgmtClientAttribute for a volume.
	 * @param x The VolumeAttributeUpdateDescriptor object.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode updateVolumeAttribute(VolumeAttributeUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(159, x);
	}

	/** This procedure saves a new value of the specified MgmtClientRecord.
	 * @param x The MgmtClientRecordWriteDescriptor object.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode writeMgmtClientRecords(MgmtClientRecordWriteDescriptor x) throws Exception {
		return (ReturnCode) call(160, x);
	}

	/** This procedure reads a range of (i.e. one or more) MgmtClient Record objects.
	 * @param x The MgmtClientRecordReadDescriptor value.
	 * @return The MgmtClientRecordReadResult object.
	 */
	public MgmtClientRecordReadResult readMgmtClientRecords(MgmtClientRecordReadDescriptor x) throws Exception {
		return (MgmtClientRecordReadResult) call(161, x);
	}

	/** This procedure deletes a range of (i.e. one or more) specified MgmtCleintRecords.
	 * @param x The MgmtClientRecordDeleteDescriptor value.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteMgmtClientRecords(MgmtClientRecordDeleteDescriptor x) throws Exception {
		return (ReturnCode) call(162, x);
	}

	/** This procedure suspends the communication between all mirrored pairs specified in the MirrorVolumeList.
	 * @param x This object contains information identifying the list of Mirror Volumes to suspend.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode suspendMirrorList(MirrorVolumeList x) throws Exception {
		return (ReturnCode) call(163, x);
	}

	/** This procedure resumes the communication between all mirrored pairs specified in the MirrorVolumeList.
	 * @param x This object contains information identifying the list of mirrored pairs on which to perform the resume operation.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode resumeMirrorList(MirrorVolumeList x) throws Exception {
		return (ReturnCode) call(164, x);
	}

	/** This procedure returns a list of persistent registrations on the array.
	 * @return A list of all volumes for which initiators have registered. Each entry in the list has a reservation type, an indication of whether the reservation, if any, persists through power loss, and a list of registrants. Each registrant contains (a) the port identifier, (b) the name of the host containing the port, if available, (c) a list of target ports, and (d) the target port through which the reservation is held, which can be a single port, "All", or "None."
	 */
	public PRegistrationList getPRegistrations( ) throws Exception {
		return (PRegistrationList) call(165, null);
	}

	/** Updates the Tray ID of a tray.
	 * @param x A reference to the physical tray and the ID value to set for the tray.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode updateTray(TrayUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(166, x);
	}

	/** This procedure sets the allowed alarm controls.
	 * @param x An AlarmUpdateDescriptor object that indicates the alarm to modify and the alarm control to activate.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setAlarm(AlarmUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(167, x);
	}

	/** This procedure executes the inter-controller discrete line diagnostics test.
	 * @return A ReturnCode object that indicates the outcome of the operation . Valid values are:
	 */
	public ReturnCode issueDiscreteLinesTest( ) throws Exception {
		return (ReturnCode) call(168, null);
	}

	/** This procedure turns the Ready to Remove indicator light on or off or puts the Ready to Remove indicator into automatic mode, for the component specified in the RTRUpdateDescriptor. This procedure is deprecated. The requestRemoval procedure should be used instead.
	 * @param x An RTRUpdateDescriptor object that indicates the component to modify and the control to execute.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode requestToRemove(RTRUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(169, x);
	}

	/** This procedure is used to enable and disable Simplex mode.
	 * @param x An enumeration object that describes the controller's redundancy mode. Use CTRL_REDUNDANCY_MODE_DUPLEX to set the redundancy mode to duplex and CTRL_REDUNDANCY_MODE_SIMPLEX to set the redundancy mode to simplex.
	 */
	public ReturnCode setSimplexMode(ControllerRedundancyMode x) throws Exception {
		return (ReturnCode) call(170, x);
	}

	/** This procedure returns a list of the persistent registrations for the specified volume.
	 * @param x The AbstractVolRef object for the specific volume.
	 * @return An indication of whether the reservation, if any, persists through power loss, and a list of registrants. Each registrant contains (a) the port identifier, (b) the name of the host containing the port, if available, (c) a list of target ports, and (d) the target port through which the reservation is held, which can be a single port, "All", or "None."
	 */
	public PRegistrationList getPRegistrationsForVolume(String x) throws Exception {
		return (PRegistrationList) call(171, x);
	}

	/** This procedure turns the Ready to Remove indicator light on or off or puts the Ready to Remove indicator into automatic mode, for the component specified in the RTRUpdateDescriptor.
	 * @param x An RTRUpdateDescription object that indicates the component to modify and the control to execute.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode requestRemoval(RTRUpdateDescription x) throws Exception {
		return (ReturnCode) call(172, x);
	}

	/** This procedure returns SOC error statistics.
	 * @param x A SOC command descriptor that indicates the devices for which statistics should be returned.
	 * @return A SocStatisticsReturned structure containing a return code indicating the outcome of the operation and, if the return code is RETCODE_OK, a SocStatistics structure. Valid return code values are:
	 */
	public SocStatisticsReturned getSocErrorStatistics(SocCommandDescriptor x) throws Exception {
		return (SocStatisticsReturned) call(173, x);
	}

	/** Set SOC error statistics baseline information
	 * @param x A reference to the controller for which statistics are to be cleared on all accessible SOC devices.
	 * @return A return code object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode clearSocErrorStatistics(String x) throws Exception {
		return (ReturnCode) call(174, x);
	}

	/** This procedure allows a client to retrieve diagnostic information from the storage array's diagnostic data capture. The client must specify a correct tag and appropriate chunk number. In case of failure, the client must either (1) retry the current chunk number or (2) discard any partially-received log data and retry from the first chunk number (which is one - zero is not a valid chunk number).
	 * @param x A DdcExtent structure specifying the chunk to be retrieved.
	 * @return A DdcLogDataReturned structure containing the procedure return code and the log data. Valid return codes are:
	 */
	public DdcLogDataReturned getDdcLog(DdcExtent x) throws Exception {
		return (DdcLogDataReturned) call(175, x);
	}

	/** This procedure clears the Needs Attention signifying the availability of diagnostic data. The client must specify a correct tag. This procedure does not clears the DDC logs in the controller.
	 * @param x A DdcTag value identifying the DDC data set that triggered the Needs Attention.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode clearDdcNeedsAttention(int x) throws Exception {
		return (ReturnCode) call(176, x);
	}

	/** This command provides a programmatic means of powering off a storage array The operation is performed as gracefully as possible. Once this command is received, all open sockets, except for those that have in-process commands, are closed, meaning that any new SYMbol commands attempted will receive an RPC error. SYMbol commands that are in-process when this command is received are allowed to continue execution. In-process SYMbol commands in the "active" category are guaranteed to complete; In-process commands in the "passive" category may complete, but there is no guarantee. This command returns and reports status just prior to the actual power down event. Authentication is required for this command.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode powerDownArray( ) throws Exception {
		return (ReturnCode) call(177, null);
	}

	/** This procedure is used to download a new firmware image to the ESM cards in a tray. This procedure is identical in behavior to loadESMFirmware. with respect to interpretation of the argument and performing the download process. It differs from that command with respect to certain pre-validation checks it performs. In particular, it requires that an ESM firmware mismatch condition exist on the indicated tray before it will proceed with the download.
	 * @param x An ESMFirmwareUpdateDescriptor object that indicates the tray to receive the firmware, the offset and size of the firmware segment being transferred.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode loadEsmFirmwareOnMismatch(ESMFirmwareUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(178, x);
	}

	/** This procedure causes the controller to store some or all of the information contained in the PendingHost argument. The information is simply stored and made available for later retrieval (see getPendingHosts procedure); it is not incorporated into the configured topology, and it is not persisted to disk. If the controller determines that the pending definition is an exact match of configured topology elements, it does not store it. It bears pointing out that, for iSCSI, multiple ports belonging to the same initiator may be present in the pending host information - when this happens, the controller creates only a single initiator, no matter how many ports for that initiator are presented. No authentication is performed on this command.
	 * @param x A PendingHost structure that describes the host to be added to the pending topology. It is not considered an error for the PendingHost structure to have a zero-length host label.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode addPendingHost(PendingHost x) throws Exception {
		return (ReturnCode) call(179, x);
	}

	/** This procedure is subject to SYMbol authentication.
	 * @param x A PendngHost structure describing a host and its related objects.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode configurePendingHost(PendingHost x) throws Exception {
		return (ReturnCode) call(180, x);
	}

	public CheckedPendingHostListReturned getPendingHosts( ) throws Exception {
		return (CheckedPendingHostListReturned) call(181, null);
	}

	/** This procedure sets arbitrary "attribute data" for a specified tray enclosure. Only the attributes specified in the argument are affected by this operation. The old data in an affected attribute is completely overwritten by the new attribute data.
	 * @param x A TrayAttributeUpdateDescriptor indicating which tray is to receive the attribute data, along with a list of elements defining new attribute data to be written.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setTrayAttributes(TrayAttributeUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(182, x);
	}

	/** This procedure gets the log data for the indicated environmental card.
	 * @param x The argument is a component reference indicating the environmental card which is to have its log data returned.
	 * @return An EnvCardLogDataReturned object containing a return code and the log data itself, if available. Valid values for the return code are:
	 */
	public EnvCardLogDataReturned getEnvCardLogData(String x) throws Exception {
		return (EnvCardLogDataReturned) call(183, x);
	}

	/** This procedure returns the SAS PHY error statistics for all SAS devices in the storage array.
	 * @return A SasStatisticsReturned structure containing a return code indicating the outcome of the operation and, if the return code is RETCODE_OK, a SasStatistics structure. Valid return code values are:
	 */
	public SasStatisticsReturned getSasErrorStatistics( ) throws Exception {
		return (SasStatisticsReturned) call(184, null);
	}

	/** Clears SAS PHY error statistics for SAS I/O controller and expander devices in the array
	 * @return A return code object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode clearSasErrorStatistics( ) throws Exception {
		return (ReturnCode) call(185, null);
	}

	/** This procedure causes the storage array to be migrated from one feature bundle definition to another, as specified in the BundleKey argument.
	 * @param x A key that defines and enables the bundle migration. This key must be obtained from an authorized source in order to be accepted by the array controller.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode applyBundleKey(BundleKey x) throws Exception {
		return (ReturnCode) call(186, x);
	}

	/** Removes all bundle keys that have been applied to change feature bundles.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode removeBundleKeys( ) throws Exception {
		return (ReturnCode) call(187, null);
	}

	/** This procedure creates a new initiator object.
	 * @param x An InitiatorCreationDescriptor object that contains all required properties for the new Initiator object.
	 * @return An InstanceReturned object that indicates the outcome of the operation, and also returns the InitiatortRef of the newly-created object if the return code is RETCODE_OK. Valid ReturnCode values are:
	 */
	public InstanceReturned createInitiator(InitiatorCreationDescriptor x) throws Exception {
		return (InstanceReturned) call(188, x);
	}

	/** This procedure deletes an initiator object.
	 * @param x A ScsiNodeRef object that identifies the initiator to delete.
	 * @return An ReturnCode object that indicates the outcome of the operation. Valid ReturnCode values are:
	 */
	public ReturnCode deleteInitiator(String x) throws Exception {
		return (ReturnCode) call(189, x);
	}

	/** This procedure returns data about active iSCSI sessions.
	 * @param x A GetIscsiSessionsFilter object that indicates that either all or a subset of the session data should be returned.
	 * @return An IscsiSessionsReturned object containing a return code and the session data, if the return code is RETCODE_OK.. Note that the case of no sessions to report is handled as a normal (RETCODE_OK) condition with the list of sessions just being an empty list. Valid ReturnCode values are:
	 */
	public IscsiSessionsReturned getIscsiSessions(GetIscsiSessionsFilter x) throws Exception {
		return (IscsiSessionsReturned) call(190, x);
	}

	/** This procedure returns the default values for negotiable settings for sessions and connections. These represent the storage array's starting point for negotiations.
	 * @return An IscsiNegotiationDefaultsReturned object containing a return code and the default negotiable settings, if the return code is RETCODE_OK.. Valid ReturnCode values are:
	 */
	public IscsiNegotiationDefaultsReturned getIscsiNegotiationDefaults( ) throws Exception {
		return (IscsiNegotiationDefaultsReturned) call(191, null);
	}

	/** This procedure returns a list of initiators that have been detected by the storage array, but which are not configured into the storage array topology. An initiator is considered unconfigured if it is not associated with a host.
	 * @return An UnconfiguredInitiatorsReturned object containing a return code and an array of ScsiNodeName that identifies the unconfigured initiators, if the return code is RETCODE_OK.. Valid ReturnCode values are:
	 */
	public UnconfiguredInitiatorsReturned getUnconfiguredInitiators( ) throws Exception {
		return (UnconfiguredInitiatorsReturned) call(192, null);
	}

	/** This procedure sets selected host properties as indicated by the input argument. It is a replacement for the deprecated moveHost, renameHost.
	 * @param x A HostPropertiesUpdateDescriptor, indicating the affected Host, which properties to set, and what values to set them to.
	 * @return An ReturnCode object indicating the outcome of the procedure Valid ReturnCode values are:
	 */
	public ReturnCode setHostProperties(HostPropertiesUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(193, x);
	}

	/** This procedure sets selected Initiator properties as indicated by the input argument.
	 * @param x An InitiatorPropertiesUpdateDescriptor, indicating which Initiator properties to set and what values to set them to.
	 * @return An ReturnCode object indicating the outcome of the procedure. Valid ReturnCode values are:
	 */
	public ReturnCode setInitiatorProperties(InitiatorPropertiesUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(194, x);
	}

	/** This procedure sets selected iSCSI entity properties for the storage array as indicated by the input argument.
	 * @param x An IscsiEntityPropertiesUpdateDescriptor, indicating which iSCSI entity properties to set and what values to set them to.
	 * @return An ReturnCode object indicating the outcome of the procedure Valid ReturnCode values are:
	 */
	public ReturnCode setIscsiEntityProperties(IscsiEntityPropertiesUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(195, x);
	}

	/** This procedure sets selected properties of a controller iSCSI interface, as indicated by the input argument.
	 * @param x An IscsiInterfacePropertiesUpdateDescriptor, indicating the affected iSCSI interface, which properties to set, and what values to set them to.
	 * @return An ReturnCode object indicating the outcome of the procedure Valid ReturnCode values are:
	 */
	public ReturnCode setIscsiInterfaceProperties(IscsiInterfacePropertiesUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(196, x);
	}

	/** This procedure sets selected Target properties as indicated by the input argument.
	 * @param x A TargetPropertiesUpdateDescriptor, indicating the affected Target, which properties to set and what values to set them to.
	 * @return An ReturnCode object indicating the outcome of the procedure Valid ReturnCode values are:
	 */
	public ReturnCode setTargetProperties(TargetPropertiesUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(197, x);
	}

	/** This procedure forcibly terminates an iSCSI session.
	 * @param x An TargetSessionIdentifyingHandle object indicating which session to terminate.
	 * @return An ReturnCode object indicating the outcome of the procedure Valid ReturnCode values are:
	 */
	public ReturnCode stopIscsiSession(int x) throws Exception {
		return (ReturnCode) call(198, x);
	}

	/** This procedure returns iSCSI statistical data collected by the storage array. The caller may request either the "raw" counts, which are relative to controller start-of-day, or baseline-relative counters, which are relative to the baseline which was last set using the setIscsiStatisticsBaselilne procedure. If the user has not set a baseline since controller start-of-day, then the time at start-of-day is the default baseline time.
	 * @param x An IscsiStatisticsReportType object that indicates if the reported statistics should be the raw or baseline-relative counters.
	 * @return An IscsiStatisticsReturned object containing a return code and the statistical data, if the return code is RETCODE_OK.. The reported statistics and time references are broken out by controller. The time references reported for the two controllers should be the same, unless, over the collection interval, one controller was reset without the other being reset. Valid ReturnCode values are:
	 */
	public IscsiStatisticsReturned getIscsiStatistics(IscsiStatisticsReportType x) throws Exception {
		return (IscsiStatisticsReturned) call(199, x);
	}

	/** This procedure, from the client's perspective, resets the iSCSI statistical counters to zero. It is a logical reset in the sense that the raw counts maintained in hardware and firmware are not actually reset; instead the firmware makes a snapshot of the current counter values and uses that to report deltas in counts when the statistics are fetched. The new baseline time is applied to both controllers, so that their counts are in sync with one another. If one controller resets without the other resetting, the counters become effectively out of sync and the client is made aware of this fact by the timestamp data reported along with the statistics.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setIscsiStatisticsBaseline( ) throws Exception {
		return (ReturnCode) call(200, null);
	}

	/** This procedure sets selected properties for the storage array that is the recipient of the call.
	 * @param x A StorageArrayPropertiesUpdateDescriptor, indicating which properties to set and what values to set them to.
	 * @return An ReturnCode object indicating the outcome of the procedure Valid ReturnCode values are:
	 */
	public ReturnCode setStorageArrayProperties(StorageArrayPropertiesUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(201, x);
	}

	/** This procedure validates the clients storage array password and reports a return code indicating whether or not the password is valid. Even though it does not modify the state of the array, this procedure behaves the same and has the same setup requirements as a procedure that does modify the state of the array.
	 * @return A ReturnCode object indicating the validity of the password. Valid values are:
	 */
	public ReturnCode validatePassword( ) throws Exception {
		return (ReturnCode) call(202, null);
	}

	/** This procedure performs a refresh of the DHCP parameters for the iSCSI interface specified by the input argument. The affected parameters are port IP address, subnet mask, and gateway IP address.
	 * @param x An Interface reference that identifies the iSCSI interface on which the operation is to be performed.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode refreshIscsiDhcpParameters(String x) throws Exception {
		return (ReturnCode) call(203, x);
	}

	/** This procedure causes the storage array to refresh its idea of the network address information for the iSNS server
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode refreshIsnsServerLocation( ) throws Exception {
		return (ReturnCode) call(204, null);
	}

	/** This procedure will disable (stop) each snapshot volume identified in the argument list. Validation checks for necessary snapshot-disable preconditions are performed prior to disabling any snapshot; if any of the requested snapshots do not meet the preconditions to be disabled, the entire command will be failed and no snapshots will be disabled. If command validation succeeds for all snapshots in the list, but one or more of the snapshots in the list fails to be disabled, the entire command will be failed and no snapshots will be disabled. Requests to disable an already-disabled Snapshot will be treated as no-ops and will be considered successful.
	 * @param x A SnapshotRefList structure identifying the snapshot volume that are to be disabled. The list may contain as few as one snapshot reference or up to MAX_SNAPSHOT_COLLECTION_SIZE references.
	 * @return A ReturnCode object that indicates either good status or the first error encountered. Valid values are:
	 */
	public ReturnCode disableSnapshotCollection(SnapshotRefList x) throws Exception {
		return (ReturnCode) call(225, x);
	}

	/** During snapshot recreation, all affected volumes (snapshots, base, and repository) will be appropriately quiesced; I/O will be resumed to all affected volumes once all snapshots have been successfully restarted.
	 * @param x A SnapshotRefList structure identifying the snapshot volume that are to be restarted. The list may contain as few as one snapshot reference or up to MAX_SNAPSHOT_COLLECTION_SIZE references.
	 * @return A ReturnCode object that indicates either good status or the first error encountered. Valid values are:
	 */
	public ReturnCode recreateSnapshotCollection(SnapshotRefList x) throws Exception {
		return (ReturnCode) call(226, x);
	}

	/** Create an empty VolumeGroup
	 * @param x A VolumeGroupCreationDescriptor structure containing the volume group creation parameters. The information about the volume group drive composition, RAID level, etc. is conveyed in an embedded VolumeCandidate structure.
	 * @return A return code indicating the outcome of the procedure. Valid values are:
	 */
	public ReturnCode createVolumeGroup(VolumeGroupCreationDescriptor x) throws Exception {
		return (ReturnCode) call(235, x);
	}

	/** Delete VolumeGroup and all Volumes in that group
	 * @param x A reference to the volume group that is to be deleted.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteVolumeGroup(String x) throws Exception {
		return (ReturnCode) call(236, x);
	}

	/** This procedure provides a way to clear the storage array configuration without bringing it all the way back to its initial state. Core security and identification may be retained, if desired.
	 * @param x A ResetConfigType object that indicates which parts of the array configuration are to be cleared.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode resetSAConfiguration(ResetConfigType x) throws Exception {
		return (ReturnCode) call(237, x);
	}

	/** Sets the user assigned label for the volume group specified in the VolumeGroupLabelUpdate structure.
	 * @param x A VolumeGroupUserLabelUpdateDescriptor structure that contains the user label and a reference to the volume group to update.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setVolumeGroupUserLabel(VolumeGroupLabelUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(238, x);
	}

	/** This procedure causes a drive, A, that is not part of a volume group to replace a drive, B, that is part of a volume group. The end result is that the volume group drive composition is redefined to include A, and exclude B. The only candidate drives for being replaced are those that belong to a volume group and are either not-present or are failed. The only candidate drives for replacing a drive are those that are either unassigned or are a fully-integrated hot spare.
	 * @param x A DriveReplacementDescriptor structure that identifies the drive to replace and the replacement drive.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode replaceDrive(DriveReplacementDescriptor x) throws Exception {
		return (ReturnCode) call(239, x);
	}

	/** The firmware prioritizes the properties of candidates for constructing the return list, subject to the volume group having a given property in the first place. The prioritization and ordering of the list is as follows:
	 * @param x A reference to the volume group to which the candidates are to apply.
	 * @return An ExpansionCandidatesReturned data type containing both a return code and the list of candidates. Possible return codes are:
	 */
	public ExpansionCandidatesReturned getVolumeGroupExpansionCandidates(String x) throws Exception {
		return (ExpansionCandidatesReturned) call(240, x);
	}

	/** This procedure places the identified volume group in an "exported" state so that its drives may be removed and installed into another array.
	 * @param x A SYMbol VolumeGroupRef identifying the volume group to export.
	 * @return A return code indicating the outcome of the operation. The list below identifies the possible return codes for this procedure:
	 */
	public ReturnCode exportVolumeGroup(String x) throws Exception {
		return (ReturnCode) call(241, x);
	}

	/** This procedure applies to a volume group for which successful migration of drives from the source array to the target array could not be completed due to hardware errors. It causes the identified volume group to move to a state called the "forced" state, from which it is still permissible to perform an import operation on the volume group.
	 * @param x A SYMbol VolumeGroupRef identifying the volume group to export.
	 * @return A return code indicating the outcome of the operation. The list below identifies the possible return codes for this procedure:
	 */
	public ReturnCode forceVolumeGroup(String x) throws Exception {
		return (ReturnCode) call(242, x);
	}

	/** This procedure causes the identified volume group to be imported, which move it from either the "exported" state or the "forced" state to the "complete" state in which it is fully operable and available for use. Note that "higher-level" volumes (SnapshotVolume, MetadataVolume, VolumeCopy, and MirrorProxyVolume) - but not their underlying RAID volumes - are removed as part of the import.
	 * @param x A SYMbol VolumeGroupRef identifying the volume group to export.
	 * @return A return code indicating the outcome of the operation. The list below identifies the possible return codes for this procedure:
	 */
	public ReturnCode importVolumeGroup(String x) throws Exception {
		return (ReturnCode) call(243, x);
	}

	/** This procedure activates the collection of a set of statistics known as a "discrete time series" (discrete time) on each control of the array. A discrete time is a time-ordered sequence of observations of a single statistic, sampled at regular intervals.
	 * @param x A DiscreteTimeSeriesDescriptor structure containing the arguments for the procedure call.
	 * @return A StatStreamIdReturned structure containing a return code, and, if the return code is RETCODE_OK, a StatStreamId object for identifying the statistics stream in other related procedure calls. The possible return code values are:
	 */
	public StatStreamIdReturned activateDiscreteTimeSeries(DiscreteTimeSeriesDescriptor x) throws Exception {
		return (StatStreamIdReturned) call(244, x);
	}

	/** This procedure deactivates the discrete time series statistical streams
	 * @param x A StatStreamId object that identifies the discrete time series to deactivate.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deactivateDiscreteTimeSeries(int x) throws Exception {
		return (ReturnCode) call(245, x);
	}

	/** This returns up to two groups of discrete time series statistics, one per controller
	 * @param x A StatStreamId object that identifies the discrete time series statistics to return.
	 * @return A DiscreteTimeSeriesBundleReturned structure containing a return code, and, if the return code value is RETCODE_OK, the discrete time series statistics. The possible return codes for this procedure are
	 */
	public DiscreteTimeSeriesBundleReturned getDiscreteTimeSeriesBundle(int x) throws Exception {
		return (DiscreteTimeSeriesBundleReturned) call(246, x);
	}

	/** This procedure resets the related discrete time series statistical streams on both controller, i.e., it sets the number of observations for the series back to zero.
	 * @param x A StatStreamId object that identifies the discrete time series to reset.
	 * @return A return code that indicates the outcome of the operation. Possible return codes for this procedure are:
	 */
	public ReturnCode resetDiscreteTimeSeries(int x) throws Exception {
		return (ReturnCode) call(247, x);
	}

	/** This procedure returns up to two groups of histogram statistics, one per controller,
	 * @param x A StatStreamId object that identifies the histogram statistics to return.
	 * @return A HistogramBundleReturned structure containing a return code, and, if the return code value is RETCODE_OK, the histogram statistics. The possible return codes for this procedure are
	 */
	public HistogramBundleReturned getHistogramBundle(int x) throws Exception {
		return (HistogramBundleReturned) call(248, x);
	}

	/** This procedure activates a type of statistics stream known as a histogram on each controller of the array. A histogram is a set of observations of a single statistic, organized into categories based on user criteria, with observation counts per category identified.
	 * @param x A HistogramDescriptor structure containing the arguments for the procedure call.
	 * @return A StatStreamIdReturned structure containing a return code, and, if the return code is RETCODE_OK, a StatStreamId object for identifying the activated statistics set in other related procedure calls. The possible return code values are:
	 */
	public StatStreamIdReturned activateHistogram(HistogramDescriptor x) throws Exception {
		return (StatStreamIdReturned) call(249, x);
	}

	/** This procedure deactivates a histogram statistics set, given a stream ID.
	 * @param x A StatStreamId object that identifies the histogram set to deactivate.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deactivateHistogram(int x) throws Exception {
		return (ReturnCode) call(250, x);
	}

	/** This procedure resets the related histograms both controllers, i.e., it sets the number of entries in each category and all observation tallies back to zero.
	 * @param x A StatStreamId object that identifies the histograms to reset.
	 * @return A return code that indicates the outcome of the operation. Possible return codes for this procedure are:
	 */
	public ReturnCode resetHistogram(int x) throws Exception {
		return (ReturnCode) call(251, x);
	}

	/** This procedure returns up to two groups of statistical counters, one per controller, bundled together. A counter group is a set of related statistical counters, accumulated over a period of time, along with the associated base time.
	 * @param x A CumulativeStatisticsDescriptor structure describing the statistics of interest.
	 * @return A CumulativeStatisticsBundleReturned structure containing a return code, and, if the return code value is RETCODE_OK, the counter bundle statistical data. Possible return codes for this procedure are:
	 */
	public CumulativeStatisticsBundleReturned getCumulativeStatisticsBundle(CumulativeStatisticsDescriptor x) throws Exception {
		return (CumulativeStatisticsBundleReturned) call(252, x);
	}

	/** This procedure sets all cumulative statistics on each controller back to zero and sets a new base time equal to the current time.
	 * @return A return code that indicates the outcome of the operation. Possible return codes for this procedure are:
	 */
	public ReturnCode resetCumulativeStatistics( ) throws Exception {
		return (ReturnCode) call(253, null);
	}

	/** This procedure returns a list of volume group export dependencies for the identified volume group. The returned list consists of the input volume group's immediate export dependencies only. The procedure does not return transitive dependencies. It is up to the caller to create the complete dependency graph through successive calls to this procedure.
	 * @param x A SYMbol VolumeGroupRef identifying the volume group for which export dependencies are to be reported.
	 * @return An ExportDependenciesReturned structure containing a return code and, provided the return code is RETCODE_OK, a list of volume group export dependencies. The list below identifies the return codes for this procedure:
	 */
	public ExportDependenciesReturned getExportDependencies(String x) throws Exception {
		return (ExportDependenciesReturned) call(254, x);
	}

	/** Deletes the snapshot volume identified by the input argument. All data on the volume is lost and all resources associated with maintaining the snapshot are released.
	 * @param x A SYMbol reference to the snapshot volume that is to be deleted.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteSnapshot(String x) throws Exception {
		return (ReturnCode) call(255, x);
	}

	/** This procedure deletes the volume referenced by the input argument. The procedure allows the caller to specify which behavior is desired for the case of deleting the last volume in the volume group - either delete or retain the volume group.
	 * @param x A VolumeDeletionDescriptor which contains (1) a reference to the volume to delete and (2) a boolean indicator, which indicates whether to delete or retain the volume group when the last volume in the group is deleted.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteVolumeFromGroup(VolumeDeletionDescriptor x) throws Exception {
		return (ReturnCode) call(256, x);
	}

	/** This procedure indicates to the storage array firmware that the client does not want to proceed with a volume group import operation, and therefore the firmware may spin down the drives that were spun up by the get- ImportDependencies procedure.
	 * @param x A reference to the volume group for which the import is to be canceled.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode cancelImport(String x) throws Exception {
		return (ReturnCode) call(257, x);
	}

	/** This procedure returns a list of volume group import dependencies for the identified volume group. The reported information identifies the types of dependencies that exist for the volume group. It is necessary for this procedure to spin up the drives in the volume group so that their configuration databases can be read. An error is returned if the volume group is not in the exported or forced state.
	 * @param x A SYMbol VolumeGroupRef identifying the volume group for which import dependencies are to be reported.
	 * @return An ImportDependenciesReturned structure containing a return code and, provided the return code is RETCODE_OK, a list of volume group import dependencies. The list below identifies the return codes for this procedure:
	 */
	public ImportDependenciesReturned getImportDependencies(String x) throws Exception {
		return (ImportDependenciesReturned) call(258, x);
	}

	/** This procedure is used for setting new values of certain volume properties. It supports setting some properties while leaving others unchanged.
	 * @param x A VolumePropertiesUpdateDescriptor structure specifying which properties to change and what their new values should be.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setVolumeProperties(VolumePropertiesUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(259, x);
	}

	/** This procedure caused the storage array to "adopt" all foreign drives that are eligible to be adopted. Adoption means accepting or incorporating elements of a foreign drive's configuration database into that of the recipient array. It must be possible for the storage array to match the adoption-candidate drives with ones that are currently being tracked as "not present." In addition, several other technical criteria must be met in order for the adoption to succeed.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode adoptAllDrives( ) throws Exception {
		return (ReturnCode) call(260, null);
	}

	/** This procedure caused the storage array to "adopt" a foreign drive that is eligible to be adopted. Adoption means accepting or incorporating elements of a foreign drive's configuration database into that of the recipient array. It must be possible for the storage array to match the adoption-candidate drive with one that is currently being tracked as "not present." In addition, several other technical criteria must be met in order for the adoption to succeed.
	 * @param x A SYMbol reference to the drive that is to be adopted.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode adoptDrive(String x) throws Exception {
		return (ReturnCode) call(261, x);
	}

	/** This procedure replaces the deprecated stateCapture procedure. It returns a single "chunk" of debug information and must be used in a series of like calls in order to retrieve the complete set of debug information.
	 * @param x A DebugInfoExtent structure containing three pieces of information: a reference to the controller that is to return the data, a "handle" identifying a single mutually-consistent set of chunks, and a chunk number that identifies the specific chunk to be returned. On the request for the initial chunk (chunk zero), the handle is not significant.
	 * @return A DebuginfoReturned union consisting of a return code, and, if the code is equal to RETCODE_OK, a structure containing the handle to use on subsequent calls, a count of the total number of chunks, and a block (i.e., "chunk") of display-able debug data.
	 */
	public DebugInfoReturned getControllerDebugInformation(DebugInfoExtent x) throws Exception {
		return (DebugInfoReturned) call(262, x);
	}

	/** This procedure returns attribute information for each InfiniBand I/O controller that is part of the Infiniband I/O Unit. An InfiniBand I/O Controller is a logical entity defined in the InfiniBand Architecture. It does not correlate one-to-one with a storage array controller
	 * @return A union containing a return code and, if the call succeeded, an array holding a set of InfiniBand IOC attributes for each InfiniBand IOC in the array. The list below identifies the return codes for this procedure.
	 */
	public IbIocAttributesReturned getIbIocAttributes( ) throws Exception {
		return (IbIocAttributesReturned) call(400, null);
	}

	/** This procedure returns a group of InfiniBand port partition tables, one table for each InfiniBand port of the Infiniband I/O Unit (i.e., storage array).
	 * @return A union containing a return code and, if the call succeeded, an array of PortPartitionTable elements, one for each InfiniBand port of the storage array. The list below identifies the return codes for this procedure.
	 */
	public IbPortPartitionTablesReturned getIbPortPartitionTables( ) throws Exception {
		return (IbPortPartitionTablesReturned) call(401, null);
	}

	/** This procedure returns various items of information about InfiniBand RDMA channels that are presently active in the Infiniband I/O Unit (i.e., storage array).
	 * @return A union containing a return code and, if the call succeeded, an array of informational elements, one for each currently-active RDMA channel. The list below identifies the return codes for this procedure.
	 */
	public IbRdmaChannelsReturned getIbRdmaChannels( ) throws Exception {
		return (IbRdmaChannelsReturned) call(402, null);
	}

	/** This procedure returns the InfiniBand statistics, which consist of start-of-day-relative interface statistics, baseline-relative interface statistics, target channel adapter statistics, and RDMA channel statistics.
	 * @return An IbStatisticsReturned structure containing the InfiniBand statistics. The list below identifies the return codes for this procedure.
	 */
	public IbStatisticsReturned getIbStatistics( ) throws Exception {
		return (IbStatisticsReturned) call(403, null);
	}

	/** This procedure, from the client's perspective, resets the InfiniBand baselined statistical counters to zero. It is a logical reset in the sense that the raw counts maintained in hardware and firmware are not actually reset; instead the firmware makes a snapshot of the current counter values and uses that to report deltas in counts when the statistics are fetched. The new baseline time is applied to both controllers, so that their counts are in sync with one another. If one controller resets without the other resetting, the counters become effectively out of sync and the client is made aware of this fact by the timestamp data reported along with the statistics.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setIbStatisticsBaseline( ) throws Exception {
		return (ReturnCode) call(404, null);
	}

	/** This procedure creates a new host port having the attributes specified in the input argument. It is a replacement for the deprecated createHostPort procedure.
	 * @param x A HostPortCreateDescriptor object containing a set of attributes to assign to the new host port.
	 */
	public InstanceReturned createAHostPort(HostPortCreateDescriptor x) throws Exception {
		return (InstanceReturned) call(405, x);
	}

	/** When this command is issued directly to the controller for which the Ethernet properties will change, controller firmware will issue a return code of RETCODE_BACKGROUND to the storage management software before resetting the Ethernet properties and stopping communication. Storage management software developers should maintain both old and new Ethernet properties for the controller in case the procedure fails (if the procedure fails at this point status will not be able to be returned and the storage management software should reestablish communication with the controller using the old Ethernet properties).
	 * @param x An EthernetInterfacePropertiesUpdateDescriptor, indicating the affected Ethernet interface, which properties to set, and what values to set them to.
	 * @return An ReturnCode object indicating the outcome of the procedure Valid ReturnCode values are:
	 */
	public ReturnCode setEthernetInterfaceProperties(EthernetInterfacePropertiesUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(407, x);
	}

	/** This procedure sets selected HostPort properties, as specified by the input argument. It is a replacement for the deprecated moveHostPort, renameHostPort.
	 * @param x A HostPortPropertiesUpdateDescriptor structure which indicates the affected host port, which properties to set, and what values to set for them.
	 */
	public ReturnCode setHostPortProperties(HostPortPropertiesUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(408, x);
	}

	/** This procedure is for setting certain changeable properties of an individual controller. The procedure works in such a way that specific properties can be changed while leaving others unchanged.
	 * @param x A ControllerPropertiesUpdateDescriptor structure that indicates to which controller the operation applies and the new settings for that controller.
	 */
	public ReturnCode setControllerProperties(ControllerPropertiesUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(409, x);
	}

	/** This procedure initiates a drive channel fault isolation diagnostic test. It returns a status code immediately and the requested tests proceed asynchronously. Any SYMbol request, other than getChannelDiagnosticsResults, cancelChannelDiagnostics, bindToController, and getSAData that is received while the test is running is rejected immediately. Since some SYMbol procedures do not provide a return code, the method of indicating the request rejection is specialized and entails the following: The RPC header that is returned to the client will consist of an RPC response of type "reply message." The reply will have a general status of "accepted," indicating the request was accepted by the controller for processing. The specific "accepted request status" value will be 0x80000001, which is an indication that the request could not be processed due to a diagnostic activity.
	 * @param x A ChannelDiagnosticDescriptor structure that contains all of the arguments needed to define the test to perform.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startChannelDiagnostics(ChannelDiagnosticDescriptor x) throws Exception {
		return (ReturnCode) call(410, x);
	}

	/** This procedure cancels a running channel diagnostic test sequence that was initiated by the startChannelDiagnostics procedure. It is possible to retrieve the (partial) results of a canceled test by calling getChannelDiagnosticsResults.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode stopChannelDiagnostics( ) throws Exception {
		return (ReturnCode) call(411, null);
	}

	/** This procedure reports the results of drive channel fault isolation diagnostic tests that were initiated by the startChannelDIagnostics procedure.
	 * @return A ChannelDiagResultsReturned structure containing a return code along with the results of the channel diagnostic tests. The results may indicate that the tests are still running.
	 */
	public ChannelDiagResultsReturned getChannelDiagnosticsResults( ) throws Exception {
		return (ChannelDiagResultsReturned) call(412, null);
	}

	/** NOTE: object graph data may not be the most recent.
	 * @param x A reference to the controller for which the I/O interface information is desired.
	 * @return The procedure return code plus the returned I/O interface data, provided the return code is RETCODE_OK.
	 */
	public ControllerHostIoInterfacesReturned getControllerHostIoInterfaces(String x) throws Exception {
		return (ControllerHostIoInterfacesReturned) call(413, x);
	}

	/** Returns a structure containing information about the controller if it is locked down.
	 * @return If getCtlLockDownInfo() returned successfully, then this union will contain information about the locked down controller.
	 */
	public LockDownInfoReturned getCtlLockDownInfo( ) throws Exception {
		return (LockDownInfoReturned) call(414, null);
	}

	/** To indicate the end of the iterative download sequence, call this procedure with a zero-length segment size. When the controller receives this end indicator, the controller writes the accumulated firmware image to stable storage (typically flash memory). The controller responds to this procedure call with the appropriate return code, delays for a short period, and then reboots to load and execute the new firmware.
	 * @param x A FirmwareUpdateDescriptor object that indicates, among other things, the offset and size of the firmware segment being transferred.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode loadControllerFirmwareOnLockdown(FirmwareUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(415, x);
	}

	/** Disables protection information (PI) usage for the specified volume.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode disableVolumeProtectionInformation(String x) throws Exception {
		return (ReturnCode) call(416, x);
	}

	/** This procedure is used in conjunction with the createLockKey procedure. This request may be issued to change the existing array lock key or to set an array lock key after a database adoption. The procedure commits the lock key generated by the createLockKey procedure to the drives and to the controllers.
	 * @return Returns a Return Code indicating if the lockKey was set
	 */
	public ReturnCode setLockKey( ) throws Exception {
		return (ReturnCode) call(504, null);
	}

	/** This procedure allows a security locked drive to be unlocked. An archived, wrapped and encrypted lock key is imported into the array. In response, the controller attempts to unlock all security-locked drives that have a matching lock key ID. The imported lock key and lock key id become the new array lock key and lock key ID.
	 * @param x A LockKeyBlob structure that contains the wrapped lock key and the pass phrase used to encrypt the lock key.
	 * @return Returns a Return Code indicating if the operation was successful.
	 */
	public ReturnCode importLockKey(LockKeyBlob x) throws Exception {
		return (ReturnCode) call(505, x);
	}

	/** This procedure returns the WrappedLockKeyReturn union for the array.The WrappedLockKeyReturn contains the WrappedLockKey structure for the array it was exported from.
	 * @param x The wrapped pass phrase used to encrypt the lock key.
	 * @return A wrapped lock key in the WrappedLockKeyReturn union. See the WrappedLockKeyReturn union and the WrappedLockKey structure for more information.
	 */
	public WrappedLockKeyReturn exportLockKey(String x) throws Exception {
		return (WrappedLockKeyReturn) call(506, x);
	}

	/** This procedure resets each drive's lock key to a new, random value and disables each drive's security system.
	 * @param x A list of drive reference values, which identifies the drives to be re-provisioned.
	 * @return A return code that indicates the outcome of the operation.
	 */
	public ReturnCode reprovisionDrive(DriveRefList x) throws Exception {
		return (ReturnCode) call(507, x);
	}

	/** This procedure converts the specified volume group to a secure volume group.
	 * @param x The VolumeGroupRef identifier for the volume to be secured.
	 * @return A return code that indicates the outcome of the operation.
	 */
	public ReturnCode secureVolumeGroup(String x) throws Exception {
		return (ReturnCode) call(508, x);
	}

	/** This procedure creates a new lock key for the array, but does not commit the key to the drives. There must be at least one FDE capable drive present on the array.
	 * @param x This is used to generate the WrappedLockKey that this procedure returns.
	 * @return This structure contains the return data for this procedure. It contains a return code, and, provided that code is RETCODE_OK, the wrapped lock key in a wrappedLockKey structure.
	 */
	public WrappedLockKeyReturn createLockKey(KeyIDInfo x) throws Exception {
		return (WrappedLockKeyReturn) call(509, x);
	}

	/** Activates an inactive host port.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode activateHostPort(String x) throws Exception {
		return (ReturnCode) call(510, x);
	}

	/** Activates inactive iSCSI initiator.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode activateInitiator(String x) throws Exception {
		return (ReturnCode) call(511, x);
	}

	/** This procedure retrieves a list of product capabilities supported by the array.
	 * @return A list of product capabilities supported by the array.
	 */
	public ProductCapabilityList getProductCapabilities( ) throws Exception {
		return (ProductCapabilityList) call(513, null);
	}

	/** Disables external KMS.
	 * @return A WrappedLockKey object that indicates the outcome of the operation.
	 */
	public WrappedLockKeyReturn disableExternalKMS(String x) throws Exception {
		return (WrappedLockKeyReturn) call(516, x);
	}

	/** Enables external KMS.
	 * @return A wrapped lock key object that indicates the outcome of the operation. Valid values are:
	 */
	public WrappedLockKeyReturn enableExternalKMS(String x) throws Exception {
		return (WrappedLockKeyReturn) call(517, x);
	}

	/** Passes an existing lock key for the array and unlocks the disks.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode installLockKey(WrappedLockKeyList x) throws Exception {
		return (ReturnCode) call(518, x);
	}

	/** Passes a new lock key for the array and commits the key to the disks.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode installNewLockKey(NewLockKey x) throws Exception {
		return (ReturnCode) call(519, x);
	}

	/** Starts a cache memory diagnostic test on the controller
	 * @param x A structure containing the test type for the controller.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startCacheMemoryDiagnostic(FruDiagDescriptor x) throws Exception {
		return (ReturnCode) call(520, x);
	}

	/** Retrieves the status of a running, interrupted, or completed cache memory diagnostic test.
	 * @return A FruDiagReturn object that indicates the outcome of the operation. Valid values are:
	 */
	public FruDiagReturn getCacheMemoryDiagnosticStatus( ) throws Exception {
		return (FruDiagReturn) call(521, null);
	}

	/** Cancels a running cache memory diagnostic test and returns the test status.
	 * @return A FruDiagReturn object that indicates the outcome of the operation. Valid values are:
	 */
	public FruDiagReturn cancelCacheMemoryDiagnostic( ) throws Exception {
		return (FruDiagReturn) call(522, null);
	}

	/** Starts a cache backup device diagnostic test on the controller
	 * @param x A structure containing the test type and slot number for the procedure call.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startCacheBackupDeviceDiagnostic(FruDiagDescriptor x) throws Exception {
		return (ReturnCode) call(523, x);
	}

	/** Retrieves the status of a running, interrupted, or completed cache backup device diagnostic test.
	 * @return A FruDiagReturn object that indicates the outcome of the operation. Valid values are:
	 */
	public FruDiagReturn getCacheBackupDeviceDiagnosticStatus( ) throws Exception {
		return (FruDiagReturn) call(524, null);
	}

	/** Cancels a running cache backup device diagnostic test and returns the test status.
	 * @return A FruDiagReturn object that indicates the outcome of the operation. Valid values are:
	 */
	public FruDiagReturn cancelCacheBackupDeviceDiagnostic( ) throws Exception {
		return (FruDiagReturn) call(525, null);
	}

	/** Starts a host card diagnostic test on the controller
	 * @param x A structure containing the test type and slot number for the procedure call.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startHostCardDiagnostic(FruDiagDescriptor x) throws Exception {
		return (ReturnCode) call(526, x);
	}

	/** Retrieves the status of a running, interrupted, or completed host card diagnostic test.
	 * @return A FruDiagReturn object that indicates the outcome of the operation. Valid values are:
	 */
	public FruDiagReturn getHostCardDiagnosticStatus( ) throws Exception {
		return (FruDiagReturn) call(527, null);
	}

	/** Cancels a running host card diagnostic test and returns the test status
	 * @return A FruDiagReturn object that indicates the outcome of the operation. Valid values are:
	 */
	public FruDiagReturn cancelHostCardDiagnostic( ) throws Exception {
		return (FruDiagReturn) call(528, null);
	}

	/** Starts a base controller diagnostic test on the controller.
	 * @param x A structure containing the test type for the procedure call.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startBaseControllerDiagnostic(FruDiagDescriptor x) throws Exception {
		return (ReturnCode) call(529, x);
	}

	/** Retrieves the status of a running, interrupted, or completed base controller diagnostic test.
	 * @return A FruDiagReturn object that indicates the outcome of the operation. Valid values are:
	 */
	public FruDiagReturn getBaseControllerDiagnosticStatus( ) throws Exception {
		return (FruDiagReturn) call(530, null);
	}

	/** Cancels a running base controller diagnostic test and returns the test status.
	 * @return A FruDiagReturn object that indicates the outcome of the operation. Valid values are:
	 */
	public FruDiagReturn cancelBaseControllerDiagnostic( ) throws Exception {
		return (FruDiagReturn) call(531, null);
	}

	/** Used to download some or all of a new firmware image file to a controller when the authentication password is unavailable.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode loadControllerFirmwareNoPassword(FirmwareUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(541, x);
	}

	/** Used to start an evaluation of a specified feature using the duration specified for the sub-model ID in the FBDT.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode enableFeatureEvaluation(Capability x) throws Exception {
		return (ReturnCode) call(542, x);
	}

	/** Used to re-key the array with a new lock key.
	 * @param x The wrapped pass phrase used to encrypt the lock key.
	 * @return A wrapped lock key in the WrappedLockKeyReturn union. See the WrappedLockKeyReturn union and the WrappedLockKey structure for more information.
	 */
	public WrappedLockKeyReturn externalKMSReKey(String x) throws Exception {
		return (WrappedLockKeyReturn) call(543, x);
	}

	/** Used to validate the supplied key with one currently on the controller.
	 * @param x A LockKeyBlob structure that contains the wrapped lock key and the pass phrase used to encrypt the lock key.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode validateLockKey(LockKeyBlob x) throws Exception {
		return (ReturnCode) call(544, x);
	}

	/** Places the set of volumes online.
	 * @param x The list AbstractVolRefList of volumes to be placed online.
	 * @return A list of responses from each volume and a return code that indicates the outcome of the operation. Valid values for the return code are:
	 */
	public VolumeListReturned setVolumeListOnline(AbstractVolRefList x) throws Exception {
		return (VolumeListReturned) call(548, x);
	}

	/** This procedure starts a raw data retrieval operation.
	 * @param x The controller ref and transfer-type-specific details of the retrieval.
	 * @return This data will contain both a return code and a raw data transfer type.
	 */
	public RawDataRetrieveStartResult startRawDataRetrieve(RawDataRetrieveStartDesc x) throws Exception {
		return (RawDataRetrieveStartResult) call(549, x);
	}

	/** This procedure is called for each chunk of raw data to be transferred to the host. The first call must be preceded by a call to startRawDataRetrieve().
	 * @param x The controller ref, raw data transfer type and the sequence number for this chunk.
	 * @return This data will contain a return code, a raw data transfer type, this sequence number, the final sequence number for the data retrieve, and the chunk details for this chunk.
	 */
	public RawDataRetrieveResult continueRawDataRetrieve(RawDataRetrieveContinueDesc x) throws Exception {
		return (RawDataRetrieveResult) call(550, x);
	}

	/** This procedure cancels a raw data retrieve operation.
	 * @param x The raw data transfer type and controller reference.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode cancelRawDataRetrieve(RawDataTransferCancelDesc x) throws Exception {
		return (ReturnCode) call(551, x);
	}

	/** starts a raw data restore operation.
	 * @param x Specifies the controller ref, data transfer type and transfer-type-specific parameters for the restore operation.
	 * @return This data will contain both a return code and a raw data transfer type.
	 */
	public RawDataRestoreResult startRawDataRestore(RawDataRestoreStartDesc x) throws Exception {
		return (RawDataRestoreResult) call(552, x);
	}

	/** This procedure is called once to restore each chunk of data, after first calling a startRawDataRestore to notify the controller that it needs to prepare for the restore. On the first call to this procedure, a return code of RETCODE_RAWDATA_TRANSFER_PREPARING indicates that the controller has not completed the preparation, and the first call should be retried. Upon successful completion of the first call (RETCODE_OK), subsequent calls should be made to transfer additional chunks of data, incrementing the sequence number by one for each call.
	 * @param x The controller ref, type of transfer, final sequence number of the transfer, the sequence number of the chunk currently being delivered, and the restore details for the chunk.
	 * @return This data will contain both a return code and a raw data transfer type.
	 */
	public RawDataRestoreResult continueRawDataRestore(RawDataRestoreContinueDesc x) throws Exception {
		return (RawDataRestoreResult) call(553, x);
	}

	/** This procedure cancels a raw data restore operation.
	 * @param x The transfer type and controller reference.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode cancelRawDataRestore(RawDataTransferCancelDesc x) throws Exception {
		return (ReturnCode) call(554, x);
	}

	/** This procedure sets the selected remote target properties as indicated by the input arguments.
	 * @param x The updated settings for the new target initiator identified in the descriptor.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setRemoteTargetProperties(InitiatorTargetPropertiesUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(556, x);
	}

	/** This procedure saves a new value of the specified MgmtClientRecords.
	 * @param x The MgmtClientRecordWriteDescriptor object.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode writeClientMgmtRecordsNoPassword(MgmtClientRecordWriteDescriptor x) throws Exception {
		return (ReturnCode) call(559, x);
	}

	/** This procedure deletes a range of (i.e. one or more) specified MgmtClientRecords.
	 * @param x The MgmtClientRecordDeleteDescriptor value.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteClientMgmtRecordsNoPassword(MgmtClientRecordDeleteDescriptor x) throws Exception {
		return (ReturnCode) call(560, x);
	}

	/** This procedure is used to download factory default information to a controller or expansion enclosure.
	 * @param x The factory default data.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode loadFactoryDefaults(FactoryDefaultsDescriptor x) throws Exception {
		return (ReturnCode) call(562, x);
	}

	/** This procedure will retrieve state capture information from controller and expansion enclosures, including DCMs, if any. Send the command to both controllers if the tray is an RBOD.
	 * @param x The ref corresponding to the enclosure for which the data is requested.
	 * @return A pointer to the statePrintBuffer where any output from the function is stored.
	 */
	public ReturnCodeWithOpaqueData getEnclosureStateCaptureData(String x) throws Exception {
		return (ReturnCodeWithOpaqueData) call(563, x);
	}

	/** Allows a client to fetch a set of entries that have the alertable, needs attention, or collect support bundle flag set from the array's MEL for analysis or display.
	 * @param x The range of MEL entries.
	 * @return Information associated with the MEL entries in the set.
	 */
	public MelEntryList getAlertableMelEntries(MelExtent x) throws Exception {
		return (MelEntryList) call(565, x);
	}

	/** This procedure will report progress on each actively running long-lived operation.
	 * @return Information about the progress of long lived operations.
	 */
	public LongLivedOpsProgressReturn getLongLivedOpsProgress( ) throws Exception {
		return (LongLivedOpsProgressReturn) call(566, null);
	}

	/** This procedure is used to initiate a snapshot rollback (to base) on one or more snapshots.
	 * @param x A reference to the snapshots to roll back.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startSnapshotRollback(SnapshotRefList x) throws Exception {
		return (ReturnCode) call(567, x);
	}

	/** This procedure is used to cancel a snapshot rollback operation.
	 * @param x A reference to the snapshot on which to cancel the rollback.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode cancelSnapshotRollback(String x) throws Exception {
		return (ReturnCode) call(568, x);
	}

	/** This procedure is used to resume suspended snapshot rollback operations.
	 * @param x A reference to the snapshot for which to resume the snapshot rollback operation.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode resumeSnapshotRollback(String x) throws Exception {
		return (ReturnCode) call(569, x);
	}

	/** This procedure is used to create a list of schedules.
	 * @param x A list of schedule creation descriptors.
	 * @return A list of refs and status.
	 */
	public ReturnCodeWithRefList createScheduleList(ScheduleCreationDescriptorList x) throws Exception {
		return (ReturnCodeWithRefList) call(570, x);
	}

	/** This procedure is used to modify a list of schedules.
	 * @param x A list of schedule update descriptors.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode modifyScheduleList(ScheduleUpdateDescriptorList x) throws Exception {
		return (ReturnCode) call(571, x);
	}

	/** This procedure will delete a list of schedules.
	 * @param x A list of schedule references.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteScheduleList(ScheduleRefList x) throws Exception {
		return (ReturnCode) call(572, x);
	}

	/** This procedure will perform diagnostic tests on all channels of a given iSCSI HIC. These diagnostics are dependent on the PHY used on a particular HIC, so they may not be available on all ports of the controller.
	 * @param x Information used to start iSCSI cable diagnostics.
	 * @return A return code is returned, and if it is RETCODE_OK, additional diagnostic information from the procedure is returned as well.
	 */
	public IscsiCableDiagnosticsReturn getIscsiCopperCableDiagnostics(IscsiCableDiagnosticsDescriptor x) throws Exception {
		return (IscsiCableDiagnosticsReturn) call(573, x);
	}

	/** This procedure is used to update the firmware on one or more power supplies.
	 * @param x A PSUFirmwareUpdateDescriptor object that contains all the attributes required to update the firmware on the power supplies.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode updatePSUFirmware(PSUFirmwareUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(574, x);
	}

	/** This procedure is used to check the progress of a power supply firmware update operation.
	 * @return A return code is returned, and if it is RETCODE_OK, additional diagnostic information from the procedure is returned as well.
	 */
	public PSUFirmwareUpdateStatus getPSUFirmwareUpdateProgress( ) throws Exception {
		return (PSUFirmwareUpdateStatus) call(575, null);
	}

	/** This procedure retrieves temperature data for each thermal sensor in each enclosure in the storage array.
	 * @return A return code is returned, and if it is RETCODE_OK, additional diagnostic information from the procedure is returned as well.
	 */
	public TrayTemperatureReturned getEnclosureTemperatures( ) throws Exception {
		return (TrayTemperatureReturned) call(576, null);
	}

	/** This procedure retrieves temperature data for drives in the storage array.
	 * @return A return code is returned, and if it is RETCODE_OK, additional diagnostic information from the procedure is returned as well.
	 */
	public DriveTemperatureReturned getDriveTemperatures( ) throws Exception {
		return (DriveTemperatureReturned) call(577, null);
	}

	/** This procedure set the interval in minutes between automatic polls of drive temperatures. For interval > 0, automatic polling is enabled at the specified interval. For interval == 0, automatic polling is disabled. Each polling event will update the driveTemperature field in each Drive structure in the ObjectBundle.
	 * @param x Polling interval in minutes.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setDriveTemperaturePollingInterval(int x) throws Exception {
		return (ReturnCode) call(578, x);
	}

	/** This procedure attempts to acquire the Customer Support Bundle lock. If the lock is successfully acquired the procedure returns success and the lock key. If another client owns the lock a failure indication is returned along with an integer indicating the suggested number of seconds to wait before retrying the reservation.
	 * @return The return data from the procedure call. If the value of returnCode is RETCODE_OK, then the lock key to be used when later releasing the reservation is returned. Valid values for a return code are:
	 */
	public ReserveSupportDataReturned reserveSupportData( ) throws Exception {
		return (ReserveSupportDataReturned) call(579, null);
	}

	/** This procedure attempts to release a previously acquired Customer Support Bundle (CSB) lock once the CSB retrieval is complete. If the provided lock key matches the current value of the lock, the lock is released and the procedure returns success. If the lock key does not match the current value of the lock or if the lock is not active, the procedure returns an error.
	 * @param x The key returned by reserveSupportData.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode releaseSupportData(int x) throws Exception {
		return (ReturnCode) call(580, x);
	}

	/** This procedure is used to create an empty disk pool.
	 * @param x Information about the intended disk pool.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode createDiskPool(DiskPoolCreationDescriptor x) throws Exception {
		return (ReturnCode) call(581, x);
	}

	/** This procedure is used to delete a disk pool and all volumes in that pool.
	 * @param x A reference to the volume group to be deleted.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteDiskPool(String x) throws Exception {
		return (ReturnCode) call(582, x);
	}

	/** This procedure is used to instruct the controller to transfer ownership of a disk pool and its associated volumes to another controller.
	 * @param x A descriptor that specifies the volume group being modified, and the controller that is to take ownership of the volume group, and thus all volumes defined on the volume group.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode assignDiskPoolOwnership(VolumeGroupOwnershipUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(583, x);
	}

	/** This procedure is used to set the user assigned label for the disk pool.
	 * @param x A DiskPoolLabelUpdateDescriptor structure that contains the user label and a reference to the volume group to update.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setDiskPoolUserLabel(VolumeGroupLabelUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(584, x);
	}

	/** This procedure creates a Volume Group and two RAID Volumes to be used for flash cache. Uses the VolumeCandidate for the RAID Volume creation and assigns labels as given. The capacity in the VolumeCandidate is split between the two RAID Volumes. A High Level Volume is also created to reference the RAID Volumes.
	 * @param x The attributes for creation of a flash cache object.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode createFlashCache(FlashCacheCreationDescriptor x) throws Exception {
		return (ReturnCode) call(585, x);
	}

	/** This procedure deletes the High Level Volume, the RAID Volumes on the SSD, and disables flash caching on any associated user volumes.
	 * @param x A reference to the flash cache object to delete.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteFlashCache(String x) throws Exception {
		return (ReturnCode) call(586, x);
	}

	/** This procedure creates a flash cache proxy linked to the referenced user RAID Volume and the flash cache High Level Volume. The flash cache attribute on the RAID Volume will be turned on.
	 * @param x A reference to the user volume to link to the flash cache proxy, and a reference to the flash cache volume.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode enableFlashCacheVolume(VolumeFlashCacheDescriptor x) throws Exception {
		return (ReturnCode) call(587, x);
	}

	/** This procedure deletes the proxy and turns off flash cache volume attributes on the referenced user volume.
	 * @param x A reference to the volume to disable.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode disableFlashCacheVolume(String x) throws Exception {
		return (ReturnCode) call(588, x);
	}

	/** This procedure suspends caching on the specified flash cache.
	 * @param x The flash cache reference.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode suspendFlashCache(String x) throws Exception {
		return (ReturnCode) call(589, x);
	}

	/** This procedure reconfigures the flash cache volume group to add additional drives.
	 * @param x A FlashCacheReconfigureDrivesDescriptor object that identifies the volume group to be expanded, plus the drive or drives to be added to the volume group. All drives specified for this operation must be in the unassigned state initially.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode addDrivesToFlashCache(FlashCacheReconfigureDrivesDescriptor x) throws Exception {
		return (ReturnCode) call(590, x);
	}

	/** This procedure reconfigures the flash cache volume group to remove drives.
	 * @param x The flash cache reference and list of drive references to be removed.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode removeDrivesFromFlashCache(FlashCacheReconfigureDrivesDescriptor x) throws Exception {
		return (ReturnCode) call(591, x);
	}

	/** This procedure sets the parameters on a given flash cache.
	 * @param x A flash cache reference, configuration type, and whether or not flash cache should be enabled on new volumes.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setFlashCacheParams(FlashCacheParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(592, x);
	}

	/** This procedure resumes a previously suspended flash cache.
	 * @param x A reference to the flash cache object.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode resumeFlashCache(String x) throws Exception {
		return (ReturnCode) call(593, x);
	}

	/** This procedure will create a new PiT Group.
	 * @param x Structure containing Pit group creation data.
	 * @return A ReturnCodeWithRef object that indicates the outcome of the operation, and also returns the PiT ref of the newly-created object. Valid values are:
	 */
	public ReturnCodeWithRef createPITGroup(PITGroupCreationDescriptor x) throws Exception {
		return (ReturnCodeWithRef) call(594, x);
	}

	/** This procedure will delete a PiT Group.
	 * @param x Structure containing PiT group reference data.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deletePITGroup(PITGroupDeletionDescriptor x) throws Exception {
		return (ReturnCode) call(595, x);
	}

	/** This procedure will update the changeable parameters of a PiT Group.
	 * @param x Structure containing PiT parameter data.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setPITGroupParams(PITGroupParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(596, x);
	}

	/** This procedure will create a new PiT in one or more existing PiT Group(s). Max list size is 64 PiT Groups.
	 * @param x Structure containing a list of PiT groups.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCodeWithRefList createPIT(PITGroupRefList x) throws Exception {
		return (ReturnCodeWithRefList) call(597, x);
	}

	/** This procedure will delete one or more PiTs.
	 * @param x Structure containing a list of PiTs.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deletePIT(PITRefList x) throws Exception {
		return (ReturnCode) call(598, x);
	}

	/** This procedure will create a new PiT in a consistency group (a PiT of all members in the group).
	 * @param x Reference to consistency group.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCodeWithRefList createCGPIT(String x) throws Exception {
		return (ReturnCodeWithRefList) call(599, x);
	}

	/** This procedure will delete a PiT in one or more members of a consistency group.
	 * @param x Structure containing information about the consistency group PiT to delete.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteCGPIT(PITConsistencyGroupPITDeletionDescriptor x) throws Exception {
		return (ReturnCode) call(600, x);
	}

	/** This procedure will create a new PiT View.
	 * @param x Structure containing information about the PiT View to create.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCodeWithRef createPITView(PITViewCreationDescriptor x) throws Exception {
		return (ReturnCodeWithRef) call(601, x);
	}

	/** This procedure will delete an existing PiT View.
	 * @param x Structure containing information about the PiT View to delete.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deletePITView(PITViewDeletionDescriptor x) throws Exception {
		return (ReturnCode) call(602, x);
	}

	/** This procedure will stop an existing PiT View.
	 * @param x Reference to PiT View to be stopped.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode stopPITView(String x) throws Exception {
		return (ReturnCode) call(603, x);
	}

	/** This procedure will change the attributes of an existing PiT View.
	 * @param x Descriptor for the PiT View parameters to be updated.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setPITViewParams(PITViewParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(604, x);
	}

	/** This procedure will create a new PiT consistency group.
	 * @param x Descriptor for the consistency group to be created.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCodeWithRef createPITConsistencyGroup(PITConsistencyGroupCreationDescriptor x) throws Exception {
		return (ReturnCodeWithRef) call(605, x);
	}

	/** This procedure will delete an existing PiT consistency group, all of the child PiT groups and their PiTs and associated ERVs. All associated views are stopped.
	 * @param x Descriptor for the consistency group to be deleted.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deletePITConsistencyGroup(PITConsistencyGroupDeletionDescriptor x) throws Exception {
		return (ReturnCode) call(606, x);
	}

	/** This procedure will add a new member to a PiT consistency group (create a new PiT group for the member volume to add and add that PiT group to the consistency group). Returns the ref of the new PiT group created and added to the PCG.
	 * @param x Descriptor for the consistency group member to be added.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCodeWithRefList addPITConsistencyGroupMember(PITConsistencyGroupAddMemberDescriptorList x) throws Exception {
		return (ReturnCodeWithRefList) call(607, x);
	}

	/** This procedure will remove a member from a PiT consistency group.
	 * @param x Descriptor for the consistency group member to be removed.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode removePITConsistencyGroupMember(PITConsistencyGroupRemoveMemberDescriptor x) throws Exception {
		return (ReturnCode) call(608, x);
	}

	/** This procedure will modify the attributes of a PiT consistency group.
	 * @param x Descriptor for the consistency group parameters to be updated.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setPITConsistencyGroupParams(PITConsistencyGroupParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(609, x);
	}

	/** This procedure will initiate a rollback on a specified list of PiTs. Note that this list could be a subset of a set of consistency group PiTs.
	 * @param x A list of references to PiTs for which to start the rollback.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startPITRollback(PITRefList x) throws Exception {
		return (ReturnCode) call(610, x);
	}

	/** This procedure will initiate a rollback on a specified PiT on all members of a consistency group (all members that have the specified PiT may not necessarily be all of them).
	 * @param x Descriptor for the consistency group rollback to be started.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startCGRollback(PITConsistencyGroupRollbackStartDescriptor x) throws Exception {
		return (ReturnCode) call(611, x);
	}

	/** This procedure will resume a paused rollback on the specified PiT.
	 * @param x A reference to the PiT rollback to be resumed.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode resumePITRollback(String x) throws Exception {
		return (ReturnCode) call(612, x);
	}

	/** This procedure will cancel a rollback on the specified PiT.
	 * @param x A reference to the PiT rollback to be canceled.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode cancelPITRollback(String x) throws Exception {
		return (ReturnCode) call(613, x);
	}

	/** This procedure will expand a concatenated volume by adding another member RAID volume. Returns the ref for the new ConcatVolMember added.
	 * @param x A descriptor of the concat volume to be expanded.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCodeWithRef expandConcatVolume(ConcatVolumeExpansionDescriptor x) throws Exception {
		return (ReturnCodeWithRef) call(614, x);
	}

	/** This procedure will trim a concatenated volume by removing one or more member RAID volumes. Note this can only be done in cases where the ConcatVolume is not being used (definition of "used" depends on parent object usage).
	 * @param x A descriptor of the concat volume to be trimmed.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode trimConcatVolume(ConcatVolumeTrimDescriptor x) throws Exception {
		return (ReturnCode) call(615, x);
	}

	/** This procedure will return repository utilization information for PiT groups.
	 * @param x A list of PiT groups for which to return repository utilization.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public PITGroupRepositoryUtilizationListReturned getPITGroupRepositoryUtilization(PITGroupRefList x) throws Exception {
		return (PITGroupRepositoryUtilizationListReturned) call(617, x);
	}

	/** This procedure will return repository utilization information for PiT Views.
	 * @param x A list of PiT Views for which to return repository utilization.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public PITViewRepositoryUtilizationListReturned getPITViewRepositoryUtilization(PITViewRefList x) throws Exception {
		return (PITViewRepositoryUtilizationListReturned) call(618, x);
	}

	/** This procedure will return the amount of repository capacity necessary to perform a rollback operation.
	 * @param x A reference to a PiT
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public PITGroupRollbackUtilizationEstimateReturned estimatePITRollbackRepositoryUtilization(String x) throws Exception {
		return (PITGroupRollbackUtilizationEstimateReturned) call(619, x);
	}

	/** This procedure will convert a read-only view to a read-write view.
	 * @param x Descriptor to PiT View to be converted.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode convertReadOnlyPITViewToReadWrite(PITViewRWConversionDescriptor x) throws Exception {
		return (ReturnCode) call(620, x);
	}

	/** This procedure will create a View on the specified PiTs in a Consistency Group.
	 * @param x An object containing all of the attributes required to create a PiT Consistency Group View.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCodeWithRef createPITConsistencyGroupView(PITConsistencyGroupViewCreationDescriptor x) throws Exception {
		return (ReturnCodeWithRef) call(621, x);
	}

	/** This procedure will delete the specified PITConsistencyGroupView.
	 * @param x An object containing all of the attributes required to delete a PiT Consistency Group View.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deletePITConsistencyGroupView(PITConsistencyGroupViewDeletionDescriptor x) throws Exception {
		return (ReturnCode) call(622, x);
	}

	/** This procedure will stop the specified PITConsistencyGroupView (and thus all of its associated member views).
	 * @param x An object containing all of the attributes required to stop a PiT Consistency Group View.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode stopPITConsistencyGroupView(PITConsistencyGroupViewStopDescriptor x) throws Exception {
		return (ReturnCode) call(623, x);
	}

	/** This procedure will set the Disk Pool Reserved Drive Count value.
	 * @param x An object containing all of the attributes required to set a reserved drive count value on a disk pool.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setDiskPoolReservedDriveCount(DiskPoolReservedDriveCountUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(624, x);
	}

	/** This procedure will set the Disk Pool Utilization Threshold values.
	 * @param x An object containing all of the attributes required to set utilization threshold values for a Disk Pool.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setDiskPoolThreshold(DiskPoolThresholdUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(625, x);
	}

	/** This procedure will set the Disk Pool Reconstruction and Background Operation priorities.
	 * @param x An object containing all of the attributes required to set priorities for a Disk Pool.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setDiskPoolPriority(DiskPoolPriorityUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(626, x);
	}

	/** This procedure forces the Disk Pool to a complete (optimal) state. This may be necessary if a drive is missing and the drive is not going to be replaced.
	 * @param x A reference to the Disk Pool to complete.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setDiskPoolToComplete(String x) throws Exception {
		return (ReturnCode) call(627, x);
	}

	/** This procedure returns a list of drive sets that are candidates for use in expanding the given Disk Pool.
	 * @param x A reference to the Disk Pool to be expanded.
	 */
	public ExpansionCandidatesReturned getDiskPoolExpansionCandidates(String x) throws Exception {
		return (ExpansionCandidatesReturned) call(628, x);
	}

	/** This procedure initiates a long-running operation to expand the capacity of a Disk Pool by adding one or more drives to it.
	 * @param x A reference to the Disk Pool to expand and the drives to use for the expansion.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startDiskPoolExpansion(DiskPoolExpansionDescriptor x) throws Exception {
		return (ReturnCode) call(629, x);
	}

	/** This procedure is used to manually trigger a DPL Core Dump.
	 */
	public DPLCoreDumpOnDemandReturn triggerDPLCoreDumpOnDemand( ) throws Exception {
		return (DPLCoreDumpOnDemandReturn) call(633, null);
	}

	/** This procedure is used to request the information about a DPL core dump. The parameter is a DPL Core Dump Tag. The value of the tag is unique for each core dump and may be obtained from the DPLCoreDumpData structure in StorageArray.
	 * @param x The integer value of the dplCoreDumpTag for which you are requesting information.
	 */
	public DPLCoreDumpInfoReturn getDPLCoreDumpInformation(int x) throws Exception {
		return (DPLCoreDumpInfoReturn) call(634, x);
	}

	/** This procedure is used to clear the flag indicating that a DPL core dump needs to be retrieved without offloading it. Otherwise, the available DPL core dump will remain in controller memory until overwritten by a new DPL core dump.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode clearDPLCoreDumpNeedsRetrieved( ) throws Exception {
		return (ReturnCode) call(635, null);
	}

	/** This procedure will restart a PiT View.
	 * @param x An object containing all of the attributes required to restart a PiT View.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode restartPITView(PITViewRestartDescriptor x) throws Exception {
		return (ReturnCode) call(636, x);
	}

	/** This procedure will restart a Consistency Group View (restart all of its associated member Views).
	 * @param x An object containing all of the attributes required to restart a Consistency Group View.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode restartPITConsistencyGroupView(PITConsistencyGroupViewRestartDescriptor x) throws Exception {
		return (ReturnCode) call(637, x);
	}

	/** This procedure disables a feature.
	 * @param x A reference to the feature to disable.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode disableFeatureByRef(String x) throws Exception {
		return (ReturnCode) call(638, x);
	}

	/** This procedure will add a member to an Async Mirror Group on the primary array. This is step 1 of the add member process.
	 * @param x An object containing all of the attributes required to add a member to an Asynchronous Mirror Group on the primary array.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode addAsyncMirrorGroupPrimaryMember(AsyncMirrorGroupAddPrimaryMemberDescriptor x) throws Exception {
		return (ReturnCode) call(639, x);
	}

	/** This procedure will add a member to an Async Mirror Group on the secondary array. This is step 2 of the add member process.
	 * @param x An object containing all of the attributes required to add a member to an Asynchronous Mirror Group on the secondary array.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode addAsyncMirrorGroupSecondaryMember(AsyncMirrorGroupAddSecondaryMemberDescriptor x) throws Exception {
		return (ReturnCode) call(640, x);
	}

	/** This procedure will change roles on an Async Mirror Group.
	 * @param x A reference to the Asynchronous Mirror Group on which to change roles and some change attributes.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode changeAsyncMirrorGroupRole(AsyncMirrorGroupRoleChangeDescriptor x) throws Exception {
		return (ReturnCode) call(642, x);
	}

	/** This procedure will clear a recovery failure posted for a given Async Mirror Group (AMG). Since some AMG needs attention / recovery failure conditions are "sticky" the user has to acknowledge the condition before it is cleared.
	 * @param x A reference to the Asynchronous Mirror Group with the condition to acknowledge/clear and the type of indication to clear.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode clearAsyncMirrorGroupFaultIndication(AsyncMirrorGroupFaultIndicationClearDescriptor x) throws Exception {
		return (ReturnCode) call(643, x);
	}

	/** This procedure will clear a recovery failure posted for a given Async Mirror Group member. Since some mirror member needs attention / recovery failure conditions are "sticky" the user has to acknowledge the condition before it is cleared.
	 * @param x A reference to the Asynchronous Mirror Group member with the condition to acknowledge/clear and the type of indication to clear.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode clearAsyncMirrorGroupMemberFaultIndication(AsyncMirrorGroupMemberFaultIndicationClearDescriptor x) throws Exception {
		return (ReturnCode) call(644, x);
	}

	/** This procedure will create an Async Mirror Group (AMG).
	 * @param x An object that contains all of the required attributes for the new mirror group.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode createAsyncMirrorGroup(AsyncMirrorGroupCreationDescriptor x) throws Exception {
		return (ReturnCode) call(645, x);
	}

	/** This procedure will delete an Async Mirror Group (AMG).
	 * @param x An object containing all of the required attributes to delete an Asynchronous Mirror Group.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteAsyncMirrorGroup(AsyncMirrorGroupDeletionDescriptor x) throws Exception {
		return (ReturnCode) call(646, x);
	}

	/** This procedure is used to clean up a mirror "place holder."
	 * @param x An object with all of the required attributes to delete an incomplete member of an Asynchronous Mirror Group.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deleteAsyncMirrorGroupIncompleteMember(String x) throws Exception {
		return (ReturnCode) call(647, x);
	}

	/** This procedure will disable mirroring over Fibre Channel (freeing up dedicated channel).
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode deactivateFibreChannelCheckPointBasedAsyncMirroring( ) throws Exception {
		return (ReturnCode) call(648, null);
	}

	/** This procedure will enable mirroring over Fibre Channel (setup dedicated channel).
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode activateFibreChannelCheckPointBasedAsyncMirroring( ) throws Exception {
		return (ReturnCode) call(649, null);
	}

	/** This procedure will return sync progress information for Async Mirror Groups and their associated members. Calls to this procedure are valid even when a sync is not running.
	 * @param x A list of Asynchronous Mirror Group references.
	 * @return Information about progress of a sync operation on an Asynchronous Mirror Group.
	 */
	public AsyncMirrorGroupSyncProgressListReturned getAsyncMirrorGroupSyncProgress(AsyncMirrorGroupRefList x) throws Exception {
		return (AsyncMirrorGroupSyncProgressListReturned) call(650, x);
	}

	/** This procedure will return repository utilization information for async mirror members.
	 * @param x A list of Asynchronous Mirror Group member references.
	 * @return Information about an async mirror repository utilization
	 */
	public AsyncMirrorRepositoryUtilizationListReturned getAsyncMirrorRepositoryUtilization(AsyncMirrorGroupMemberRefList x) throws Exception {
		return (AsyncMirrorRepositoryUtilizationListReturned) call(651, x);
	}

	/** This procedure will remove a member from an Async Mirror Group.
	 * @param x An object containing all of the required attributes to remove an Asynchronous Mirror Group member.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode removeAsyncMirrorGroupMember(AsyncMirrorGroupRemoveMemberDescriptor x) throws Exception {
		return (ReturnCode) call(654, x);
	}

	/** Resume an Async Mirror Group.
	 * @param x A descriptor containing a reference to the Asynchronous Mirror Group to resume.
	 * @return The result of the procedure action.
	 */
	public AsyncMirrorGroupActionResult resumeAsyncMirrorGroup(AsyncMirrorGroupResumeDescriptor x) throws Exception {
		return (AsyncMirrorGroupActionResult) call(655, x);
	}

	/** This procedure will change the parameters of an Async Mirror Group.
	 * @param x An object containing the Asynchronous Mirror Group parameters.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setAsyncMirrorGroupParams(AsyncMirrorGroupParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(656, x);
	}

	/** This procedure will suspend an Async Mirror Group.
	 * @param x A descriptor that lists the AMG on which the synchronization is to be suspended.
	 * @return A return code is returned, and if it is RETCODE_ARVM_RECOVERY_POINT_DELETION_REQUIRED, a list of members that triggered a fault and require deletion is also returned.
	 */
	public AsyncMirrorGroupActionResult suspendAsyncMirrorGroup(AsyncMirrorGroupSuspendDescriptor x) throws Exception {
		return (AsyncMirrorGroupActionResult) call(657, x);
	}

	/** This procedure will start a manual resynchronization on an Async Mirror Group.
	 * @param x A reference to the Asynchronous Mirror Group to synchronize.
	 * @return A list of async mirror group members that triggered a fault and require deletion.
	 */
	public AsyncMirrorGroupActionResult synchronizeAsyncMirrorGroup(AsyncMirrorGroupSynchronizeDescriptor x) throws Exception {
		return (AsyncMirrorGroupActionResult) call(658, x);
	}

	/** This procedure will return the maximum Reserved Drive Count possible on a disk pool.
	 * @param x A reference to the Disk Pool for which you want the maximum reserved drive count.
	 * @return The maximum Reserved Drive Count possible on a disk pool.
	 */
	public DiskPoolMaxReservedDriveCountReturn getDiskPoolMaxReservedDriveCount(String x) throws Exception {
		return (DiskPoolMaxReservedDriveCountReturn) call(659, x);
	}

	/** This procedure cancels a Pending PiT Creation for a PiT Consistency Group.
	 * @param x A reference to the PiT Consistency Group for which you want to cancel a pending creation.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode cancelPendingCGPITCreation(String x) throws Exception {
		return (ReturnCode) call(660, x);
	}

	/** This procedure cancels a Pending PiT Creation for a PiT Group. This returns the pending PiT creation state back to "none" from either "waiting" or "failed".
	 * @param x A reference to the PiT Group for which you want to cancel a pending creation.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode cancelPendingPITCreation(String x) throws Exception {
		return (ReturnCode) call(661, x);
	}

	/** This procedure revives a failed PiT Group.
	 * @param x A reference to the PiT Group you want to revive.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode revivePITGroup(String x) throws Exception {
		return (ReturnCode) call(662, x);
	}

	/** This procedure revives a failed PiT View.
	 * @param x A reference to the PiT View you want to revive.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode revivePITView(String x) throws Exception {
		return (ReturnCode) call(663, x);
	}

	/** This procedure changes the user-settable parameters on a PITConsistencyGroupView.
	 * @param x An object containing the required user-settable attributes to set on a PiT Consistency Group View.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setPITConsistencyGroupViewParams(PITConsistencyGroupViewParamsUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(664, x);
	}

	/** This procedure creates a new Thin Provisioned Volume.
	 * @param x An object containing all of the required attributes for a Thin Provisioned Volume.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode createThinVolume(ThinVolumeCreationDescriptor x) throws Exception {
		return (ReturnCode) call(665, x);
	}

	/** This procedure will expand a thin volume's virtual capacity. It does not affect the repository volume's capacity.
	 * @param x An object containing all of the attributes necessary to expand a thin volume's virtual capacity.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode expandThinVolumeVirtualCapacity(ThinVolumeExpansionDescriptor x) throws Exception {
		return (ReturnCode) call(666, x);
	}

	/** This procedure will retrieve a thin volume's Expandable Repository Volume consumed capacity.
	 * @param x A reference to the thin volume for which you want the consumed capacity.
	 */
	public ThinVolumeConsumedCapacityReturned getThinVolumeConsumedCapacity(ThinVolumeRefList x) throws Exception {
		return (ThinVolumeConsumedCapacityReturned) call(667, x);
	}

	/** This procedure will retrieve a thin volume's repository expansion history.
	 * @param x A reference to the thin volume for which you want the repository expansion history.
	 */
	public ThinVolumeRepositoryExpansionHistoryListReturned getThinVolumeExpansionHistory(String x) throws Exception {
		return (ThinVolumeRepositoryExpansionHistoryListReturned) call(668, x);
	}

	/** This procedure causes the referenced thin volume to be reinitialized to have no content.
	 * @param x An object containing all of the required attributes for reinitializing a thin volume.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode reinitializeThinVolume(ThinVolumeReinitializeDescriptor x) throws Exception {
		return (ReturnCode) call(669, x);
	}

	/** This procedure will set a thin volume's capacity threshold warning level.
	 * @param x An object containing all of the required attributes for setting the capacity threshold warning level on a thin volume.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setThinVolumeCapacityThreshold(ThinVolumeThresholdUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(670, x);
	}

	/** This procedure will set a thin volume's repository volume expansion policy.
	 * @param x An object containing all of the required attributes needed to set the repository volume expansion policy for a thin volume.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setThinVolumeExpansionPolicy(ThinVolumeExpansionPolicyUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(671, x);
	}

	/** This procedure will set a thin volume's provisioned capacity quota. This is the maximum value to which a thin volume's repository can grow.
	 * @param x An object containing all of the required attributes needed to set a thin volume's provisioned capacity quota.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setThinVolumeProvisionedCapacityQuota(ThinVolumeCapacityQuotaUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(672, x);
	}

	/** This procedure returns the default values for system attributes.
	 * @return The system default attributes are returned.
	 */
	public SystemAttributeDefaultsReturned getSystemAttributeDefaults( ) throws Exception {
		return (SystemAttributeDefaultsReturned) call(673, null);
	}

	/** This procedure is used to request a list of bundles of statistical data. The argument describes the statistics being requested.
	 * @param x An object containing all of the required elements for the procedure.
	 * @return The list of bundles of statistical data are returned (when the procedure return code is RETCODE_OK).
	 */
	public CumulativeStatisticsBundleListReturned getCumulativeStatisticsBundles(CumulativeStatisticsListDescriptor x) throws Exception {
		return (CumulativeStatisticsBundleListReturned) call(674, x);
	}

	/** This procedure creates a zero size FlashCache for performing analytics. It creates a flashcache with no repository to allow collection of projected cache hits during I/O.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode createFlashCacheAnalytics(FlashCacheAnalyticsCreationDescriptor x) throws Exception {
		return (ReturnCode) call(675, x);
	}

	/** This procedure starts collecting analytics data for flash cache. It resets analytics counters and begins capturing cache data.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startFlashCacheAnalytics(String x) throws Exception {
		return (ReturnCode) call(676, x);
	}

	/** This procedure stops the collection of analytics data for flash cache. It disables the collection of cache hits.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode stopFlashCacheAnalytics(String x) throws Exception {
		return (ReturnCode) call(677, x);
	}

	/** This procedure retrieves analytics data from the last capture period. It returns the cache hits for various sizes of flash cache.
	 * @return Data collected for flash cache analytics.
	 */
	public FlashCacheAnalyticsReturned getFlashCacheAnalytics(String x) throws Exception {
		return (FlashCacheAnalyticsReturned) call(678, x);
	}

	/** This procedure will convert all snapshots of a given base volume to PiT groups.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode convertSnapshotsToPITGroups(SnapshotConversionDescriptor x) throws Exception {
		return (ReturnCode) call(679, x);
	}

	/** This procedure will run an analysis on the metadata contained in a copy-on-write repository to identify possible causes for failure.
	 * @return The analysis results are returned.
	 */
	public CoWRepositoryAnalysisResultsReturned analyzeCopyOnWriteRepository(CoWRepositoryAnalysisRequest x) throws Exception {
		return (CoWRepositoryAnalysisResultsReturned) call(680, x);
	}

	/** This procedure is used to retrieve stable store database metadata.
	 * @return The database metadata is returned.
	 */
	public DatabaseMetadataReturned getDatabaseMetadata( ) throws Exception {
		return (DatabaseMetadataReturned) call(681, null);
	}

	/** This procedure is used to cancel stable store database recovery.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode cancelDatabaseRecoveryMode( ) throws Exception {
		return (ReturnCode) call(682, null);
	}

	/** This procedure is used to cancel an Async Mirror Group role change operation.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode cancelAsyncMirrorGroupRoleChange(AsyncMirrorGroupRoleChangeCancelDescriptor x) throws Exception {
		return (ReturnCode) call(683, x);
	}

	/** This procedure is used to initiate an Async Mirror Group link connectivity test.
	 * @return The connectivity test results are returned.
	 */
	public AsyncMirrorGroupConnectivityTestResultsReturned testAsyncMirrorGroupConnectivity(AsyncMirrorGroupConnectivityTestDescriptor x) throws Exception {
		return (AsyncMirrorGroupConnectivityTestResultsReturned) call(684, x);
	}

	/** This procedure is used to retrieve flash cache statistics.
	 * @return The flash cache statistics are returned.
	 */
	public FlashCacheStatisticsReturned getFlashCacheStatistics(String x) throws Exception {
		return (FlashCacheStatisticsReturned) call(685, x);
	}

	/** This procedure is used to download a NVSRAM image file to a controller when the duplex setting gets erroneously inserted into a Native SATA array. In such a situation, none of the native SATA drives will be recognized by the firmware since the IOC will be set to enable the STP (SATA) layer only if the setting is Simplex. The Recovery Action in such a scenario is to download new NVSRAM using this command and boot with it.
	 */
	public ReturnCode loadControllerNVSRAMNoPassword(FirmwareUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(686, x);
	}

	/** This procedure is used to recover a stopped or failed Async Mirror Group Member.
	 * @param x An object containing all of the required attributes to recover an Asynchronous Mirror Group member.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode recoverAsyncMirrorGroupMember(String x) throws Exception {
		return (ReturnCode) call(687, x);
	}

	/** This procedure attempts to revive the given disk pool.
	 * @param x An object containing all of the required attributes to revive the given disk pool.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode forceDiskPoolToOptimal(String x) throws Exception {
		return (ReturnCode) call(688, x);
	}

	/** This procedure converts the specified disk pool to a secure volume group.
	 * @param x An object containing all of the required attributes to convert the specified disk pool to a secure volume group.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode secureDiskPool(String x) throws Exception {
		return (ReturnCode) call(689, x);
	}

	/** This procedure is used to enable Autosupport.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode enableASUP( ) throws Exception {
		return (ReturnCode) call(690, null);
	}

	/** This procedure is used to disable Autosupport.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode disableASUP( ) throws Exception {
		return (ReturnCode) call(691, null);
	}

	/** This procedure returns information on the connections established to a remote array for an existing AsyncMirrorGroup. This will return connection information for both controllers.
	 * @return Remote connection information is returned.
	 */
	public ScsiRemoteConnectionsReturned getAsyncMirrorGroupRemoteConnections(String x) throws Exception {
		return (ScsiRemoteConnectionsReturned) call(692, x);
	}

	/** This procedure will return synchronization time statistics for a list of mirror members.
	 * @return Synchronization time statistics are returned.
	 */
	public AsyncMirrorSyncStatisticsListReturned getAsyncMirrorSyncStatistics(AsyncMirrorSyncStatisticsRequestDescriptor x) throws Exception {
		return (AsyncMirrorSyncStatisticsListReturned) call(693, x);
	}

	/** This procedure returns information on the available connections between two arrays. This can be used prior to creation of an AsyncMirrorGroup to determine if there are wiring or other connection configuration issues between the two arrays. A call to this procedure acts like a ping test between the arrays and returns back information on the connections that succeed. This must be issued to each controller independently and should be called in fibre channel environments after activation of fibre channel remote mirroring.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ScsiRemoteConnectionsReturned getRemoteConnections(InitiatorTargetInitialProperties x) throws Exception {
		return (ScsiRemoteConnectionsReturned) call(694, x);
	}

	/** This procedure will reset (clear) synchronization time statistics for a list of mirror members.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode resetAsyncMirrorSyncStatistics(AsyncMirrorSyncStatisticsResetDescriptor x) throws Exception {
		return (ReturnCode) call(695, x);
	}

	/** This procedure is used to set the initial view array password or change an existing view array password.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setSAViewPassword(EncryptedPassword x) throws Exception {
		return (ReturnCode) call(696, x);
	}

	/** This procedure is used to retrieve the digest of the view array password and its associated salt value which are saved in the array by the setViewPassword procedure. If the view array password isn't set, the procedure returns a random salt value and the digest of the salt value message.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public SAViewPasswordDigestReturned getSAViewPasswordDigest( ) throws Exception {
		return (SAViewPasswordDigestReturned) call(697, null);
	}

	/** This procedure is used to add a known SNMP community string. SNMP GET/SET requests are only allowed for known communities.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCodeWithRefList addSNMPCommunity(SNMPCommunityAddDescriptorList x) throws Exception {
		return (ReturnCodeWithRefList) call(698, x);
	}

	/** This procedure is used to add an SNMP trap destination.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCodeWithRefList addSNMPTrapDestination(SNMPTrapDestinationAddDescriptorList x) throws Exception {
		return (ReturnCodeWithRefList) call(699, x);
	}

	/** This procedure is used to remove a previous configured SNMP community from the list of known community strings.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode removeSNMPCommunity(SNMPCommunityRefList x) throws Exception {
		return (ReturnCode) call(700, x);
	}

	/** This procedure is used to remove a previously configured SNMP trap destination.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode removeSNMPTrapDestination(SNMPTrapDestinationRefList x) throws Exception {
		return (ReturnCode) call(701, x);
	}

	/** This procedure is used to modify an existing SNMP community.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setSNMPCommunityParams(SNMPCommunityParamsUpdateDescriptorList x) throws Exception {
		return (ReturnCode) call(702, x);
	}

	/** This procedure is used to set values of user-settable SNMP system variables.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setSNMPSystemVariables(SNMPSystemVariablesUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(703, x);
	}

	/** This procedure is used to modify an existing SNMP trap destination.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setSNMPTrapDestinationParams(SNMPTrapDestinationParamsUpdateDescriptorList x) throws Exception {
		return (ReturnCode) call(704, x);
	}

	/** This procedure initiates a long-running operation to reduce the capacity of a Disk Pool by removing one or more drives from it.
	 * @return A return code that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startDiskPoolReduction(DiskPoolReductionDescriptor x) throws Exception {
		return (ReturnCode) call(705, x);
	}

	/** This procedure calculates the maximum number of drives that can be removed from a disk pool.
	 * @return The maximum number of drives that can be removed from a disk pool.
	 */
	public DiskPoolReductionDriveCountReturn getDiskPoolReductionDriveCount(String x) throws Exception {
		return (DiskPoolReductionDriveCountReturn) call(706, x);
	}

	/** This procedure is used to test SNMP trap destinations (generate test trap).
	 */
	public ReturnCode testSNMPTrapDestination(SNMPTrapDestinationTestDescriptorList x) throws Exception {
		return (ReturnCode) call(707, x);
	}

	/** This procedure is used to recover a stopped or failed asynchronous mirror group member.
	 */
	public ReturnCode recoverAsyncMirrorGroupMemberDeleteRecoveryPoint(AsyncMirrorGroupRecoverDescriptor x) throws Exception {
		return (ReturnCode) call(708, x);
	}

	/** This procedure is used to get the current Autosupport status values.
	 */
	public AsupStatusReturned getAsupStatus( ) throws Exception {
		return (AsupStatusReturned) call(709, null);
	}

	/** This procedure is used to set the current Autosupport status values.
	 */
	public ReturnCode setAsupStatus(AsupStatus x) throws Exception {
		return (ReturnCode) call(710, x);
	}

	/** This procedure is used to manually trigger an IOC Dump on the specified channel.
	 */
	public IOCDumpOnDemandReturn triggerIOCDumpOnDemand(ChannelLocation x) throws Exception {
		return (IOCDumpOnDemandReturn) call(711, x);
	}

	/** This procedure is used to request information about an IOC Dump. The parameter is an IOC Dump Tag. The value of the tag is unique for each dump and may be obtained from the IOCDumpData structure in StorageArray.
	 */
	public IOCDumpInfoReturn getIOCDumpInformation(int x) throws Exception {
		return (IOCDumpInfoReturn) call(712, x);
	}

	/** This procedure is used to tell the controller that corrective action has been taken to recover from a mis-wire condition. The controller will re-enable any SAS Ports that were disabled when a mis-wire was detected.
	 */
	public ReturnCode recoverFromMiswire( ) throws Exception {
		return (ReturnCode) call(713, null);
	}

	/** This procedure is used to request Energy Star data from all power supplies.
	 */
	public EnergyStarDataReturn getEnergyStarData( ) throws Exception {
		return (EnergyStarDataReturn) call(714, null);
	}

	/** This procedure is used to get the state of a function, enable or disable the function, or revert the function back to its default value.
	 * @param x The function ID and the action to be performed.
	 * @return The outcome of the get/set operation.
	 */
	public FunctionStateReturned setFunctionState(FunctionStateDescriptor x) throws Exception {
		return (FunctionStateReturned) call(715, x);
	}

	/** This procedure is used to power cycle an individual physical drive.
	 * @param x The descriptor for the drive to be power cycled.
	 * @return A structure that includes the return code of the operation, the drive ref of the drive for which the command was sent, and the power state of the drive.
	 */
	public PowerCyclePhysicalDriveDataReturn powerCyclePhysicalDrive(PowerCyclePhysicalDriveDescriptor x) throws Exception {
		return (PowerCyclePhysicalDriveDataReturn) call(716, x);
	}

	/** This command cancels an evacuation on the referenced drive.
	 * @param x The drive on which to cancel an evacuation.
	 * @return The return code from the operation.
	 */
	public ReturnCode cancelEvacuation(String x) throws Exception {
		return (ReturnCode) call(717, x);
	}

	/** This procedure triggers the copy of an assigned volume group drive to a standby hot spare. Upon successful completion of the copy, the assigned drive is failed and the hot spare becomes an active drive in the volume group, sparing for the failed drive.
	 * @param x The drive on which to perform the operation.
	 * @return The return code from the operation.
	 */
	public ReturnCode copyDriveThenFail(String x) throws Exception {
		return (ReturnCode) call(718, x);
	}

	/** This command will trigger an evacuation from an assigned volume group drive to an unassigned drive and replace the original drive in the volume group with the new one.
	 * @param x Indicates both the drive to replace and the replacement drive.
	 * @return The return code from the operation.
	 */
	public ReturnCode copyDriveThenReplace(CopyThenReplaceDescriptor x) throws Exception {
		return (ReturnCode) call(719, x);
	}

	/** This procedure returns the InfiniBand statistics, which consists of start-of-day-relative interface statistics and baseline-relative statistics. It supersedes the deprecated getIbStatistics () routine.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public EnhancedIbStatisticsReturned getEnhancedIbStatistics( ) throws Exception {
		return (EnhancedIbStatisticsReturned) call(720, null);
	}

	/** This procedure returns the success of starting statistic data collection.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode startPerformanceMonitor( ) throws Exception {
		return (ReturnCode) call(721, null);
	}

	/** This procedure returns the success of stopping statistic data collection.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode stopPerformanceMonitor( ) throws Exception {
		return (ReturnCode) call(722, null);
	}

	/** This procedure enables or disables high resolution statistics gathering.
	 * @param x None.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public HighResolutionReturned setHighResolutionSampling(HighResolutionRequestDescriptor x) throws Exception {
		return (HighResolutionReturned) call(728, x);
	}

	/** This procedure enables or disables the auto load balancing capability on this array.
	 * @param x Input descriptor indicating whether auto load balancing is to be enabled or disabled
	 * @return ReturnCode indicating success or failure of request
	 */
	public ReturnCode setAutoLoadBalancing(AutoLoadBalancingControlDescriptor x) throws Exception {
		return (ReturnCode) call(751, x);
	}

	/** This procedure will perform an immediate fail-back of volume current ownership to the preferred owner.
	 * @param x Descriptor containing input parameters for fail back request operation.
	 * @return ReturnCode from result of the operation.
	 */
	public ReturnCode failBackVolumeOwnership(VolumeOwnershipFailBackRequestDescriptor x) throws Exception {
		return (ReturnCode) call(755, x);
	}

	/** This procedure requests an on-demand volume ownership redistribution for load balancing purposes.
	 * @param x Request descriptor specifying details of the load balance request.
	 * @return Return code from result of requested operation.
	 */
	public ReturnCode autoLoadBalanceRequest(AutoLoadBalanceRequestDescriptor x) throws Exception {
		return (ReturnCode) call(756, x);
	}

	/** This procedure is used to set the Physical Security ID for a drive. The PSID is required in order to set a FIPS drive back to factory settings if the previous PSID is lost. In that case, the drive must be set back to factory settings in order to be used.
	 * @param x The input structure contains a reference to the drive and the Physical Security ID string.
	 * @return The procedure returns a return code, indicating the success or failure of the command. If the command works, RETCODE_OK will be returned. If the drive reference is invalid, RETCODE_INVALID_DRIVE will be returned. If the PSID is not accepted by the drive, RETCODE_INVALID_PSID will be returned.
	 */
	public ReturnCode setDrivePhysicalSecurityID(DrivePhysicalSecurityIdDescriptor x) throws Exception {
		return (ReturnCode) call(760, x);
	}

	/** This procedure changes the reporting policy of a thin volume. The reporting policy controls how a thin volume is reported to the host on the SCSI interface, i.e., as a thin volume that supports unmap commands or as a thick volume.
	 * @param x A ThinVolumeReportingPolicyUpdateDescriptor structure containing the arguments for the procedure call.
	 * @return A return code that indicates the output of the operation.
	 */
	public ReturnCode setThinVolumeReportingPolicy(ThinVolumeReportingPolicyUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(761, x);
	}

	/** This procedure allows the user to limit the performance of a host cluster. The limitations that can be set are throughput (MB/s) and IOPs.
	 * @param x The procedure takes as input a structure containing the limitations on the performance of the cluster.
	 * @return The procedure returns a return code.
	 */
	public ReturnCode setClusterPerformanceLimitationValues(ClusterPerformanceLimitationValuesDescriptor x) throws Exception {
		return (ReturnCode) call(763, x);
	}

	/** This procedures returns the performance limitation values for a host cluster. Those values include the limits on the IOPs and throughput (MB/s). The number of IOPs impacted by the performance limits is also returned.
	 * @param x This procedure takes a cluster reference as an input parameter.
	 * @return This procedures returns the performance limitation values for a host cluster.
	 */
	public ClusterPerformanceLimitationValuesReturned getClusterPerformanceLimitationValues(String x) throws Exception {
		return (ClusterPerformanceLimitationValuesReturned) call(764, x);
	}

	/** This procedure is utilized to add new key-value tags to the persistent memory so they can be used for application awareness.
	 * @param x The input is an array of key-value descriptors. The content of each is two opaque, fixed length byte arrays.
	 * @return The response is a return code indicating overall status. If the return is successful, it also includes a list of the KeyValueTagRef objects, in the same order as the request descriptor.
	 */
	public ReturnCodeWithRefList createKeyValueTag(KeyValueTagCreationDescriptorList x) throws Exception {
		return (ReturnCodeWithRefList) call(765, x);
	}

	/** This procedure removes from the array the specified key-value tags. It is an error to remove in-use key-value tags.
	 * @param x The input identifies the key-value pairs to be deleted from the array. Unknown references are ignored.
	 * @return A return code indicates the success or failure (with reason).
	 */
	public ReturnCode deleteKeyValueTag(KeyValueTagRefList x) throws Exception {
		return (ReturnCode) call(766, x);
	}

	/** This procedure persists the association between the Key-Value tags and the Volumes (or Workloads). This procedure is used both for creating the initial mappings and to update. Each execution will remove any existing mappings and replace them with the mappings defined within the argument list.
	 * @param x The input is a list of mappings, each mapping consists of a Volume Reference and a Key-Value Pair reference. This method will create the initial associations and can be used to perform a replacement of those associations.
	 * @return Reports the success or failure of the procedure. It is an error if the input descriptor contains invalid references or duplicate entries.
	 */
	public ReturnCode setKeyValueTagMapping(KeyValueTagMappingSetDescriptorList x) throws Exception {
		return (ReturnCode) call(768, x);
	}

	/** This procedure removes from the specified volumes all references to specific Key-Value tags.
	 * @param x The input is a list of references to Volumes (or Workloads). For each in the list, all references to Key-Value tags are deleted.
	 * @return A return value that indicates the success or failure of the procedure.
	 */
	public ReturnCode deleteKeyValueTagMapping(KeyValueTagMappingDeletionDescriptorList x) throws Exception {
		return (ReturnCode) call(769, x);
	}

	/** This procedure is utilized to add new application awareness workloads to persistent memory. The workload objects are created but do not as yet have Key-Value Tags associated to them. That requires calling the setKeyValueTagMapping procedure.
	 * @param x A list of the WorkloadCreationDescriptors used as an input to the createWorkload procedure.
	 * @return The returned structure allows this function to return a list of workload references and a return status.
	 */
	public ReturnCodeWithRefList createWorkload(WorkloadCreationDescriptorList x) throws Exception {
		return (ReturnCodeWithRefList) call(770, x);
	}

	/** This procedure removes the specified application awareness workloads. It is not an error to remove in-use (association mapped) workloads. All association mappings for the workload are removed including any KeyValueTag mappings. The actual KeyValueTag records are not deleted.
	 * @param x A list of SYMbol application awareness workload references.
	 * @return A return code indicates the success or failure (with reason).
	 */
	public ReturnCode deleteWorkload(WorkloadRefList x) throws Exception {
		return (ReturnCode) call(771, x);
	}

	/** This procedure creates the mappings between the list of workloads and volumes specified by the input descriptor.
	 * @param x The input descriptor is a list of workload and volume pairs, each pair is to be mapped.
	 * @return The return code specifies the success or failure of the procedure.
	 */
	public ReturnCode createWorkloadVolumeMapping(WorkloadVolumeCreateMappingDescriptorList x) throws Exception {
		return (ReturnCode) call(772, x);
	}

	/** This procedure deletes the specified workload to volume mappings.
	 * @param x A list of unique identifiers to the workload to volume mappings to be deleted.
	 * @return A return code that indicates the success or failure of the procedure.
	 */
	public ReturnCode deleteWorkloadVolumeMapping(WorkloadVolumeDeleteMappingDescriptorList x) throws Exception {
		return (ReturnCode) call(773, x);
	}

	/** Generates a Key Management Server (KMS) Client Certificate Signing Request (CSR) that needs to be signed by a Certificate Authority (CA). The resulting signed certificate or client certificate is installed on the storage array for authenticating with the KMIP server.
	 */
	public KMSCertificateFileReturn generateCertificateSigningRequest(KMSClientCSRDescriptor x) throws Exception {
		return (KMSCertificateFileReturn) call(774, x);
	}

	/** Installs a Key Management Server (KMS) Certificate File on the storage array. In addition to the contents of the certificate file, the type of certificate must be specified. If a certificate of the type specified already exists on the storage array, it will be overwritten by the new certificate.
	 */
	public ReturnCode installKMSCertificateFile(KMSCertificateFileInstallDescriptor x) throws Exception {
		return (ReturnCode) call(775, x);
	}

	/** Retrieves a specified Key Management Server (KMS) ertificate currently installed on the storage array so that information about the certifiacte such as date of expiration can be extracted and displayed. This allows the storage administrator to know what is installed on the system and used for authentication with the KMIP server.
	 */
	public KMSCertificateFileReturn retrieveKMSCertificateFile(KMSCertificateFileRetrieveDescriptor x) throws Exception {
		return (KMSCertificateFileReturn) call(776, x);
	}

	/** This procedure will remove a specified installed KMS certificate from the storage array.
	 */
	public ReturnCode removeInstalledKMSCertificateFiles(KMSCertificateFileType x) throws Exception {
		return (ReturnCode) call(778, x);
	}

	/** This procedure sets selected HostPorts attributes, as specified by the input argument. It is meant to operate on a group of ports, for example all the ports on a host interface card or base board.
	 * @param x A HostPortsAttributesUpdateDescriptor structure containing the arguments for the procedure call.
	 * @return A return code that indicates the outcome of the operation.
	 */
	public ReturnCode setHostPortsAttributes(HostPortsAttributesUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(779, x);
	}

	/** Sets parameters necessary to communicate with an external key management server.
	 */
	public ReturnCode setExternalKMSParameters(ExternalKMSParametersSetDescriptor x) throws Exception {
		return (ReturnCode) call(780, x);
	}

	/** Uses the credentials (certificates, address of the KMIP server, and the KMIP port number) provided to verify that the storage array is able to communicate with the external KMIP server.
	 */
	public ReturnCode verifyExternalKMSCommunication( ) throws Exception {
		return (ReturnCode) call(781, null);
	}

	/** A procedure that provides a means to tunnel HTTP calls through the UTM Lun. The HTTP call is executed against the embedded web server.
	 * @param x A SymbolTunnelRequest structure that provides the input data for an HTTP call against an embedded web server.
	 * @return A SymbolTunnelReply object that describes the Symbol return value as well as the results of the HTTP request executed against the embedded web server.
	 */
	public SymbolTunnelReply tunnelHttpCall(SymbolTunnelRequest x) throws Exception {
		return (SymbolTunnelReply) call(782, x);
	}

	/** This procedure sets the properties of a NVMe over Fabrics Host Interface port.
	 * @param x NVMe over Fabrics Host Interface Properties
	 * @return RETCODE value
	 */
	public ReturnCode setNVMeHostInterfaceProperties(NVMeInterfacePropertiesUpdateDescriptor x) throws Exception {
		return (ReturnCode) call(783, x);
	}

	/** Intended to allow processes external to EOS to send messages and events into EOS. This is primarily to allow non-EOS processes (like the WebServices Proxy) to generate MEL and Needs Attention conditions, but is extensible to allow other types of messages as well
	 * @param x Describes the type and details of the internal message being sent to the EOS process
	 * @return Returns RETCODE_OK on success. Will return an appropriate error code for all failures
	 */
	public InternalMessageResults handleInternalMessage(InternalMessageDesc x) throws Exception {
		return (InternalMessageResults) call(784, x);
	}

	/** This procedure returns the NVMeoF statistics, which consist of start-of-day-relative interface/queue statistics and baseline-relative interface/queue statistics.
	 * @return An NvmeofStatisticsReturned structure containing the list of NVMeoF statistics. The list below identifies the return codes for this procedure.
	 */
	public NVMeoFStatisticsReturned getNVMeoFStatistics( ) throws Exception {
		return (NVMeoFStatisticsReturned) call(785, null);
	}

	/** This procedure, from the client's perspective, resets the NVMe over Fabrics baselined statistical counters to zero. It is a logical reset in the sense that the raw counts maintained in hardware and firmware are not actually reset; instead the firmware makes a snapshot of the current counter values and uses that to report deltas in counts when the statistics are fetched. The new baseline time is applied to both storage controllers, so that their counts are in sync with one another. If one storage controller resets without the other resetting, the counters become effectively out of sync and the client is made aware of this fact by the timestamp data reported along with the statistics.
	 * @return A ReturnCode object that indicates the outcome of the operation. Valid values are:
	 */
	public ReturnCode setNVMeoFStatisticsBaseline( ) throws Exception {
		return (ReturnCode) call(786, null);
	}

	/** This procedure allows checking of protection information of cache mirroring to be enabled or disabled, if this feature is supported. There is a capability enumeration that indicates whether or not this feature is supported.
	 * @param x A CacheMirroringProtectionInformationDescriptor containing the arguments for the call.
	 * @return A return code that indicates the status of the operation.
	 */
	public ReturnCode setCacheMirroringProtectionInformation(CacheMirroringProtectionInformationDescriptor x) throws Exception {
		return (ReturnCode) call(787, x);
	}
}
