package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure contains information about a serial-attached SCSI I/O interface on a controller board. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(1204)
public class SasInterface implements Serializable,devmgr.api.model.Identifiable {
	public SasInterface() {
	}

	/** The number of the channel corresponding to this interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of the channel corresponding to this interface." , required = true)
	@XmlElement(required = true)
	private int channel;

	/** @return The number of the channel corresponding to this interface. */
	public int getChannel() {
		return this.channel;
	}
	/** @param x The number of the channel corresponding to this interface. */
	public void setChannel(int x) {
		this.channel = x;
	}

	/** The current interface speed of the SAS interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The current interface speed of the SAS interface." , required = true)
	@XmlElement(required = true)
	private InterfaceSpeed currentInterfaceSpeed = InterfaceSpeed.__UNDEFINED;

	/** @return The current interface speed of the SAS interface. */
	public InterfaceSpeed getCurrentInterfaceSpeed() {
		return this.currentInterfaceSpeed;
	}
	/** @param x The current interface speed of the SAS interface. */
	public void setCurrentInterfaceSpeed(InterfaceSpeed x) {
		this.currentInterfaceSpeed = x;
	}

	/** The maximum interface speed of the SAS interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum interface speed of the SAS interface." , required = true)
	@XmlElement(required = true)
	private InterfaceSpeed maximumInterfaceSpeed = InterfaceSpeed.__UNDEFINED;

	/** @return The maximum interface speed of the SAS interface. */
	public InterfaceSpeed getMaximumInterfaceSpeed() {
		return this.maximumInterfaceSpeed;
	}
	/** @param x The maximum interface speed of the SAS interface. */
	public void setMaximumInterfaceSpeed(InterfaceSpeed x) {
		this.maximumInterfaceSpeed = x;
	}

	/** A string indicating the chip type. */
	@io.swagger.annotations.ApiModelProperty(value ="A string indicating the chip type." , required = true)
	@XmlElement(required = true)
	private String part;

	/** @return A string indicating the chip type. */
	public String getPart() {
		return this.part;
	}
	/** @param x A string indicating the chip type. */
	public void setPart(String x) {
		this.part = x;
	}

	/** The revision level of the firmware on the SAS I/O controller. */
	@io.swagger.annotations.ApiModelProperty(value ="The revision level of the firmware on the SAS I/O controller." , required = true)
	@XmlElement(required = true)
	private int revision;

	/** @return The revision level of the firmware on the SAS I/O controller. */
	public int getRevision() {
		return this.revision;
	}
	/** @param x The revision level of the firmware on the SAS I/O controller. */
	public void setRevision(int x) {
		this.revision = x;
	}

	/** True if the channel corresponding to this interface is degraded. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the channel corresponding to this interface is degraded." , required = true)
	@XmlElement(required = true)
	private boolean isDegraded;

	/** @return True if the channel corresponding to this interface is degraded. */
	public boolean isIsDegraded() {
		return this.isDegraded;
	}
	/** @param x True if the channel corresponding to this interface is degraded. */
	public void setIsDegraded(boolean x) {
		this.isDegraded = x;
	}

	/** Information about the SAS I/O controller port corresponding to this interface. */
	@io.swagger.annotations.ApiModelProperty(value ="Information about the SAS I/O controller port corresponding to this interface." , required = true)
	@XmlElement(required = true)
	private SasPort iocPort;

	/** @return Information about the SAS I/O controller port corresponding to this interface. */
	public SasPort getIocPort() {
		return this.iocPort;
	}
	/** @param x Information about the SAS I/O controller port corresponding to this interface. */
	public void setIocPort(SasPort x) {
		this.iocPort = x;
	}

	/** The unique identifier for a given instance of this structure. */
	@io.swagger.annotations.ApiModelProperty(value ="The unique identifier for a given instance of this structure." , required = true)
	@XmlElement(required = true)
	private String interfaceRef;

	/** @return The unique identifier for a given instance of this structure. */
	public String getInterfaceRef() {
		return this.interfaceRef;
	}
	/** @param x The unique identifier for a given instance of this structure. */
	public void setInterfaceRef(String x) {
		this.interfaceRef = x;
	}

	/** The physical location of the SAS interface. The parent reference in Location identifies the physical component (e.g., controller or host card) where the interface circuitry is located, and the position field is a firmware-assigned 1-relative number signifying "1st SAS interface relative to the parent," "2nd SAS interface relative to the parent," etc. This "interface number" is independent of the interface's channel association. */
	@io.swagger.annotations.ApiModelProperty(value ="The physical location of the SAS interface. The parent reference in Location identifies the physical component (e.g., controller or host card) where the interface circuitry is located, and the position field is a firmware-assigned 1-relative number signifying \"1st SAS interface relative to the parent,\" \"2nd SAS interface relative to the parent,\" etc. This \"interface number\" is independent of the interface's channel association." , required = true)
	@XmlElement(required = true)
	private Location physicalLocation;

	/** @return The physical location of the SAS interface. The parent reference in Location identifies the physical component (e.g., controller or host card) where the interface circuitry is located, and the position field is a firmware-assigned 1-relative number signifying "1st SAS interface relative to the parent," "2nd SAS interface relative to the parent," etc. This "interface number" is independent of the interface's channel association. */
	public Location getPhysicalLocation() {
		return this.physicalLocation;
	}
	/** @param x The physical location of the SAS interface. The parent reference in Location identifies the physical component (e.g., controller or host card) where the interface circuitry is located, and the position field is a firmware-assigned 1-relative number signifying "1st SAS interface relative to the parent," "2nd SAS interface relative to the parent," etc. This "interface number" is independent of the interface's channel association. */
	public void setPhysicalLocation(Location x) {
		this.physicalLocation = x;
	}

	/** This field indicates whether or not the I/O interface is PI capable. */
	@io.swagger.annotations.ApiModelProperty(value ="This field indicates whether or not the I/O interface is PI capable." , required = true)
	@XmlElement(required = true)
	private boolean protectionInformationCapable;

	/** @return This field indicates whether or not the I/O interface is PI capable. */
	public boolean isProtectionInformationCapable() {
		return this.protectionInformationCapable;
	}
	/** @param x This field indicates whether or not the I/O interface is PI capable. */
	public void setProtectionInformationCapable(boolean x) {
		this.protectionInformationCapable = x;
	}

	/** Maximum one way data rate in B/s */
	@io.swagger.annotations.ApiModelProperty(value ="Maximum one way data rate in B/s" , required = true)
	@XmlElement(required = true)
	private long oneWayMaxRate;

	/** @return Maximum one way data rate in B/s */
	public long getOneWayMaxRate() {
		return this.oneWayMaxRate;
	}
	/** @param x Maximum one way data rate in B/s */
	public void setOneWayMaxRate(long x) {
		this.oneWayMaxRate = x;
	}

	/** Maximum bi-directional data rate in B/s */
	@io.swagger.annotations.ApiModelProperty(value ="Maximum bi-directional data rate in B/s" , required = true)
	@XmlElement(required = true)
	private long bidirectionalMaxRate;

	/** @return Maximum bi-directional data rate in B/s */
	public long getBidirectionalMaxRate() {
		return this.bidirectionalMaxRate;
	}
	/** @param x Maximum bi-directional data rate in B/s */
	public void setBidirectionalMaxRate(long x) {
		this.bidirectionalMaxRate = x;
	}
	@Override
	public String getId(){
		return interfaceRef;
	}
}
