package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used to represent the characteristics of a storage array. Exactly one object of this type is reported in the information returned by the getObjectGraph operation. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(1057)
public class StorageArray implements Serializable {
	public StorageArray() {
	}

	/** General information and characteristics of the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="General information and characteristics of the storage array." , required = true)
	@XmlElement(required = true)
	private SAData saData;

	/** @return General information and characteristics of the storage array. */
	public SAData getSaData() {
		return this.saData;
	}
	/** @param x General information and characteristics of the storage array. */
	public void setSaData(SAData x) {
		this.saData = x;
	}

	/** This field contains a unique identifier maintained by SAFE for use by storage management software. Storage management software uses this data to enable SAFE features and perform Feature Bundle migration. */
	@io.swagger.annotations.ApiModelProperty(value ="This field contains a unique identifier maintained by SAFE for use by storage management software. Storage management software uses this data to enable SAFE features and perform Feature Bundle migration." , required = true)
	@XmlElement(required = true)
	private SAIdentifier safeId;

	/** @return This field contains a unique identifier maintained by SAFE for use by storage management software. Storage management software uses this data to enable SAFE features and perform Feature Bundle migration. */
	public SAIdentifier getSafeId() {
		return this.safeId;
	}
	/** @param x This field contains a unique identifier maintained by SAFE for use by storage management software. Storage management software uses this data to enable SAFE features and perform Feature Bundle migration. */
	public void setSafeId(SAIdentifier x) {
		this.safeId = x;
	}

	/** Information about cache settings that apply to the storage array as a whole. */
	@io.swagger.annotations.ApiModelProperty(value ="Information about cache settings that apply to the storage array as a whole." , required = true)
	@XmlElement(required = true)
	private SACache cache;

	/** @return Information about cache settings that apply to the storage array as a whole. */
	public SACache getCache() {
		return this.cache;
	}
	/** @param x Information about cache settings that apply to the storage array as a whole. */
	public void setCache(SACache x) {
		this.cache = x;
	}

	/** Information about the access volume that is used to convey configuration commands (via the UTM protocol) to the controllers within the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="Information about the access volume that is used to convey configuration commands (via the UTM protocol) to the controllers within the storage array." , required = true)
	@XmlElement(required = true)
	private AccessVolume accessVolume;

	/** @return Information about the access volume that is used to convey configuration commands (via the UTM protocol) to the controllers within the storage array. */
	public AccessVolume getAccessVolume() {
		return this.accessVolume;
	}
	/** @param x Information about the access volume that is used to convey configuration commands (via the UTM protocol) to the controllers within the storage array. */
	public void setAccessVolume(AccessVolume x) {
		this.accessVolume = x;
	}

	/** An object that provides information about the parameters and limits of certain functions that are supported by the controllers that reside within the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="An object that provides information about the parameters and limits of certain functions that are supported by the controllers that reside within the storage array." , required = true)
	@XmlElement(required = true)
	private FeatureParams featureParameters;

	/** @return An object that provides information about the parameters and limits of certain functions that are supported by the controllers that reside within the storage array. */
	public FeatureParams getFeatureParameters() {
		return this.featureParameters;
	}
	/** @param x An object that provides information about the parameters and limits of certain functions that are supported by the controllers that reside within the storage array. */
	public void setFeatureParameters(FeatureParams x) {
		this.featureParameters = x;
	}

	/** The current value of the media scan period parameter for the storage array. This value indicates the number of days over which a complete scan of the media will occur. The array controller(s) will attempt to achieve this configured period on a best-effort basis, but certain operational factors may cause slight deviations from the configured value. */
	@io.swagger.annotations.ApiModelProperty(value ="The current value of the media scan period parameter for the storage array. This value indicates the number of days over which a complete scan of the media will occur. The array controller(s) will attempt to achieve this configured period on a best-effort basis, but certain operational factors may cause slight deviations from the configured value." , required = true)
	@XmlElement(required = true)
	private int mediaScanPeriod;

	/** @return The current value of the media scan period parameter for the storage array. This value indicates the number of days over which a complete scan of the media will occur. The array controller(s) will attempt to achieve this configured period on a best-effort basis, but certain operational factors may cause slight deviations from the configured value. */
	public int getMediaScanPeriod() {
		return this.mediaScanPeriod;
	}
	/** @param x The current value of the media scan period parameter for the storage array. This value indicates the number of days over which a complete scan of the media will occur. The array controller(s) will attempt to achieve this configured period on a best-effort basis, but certain operational factors may cause slight deviations from the configured value. */
	public void setMediaScanPeriod(int x) {
		this.mediaScanPeriod = x;
	}

	/** A variable-length array that provides an enumeration of the high-level capabilities that are supported by the controllers that reside within the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array that provides an enumeration of the high-level capabilities that are supported by the controllers that reside within the storage array." , required = true)
	@XmlElement(required = true)
	private Capability[] capabilities;

	/** @return A variable-length array that provides an enumeration of the high-level capabilities that are supported by the controllers that reside within the storage array. */
	public Capability[] getCapabilities() {
		return this.capabilities;
	}
	/** @param x A variable-length array that provides an enumeration of the high-level capabilities that are supported by the controllers that reside within the storage array. */
	public void setCapabilities(Capability[] x) {
		this.capabilities = x;
	}

	/** An object that provides information about the premium features that are currently enabled. This field is deprecated. The featureBundle and featureState fields can be used in its place to obtain information about how features are defined and the state they are in. */
	@io.swagger.annotations.ApiModelProperty(value ="An object that provides information about the premium features that are currently enabled. This field is deprecated. The featureBundle and featureState fields can be used in its place to obtain information about how features are defined and the state they are in." , required = true)
	@XmlElement(required = true)
	private PremiumFeature[] premiumFeatures;

	/** @return An object that provides information about the premium features that are currently enabled. This field is deprecated. The featureBundle and featureState fields can be used in its place to obtain information about how features are defined and the state they are in. */
	public PremiumFeature[] getPremiumFeatures() {
		return this.premiumFeatures;
	}
	/** @param x An object that provides information about the premium features that are currently enabled. This field is deprecated. The featureBundle and featureState fields can be used in its place to obtain information about how features are defined and the state they are in. */
	public void setPremiumFeatures(PremiumFeature[] x) {
		this.premiumFeatures = x;
	}

	/** A list of tray positions that provides information to the client of the SYMbol interface about the relative physical positions of the trays (i.e. enclosures) that comprise the storage array. In the current implementation of the SYMbol interface, the client is responsible for providing this information to the controller for long-term storage, and also for retrieving it from the controller via this object. That is, the controller does not initially contain a valid tray position list; in fact, the default is an empty list. The client is responsible for obtaining any pertinent information about tray positions via an appropriate external mechanism, and then informing the controller about it via the setSATrayPositions procedure. Once this is done, the controller will always return the position information as part of the StorageArray object. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of tray positions that provides information to the client of the SYMbol interface about the relative physical positions of the trays (i.e. enclosures) that comprise the storage array. In the current implementation of the SYMbol interface, the client is responsible for providing this information to the controller for long-term storage, and also for retrieving it from the controller via this object. That is, the controller does not initially contain a valid tray position list; in fact, the default is an empty list. The client is responsible for obtaining any pertinent information about tray positions via an appropriate external mechanism, and then informing the controller about it via the setSATrayPositions procedure. Once this is done, the controller will always return the position information as part of the StorageArray object." , required = true)
	@XmlElement(required = true)
	private TrayPositionList trayPositionList;

	/** @return A list of tray positions that provides information to the client of the SYMbol interface about the relative physical positions of the trays (i.e. enclosures) that comprise the storage array. In the current implementation of the SYMbol interface, the client is responsible for providing this information to the controller for long-term storage, and also for retrieving it from the controller via this object. That is, the controller does not initially contain a valid tray position list; in fact, the default is an empty list. The client is responsible for obtaining any pertinent information about tray positions via an appropriate external mechanism, and then informing the controller about it via the setSATrayPositions procedure. Once this is done, the controller will always return the position information as part of the StorageArray object. */
	public TrayPositionList getTrayPositionList() {
		return this.trayPositionList;
	}
	/** @param x A list of tray positions that provides information to the client of the SYMbol interface about the relative physical positions of the trays (i.e. enclosures) that comprise the storage array. In the current implementation of the SYMbol interface, the client is responsible for providing this information to the controller for long-term storage, and also for retrieving it from the controller via this object. That is, the controller does not initially contain a valid tray position list; in fact, the default is an empty list. The client is responsible for obtaining any pertinent information about tray positions via an appropriate external mechanism, and then informing the controller about it via the setSATrayPositions procedure. Once this is done, the controller will always return the position information as part of the StorageArray object. */
	public void setTrayPositionList(TrayPositionList x) {
		this.trayPositionList = x;
	}

	/** This variable-length array has label values that provide descriptive strings for each supported index value that can appear in the HostPort object and its associated elements. */
	@io.swagger.annotations.ApiModelProperty(value ="This variable-length array has label values that provide descriptive strings for each supported index value that can appear in the HostPort object and its associated elements." , required = true)
	@XmlElement(required = true)
	private String[] hostPortType;

	/** @return This variable-length array has label values that provide descriptive strings for each supported index value that can appear in the HostPort object and its associated elements. */
	public String[] getHostPortType() {
		return this.hostPortType;
	}
	/** @param x This variable-length array has label values that provide descriptive strings for each supported index value that can appear in the HostPort object and its associated elements. */
	public void setHostPortType(String[] x) {
		this.hostPortType = x;
	}

	/** The values from the heterogeneous host regions. Each element in this array corresponds to a type in the hostPortType array, and the ordering of the types in this array matches that of the hostPortType array, i.e., hostPortType[i] is equal to hostSpecificVals[i].hostPortType. */
	@io.swagger.annotations.ApiModelProperty(value ="The values from the heterogeneous host regions. Each element in this array corresponds to a type in the hostPortType array, and the ordering of the types in this array matches that of the hostPortType array, i.e., hostPortType[i] is equal to hostSpecificVals[i].hostPortType." , required = true)
	@XmlElement(required = true)
	private HostSpecificValues[] hostSpecificVals;

	/** @return The values from the heterogeneous host regions. Each element in this array corresponds to a type in the hostPortType array, and the ordering of the types in this array matches that of the hostPortType array, i.e., hostPortType[i] is equal to hostSpecificVals[i].hostPortType. */
	public HostSpecificValues[] getHostSpecificVals() {
		return this.hostSpecificVals;
	}
	/** @param x The values from the heterogeneous host regions. Each element in this array corresponds to a type in the hostPortType array, and the ordering of the types in this array matches that of the hostPortType array, i.e., hostPortType[i] is equal to hostSpecificVals[i].hostPortType. */
	public void setHostSpecificVals(HostSpecificValues[] x) {
		this.hostSpecificVals = x;
	}

	/** A variable-length array of firmware compatibility specifiers. These values generally identify certain levels of firmware that are allowed for downgrading the current storage array firmware. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array of firmware compatibility specifiers. These values generally identify certain levels of firmware that are allowed for downgrading the current storage array firmware." , required = true)
	@XmlElement(required = true)
	private CompatibleFirmware[] compatibility;

	/** @return A variable-length array of firmware compatibility specifiers. These values generally identify certain levels of firmware that are allowed for downgrading the current storage array firmware. */
	public CompatibleFirmware[] getCompatibility() {
		return this.compatibility;
	}
	/** @param x A variable-length array of firmware compatibility specifiers. These values generally identify certain levels of firmware that are allowed for downgrading the current storage array firmware. */
	public void setCompatibility(CompatibleFirmware[] x) {
		this.compatibility = x;
	}

	/** The recommended usage parameter combinations. */
	@io.swagger.annotations.ApiModelProperty(value ="The recommended usage parameter combinations." , required = true)
	@XmlElement(required = true)
	private VolumeUsageHint[] usageHints;

	/** @return The recommended usage parameter combinations. */
	public VolumeUsageHint[] getUsageHints() {
		return this.usageHints;
	}
	/** @param x The recommended usage parameter combinations. */
	public void setUsageHints(VolumeUsageHint[] x) {
		this.usageHints = x;
	}

	/** The number of partitions calculated from the user's current mappings. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of partitions calculated from the user's current mappings." , required = true)
	@XmlElement(required = true)
	private int definedPartitionCount;

	/** @return The number of partitions calculated from the user's current mappings. */
	public int getDefinedPartitionCount() {
		return this.definedPartitionCount;
	}
	/** @param x The number of partitions calculated from the user's current mappings. */
	public void setDefinedPartitionCount(int x) {
		this.definedPartitionCount = x;
	}

	/** The Host Port Type Index to use for undefined and newly created host ports. The defaultHostPortTypeIndex can only be set if Storage Partitions are disabled through the SYMbol Interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The Host Port Type Index to use for undefined and newly created host ports. The defaultHostPortTypeIndex can only be set if Storage Partitions are disabled through the SYMbol Interface." , required = true)
	@XmlElement(required = true)
	private int defaultHostPortTypeIndex;

	/** @return The Host Port Type Index to use for undefined and newly created host ports. The defaultHostPortTypeIndex can only be set if Storage Partitions are disabled through the SYMbol Interface. */
	public int getDefaultHostPortTypeIndex() {
		return this.defaultHostPortTypeIndex;
	}
	/** @param x The Host Port Type Index to use for undefined and newly created host ports. The defaultHostPortTypeIndex can only be set if Storage Partitions are disabled through the SYMbol Interface. */
	public void setDefaultHostPortTypeIndex(int x) {
		this.defaultHostPortTypeIndex = x;
	}

	/** Array-specific ID used for remote device discovery. */
	@io.swagger.annotations.ApiModelProperty(value ="Array-specific ID used for remote device discovery." , required = true)
	@XmlElement(required = true)
	private String remoteAccessID;

	/** @return Array-specific ID used for remote device discovery. */
	public String getRemoteAccessID() {
		return this.remoteAccessID;
	}
	/** @param x Array-specific ID used for remote device discovery. */
	public void setRemoteAccessID(String x) {
		this.remoteAccessID = x;
	}

	/** True if RVM is activated. */
	@io.swagger.annotations.ApiModelProperty(value ="True if RVM is activated." , required = true)
	@XmlElement(required = true)
	private boolean remoteMirroringActive;

	/** @return True if RVM is activated. */
	public boolean isRemoteMirroringActive() {
		return this.remoteMirroringActive;
	}
	/** @param x True if RVM is activated. */
	public void setRemoteMirroringActive(boolean x) {
		this.remoteMirroringActive = x;
	}

	/** Volume transfer alert delay period. */
	@io.swagger.annotations.ApiModelProperty(value ="Volume transfer alert delay period." , required = true)
	@XmlElement(required = true)
	private int volXferAlertDelayPeriod;

	/** @return Volume transfer alert delay period. */
	public int getVolXferAlertDelayPeriod() {
		return this.volXferAlertDelayPeriod;
	}
	/** @param x Volume transfer alert delay period. */
	public void setVolXferAlertDelayPeriod(int x) {
		this.volXferAlertDelayPeriod = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private String reserved1;

	/** @return Reserved for future use. */
	public String getReserved1() {
		return this.reserved1;
	}
	/** @param x Reserved for future use. */
	public void setReserved1(String x) {
		this.reserved1 = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private String reserved2;

	/** @return Reserved for future use. */
	public String getReserved2() {
		return this.reserved2;
	}
	/** @param x Reserved for future use. */
	public void setReserved2(String x) {
		this.reserved2 = x;
	}

	/** Information on possible staged controller firmware. */
	@io.swagger.annotations.ApiModelProperty(value ="Information on possible staged controller firmware." , required = true)
	@XmlElement(required = true)
	private StagedFirmware stagedFirmware;

	/** @return Information on possible staged controller firmware. */
	public StagedFirmware getStagedFirmware() {
		return this.stagedFirmware;
	}
	/** @param x Information on possible staged controller firmware. */
	public void setStagedFirmware(StagedFirmware x) {
		this.stagedFirmware = x;
	}

	/** Storage array unreadable sector count and max limit. */
	@io.swagger.annotations.ApiModelProperty(value ="Storage array unreadable sector count and max limit." , required = true)
	@XmlElement(required = true)
	private UnreadableSectors unreadableSectors;

	/** @return Storage array unreadable sector count and max limit. */
	public UnreadableSectors getUnreadableSectors() {
		return this.unreadableSectors;
	}
	/** @param x Storage array unreadable sector count and max limit. */
	public void setUnreadableSectors(UnreadableSectors x) {
		this.unreadableSectors = x;
	}

	/** A list of drive channel structures. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of drive channel structures." , required = true)
	@XmlElement(required = true)
	private DriveChannel[] driveChannels;

	/** @return A list of drive channel structures. */
	public DriveChannel[] getDriveChannels() {
		return this.driveChannels;
	}
	/** @param x A list of drive channel structures. */
	public void setDriveChannels(DriveChannel[] x) {
		this.driveChannels = x;
	}

	/** A list of drive channel port locations. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of drive channel port locations." , required = true)
	@XmlElement(required = true)
	private DriveChannelPort[] portLocations;

	/** @return A list of drive channel port locations. */
	public DriveChannelPort[] getPortLocations() {
		return this.portLocations;
	}
	/** @param x A list of drive channel port locations. */
	public void setPortLocations(DriveChannelPort[] x) {
		this.portLocations = x;
	}

	/** The tag value to be used in retrieving DDC log data. A value of DDC_NULL_TAG indicates there is no DDC log data to retrieve. */
	@io.swagger.annotations.ApiModelProperty(value ="The tag value to be used in retrieving DDC log data. A value of DDC_NULL_TAG indicates there is no DDC log data to retrieve." , required = true)
	@XmlElement(required = true)
	private int ddcTag;

	/** @return The tag value to be used in retrieving DDC log data. A value of DDC_NULL_TAG indicates there is no DDC log data to retrieve. */
	public int getDdcTag() {
		return this.ddcTag;
	}
	/** @param x The tag value to be used in retrieving DDC log data. A value of DDC_NULL_TAG indicates there is no DDC log data to retrieve. */
	public void setDdcTag(int x) {
		this.ddcTag = x;
	}

	/** A structure describing the features and feature limits that are associated with this storage array product. */
	@io.swagger.annotations.ApiModelProperty(value ="A structure describing the features and feature limits that are associated with this storage array product." , required = true)
	@XmlElement(required = true)
	private FeatureBundle featureBundle;

	/** @return A structure describing the features and feature limits that are associated with this storage array product. */
	public FeatureBundle getFeatureBundle() {
		return this.featureBundle;
	}
	/** @param x A structure describing the features and feature limits that are associated with this storage array product. */
	public void setFeatureBundle(FeatureBundle x) {
		this.featureBundle = x;
	}

	/** An array describing the current state of the array feature set - one element in the array per feature. This array is used by host software to track feature licensing compliance. It is populated with all supported features having both a feature ID and a capability code, regardless of their enabled or compliance state. Features that are not supported because of gold key restrictions or because there is no way to enable them (i.e., both SHIPPED_ENABLED and KEY_ENABLED are false) are not in the list. */
	@io.swagger.annotations.ApiModelProperty(value ="An array describing the current state of the array feature set - one element in the array per feature. This array is used by host software to track feature licensing compliance. It is populated with all supported features having both a feature ID and a capability code, regardless of their enabled or compliance state. Features that are not supported because of gold key restrictions or because there is no way to enable them (i.e., both SHIPPED_ENABLED and KEY_ENABLED are false) are not in the list." , required = true)
	@XmlElement(required = true)
	private FeatureState[] featureState;

	/** @return An array describing the current state of the array feature set - one element in the array per feature. This array is used by host software to track feature licensing compliance. It is populated with all supported features having both a feature ID and a capability code, regardless of their enabled or compliance state. Features that are not supported because of gold key restrictions or because there is no way to enable them (i.e., both SHIPPED_ENABLED and KEY_ENABLED are false) are not in the list. */
	public FeatureState[] getFeatureState() {
		return this.featureState;
	}
	/** @param x An array describing the current state of the array feature set - one element in the array per feature. This array is used by host software to track feature licensing compliance. It is populated with all supported features having both a feature ID and a capability code, regardless of their enabled or compliance state. Features that are not supported because of gold key restrictions or because there is no way to enable them (i.e., both SHIPPED_ENABLED and KEY_ENABLED are false) are not in the list. */
	public void setFeatureState(FeatureState[] x) {
		this.featureState = x;
	}

	/** A list of all channel ports in the storage array, including host channel ports, drive channel ports, and ESM channel ports. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of all channel ports in the storage array, including host channel ports, drive channel ports, and ESM channel ports." , required = true)
	@XmlElement(required = true)
	private ChannelPort[] channelPortLocations;

	/** @return A list of all channel ports in the storage array, including host channel ports, drive channel ports, and ESM channel ports. */
	public ChannelPort[] getChannelPortLocations() {
		return this.channelPortLocations;
	}
	/** @param x A list of all channel ports in the storage array, including host channel ports, drive channel ports, and ESM channel ports. */
	public void setChannelPortLocations(ChannelPort[] x) {
		this.channelPortLocations = x;
	}

	/** Information about the storage array pertaining to its role as an iSCSI entity. */
	@io.swagger.annotations.ApiModelProperty(value ="Information about the storage array pertaining to its role as an iSCSI entity." , required = true)
	@XmlElement(required = true)
	private IscsiEntityData iscsiEntityData;

	/** @return Information about the storage array pertaining to its role as an iSCSI entity. */
	public IscsiEntityData getIscsiEntityData() {
		return this.iscsiEntityData;
	}
	/** @param x Information about the storage array pertaining to its role as an iSCSI entity. */
	public void setIscsiEntityData(IscsiEntityData x) {
		this.iscsiEntityData = x;
	}

	/** This variable-length array has label values that provide descriptive strings for each supported index value that can appear in the Host object. Zero-length strings are allowed and indicate that the associated host-specific NVSRAM regions have been cleared. This field should be used in place of the deprecated hostPortType field. */
	@io.swagger.annotations.ApiModelProperty(value ="This variable-length array has label values that provide descriptive strings for each supported index value that can appear in the Host object. Zero-length strings are allowed and indicate that the associated host-specific NVSRAM regions have been cleared. This field should be used in place of the deprecated hostPortType field." , required = true)
	@XmlElement(required = true)
	private String[] hostType;

	/** @return This variable-length array has label values that provide descriptive strings for each supported index value that can appear in the Host object. Zero-length strings are allowed and indicate that the associated host-specific NVSRAM regions have been cleared. This field should be used in place of the deprecated hostPortType field. */
	public String[] getHostType() {
		return this.hostType;
	}
	/** @param x This variable-length array has label values that provide descriptive strings for each supported index value that can appear in the Host object. Zero-length strings are allowed and indicate that the associated host-specific NVSRAM regions have been cleared. This field should be used in place of the deprecated hostPortType field. */
	public void setHostType(String[] x) {
		this.hostType = x;
	}

	/** The Host Type Index to use for undefined and newly created host ports. */
	@io.swagger.annotations.ApiModelProperty(value ="The Host Type Index to use for undefined and newly created host ports." , required = true)
	@XmlElement(required = true)
	private int defaultHostTypeIndex;

	/** @return The Host Type Index to use for undefined and newly created host ports. */
	public int getDefaultHostTypeIndex() {
		return this.defaultHostTypeIndex;
	}
	/** @param x The Host Type Index to use for undefined and newly created host ports. */
	public void setDefaultHostTypeIndex(int x) {
		this.defaultHostTypeIndex = x;
	}

	/** The number (in the range 1 through n, where n is the number of host ports on an individual controller) of the controller host channel that the firmware uses for remote volume mirroring. This field is set to zero when the data is unavailable or not applicable, including when the RVM feature is disabled, */
	@io.swagger.annotations.ApiModelProperty(value ="The number (in the range 1 through n, where n is the number of host ports on an individual controller) of the controller host channel that the firmware uses for remote volume mirroring. This field is set to zero when the data is unavailable or not applicable, including when the RVM feature is disabled," , required = true)
	@XmlElement(required = true)
	private int rvmControllerHostChannel;

	/** @return The number (in the range 1 through n, where n is the number of host ports on an individual controller) of the controller host channel that the firmware uses for remote volume mirroring. This field is set to zero when the data is unavailable or not applicable, including when the RVM feature is disabled, */
	public int getRvmControllerHostChannel() {
		return this.rvmControllerHostChannel;
	}
	/** @param x The number (in the range 1 through n, where n is the number of host ports on an individual controller) of the controller host channel that the firmware uses for remote volume mirroring. This field is set to zero when the data is unavailable or not applicable, including when the RVM feature is disabled, */
	public void setRvmControllerHostChannel(int x) {
		this.rvmControllerHostChannel = x;
	}

	/** sub-structure of StorageArray contains info relating to smart battery configuration. Meaningful if the smartBatteryTechnology field in the featureParameters sub-structure is set to true. Moved to the Battery object instead to support per-battery reporting */
	@io.swagger.annotations.ApiModelProperty(value ="sub-structure of StorageArray contains info relating to smart battery configuration. Meaningful if the smartBatteryTechnology field in the featureParameters sub-structure is set to true. Moved to the Battery object instead to support per-battery reporting" , required = true)
	@XmlElement(required = true)
	private SmartBatteryData smartBatteryData;

	/** @return sub-structure of StorageArray contains info relating to smart battery configuration. Meaningful if the smartBatteryTechnology field in the featureParameters sub-structure is set to true. Moved to the Battery object instead to support per-battery reporting */
	public SmartBatteryData getSmartBatteryData() {
		return this.smartBatteryData;
	}
	/** @param x sub-structure of StorageArray contains info relating to smart battery configuration. Meaningful if the smartBatteryTechnology field in the featureParameters sub-structure is set to true. Moved to the Battery object instead to support per-battery reporting */
	public void setSmartBatteryData(SmartBatteryData x) {
		this.smartBatteryData = x;
	}

	/** True if the storage array has an invalid system configuration; otherwise false. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the storage array has an invalid system configuration; otherwise false." , required = true)
	@XmlElement(required = true)
	private boolean invalidSystemConfig;

	/** @return True if the storage array has an invalid system configuration; otherwise false. */
	public boolean isInvalidSystemConfig() {
		return this.invalidSystemConfig;
	}
	/** @param x True if the storage array has an invalid system configuration; otherwise false. */
	public void setInvalidSystemConfig(boolean x) {
		this.invalidSystemConfig = x;
	}

	/** A boolean which describes the current state of the lock key. True if the array lock key has been set, otherwise false. */
	@io.swagger.annotations.ApiModelProperty(value ="A boolean which describes the current state of the lock key. True if the array lock key has been set, otherwise false." , required = true)
	@XmlElement(required = true)
	private boolean securityLockKey;

	/** @return A boolean which describes the current state of the lock key. True if the array lock key has been set, otherwise false. */
	public boolean isSecurityLockKey() {
		return this.securityLockKey;
	}
	/** @param x A boolean which describes the current state of the lock key. True if the array lock key has been set, otherwise false. */
	public void setSecurityLockKey(boolean x) {
		this.securityLockKey = x;
	}

	/** The lock key ID for the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="The lock key ID for the storage array." , required = true)
	@XmlElement(required = true)
	private String lockKeyIDRef;

	/** @return The lock key ID for the storage array. */
	public String getLockKeyIDRef() {
		return this.lockKeyIDRef;
	}
	/** @param x The lock key ID for the storage array. */
	public void setLockKeyIDRef(String x) {
		this.lockKeyIDRef = x;
	}

	/** This field contains the configuration information used by the storage array for writing MEL events to a syslog server. */
	@io.swagger.annotations.ApiModelProperty(value ="This field contains the configuration information used by the storage array for writing MEL events to a syslog server." , required = true)
	@XmlElement(required = true)
	private SyslogConfiguration syslogConfiguration;

	/** @return This field contains the configuration information used by the storage array for writing MEL events to a syslog server. */
	public SyslogConfiguration getSyslogConfiguration() {
		return this.syslogConfiguration;
	}
	/** @param x This field contains the configuration information used by the storage array for writing MEL events to a syslog server. */
	public void setSyslogConfiguration(SyslogConfiguration x) {
		this.syslogConfiguration = x;
	}

	/** True if external key management is in effect and false if controller is using local key management. */
	@io.swagger.annotations.ApiModelProperty(value ="True if external key management is in effect and false if controller is using local key management." , required = true)
	@XmlElement(required = true)
	private boolean securityExternalKmsEnable;

	/** @return True if external key management is in effect and false if controller is using local key management. */
	public boolean isSecurityExternalKmsEnable() {
		return this.securityExternalKmsEnable;
	}
	/** @param x True if external key management is in effect and false if controller is using local key management. */
	public void setSecurityExternalKmsEnable(boolean x) {
		this.securityExternalKmsEnable = x;
	}

	/** Sequence number used to serialize installNewKey requests from multiple proxy key management SYMbol servers. */
	@io.swagger.annotations.ApiModelProperty(value ="Sequence number used to serialize installNewKey requests from multiple proxy key management SYMbol servers." , required = true)
	@XmlElement(required = true)
	private int newKeySequence;

	/** @return Sequence number used to serialize installNewKey requests from multiple proxy key management SYMbol servers. */
	public int getNewKeySequence() {
		return this.newKeySequence;
	}
	/** @param x Sequence number used to serialize installNewKey requests from multiple proxy key management SYMbol servers. */
	public void setNewKeySequence(int x) {
		this.newKeySequence = x;
	}

	/** The controller's current key status. If external key management not enabled, set to EXTERNAL_KMS_KEY_STATUS_OK. */
	@io.swagger.annotations.ApiModelProperty(value ="The controller's current key status. If external key management not enabled, set to EXTERNAL_KMS_KEY_STATUS_OK." , required = true)
	@XmlElement(required = true)
	private SecurityExternalKMSKeyStatus securityExternalKmsKeyStatus = SecurityExternalKMSKeyStatus.__UNDEFINED;

	/** @return The controller's current key status. If external key management not enabled, set to EXTERNAL_KMS_KEY_STATUS_OK. */
	public SecurityExternalKMSKeyStatus getSecurityExternalKmsKeyStatus() {
		return this.securityExternalKmsKeyStatus;
	}
	/** @param x The controller's current key status. If external key management not enabled, set to EXTERNAL_KMS_KEY_STATUS_OK. */
	public void setSecurityExternalKmsKeyStatus(SecurityExternalKMSKeyStatus x) {
		this.securityExternalKmsKeyStatus = x;
	}

	/** Contains the lock key IDs of keys needed by the array controller. */
	@io.swagger.annotations.ApiModelProperty(value ="Contains the lock key IDs of keys needed by the array controller." , required = true)
	@XmlElement(required = true)
	private String[] lockKeyNeededList;

	/** @return Contains the lock key IDs of keys needed by the array controller. */
	public String[] getLockKeyNeededList() {
		return this.lockKeyNeededList;
	}
	/** @param x Contains the lock key IDs of keys needed by the array controller. */
	public void setLockKeyNeededList(String[] x) {
		this.lockKeyNeededList = x;
	}

	/** Information about a core dump in controller memory, if one exists. */
	@io.swagger.annotations.ApiModelProperty(value ="Information about a core dump in controller memory, if one exists." , required = true)
	@XmlElement(required = true)
	private DPLCoreDumpData dplCoreDumpData;

	/** @return Information about a core dump in controller memory, if one exists. */
	public DPLCoreDumpData getDplCoreDumpData() {
		return this.dplCoreDumpData;
	}
	/** @param x Information about a core dump in controller memory, if one exists. */
	public void setDplCoreDumpData(DPLCoreDumpData x) {
		this.dplCoreDumpData = x;
	}

	/** Indicator of whether fibre channel remote mirroring has been enabled, and if so, whether it is enabled for use by legacy (synchronous) mirroring or ARVM. If this is set to something other than FC_MIRROR_STATE_DISABLED or FC_MIRROR_STATE_UNKNOWN, then the rvmControllerHostChannel field can be used to determine the particular host channel reserved for remote mirroring. */
	@io.swagger.annotations.ApiModelProperty(value ="Indicator of whether fibre channel remote mirroring has been enabled, and if so, whether it is enabled for use by legacy (synchronous) mirroring or ARVM. If this is set to something other than FC_MIRROR_STATE_DISABLED or FC_MIRROR_STATE_UNKNOWN, then the rvmControllerHostChannel field can be used to determine the particular host channel reserved for remote mirroring." , required = true)
	@XmlElement(required = true)
	private FibreChannelRemoteMirroringState fcRVMState = FibreChannelRemoteMirroringState.__UNDEFINED;

	/** @return Indicator of whether fibre channel remote mirroring has been enabled, and if so, whether it is enabled for use by legacy (synchronous) mirroring or ARVM. If this is set to something other than FC_MIRROR_STATE_DISABLED or FC_MIRROR_STATE_UNKNOWN, then the rvmControllerHostChannel field can be used to determine the particular host channel reserved for remote mirroring. */
	public FibreChannelRemoteMirroringState getFcRVMState() {
		return this.fcRVMState;
	}
	/** @param x Indicator of whether fibre channel remote mirroring has been enabled, and if so, whether it is enabled for use by legacy (synchronous) mirroring or ARVM. If this is set to something other than FC_MIRROR_STATE_DISABLED or FC_MIRROR_STATE_UNKNOWN, then the rvmControllerHostChannel field can be used to determine the particular host channel reserved for remote mirroring. */
	public void setFcRVMState(FibreChannelRemoteMirroringState x) {
		this.fcRVMState = x;
	}

	/** True if Autosupport is enabled. */
	@io.swagger.annotations.ApiModelProperty(value ="True if Autosupport is enabled." , required = true)
	@XmlElement(required = true)
	private boolean asupEnabled;

	/** @return True if Autosupport is enabled. */
	public boolean isAsupEnabled() {
		return this.asupEnabled;
	}
	/** @param x True if Autosupport is enabled. */
	public void setAsupEnabled(boolean x) {
		this.asupEnabled = x;
	}

	/** True if Autosupport On Demand is enabled. */
	@io.swagger.annotations.ApiModelProperty(value ="True if Autosupport On Demand is enabled." , required = true)
	@XmlElement(required = true)
	private boolean asupOnDemandEnabled;

	/** @return True if Autosupport On Demand is enabled. */
	public boolean isAsupOnDemandEnabled() {
		return this.asupOnDemandEnabled;
	}
	/** @param x True if Autosupport On Demand is enabled. */
	public void setAsupOnDemandEnabled(boolean x) {
		this.asupOnDemandEnabled = x;
	}

	/** True if Autosupport On Demand Remote Diagnostics is enabled. */
	@io.swagger.annotations.ApiModelProperty(value ="True if Autosupport On Demand Remote Diagnostics is enabled." , required = true)
	@XmlElement(required = true)
	private boolean asupRemoteDiagsEnabled;

	/** @return True if Autosupport On Demand Remote Diagnostics is enabled. */
	public boolean isAsupRemoteDiagsEnabled() {
		return this.asupRemoteDiagsEnabled;
	}
	/** @param x True if Autosupport On Demand Remote Diagnostics is enabled. */
	public void setAsupRemoteDiagsEnabled(boolean x) {
		this.asupRemoteDiagsEnabled = x;
	}

	/** Information about an IOC Dump in controller memory, if one exists. */
	@io.swagger.annotations.ApiModelProperty(value ="Information about an IOC Dump in controller memory, if one exists." , required = true)
	@XmlElement(required = true)
	private IOCDumpData iocDumpData;

	/** @return Information about an IOC Dump in controller memory, if one exists. */
	public IOCDumpData getIocDumpData() {
		return this.iocDumpData;
	}
	/** @param x Information about an IOC Dump in controller memory, if one exists. */
	public void setIocDumpData(IOCDumpData x) {
		this.iocDumpData = x;
	}

	/** True if one or more drive channel ports have been disabled by the controllers to protect against faulty expansion cabling. This could have been necessitated by a miswire condition or by a bad expansion cable. Check the Recovery Events for an indication of which connection(s) have been disabled and correct the cabling as required. */
	@io.swagger.annotations.ApiModelProperty(value ="True if one or more drive channel ports have been disabled by the controllers to protect against faulty expansion cabling. This could have been necessitated by a miswire condition or by a bad expansion cable. Check the Recovery Events for an indication of which connection(s) have been disabled and correct the cabling as required." , required = true)
	@XmlElement(required = true)
	private boolean driveChannelPortDisabled;

	/** @return True if one or more drive channel ports have been disabled by the controllers to protect against faulty expansion cabling. This could have been necessitated by a miswire condition or by a bad expansion cable. Check the Recovery Events for an indication of which connection(s) have been disabled and correct the cabling as required. */
	public boolean isDriveChannelPortDisabled() {
		return this.driveChannelPortDisabled;
	}
	/** @param x True if one or more drive channel ports have been disabled by the controllers to protect against faulty expansion cabling. This could have been necessitated by a miswire condition or by a bad expansion cable. Check the Recovery Events for an indication of which connection(s) have been disabled and correct the cabling as required. */
	public void setDriveChannelPortDisabled(boolean x) {
		this.driveChannelPortDisabled = x;
	}

	/** True if the VAAI function is enabled. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the VAAI function is enabled." , required = true)
	@XmlElement(required = true)
	private boolean VAAIEnabled;

	/** @return True if the VAAI function is enabled. */
	public boolean isVAAIEnabled() {
		return this.VAAIEnabled;
	}
	/** @param x True if the VAAI function is enabled. */
	public void setVAAIEnabled(boolean x) {
		this.VAAIEnabled = x;
	}

	/** True if the ODX function is enabled. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the ODX function is enabled." , required = true)
	@XmlElement(required = true)
	private boolean ODXEnabled;

	/** @return True if the ODX function is enabled. */
	public boolean isODXEnabled() {
		return this.ODXEnabled;
	}
	/** @param x True if the ODX function is enabled. */
	public void setODXEnabled(boolean x) {
		this.ODXEnabled = x;
	}

	/** This boolean is true if direct expansion ports are in use by the controllers. */
	@io.swagger.annotations.ApiModelProperty(value ="This boolean is true if direct expansion ports are in use by the controllers." , required = true)
	@XmlElement(required = true)
	private boolean directExpansionPortInUse;

	/** @return This boolean is true if direct expansion ports are in use by the controllers. */
	public boolean isDirectExpansionPortInUse() {
		return this.directExpansionPortInUse;
	}
	/** @param x This boolean is true if direct expansion ports are in use by the controllers. */
	public void setDirectExpansionPortInUse(boolean x) {
		this.directExpansionPortInUse = x;
	}

	/** Cumulative Performance stats high resolution indicator */
	@io.swagger.annotations.ApiModelProperty(value ="Cumulative Performance stats high resolution indicator" , required = true)
	@XmlElement(required = true)
	private boolean highResolutionStatisticsEnabled;

	/** @return Cumulative Performance stats high resolution indicator */
	public boolean isHighResolutionStatisticsEnabled() {
		return this.highResolutionStatisticsEnabled;
	}
	/** @param x Cumulative Performance stats high resolution indicator */
	public void setHighResolutionStatisticsEnabled(boolean x) {
		this.highResolutionStatisticsEnabled = x;
	}

	/** Auto Load Balancing is user-enabled on this array */
	@io.swagger.annotations.ApiModelProperty(value ="Auto Load Balancing is user-enabled on this array" , required = true)
	@XmlElement(required = true)
	private boolean autoLoadBalancingEnabled;

	/** @return Auto Load Balancing is user-enabled on this array */
	public boolean isAutoLoadBalancingEnabled() {
		return this.autoLoadBalancingEnabled;
	}
	/** @param x Auto Load Balancing is user-enabled on this array */
	public void setAutoLoadBalancingEnabled(boolean x) {
		this.autoLoadBalancingEnabled = x;
	}

	/** This reserved field is needed to maintain compatibility with host applications. */
	@io.swagger.annotations.ApiModelProperty(value ="This reserved field is needed to maintain compatibility with host applications." , required = true)
	@XmlElement(required = true)
	private String reserved3;

	/** @return This reserved field is needed to maintain compatibility with host applications. */
	public String getReserved3() {
		return this.reserved3;
	}
	/** @param x This reserved field is needed to maintain compatibility with host applications. */
	public void setReserved3(String x) {
		this.reserved3 = x;
	}

	/** This structure contains the external key management information. See the structure definition for details. */
	@io.swagger.annotations.ApiModelProperty(value ="This structure contains the external key management information. See the structure definition for details." , required = true)
	@XmlElement(required = true)
	private EmbeddedExternalKMSInformation embeddedExternalKMSInformation;

	/** @return This structure contains the external key management information. See the structure definition for details. */
	public EmbeddedExternalKMSInformation getEmbeddedExternalKMSInformation() {
		return this.embeddedExternalKMSInformation;
	}
	/** @param x This structure contains the external key management information. See the structure definition for details. */
	public void setEmbeddedExternalKMSInformation(EmbeddedExternalKMSInformation x) {
		this.embeddedExternalKMSInformation = x;
	}

	/** Provides an indication of whether LUN 0 is restricted (disallowed) for the default storage partition. */
	@io.swagger.annotations.ApiModelProperty(value ="Provides an indication of whether LUN 0 is restricted (disallowed) for the default storage partition." , required = true)
	@XmlElement(required = true)
	private boolean isLun0RestrictedForDefaultPartition;

	/** @return Provides an indication of whether LUN 0 is restricted (disallowed) for the default storage partition. */
	public boolean isIsLun0RestrictedForDefaultPartition() {
		return this.isLun0RestrictedForDefaultPartition;
	}
	/** @param x Provides an indication of whether LUN 0 is restricted (disallowed) for the default storage partition. */
	public void setIsLun0RestrictedForDefaultPartition(boolean x) {
		this.isLun0RestrictedForDefaultPartition = x;
	}
}
