package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used to convey information about a volume's attributes and current operational status. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(986)
public class Volume implements Serializable,devmgr.api.model.Identifiable,devmgr.api.model.Named {
	public Volume() {
	}

	/** An indication of whether the volume is currently offline. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of whether the volume is currently offline." , required = true)
	@XmlElement(required = true)
	private boolean offline;

	/** @return An indication of whether the volume is currently offline. */
	public boolean isOffline() {
		return this.offline;
	}
	/** @param x An indication of whether the volume is currently offline. */
	public void setOffline(boolean x) {
		this.offline = x;
	}

	/** An indication of whether the volume is configured for extreme protection. Such configurations generally call for extensive consistency checks and parity validations with each I/O request to the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of whether the volume is configured for extreme protection. Such configurations generally call for extensive consistency checks and parity validations with each I/O request to the volume." , required = true)
	@XmlElement(required = true)
	private boolean extremeProtection;

	/** @return An indication of whether the volume is configured for extreme protection. Such configurations generally call for extensive consistency checks and parity validations with each I/O request to the volume. */
	public boolean isExtremeProtection() {
		return this.extremeProtection;
	}
	/** @param x An indication of whether the volume is configured for extreme protection. Such configurations generally call for extensive consistency checks and parity validations with each I/O request to the volume. */
	public void setExtremeProtection(boolean x) {
		this.extremeProtection = x;
	}

	/** The internal identifier value associated with this volume. When the Storage Partitions feature is NOT present, this value represents the logical unit number (LUN) that is used to access the volume via the host I/O path. If the Storage Partitions feature IS enabled, this field has no external meaning. */
	@io.swagger.annotations.ApiModelProperty(value ="The internal identifier value associated with this volume. When the Storage Partitions feature is NOT present, this value represents the logical unit number (LUN) that is used to access the volume via the host I/O path. If the Storage Partitions feature IS enabled, this field has no external meaning." , required = true)
	@XmlElement(required = true)
	private int volumeHandle;

	/** @return The internal identifier value associated with this volume. When the Storage Partitions feature is NOT present, this value represents the logical unit number (LUN) that is used to access the volume via the host I/O path. If the Storage Partitions feature IS enabled, this field has no external meaning. */
	public int getVolumeHandle() {
		return this.volumeHandle;
	}
	/** @param x The internal identifier value associated with this volume. When the Storage Partitions feature is NOT present, this value represents the logical unit number (LUN) that is used to access the volume via the host I/O path. If the Storage Partitions feature IS enabled, this field has no external meaning. */
	public void setVolumeHandle(int x) {
		this.volumeHandle = x;
	}

	/** The RAID level for which this volume is configured. */
	@io.swagger.annotations.ApiModelProperty(value ="The RAID level for which this volume is configured." , required = true)
	@XmlElement(required = true)
	private RAIDLevel raidLevel = RAIDLevel.__UNDEFINED;

	/** @return The RAID level for which this volume is configured. */
	public RAIDLevel getRaidLevel() {
		return this.raidLevel;
	}
	/** @param x The RAID level for which this volume is configured. */
	public void setRaidLevel(RAIDLevel x) {
		this.raidLevel = x;
	}

	/** The sector offset of this volume within its volume group. This value is provided only to allow the client application to determine the relative positions of multiple volumes within a given volume group. No other assumptions or computations should be made with this value. */
	@io.swagger.annotations.ApiModelProperty(value ="The sector offset of this volume within its volume group. This value is provided only to allow the client application to determine the relative positions of multiple volumes within a given volume group. No other assumptions or computations should be made with this value." , required = true)
	@XmlElement(required = true)
	private long sectorOffset;

	/** @return The sector offset of this volume within its volume group. This value is provided only to allow the client application to determine the relative positions of multiple volumes within a given volume group. No other assumptions or computations should be made with this value. */
	public long getSectorOffset() {
		return this.sectorOffset;
	}
	/** @param x The sector offset of this volume within its volume group. This value is provided only to allow the client application to determine the relative positions of multiple volumes within a given volume group. No other assumptions or computations should be made with this value. */
	public void setSectorOffset(long x) {
		this.sectorOffset = x;
	}

	/** A variable-length opaque field that provides the volume's worldwide unique identification value. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length opaque field that provides the volume's worldwide unique identification value." , required = true)
	@XmlElement(required = true)
	private String worldWideName;

	/** @return A variable-length opaque field that provides the volume's worldwide unique identification value. */
	public String getWorldWideName() {
		return this.worldWideName;
	}
	/** @param x A variable-length opaque field that provides the volume's worldwide unique identification value. */
	public void setWorldWideName(String x) {
		this.worldWideName = x;
	}

	/** The user-assigned symbol label associated with the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="The user-assigned symbol label associated with the volume." , required = true)
	@XmlElement(required = true)
	private String label;

	/** @return The user-assigned symbol label associated with the volume. */
	public String getLabel() {
		return this.label;
	}
	/** @param x The user-assigned symbol label associated with the volume. */
	public void setLabel(String x) {
		this.label = x;
	}

	/** The block size (in bytes) of the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="The block size (in bytes) of the volume." , required = true)
	@XmlElement(required = true)
	private int blkSize;

	/** @return The block size (in bytes) of the volume. */
	public int getBlkSize() {
		return this.blkSize;
	}
	/** @param x The block size (in bytes) of the volume. */
	public void setBlkSize(int x) {
		this.blkSize = x;
	}

	/** The capacity (in bytes) of the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="The capacity (in bytes) of the volume." , required = true)
	@XmlElement(required = true)
	private long capacity;

	/** @return The capacity (in bytes) of the volume. */
	public long getCapacity() {
		return this.capacity;
	}
	/** @param x The capacity (in bytes) of the volume. */
	public void setCapacity(long x) {
		this.capacity = x;
	}

	/** The reconstruction priority value for the volume. This value is in the range 0-4, with 0 indicating that reconstruction is favored over any I/O, and 4 indicating that reconstruction should be performed with minimal impact to I/O. Intermediate values indicate various levels of compromise between these two extremes. */
	@io.swagger.annotations.ApiModelProperty(value ="The reconstruction priority value for the volume. This value is in the range 0-4, with 0 indicating that reconstruction is favored over any I/O, and 4 indicating that reconstruction should be performed with minimal impact to I/O. Intermediate values indicate various levels of compromise between these two extremes." , required = true)
	@XmlElement(required = true)
	private int reconPriority;

	/** @return The reconstruction priority value for the volume. This value is in the range 0-4, with 0 indicating that reconstruction is favored over any I/O, and 4 indicating that reconstruction should be performed with minimal impact to I/O. Intermediate values indicate various levels of compromise between these two extremes. */
	public int getReconPriority() {
		return this.reconPriority;
	}
	/** @param x The reconstruction priority value for the volume. This value is in the range 0-4, with 0 indicating that reconstruction is favored over any I/O, and 4 indicating that reconstruction should be performed with minimal impact to I/O. Intermediate values indicate various levels of compromise between these two extremes. */
	public void setReconPriority(int x) {
		this.reconPriority = x;
	}

	/** The segment size (in bytes) of the volume. The segment size is, for the most part, an indication of the stripe depth used to lay out the volume's block addresses. */
	@io.swagger.annotations.ApiModelProperty(value ="The segment size (in bytes) of the volume. The segment size is, for the most part, an indication of the stripe depth used to lay out the volume's block addresses." , required = true)
	@XmlElement(required = true)
	private int segmentSize;

	/** @return The segment size (in bytes) of the volume. The segment size is, for the most part, an indication of the stripe depth used to lay out the volume's block addresses. */
	public int getSegmentSize() {
		return this.segmentSize;
	}
	/** @param x The segment size (in bytes) of the volume. The segment size is, for the most part, an indication of the stripe depth used to lay out the volume's block addresses. */
	public void setSegmentSize(int x) {
		this.segmentSize = x;
	}

	/** An indication of what current long-running activity, if any, is currently in progress on the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of what current long-running activity, if any, is currently in progress on the volume." , required = true)
	@XmlElement(required = true)
	private VolumeAction action = VolumeAction.__UNDEFINED;

	/** @return An indication of what current long-running activity, if any, is currently in progress on the volume. */
	public VolumeAction getAction() {
		return this.action;
	}
	/** @param x An indication of what current long-running activity, if any, is currently in progress on the volume. */
	public void setAction(VolumeAction x) {
		this.action = x;
	}

	/** The volume-specific caching parameters currently in effect for the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="The volume-specific caching parameters currently in effect for the volume." , required = true)
	@XmlElement(required = true)
	private VolumeCache cache;

	/** @return The volume-specific caching parameters currently in effect for the volume. */
	public VolumeCache getCache() {
		return this.cache;
	}
	/** @param x The volume-specific caching parameters currently in effect for the volume. */
	public void setCache(VolumeCache x) {
		this.cache = x;
	}

	/** The volume-specific media scan settings currently in effect for the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="The volume-specific media scan settings currently in effect for the volume." , required = true)
	@XmlElement(required = true)
	private VolumeMediaScanParams mediaScan;

	/** @return The volume-specific media scan settings currently in effect for the volume. */
	public VolumeMediaScanParams getMediaScan() {
		return this.mediaScan;
	}
	/** @param x The volume-specific media scan settings currently in effect for the volume. */
	public void setMediaScan(VolumeMediaScanParams x) {
		this.mediaScan = x;
	}

	/** The unique identification value for this volume. Other objects may use this reference value to refer to the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="The unique identification value for this volume. Other objects may use this reference value to refer to the volume." , required = true)
	@XmlElement(required = true)
	private String volumeRef;

	/** @return The unique identification value for this volume. Other objects may use this reference value to refer to the volume. */
	public String getVolumeRef() {
		return this.volumeRef;
	}
	/** @param x The unique identification value for this volume. Other objects may use this reference value to refer to the volume. */
	public void setVolumeRef(String x) {
		this.volumeRef = x;
	}

	/** The current operational state of the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="The current operational state of the volume." , required = true)
	@XmlElement(required = true)
	private VolumeStatus status = VolumeStatus.__UNDEFINED;

	/** @return The current operational state of the volume. */
	public VolumeStatus getStatus() {
		return this.status;
	}
	/** @param x The current operational state of the volume. */
	public void setStatus(VolumeStatus x) {
		this.status = x;
	}

	/** The volume group reference value of the volume group on which this volume resides. */
	@io.swagger.annotations.ApiModelProperty(value ="The volume group reference value of the volume group on which this volume resides." , required = true)
	@XmlElement(required = true)
	private String volumeGroupRef;

	/** @return The volume group reference value of the volume group on which this volume resides. */
	public String getVolumeGroupRef() {
		return this.volumeGroupRef;
	}
	/** @param x The volume group reference value of the volume group on which this volume resides. */
	public void setVolumeGroupRef(String x) {
		this.volumeGroupRef = x;
	}

	/** The reference value of the controller that currently owns (i.e. manages) this volume. In non-AVT (Auto Volume Transfer) mode, host I/O access to the blocks in this volume is permitted only through the controller that is the current manager. In AVT mode, an I/O access to the controller that is not the current manager causes it to automatically become the current manager. */
	@io.swagger.annotations.ApiModelProperty(value ="The reference value of the controller that currently owns (i.e. manages) this volume. In non-AVT (Auto Volume Transfer) mode, host I/O access to the blocks in this volume is permitted only through the controller that is the current manager. In AVT mode, an I/O access to the controller that is not the current manager causes it to automatically become the current manager." , required = true)
	@XmlElement(required = true)
	private String currentManager;

	/** @return The reference value of the controller that currently owns (i.e. manages) this volume. In non-AVT (Auto Volume Transfer) mode, host I/O access to the blocks in this volume is permitted only through the controller that is the current manager. In AVT mode, an I/O access to the controller that is not the current manager causes it to automatically become the current manager. */
	public String getCurrentManager() {
		return this.currentManager;
	}
	/** @param x The reference value of the controller that currently owns (i.e. manages) this volume. In non-AVT (Auto Volume Transfer) mode, host I/O access to the blocks in this volume is permitted only through the controller that is the current manager. In AVT mode, an I/O access to the controller that is not the current manager causes it to automatically become the current manager. */
	public void setCurrentManager(String x) {
		this.currentManager = x;
	}

	/** The reference value of the controller that is the preferred manager of the volume. The preferred manager is tracked independent of the current manager, since the current manager may be switched dynamically as a result of host-base multi-path transitions. Later, when the error conditions that cause a multi-path transition have been corrected it is still possible to determine the preferred manager and switch ownership back to it. */
	@io.swagger.annotations.ApiModelProperty(value ="The reference value of the controller that is the preferred manager of the volume. The preferred manager is tracked independent of the current manager, since the current manager may be switched dynamically as a result of host-base multi-path transitions. Later, when the error conditions that cause a multi-path transition have been corrected it is still possible to determine the preferred manager and switch ownership back to it." , required = true)
	@XmlElement(required = true)
	private String preferredManager;

	/** @return The reference value of the controller that is the preferred manager of the volume. The preferred manager is tracked independent of the current manager, since the current manager may be switched dynamically as a result of host-base multi-path transitions. Later, when the error conditions that cause a multi-path transition have been corrected it is still possible to determine the preferred manager and switch ownership back to it. */
	public String getPreferredManager() {
		return this.preferredManager;
	}
	/** @param x The reference value of the controller that is the preferred manager of the volume. The preferred manager is tracked independent of the current manager, since the current manager may be switched dynamically as a result of host-base multi-path transitions. Later, when the error conditions that cause a multi-path transition have been corrected it is still possible to determine the preferred manager and switch ownership back to it. */
	public void setPreferredManager(String x) {
		this.preferredManager = x;
	}

	/** Operations allowed on this volume. */
	@io.swagger.annotations.ApiModelProperty(value ="Operations allowed on this volume." , required = true)
	@XmlElement(required = true)
	private VolumePerms perms;

	/** @return Operations allowed on this volume. */
	public VolumePerms getPerms() {
		return this.perms;
	}
	/** @param x Operations allowed on this volume. */
	public void setPerms(VolumePerms x) {
		this.perms = x;
	}

	/** For use by management client. */
	@io.swagger.annotations.ApiModelProperty(value ="For use by management client." , required = true)
	@XmlElement(required = true)
	private int mgmtClientAttribute;

	/** @return For use by management client. */
	public int getMgmtClientAttribute() {
		return this.mgmtClientAttribute;
	}
	/** @param x For use by management client. */
	public void setMgmtClientAttribute(int x) {
		this.mgmtClientAttribute = x;
	}

	/** True if dynamic segment sizing pre-allocation is enabled for the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="True if dynamic segment sizing pre-allocation is enabled for the volume." , required = true)
	@XmlElement(required = true)
	private boolean dssPreallocEnabled;

	/** @return True if dynamic segment sizing pre-allocation is enabled for the volume. */
	public boolean isDssPreallocEnabled() {
		return this.dssPreallocEnabled;
	}
	/** @param x True if dynamic segment sizing pre-allocation is enabled for the volume. */
	public void setDssPreallocEnabled(boolean x) {
		this.dssPreallocEnabled = x;
	}

	/** The maximum segment size (in bytes) that this volume could assume with the dynamic segment sizing feature. This field is only meaningful if dssPreallocEnabled is true. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum segment size (in bytes) that this volume could assume with the dynamic segment sizing feature. This field is only meaningful if dssPreallocEnabled is true." , required = true)
	@XmlElement(required = true)
	private int dssMaxSegmentSize;

	/** @return The maximum segment size (in bytes) that this volume could assume with the dynamic segment sizing feature. This field is only meaningful if dssPreallocEnabled is true. */
	public int getDssMaxSegmentSize() {
		return this.dssMaxSegmentSize;
	}
	/** @param x The maximum segment size (in bytes) that this volume could assume with the dynamic segment sizing feature. This field is only meaningful if dssPreallocEnabled is true. */
	public void setDssMaxSegmentSize(int x) {
		this.dssMaxSegmentSize = x;
	}

	/** If set to true, then the storage controller will, on READ operations, verify the consistency of RAID redundancy data for the stripe(s) containing the READ data. */
	@io.swagger.annotations.ApiModelProperty(value ="If set to true, then the storage controller will, on READ operations, verify the consistency of RAID redundancy data for the stripe(s) containing the READ data." , required = true)
	@XmlElement(required = true)
	private boolean preReadRedundancyCheckEnabled;

	/** @return If set to true, then the storage controller will, on READ operations, verify the consistency of RAID redundancy data for the stripe(s) containing the READ data. */
	public boolean isPreReadRedundancyCheckEnabled() {
		return this.preReadRedundancyCheckEnabled;
	}
	/** @param x If set to true, then the storage controller will, on READ operations, verify the consistency of RAID redundancy data for the stripe(s) containing the READ data. */
	public void setPreReadRedundancyCheckEnabled(boolean x) {
		this.preReadRedundancyCheckEnabled = x;
	}

	/** This field is no longer used. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is no longer used." , required = true)
	@XmlElement(required = true)
	private boolean protectionInformationCapable;

	/** @return This field is no longer used. */
	public boolean isProtectionInformationCapable() {
		return this.protectionInformationCapable;
	}
	/** @param x This field is no longer used. */
	public void setProtectionInformationCapable(boolean x) {
		this.protectionInformationCapable = x;
	}

	/** The protection type of the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="The protection type of the volume." , required = true)
	@XmlElement(required = true)
	private ProtectionType protectionType = ProtectionType.__UNDEFINED;

	/** @return The protection type of the volume. */
	public ProtectionType getProtectionType() {
		return this.protectionType;
	}
	/** @param x The protection type of the volume. */
	public void setProtectionType(ProtectionType x) {
		this.protectionType = x;
	}

	/** True if application tag is owned by the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="True if application tag is owned by the storage array." , required = true)
	@XmlElement(required = true)
	private boolean applicationTagOwned;

	/** @return True if application tag is owned by the storage array. */
	public boolean isApplicationTagOwned() {
		return this.applicationTagOwned;
	}
	/** @param x True if application tag is owned by the storage array. */
	public void setApplicationTagOwned(boolean x) {
		this.applicationTagOwned = x;
	}

	/** This element contains a count of the number of blocks in the volume that have had data assurance errors repaired. */
	@io.swagger.annotations.ApiModelProperty(value ="This element contains a count of the number of blocks in the volume that have had data assurance errors repaired." , required = true)
	@XmlElement(required = true)
	private int repairedBlockCount;

	/** @return This element contains a count of the number of blocks in the volume that have had data assurance errors repaired. */
	public int getRepairedBlockCount() {
		return this.repairedBlockCount;
	}
	/** @param x This element contains a count of the number of blocks in the volume that have had data assurance errors repaired. */
	public void setRepairedBlockCount(int x) {
		this.repairedBlockCount = x;
	}
	@Override
	public String getId(){
		return volumeRef;
	}
	@Override
	public String getName(){
		return label;
	}
}
