package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used to convey information about a volume's caching attributes and cache parameter configuration. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(491)
public class VolumeCache implements Serializable {
	public VolumeCache() {
	}

	/** A true value means that the controller is allowed to use write-back caching of dirty data even when the cache memory's battery-backup protection is not available or not operational. A false value means that any problems with the battery-backup protection of the write cache will cause the controller to suspend all write-back caching operations for the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="A true value means that the controller is allowed to use write-back caching of dirty data even when the cache memory's battery-backup protection is not available or not operational. A false value means that any problems with the battery-backup protection of the write cache will cause the controller to suspend all write-back caching operations for the volume." , required = true)
	@XmlElement(required = true)
	private boolean cwob;

	/** @return A true value means that the controller is allowed to use write-back caching of dirty data even when the cache memory's battery-backup protection is not available or not operational. A false value means that any problems with the battery-backup protection of the write cache will cause the controller to suspend all write-back caching operations for the volume. */
	public boolean isCwob() {
		return this.cwob;
	}
	/** @param x A true value means that the controller is allowed to use write-back caching of dirty data even when the cache memory's battery-backup protection is not available or not operational. A false value means that any problems with the battery-backup protection of the write cache will cause the controller to suspend all write-back caching operations for the volume. */
	public void setCwob(boolean x) {
		this.cwob = x;
	}

	/** A true value means that all dirty data in the write cache will be flushed immediately and further write-back caching will be disabled if the controller detects that a UPS unit has switched from standard power to battery backup. A false value means that write-back caching is not impacted by the state of the UPS. */
	@io.swagger.annotations.ApiModelProperty(value ="A true value means that all dirty data in the write cache will be flushed immediately and further write-back caching will be disabled if the controller detects that a UPS unit has switched from standard power to battery backup. A false value means that write-back caching is not impacted by the state of the UPS." , required = true)
	@XmlElement(required = true)
	private boolean enterpriseCacheDump;

	/** @return A true value means that all dirty data in the write cache will be flushed immediately and further write-back caching will be disabled if the controller detects that a UPS unit has switched from standard power to battery backup. A false value means that write-back caching is not impacted by the state of the UPS. */
	public boolean isEnterpriseCacheDump() {
		return this.enterpriseCacheDump;
	}
	/** @param x A true value means that all dirty data in the write cache will be flushed immediately and further write-back caching will be disabled if the controller detects that a UPS unit has switched from standard power to battery backup. A false value means that write-back caching is not impacted by the state of the UPS. */
	public void setEnterpriseCacheDump(boolean x) {
		this.enterpriseCacheDump = x;
	}

	/** An indication of whether the cache mirroring option is active for the volume's data. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of whether the cache mirroring option is active for the volume's data." , required = true)
	@XmlElement(required = true)
	private boolean mirrorActive;

	/** @return An indication of whether the cache mirroring option is active for the volume's data. */
	public boolean isMirrorActive() {
		return this.mirrorActive;
	}
	/** @param x An indication of whether the cache mirroring option is active for the volume's data. */
	public void setMirrorActive(boolean x) {
		this.mirrorActive = x;
	}

	/** An indication of whether the cache mirroring feature is currently enabled for this volume. It is possible that the mirrorEnable and mirrorActive values differ; this may occur, for example, if the alternate controller is removed or failed. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of whether the cache mirroring feature is currently enabled for this volume. It is possible that the mirrorEnable and mirrorActive values differ; this may occur, for example, if the alternate controller is removed or failed." , required = true)
	@XmlElement(required = true)
	private boolean mirrorEnable;

	/** @return An indication of whether the cache mirroring feature is currently enabled for this volume. It is possible that the mirrorEnable and mirrorActive values differ; this may occur, for example, if the alternate controller is removed or failed. */
	public boolean isMirrorEnable() {
		return this.mirrorEnable;
	}
	/** @param x An indication of whether the cache mirroring feature is currently enabled for this volume. It is possible that the mirrorEnable and mirrorActive values differ; this may occur, for example, if the alternate controller is removed or failed. */
	public void setMirrorEnable(boolean x) {
		this.mirrorEnable = x;
	}

	/** An indication of whether read caching is active for the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of whether read caching is active for the volume." , required = true)
	@XmlElement(required = true)
	private boolean readCacheActive;

	/** @return An indication of whether read caching is active for the volume. */
	public boolean isReadCacheActive() {
		return this.readCacheActive;
	}
	/** @param x An indication of whether read caching is active for the volume. */
	public void setReadCacheActive(boolean x) {
		this.readCacheActive = x;
	}

	/** An indication of whether read caching is enabled for the volume. Note that this value may not match the readCacheActive setting in cases where problems with the controller cache or its battery back-up have been detected. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of whether read caching is enabled for the volume. Note that this value may not match the readCacheActive setting in cases where problems with the controller cache or its battery back-up have been detected." , required = true)
	@XmlElement(required = true)
	private boolean readCacheEnable;

	/** @return An indication of whether read caching is enabled for the volume. Note that this value may not match the readCacheActive setting in cases where problems with the controller cache or its battery back-up have been detected. */
	public boolean isReadCacheEnable() {
		return this.readCacheEnable;
	}
	/** @param x An indication of whether read caching is enabled for the volume. Note that this value may not match the readCacheActive setting in cases where problems with the controller cache or its battery back-up have been detected. */
	public void setReadCacheEnable(boolean x) {
		this.readCacheEnable = x;
	}

	/** An indication of whether write-back caching is active for the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of whether write-back caching is active for the volume." , required = true)
	@XmlElement(required = true)
	private boolean writeCacheActive;

	/** @return An indication of whether write-back caching is active for the volume. */
	public boolean isWriteCacheActive() {
		return this.writeCacheActive;
	}
	/** @param x An indication of whether write-back caching is active for the volume. */
	public void setWriteCacheActive(boolean x) {
		this.writeCacheActive = x;
	}

	/** An indication of whether write-back caching is enabled for the volume. Note that this value may not match the writeCacheActive setting in cases where problems with the controller cache or its battery back-up have been detected. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of whether write-back caching is enabled for the volume. Note that this value may not match the writeCacheActive setting in cases where problems with the controller cache or its battery back-up have been detected." , required = true)
	@XmlElement(required = true)
	private boolean writeCacheEnable;

	/** @return An indication of whether write-back caching is enabled for the volume. Note that this value may not match the writeCacheActive setting in cases where problems with the controller cache or its battery back-up have been detected. */
	public boolean isWriteCacheEnable() {
		return this.writeCacheEnable;
	}
	/** @param x An indication of whether write-back caching is enabled for the volume. Note that this value may not match the writeCacheActive setting in cases where problems with the controller cache or its battery back-up have been detected. */
	public void setWriteCacheEnable(boolean x) {
		this.writeCacheEnable = x;
	}

	/** The cache flush modifier value, which is used to specify the maximum amount of time that dirty data for this volume may be retained in the controller's write cache prior to being flushed to disk. */
	@io.swagger.annotations.ApiModelProperty(value ="The cache flush modifier value, which is used to specify the maximum amount of time that dirty data for this volume may be retained in the controller's write cache prior to being flushed to disk." , required = true)
	@XmlElement(required = true)
	private CacheFlushModifier cacheFlushModifier = CacheFlushModifier.__UNDEFINED;

	/** @return The cache flush modifier value, which is used to specify the maximum amount of time that dirty data for this volume may be retained in the controller's write cache prior to being flushed to disk. */
	public CacheFlushModifier getCacheFlushModifier() {
		return this.cacheFlushModifier;
	}
	/** @param x The cache flush modifier value, which is used to specify the maximum amount of time that dirty data for this volume may be retained in the controller's write cache prior to being flushed to disk. */
	public void setCacheFlushModifier(CacheFlushModifier x) {
		this.cacheFlushModifier = x;
	}

	/** A true (non-zero) / false (zero) indicator of whether or not automatic cache read-ahead is enabled. */
	@io.swagger.annotations.ApiModelProperty(value ="A true (non-zero) / false (zero) indicator of whether or not automatic cache read-ahead is enabled." , required = true)
	@XmlElement(required = true)
	private int readAheadMultiplier;

	/** @return A true (non-zero) / false (zero) indicator of whether or not automatic cache read-ahead is enabled. */
	public int getReadAheadMultiplier() {
		return this.readAheadMultiplier;
	}
	/** @param x A true (non-zero) / false (zero) indicator of whether or not automatic cache read-ahead is enabled. */
	public void setReadAheadMultiplier(int x) {
		this.readAheadMultiplier = x;
	}
}
