package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This union object provides information about a particular controller-detected failure that requires corrective action by an end-user. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(1207)
public class FailureTypeEntry implements Serializable {
	public FailureTypeEntry() {
	}

	/** This enumeration defines the different recovery failure types that may be reported by a controller as part of the getRecoveryFailureList procedure. */
	@io.swagger.annotations.ApiModelProperty(value ="This enumeration defines the different recovery failure types that may be reported by a controller as part of the getRecoveryFailureList procedure." , required = true)
	@XmlElement(required = true)
	private RecoveryFailureType recFailureType = RecoveryFailureType.__UNDEFINED;

	/** @return This enumeration defines the different recovery failure types that may be reported by a controller as part of the getRecoveryFailureList procedure. */
	public RecoveryFailureType getRecFailureType() {
		return this.recFailureType;
	}
	/** @param x This enumeration defines the different recovery failure types that may be reported by a controller as part of the getRecoveryFailureList procedure. */
	public void setRecFailureType(RecoveryFailureType x) {
		this.recFailureType = x;
	}

	/** Identifies a controller that is unable to read the board ID of its alternate. The referenced controller is not necessarily the source of the problem. */
	@io.swagger.annotations.ApiModelProperty(value ="Identifies a controller that is unable to read the board ID of its alternate. The referenced controller is not necessarily the source of the problem." , required = false)
	@XmlElement(required = false)
	private String altCtlrBoardIdUnreadable;

	/** @return Identifies a controller that is unable to read the board ID of its alternate. The referenced controller is not necessarily the source of the problem. */
	public String getAltCtlrBoardIdUnreadable() {
		return this.altCtlrBoardIdUnreadable;
	}
	/** @param x Identifies a controller that is unable to read the board ID of its alternate. The referenced controller is not necessarily the source of the problem. */
	public void setAltCtlrBoardIdUnreadable(String x) {
		this.altCtlrBoardIdUnreadable = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_BASE_CONTROLLER_DIAG_FAILED. It contains the identification of the controller that failed diagnostic testing. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_BASE_CONTROLLER_DIAG_FAILED. It contains the identification of the controller that failed diagnostic testing." , required = false)
	@XmlElement(required = false)
	private String baseControllerDiagFailed;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_BASE_CONTROLLER_DIAG_FAILED. It contains the identification of the controller that failed diagnostic testing. */
	public String getBaseControllerDiagFailed() {
		return this.baseControllerDiagFailed;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_BASE_CONTROLLER_DIAG_FAILED. It contains the identification of the controller that failed diagnostic testing. */
	public void setBaseControllerDiagFailed(String x) {
		this.baseControllerDiagFailed = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_BATTERY_CONFIG_MISMATCH */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_BATTERY_CONFIG_MISMATCH" , required = false)
	@XmlElement(required = false)
	private String batteryConfigMismatch;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_BATTERY_CONFIG_MISMATCH */
	public String getBatteryConfigMismatch() {
		return this.batteryConfigMismatch;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_BATTERY_CONFIG_MISMATCH */
	public void setBatteryConfigMismatch(String x) {
		this.batteryConfigMismatch = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_BATTERY_NEAR_EXPIRATION. It contains the identification of the battery component that is nearing its age limit. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_BATTERY_NEAR_EXPIRATION. It contains the identification of the battery component that is nearing its age limit." , required = false)
	@XmlElement(required = false)
	private String batteryWarn;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_BATTERY_NEAR_EXPIRATION. It contains the identification of the battery component that is nearing its age limit. */
	public String getBatteryWarn() {
		return this.batteryWarn;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_BATTERY_NEAR_EXPIRATION. It contains the identification of the battery component that is nearing its age limit. */
	public void setBatteryWarn(String x) {
		this.batteryWarn = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_BATTERY_OVERTEMP. It is a reference to a battery component that is experiencing the over-temp condition. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_BATTERY_OVERTEMP. It is a reference to a battery component that is experiencing the over-temp condition." , required = false)
	@XmlElement(required = false)
	private String batteryTempWarn;

	/** @return This field is present only if the value of recFailureType is equal to REC_BATTERY_OVERTEMP. It is a reference to a battery component that is experiencing the over-temp condition. */
	public String getBatteryTempWarn() {
		return this.batteryTempWarn;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_BATTERY_OVERTEMP. It is a reference to a battery component that is experiencing the over-temp condition. */
	public void setBatteryTempWarn(String x) {
		this.batteryTempWarn = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_BATTERY_UNKNOWN_STAT. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_BATTERY_UNKNOWN_STAT." , required = false)
	@XmlElement(required = false)
	private String batteryStatUnknown;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_BATTERY_UNKNOWN_STAT. */
	public String getBatteryStatUnknown() {
		return this.batteryStatUnknown;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_BATTERY_UNKNOWN_STAT. */
	public void setBatteryStatUnknown(String x) {
		this.batteryStatUnknown = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_BATTERY_WARN. It is a reference to a battery component that has insufficient capacity to hold up the cache. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_BATTERY_WARN. It is a reference to a battery component that has insufficient capacity to hold up the cache." , required = false)
	@XmlElement(required = false)
	private String batteryCapacityWarn;

	/** @return This field is present only if the value of recFailureType is equal to REC_BATTERY_WARN. It is a reference to a battery component that has insufficient capacity to hold up the cache. */
	public String getBatteryCapacityWarn() {
		return this.batteryCapacityWarn;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_BATTERY_WARN. It is a reference to a battery component that has insufficient capacity to hold up the cache. */
	public void setBatteryCapacityWarn(String x) {
		this.batteryCapacityWarn = x;
	}

	/** This field is present if the recFailuretype is equal to REC_CACHE_BACKUP_DEVICE_FAILED. It identifies a cache backup device that has failed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the recFailuretype is equal to REC_CACHE_BACKUP_DEVICE_FAILED. It identifies a cache backup device that has failed." , required = false)
	@XmlElement(required = false)
	private String failedCacheBackupDevice;

	/** @return This field is present if the recFailuretype is equal to REC_CACHE_BACKUP_DEVICE_FAILED. It identifies a cache backup device that has failed. */
	public String getFailedCacheBackupDevice() {
		return this.failedCacheBackupDevice;
	}
	/** @param x This field is present if the recFailuretype is equal to REC_CACHE_BACKUP_DEVICE_FAILED. It identifies a cache backup device that has failed. */
	public void setFailedCacheBackupDevice(String x) {
		this.failedCacheBackupDevice = x;
	}

	/** This field is present if the recFailuretype is equal to REC_CACHE_BACKUP_DEVICE_INSUFFICIENT_CAPACITY. It identifies a controller whose cache backup device configuration is such that it does not have sufficient space for a full cache backup. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the recFailuretype is equal to REC_CACHE_BACKUP_DEVICE_INSUFFICIENT_CAPACITY. It identifies a controller whose cache backup device configuration is such that it does not have sufficient space for a full cache backup." , required = false)
	@XmlElement(required = false)
	private String insufficientCacheBackupDeviceCapacity;

	/** @return This field is present if the recFailuretype is equal to REC_CACHE_BACKUP_DEVICE_INSUFFICIENT_CAPACITY. It identifies a controller whose cache backup device configuration is such that it does not have sufficient space for a full cache backup. */
	public String getInsufficientCacheBackupDeviceCapacity() {
		return this.insufficientCacheBackupDeviceCapacity;
	}
	/** @param x This field is present if the recFailuretype is equal to REC_CACHE_BACKUP_DEVICE_INSUFFICIENT_CAPACITY. It identifies a controller whose cache backup device configuration is such that it does not have sufficient space for a full cache backup. */
	public void setInsufficientCacheBackupDeviceCapacity(String x) {
		this.insufficientCacheBackupDeviceCapacity = x;
	}

	/** This field is present if the recFailuretype is equal to REC_CACHE_BACKUP_DEVICE_WRITE_PROTECTED. It identifies a cache backup device that is write-protected. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the recFailuretype is equal to REC_CACHE_BACKUP_DEVICE_WRITE_PROTECTED. It identifies a cache backup device that is write-protected." , required = false)
	@XmlElement(required = false)
	private String writeProtectedCacheBackupDevice;

	/** @return This field is present if the recFailuretype is equal to REC_CACHE_BACKUP_DEVICE_WRITE_PROTECTED. It identifies a cache backup device that is write-protected. */
	public String getWriteProtectedCacheBackupDevice() {
		return this.writeProtectedCacheBackupDevice;
	}
	/** @param x This field is present if the recFailuretype is equal to REC_CACHE_BACKUP_DEVICE_WRITE_PROTECTED. It identifies a cache backup device that is write-protected. */
	public void setWriteProtectedCacheBackupDevice(String x) {
		this.writeProtectedCacheBackupDevice = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_CHANNEL_DEGRADED. The channel is in a degraded state. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_CHANNEL_DEGRADED. The channel is in a degraded state." , required = false)
	@XmlElement(required = false)
	private ChannelDegradedFailure channelDegradedFailure;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_CHANNEL_DEGRADED. The channel is in a degraded state. */
	public ChannelDegradedFailure getChannelDegradedFailure() {
		return this.channelDegradedFailure;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_CHANNEL_DEGRADED. The channel is in a degraded state. */
	public void setChannelDegradedFailure(ChannelDegradedFailure x) {
		this.channelDegradedFailure = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_CHANNEL_FAILED. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_CHANNEL_FAILED." , required = false)
	@XmlElement(required = false)
	private ChannelFailedFailure channelFailedFailure;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_CHANNEL_FAILED. */
	public ChannelFailedFailure getChannelFailedFailure() {
		return this.channelFailedFailure;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_CHANNEL_FAILED. */
	public void setChannelFailedFailure(ChannelFailedFailure x) {
		this.channelFailedFailure = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_CHANNEL_MISWIRE. It identifies the controller having the channel miswire information. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_CHANNEL_MISWIRE. It identifies the controller having the channel miswire information." , required = false)
	@XmlElement(required = false)
	private String chanMiswire;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_CHANNEL_MISWIRE. It identifies the controller having the channel miswire information. */
	public String getChanMiswire() {
		return this.chanMiswire;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_CHANNEL_MISWIRE. It identifies the controller having the channel miswire information. */
	public void setChanMiswire(String x) {
		this.chanMiswire = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_CORRUPT_VPD_EEPROM. It indicates a controller tray in which corruption of one of the redundant Storage Bridge Bay (SBB) EEPROMs has been detected. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_CORRUPT_VPD_EEPROM. It indicates a controller tray in which corruption of one of the redundant Storage Bridge Bay (SBB) EEPROMs has been detected." , required = false)
	@XmlElement(required = false)
	private String vpdEepromCorrupted;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_CORRUPT_VPD_EEPROM. It indicates a controller tray in which corruption of one of the redundant Storage Bridge Bay (SBB) EEPROMs has been detected. */
	public String getVpdEepromCorrupted() {
		return this.vpdEepromCorrupted;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_CORRUPT_VPD_EEPROM. It indicates a controller tray in which corruption of one of the redundant Storage Bridge Bay (SBB) EEPROMs has been detected. */
	public void setVpdEepromCorrupted(String x) {
		this.vpdEepromCorrupted = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_CTL_MISMATCH. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_CTL_MISMATCH." , required = false)
	@XmlElement(required = false)
	private String ctlMismatch;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_CTL_MISMATCH. */
	public String getCtlMismatch() {
		return this.ctlMismatch;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_CTL_MISMATCH. */
	public void setCtlMismatch(String x) {
		this.ctlMismatch = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_CTL_MISWIRE. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_CTL_MISWIRE." , required = false)
	@XmlElement(required = false)
	private ControllerMiswireError ctlMiswire;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_CTL_MISWIRE. */
	public ControllerMiswireError getCtlMiswire() {
		return this.ctlMiswire;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_CTL_MISWIRE. */
	public void setCtlMiswire(ControllerMiswireError x) {
		this.ctlMiswire = x;
	}

	/** This field is present only if recFailureType is equal to REC_DDF_DRIVE_OTHER_VENDOR. It identifies a drive that has a SNIA Disk Data Format (DDF) anchor indicating a vendor other than LSI-Engenio. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if recFailureType is equal to REC_DDF_DRIVE_OTHER_VENDOR. It identifies a drive that has a SNIA Disk Data Format (DDF) anchor indicating a vendor other than LSI-Engenio." , required = false)
	@XmlElement(required = false)
	private String ddfDriveOtherVendor;

	/** @return This field is present only if recFailureType is equal to REC_DDF_DRIVE_OTHER_VENDOR. It identifies a drive that has a SNIA Disk Data Format (DDF) anchor indicating a vendor other than LSI-Engenio. */
	public String getDdfDriveOtherVendor() {
		return this.ddfDriveOtherVendor;
	}
	/** @param x This field is present only if recFailureType is equal to REC_DDF_DRIVE_OTHER_VENDOR. It identifies a drive that has a SNIA Disk Data Format (DDF) anchor indicating a vendor other than LSI-Engenio. */
	public void setDdfDriveOtherVendor(String x) {
		this.ddfDriveOtherVendor = x;
	}

	/** This field is present if the value of recFailureType is equal to REC_DEDICATED_MIRROR_CHANNEL_FAILED. It identifies a degraded controller that is the root cause of the channel failure(s). If the channel failure root cause cannot be tied to a controller, the reference is null. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the value of recFailureType is equal to REC_DEDICATED_MIRROR_CHANNEL_FAILED. It identifies a degraded controller that is the root cause of the channel failure(s). If the channel failure root cause cannot be tied to a controller, the reference is null." , required = false)
	@XmlElement(required = false)
	private String failedDedicatedMirrorChannel;

	/** @return This field is present if the value of recFailureType is equal to REC_DEDICATED_MIRROR_CHANNEL_FAILED. It identifies a degraded controller that is the root cause of the channel failure(s). If the channel failure root cause cannot be tied to a controller, the reference is null. */
	public String getFailedDedicatedMirrorChannel() {
		return this.failedDedicatedMirrorChannel;
	}
	/** @param x This field is present if the value of recFailureType is equal to REC_DEDICATED_MIRROR_CHANNEL_FAILED. It identifies a degraded controller that is the root cause of the channel failure(s). If the channel failure root cause cannot be tied to a controller, the reference is null. */
	public void setFailedDedicatedMirrorChannel(String x) {
		this.failedDedicatedMirrorChannel = x;
	}

	/** This field is present only if the recFailureType is equal to REC_DEGRADED_HOST_IO_CARD. It identifies s host board, for which some, but not all, of its I/O ports are operational. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the recFailureType is equal to REC_DEGRADED_HOST_IO_CARD. It identifies s host board, for which some, but not all, of its I/O ports are operational." , required = false)
	@XmlElement(required = false)
	private String degradedHostBoard;

	/** @return This field is present only if the recFailureType is equal to REC_DEGRADED_HOST_IO_CARD. It identifies s host board, for which some, but not all, of its I/O ports are operational. */
	public String getDegradedHostBoard() {
		return this.degradedHostBoard;
	}
	/** @param x This field is present only if the recFailureType is equal to REC_DEGRADED_HOST_IO_CARD. It identifies s host board, for which some, but not all, of its I/O ports are operational. */
	public void setDegradedHostBoard(String x) {
		this.degradedHostBoard = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_DEGRADED_VOLUME. It contains the identification of a volume group that has transitioned to the degraded state due to a drive failure. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_DEGRADED_VOLUME. It contains the identification of a volume group that has transitioned to the degraded state due to a drive failure." , required = false)
	@XmlElement(required = false)
	private String volDegraded;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_DEGRADED_VOLUME. It contains the identification of a volume group that has transitioned to the degraded state due to a drive failure. */
	public String getVolDegraded() {
		return this.volDegraded;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_DEGRADED_VOLUME. It contains the identification of a volume group that has transitioned to the degraded state due to a drive failure. */
	public void setVolDegraded(String x) {
		this.volDegraded = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_DRIVE_BYPASSED_CAUSE_UNKNOWN. It contains the identification of the drive that was bypassed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_DRIVE_BYPASSED_CAUSE_UNKNOWN. It contains the identification of the drive that was bypassed." , required = false)
	@XmlElement(required = false)
	private String drvBypassCauseUnknown;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_DRIVE_BYPASSED_CAUSE_UNKNOWN. It contains the identification of the drive that was bypassed. */
	public String getDrvBypassCauseUnknown() {
		return this.drvBypassCauseUnknown;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_DRIVE_BYPASSED_CAUSE_UNKNOWN. It contains the identification of the drive that was bypassed. */
	public void setDrvBypassCauseUnknown(String x) {
		this.drvBypassCauseUnknown = x;
	}

	/** This field is present only if the value of the recFailureType is equal to REC_DRIVE_BYPASSED_SINGLE_PORT. It is a reference to a drive that is bypassed on just one of its ports. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of the recFailureType is equal to REC_DRIVE_BYPASSED_SINGLE_PORT. It is a reference to a drive that is bypassed on just one of its ports." , required = false)
	@XmlElement(required = false)
	private String driveBypassedSinglePort;

	/** @return This field is present only if the value of the recFailureType is equal to REC_DRIVE_BYPASSED_SINGLE_PORT. It is a reference to a drive that is bypassed on just one of its ports. */
	public String getDriveBypassedSinglePort() {
		return this.driveBypassedSinglePort;
	}
	/** @param x This field is present only if the value of the recFailureType is equal to REC_DRIVE_BYPASSED_SINGLE_PORT. It is a reference to a drive that is bypassed on just one of its ports. */
	public void setDriveBypassedSinglePort(String x) {
		this.driveBypassedSinglePort = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_DRIVE_BYPASSED_SPEED_MISMATCH. It contains the identification of the drive that was bypassed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_DRIVE_BYPASSED_SPEED_MISMATCH. It contains the identification of the drive that was bypassed." , required = false)
	@XmlElement(required = false)
	private String speedMismatchDrive;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_DRIVE_BYPASSED_SPEED_MISMATCH. It contains the identification of the drive that was bypassed. */
	public String getSpeedMismatchDrive() {
		return this.speedMismatchDrive;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_DRIVE_BYPASSED_SPEED_MISMATCH. It contains the identification of the drive that was bypassed. */
	public void setSpeedMismatchDrive(String x) {
		this.speedMismatchDrive = x;
	}

	/** This field is only present if the value of recFailureType is equal to REC_DRIVE_INCOMPATIBLE_DOWNREV_DACSTORE. It is a reference to a drive that has an unrecognizable DACStore that was written by an earlier firmware version. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is only present if the value of recFailureType is equal to REC_DRIVE_INCOMPATIBLE_DOWNREV_DACSTORE. It is a reference to a drive that has an unrecognizable DACStore that was written by an earlier firmware version." , required = false)
	@XmlElement(required = false)
	private String incompatibleDownRevDacstoreDriveRef;

	/** @return This field is only present if the value of recFailureType is equal to REC_DRIVE_INCOMPATIBLE_DOWNREV_DACSTORE. It is a reference to a drive that has an unrecognizable DACStore that was written by an earlier firmware version. */
	public String getIncompatibleDownRevDacstoreDriveRef() {
		return this.incompatibleDownRevDacstoreDriveRef;
	}
	/** @param x This field is only present if the value of recFailureType is equal to REC_DRIVE_INCOMPATIBLE_DOWNREV_DACSTORE. It is a reference to a drive that has an unrecognizable DACStore that was written by an earlier firmware version. */
	public void setIncompatibleDownRevDacstoreDriveRef(String x) {
		this.incompatibleDownRevDacstoreDriveRef = x;
	}

	/** This field is only present if the value of recFailureType is equal to REC_MIXED_DRIVE_ENCLOSURE_MISWIRE. It identifies the drive channels with an unsupported combination of drive enclosures. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is only present if the value of recFailureType is equal to REC_MIXED_DRIVE_ENCLOSURE_MISWIRE. It identifies the drive channels with an unsupported combination of drive enclosures." , required = false)
	@XmlElement(required = false)
	private MiswiredDriveChannelList[] mixedDriveEnclosureMiswire;

	/** @return This field is only present if the value of recFailureType is equal to REC_MIXED_DRIVE_ENCLOSURE_MISWIRE. It identifies the drive channels with an unsupported combination of drive enclosures. */
	public MiswiredDriveChannelList[] getMixedDriveEnclosureMiswire() {
		return this.mixedDriveEnclosureMiswire;
	}
	/** @param x This field is only present if the value of recFailureType is equal to REC_MIXED_DRIVE_ENCLOSURE_MISWIRE. It identifies the drive channels with an unsupported combination of drive enclosures. */
	public void setMixedDriveEnclosureMiswire(MiswiredDriveChannelList[] x) {
		this.mixedDriveEnclosureMiswire = x;
	}

	/** This field is only present if the value of recFailureType is equal to REC_DRIVE_INCOMPATIBLE_SECTOR_SIZE. It is a reference to a drive that has a formatted sector size that is different from the other drives in the array. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is only present if the value of recFailureType is equal to REC_DRIVE_INCOMPATIBLE_SECTOR_SIZE. It is a reference to a drive that has a formatted sector size that is different from the other drives in the array." , required = false)
	@XmlElement(required = false)
	private String incompatibleSectorSizeDriveRef;

	/** @return This field is only present if the value of recFailureType is equal to REC_DRIVE_INCOMPATIBLE_SECTOR_SIZE. It is a reference to a drive that has a formatted sector size that is different from the other drives in the array. */
	public String getIncompatibleSectorSizeDriveRef() {
		return this.incompatibleSectorSizeDriveRef;
	}
	/** @param x This field is only present if the value of recFailureType is equal to REC_DRIVE_INCOMPATIBLE_SECTOR_SIZE. It is a reference to a drive that has a formatted sector size that is different from the other drives in the array. */
	public void setIncompatibleSectorSizeDriveRef(String x) {
		this.incompatibleSectorSizeDriveRef = x;
	}

	/** This field is only present if the value of recFailureType is equal to REC_DRIVE_INCOMPATIBLE_UPREV_DACSTORE. It is a reference to a drive that has an unrecognizable DACStore that was written by a later firmware version. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is only present if the value of recFailureType is equal to REC_DRIVE_INCOMPATIBLE_UPREV_DACSTORE. It is a reference to a drive that has an unrecognizable DACStore that was written by a later firmware version." , required = false)
	@XmlElement(required = false)
	private String incompatibleUpRevDacstoreDriveRef;

	/** @return This field is only present if the value of recFailureType is equal to REC_DRIVE_INCOMPATIBLE_UPREV_DACSTORE. It is a reference to a drive that has an unrecognizable DACStore that was written by a later firmware version. */
	public String getIncompatibleUpRevDacstoreDriveRef() {
		return this.incompatibleUpRevDacstoreDriveRef;
	}
	/** @param x This field is only present if the value of recFailureType is equal to REC_DRIVE_INCOMPATIBLE_UPREV_DACSTORE. It is a reference to a drive that has an unrecognizable DACStore that was written by a later firmware version. */
	public void setIncompatibleUpRevDacstoreDriveRef(String x) {
		this.incompatibleUpRevDacstoreDriveRef = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_DRIVE_TRAYS_NOT_COMPLIANT. It indicates that the drive tray feature is out of compliance. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_DRIVE_TRAYS_NOT_COMPLIANT. It indicates that the drive tray feature is out of compliance." , required = false)
	@XmlElement(required = false)
	private FeatureState driveTrayExpansionFeature;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_DRIVE_TRAYS_NOT_COMPLIANT. It indicates that the drive tray feature is out of compliance. */
	public FeatureState getDriveTrayExpansionFeature() {
		return this.driveTrayExpansionFeature;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_DRIVE_TRAYS_NOT_COMPLIANT. It indicates that the drive tray feature is out of compliance. */
	public void setDriveTrayExpansionFeature(FeatureState x) {
		this.driveTrayExpansionFeature = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_DRIVE_TRAYS_NOT_GROUPED_TOGETHER. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_DRIVE_TRAYS_NOT_GROUPED_TOGETHER." , required = false)
	@XmlElement(required = false)
	private TrayRefList driveTraysNotGroupedTogether;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_DRIVE_TRAYS_NOT_GROUPED_TOGETHER. */
	public TrayRefList getDriveTraysNotGroupedTogether() {
		return this.driveTraysNotGroupedTogether;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_DRIVE_TRAYS_NOT_GROUPED_TOGETHER. */
	public void setDriveTraysNotGroupedTogether(TrayRefList x) {
		this.driveTraysNotGroupedTogether = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ENCLOSURE_MISCONFIGURED. It indicates an enclosure has invalid configuration settings. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ENCLOSURE_MISCONFIGURED. It indicates an enclosure has invalid configuration settings." , required = false)
	@XmlElement(required = false)
	private String misconfiguredEnclosure;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ENCLOSURE_MISCONFIGURED. It indicates an enclosure has invalid configuration settings. */
	public String getMisconfiguredEnclosure() {
		return this.misconfiguredEnclosure;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ENCLOSURE_MISCONFIGURED. It indicates an enclosure has invalid configuration settings. */
	public void setMisconfiguredEnclosure(String x) {
		this.misconfiguredEnclosure = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ESM_CODE_VERSION_MISMATCH. It contains the identification of the tray that has the ESM cards that have mismatching firmware versions. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ESM_CODE_VERSION_MISMATCH. It contains the identification of the tray that has the ESM cards that have mismatching firmware versions." , required = false)
	@XmlElement(required = false)
	private String trayCodeMismatch;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ESM_CODE_VERSION_MISMATCH. It contains the identification of the tray that has the ESM cards that have mismatching firmware versions. */
	public String getTrayCodeMismatch() {
		return this.trayCodeMismatch;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ESM_CODE_VERSION_MISMATCH. It contains the identification of the tray that has the ESM cards that have mismatching firmware versions. */
	public void setTrayCodeMismatch(String x) {
		this.trayCodeMismatch = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_ESM_FACTORY_DEFAULTS_MISMATCH. It is a reference to a tray in which the versions of the factory default settings reported by the two ESMs do not match. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_ESM_FACTORY_DEFAULTS_MISMATCH. It is a reference to a tray in which the versions of the factory default settings reported by the two ESMs do not match." , required = false)
	@XmlElement(required = false)
	private String esmFactoryDefaultsMismatch;

	/** @return This field is present only if the value of recFailureType is equal to REC_ESM_FACTORY_DEFAULTS_MISMATCH. It is a reference to a tray in which the versions of the factory default settings reported by the two ESMs do not match. */
	public String getEsmFactoryDefaultsMismatch() {
		return this.esmFactoryDefaultsMismatch;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_ESM_FACTORY_DEFAULTS_MISMATCH. It is a reference to a tray in which the versions of the factory default settings reported by the two ESMs do not match. */
	public void setEsmFactoryDefaultsMismatch(String x) {
		this.esmFactoryDefaultsMismatch = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ESM_HARDWARE_MISMATCH. It contains the identification of the tray that has the mismatched ESM cards. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ESM_HARDWARE_MISMATCH. It contains the identification of the tray that has the mismatched ESM cards." , required = false)
	@XmlElement(required = false)
	private String trayHardwareMismatch;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ESM_HARDWARE_MISMATCH. It contains the identification of the tray that has the mismatched ESM cards. */
	public String getTrayHardwareMismatch() {
		return this.trayHardwareMismatch;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ESM_HARDWARE_MISMATCH. It contains the identification of the tray that has the mismatched ESM cards. */
	public void setTrayHardwareMismatch(String x) {
		this.trayHardwareMismatch = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ESM_MISWIRE. It contains the identification of the tray that has the ESM miswire. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ESM_MISWIRE. It contains the identification of the tray that has the ESM miswire." , required = false)
	@XmlElement(required = false)
	private String esmMiswire;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ESM_MISWIRE. It contains the identification of the tray that has the ESM miswire. */
	public String getEsmMiswire() {
		return this.esmMiswire;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ESM_MISWIRE. It contains the identification of the tray that has the ESM miswire. */
	public void setEsmMiswire(String x) {
		this.esmMiswire = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ESM_UNKNOWN_STAT. It contains the identification of the ESM that has failed with unknown status. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ESM_UNKNOWN_STAT. It contains the identification of the ESM that has failed with unknown status." , required = false)
	@XmlElement(required = false)
	private String esmStatUnknown;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ESM_UNKNOWN_STAT. It contains the identification of the ESM that has failed with unknown status. */
	public String getEsmStatUnknown() {
		return this.esmStatUnknown;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ESM_UNKNOWN_STAT. It contains the identification of the ESM that has failed with unknown status. */
	public void setEsmStatUnknown(String x) {
		this.esmStatUnknown = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_EXPIRED_BATTERY,. It contains the identification of the battery component that has expired. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_EXPIRED_BATTERY,. It contains the identification of the battery component that has expired." , required = false)
	@XmlElement(required = false)
	private String batteryExpired;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_EXPIRED_BATTERY,. It contains the identification of the battery component that has expired. */
	public String getBatteryExpired() {
		return this.batteryExpired;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_EXPIRED_BATTERY,. It contains the identification of the battery component that has expired. */
	public void setBatteryExpired(String x) {
		this.batteryExpired = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_EXPIRED_INTEGRATED_BATTERY. It contains the identification of the integrated battery component that has expired. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_EXPIRED_INTEGRATED_BATTERY. It contains the identification of the integrated battery component that has expired." , required = false)
	@XmlElement(required = false)
	private String integratedBatteryExpired;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_EXPIRED_INTEGRATED_BATTERY. It contains the identification of the integrated battery component that has expired. */
	public String getIntegratedBatteryExpired() {
		return this.integratedBatteryExpired;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_EXPIRED_INTEGRATED_BATTERY. It contains the identification of the integrated battery component that has expired. */
	public void setIntegratedBatteryExpired(String x) {
		this.integratedBatteryExpired = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAILED_BATTERY. It contains the identification of the battery component that has failed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAILED_BATTERY. It contains the identification of the battery component that has failed." , required = false)
	@XmlElement(required = false)
	private String batteryFail;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAILED_BATTERY. It contains the identification of the battery component that has failed. */
	public String getBatteryFail() {
		return this.batteryFail;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAILED_BATTERY. It contains the identification of the battery component that has failed. */
	public void setBatteryFail(String x) {
		this.batteryFail = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_FAILED_BATTERY_SYSTEM. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_FAILED_BATTERY_SYSTEM." , required = false)
	@XmlElement(required = false)
	private BatteryPackICCFailure batterySystemFail;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_FAILED_BATTERY_SYSTEM. */
	public BatteryPackICCFailure getBatterySystemFail() {
		return this.batterySystemFail;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_FAILED_BATTERY_SYSTEM. */
	public void setBatterySystemFail(BatteryPackICCFailure x) {
		this.batterySystemFail = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_FAILED_DISCRETE_LINE. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_FAILED_DISCRETE_LINE." , required = false)
	@XmlElement(required = false)
	private String discreteLineFail;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_FAILED_DISCRETE_LINE. */
	public String getDiscreteLineFail() {
		return this.discreteLineFail;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_FAILED_DISCRETE_LINE. */
	public void setDiscreteLineFail(String x) {
		this.discreteLineFail = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAILED_DRIVE. It contains the identification of a drive that has failed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAILED_DRIVE. It contains the identification of a drive that has failed." , required = false)
	@XmlElement(required = false)
	private String driveFail;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAILED_DRIVE. It contains the identification of a drive that has failed. */
	public String getDriveFail() {
		return this.driveFail;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAILED_DRIVE. It contains the identification of a drive that has failed. */
	public void setDriveFail(String x) {
		this.driveFail = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAILED_DRIVE_SCSI_CHANNEL. It contains the identification of the controller that has experienced a failed drive-side I/O channel. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAILED_DRIVE_SCSI_CHANNEL. It contains the identification of the controller that has experienced a failed drive-side I/O channel." , required = false)
	@XmlElement(required = false)
	private String chFail;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAILED_DRIVE_SCSI_CHANNEL. It contains the identification of the controller that has experienced a failed drive-side I/O channel. */
	public String getChFail() {
		return this.chFail;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAILED_DRIVE_SCSI_CHANNEL. It contains the identification of the controller that has experienced a failed drive-side I/O channel. */
	public void setChFail(String x) {
		this.chFail = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAILED_ESM. It contains the identification of the ESM component that has failed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAILED_ESM. It contains the identification of the ESM component that has failed." , required = false)
	@XmlElement(required = false)
	private String esmFail;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAILED_ESM. It contains the identification of the ESM component that has failed. */
	public String getEsmFail() {
		return this.esmFail;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAILED_ESM. It contains the identification of the ESM component that has failed. */
	public void setEsmFail(String x) {
		this.esmFail = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAILED_FAN. It contains the identification of the fan component that has failed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAILED_FAN. It contains the identification of the fan component that has failed." , required = false)
	@XmlElement(required = false)
	private String fanFail;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAILED_FAN. It contains the identification of the fan component that has failed. */
	public String getFanFail() {
		return this.fanFail;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAILED_FAN. It contains the identification of the fan component that has failed. */
	public void setFanFail(String x) {
		this.fanFail = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAILED_I2C_BUS. It refers to a controller that has detected a failure of one of the I2C busses used to access the Storage Bridge Bay (SBB) vital product data stored in EEPROM. For a given I2C bus failure, the failure type list may contain an entry for one or both controllers. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAILED_I2C_BUS. It refers to a controller that has detected a failure of one of the I2C busses used to access the Storage Bridge Bay (SBB) vital product data stored in EEPROM. For a given I2C bus failure, the failure type list may contain an entry for one or both controllers." , required = false)
	@XmlElement(required = false)
	private String vpdI2cFailure;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAILED_I2C_BUS. It refers to a controller that has detected a failure of one of the I2C busses used to access the Storage Bridge Bay (SBB) vital product data stored in EEPROM. For a given I2C bus failure, the failure type list may contain an entry for one or both controllers. */
	public String getVpdI2cFailure() {
		return this.vpdI2cFailure;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAILED_I2C_BUS. It refers to a controller that has detected a failure of one of the I2C busses used to access the Storage Bridge Bay (SBB) vital product data stored in EEPROM. For a given I2C bus failure, the failure type list may contain an entry for one or both controllers. */
	public void setVpdI2cFailure(String x) {
		this.vpdI2cFailure = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_FAILED_ICC_CRU. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_FAILED_ICC_CRU." , required = false)
	@XmlElement(required = false)
	private String iccCruFail;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_FAILED_ICC_CRU. */
	public String getIccCruFail() {
		return this.iccCruFail;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_FAILED_ICC_CRU. */
	public void setIccCruFail(String x) {
		this.iccCruFail = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAILED_MINIHUB. It contains the identification of the minihub component that has failed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAILED_MINIHUB. It contains the identification of the minihub component that has failed." , required = false)
	@XmlElement(required = false)
	private String miniHubFail;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAILED_MINIHUB. It contains the identification of the minihub component that has failed. */
	public String getMiniHubFail() {
		return this.miniHubFail;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAILED_MINIHUB. It contains the identification of the minihub component that has failed. */
	public void setMiniHubFail(String x) {
		this.miniHubFail = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAILED_MODIFYING_MULTI_RAID. It contains the identification of a volume group that has experienced a failure during a modification operation (i.e. dynamic capacity expansion, RAID migration, segment resizing, initialization, etc.). This failure indication applies specifically to volume groups containing volumes of different RAID levels. It is not supported in the current release of the firmware. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAILED_MODIFYING_MULTI_RAID. It contains the identification of a volume group that has experienced a failure during a modification operation (i.e. dynamic capacity expansion, RAID migration, segment resizing, initialization, etc.). This failure indication applies specifically to volume groups containing volumes of different RAID levels. It is not supported in the current release of the firmware." , required = false)
	@XmlElement(required = false)
	private String volFailDuringModifyMultiRaid;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAILED_MODIFYING_MULTI_RAID. It contains the identification of a volume group that has experienced a failure during a modification operation (i.e. dynamic capacity expansion, RAID migration, segment resizing, initialization, etc.). This failure indication applies specifically to volume groups containing volumes of different RAID levels. It is not supported in the current release of the firmware. */
	public String getVolFailDuringModifyMultiRaid() {
		return this.volFailDuringModifyMultiRaid;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAILED_MODIFYING_MULTI_RAID. It contains the identification of a volume group that has experienced a failure during a modification operation (i.e. dynamic capacity expansion, RAID migration, segment resizing, initialization, etc.). This failure indication applies specifically to volume groups containing volumes of different RAID levels. It is not supported in the current release of the firmware. */
	public void setVolFailDuringModifyMultiRaid(String x) {
		this.volFailDuringModifyMultiRaid = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAILED_MODIFYING_VOLUME. It contains the identification of a volume group that has experienced a failure during a modification operation (i.e. dynamic capacity expansion, RAID migration, segment resizing, initialization, etc.). */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAILED_MODIFYING_VOLUME. It contains the identification of a volume group that has experienced a failure during a modification operation (i.e. dynamic capacity expansion, RAID migration, segment resizing, initialization, etc.)." , required = false)
	@XmlElement(required = false)
	private String volFailDuringModify;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAILED_MODIFYING_VOLUME. It contains the identification of a volume group that has experienced a failure during a modification operation (i.e. dynamic capacity expansion, RAID migration, segment resizing, initialization, etc.). */
	public String getVolFailDuringModify() {
		return this.volFailDuringModify;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAILED_MODIFYING_VOLUME. It contains the identification of a volume group that has experienced a failure during a modification operation (i.e. dynamic capacity expansion, RAID migration, segment resizing, initialization, etc.). */
	public void setVolFailDuringModify(String x) {
		this.volFailDuringModify = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAILED_POWER_SUPPLY. It contains the identification of the power supply component that has failed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAILED_POWER_SUPPLY. It contains the identification of the power supply component that has failed." , required = false)
	@XmlElement(required = false)
	private String powerSupplyFail;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAILED_POWER_SUPPLY. It contains the identification of the power supply component that has failed. */
	public String getPowerSupplyFail() {
		return this.powerSupplyFail;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAILED_POWER_SUPPLY. It contains the identification of the power supply component that has failed. */
	public void setPowerSupplyFail(String x) {
		this.powerSupplyFail = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_FAILED_SUPPORT_CRU. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_FAILED_SUPPORT_CRU." , required = false)
	@XmlElement(required = false)
	private String supportCruFail;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_FAILED_SUPPORT_CRU. */
	public String getSupportCruFail() {
		return this.supportCruFail;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_FAILED_SUPPORT_CRU. */
	public void setSupportCruFail(String x) {
		this.supportCruFail = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAILED_TRANSCEIVER_MODULE. It contains the identification of the transceiver module. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAILED_TRANSCEIVER_MODULE. It contains the identification of the transceiver module." , required = false)
	@XmlElement(required = false)
	private String transceiverModuleFailed;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAILED_TRANSCEIVER_MODULE. It contains the identification of the transceiver module. */
	public String getTransceiverModuleFailed() {
		return this.transceiverModuleFailed;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAILED_TRANSCEIVER_MODULE. It contains the identification of the transceiver module. */
	public void setTransceiverModuleFailed(String x) {
		this.transceiverModuleFailed = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAILED_VOLUME_INTERRUPTED_WRITE. It contains the identification of a volume group that has experienced an interrupted write failure. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAILED_VOLUME_INTERRUPTED_WRITE. It contains the identification of a volume group that has experienced an interrupted write failure." , required = false)
	@XmlElement(required = false)
	private String volFail;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAILED_VOLUME_INTERRUPTED_WRITE. It contains the identification of a volume group that has experienced an interrupted write failure. */
	public String getVolFail() {
		return this.volFail;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAILED_VOLUME_INTERRUPTED_WRITE. It contains the identification of a volume group that has experienced an interrupted write failure. */
	public void setVolFail(String x) {
		this.volFail = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_VOLUME_AWAITING_INIT. It contains the identification of a volume group that was failed due to excessive drive failures, but has since had all failed drives replaced. Since the volumes within the volume group are no longer usable, they must all be formatted/initialized to make them usable again. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_VOLUME_AWAITING_INIT. It contains the identification of a volume group that was failed due to excessive drive failures, but has since had all failed drives replaced. Since the volumes within the volume group are no longer usable, they must all be formatted/initialized to make them usable again." , required = false)
	@XmlElement(required = false)
	private String volFailAwaitingInit;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_VOLUME_AWAITING_INIT. It contains the identification of a volume group that was failed due to excessive drive failures, but has since had all failed drives replaced. Since the volumes within the volume group are no longer usable, they must all be formatted/initialized to make them usable again. */
	public String getVolFailAwaitingInit() {
		return this.volFailAwaitingInit;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_VOLUME_AWAITING_INIT. It contains the identification of a volume group that was failed due to excessive drive failures, but has since had all failed drives replaced. Since the volumes within the volume group are no longer usable, they must all be formatted/initialized to make them usable again. */
	public void setVolFailAwaitingInit(String x) {
		this.volFailAwaitingInit = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAILED_VOLUME_INTERRUPTED_WRITE. It contains the identification of a volume group that has experienced an interrupted write failure. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAILED_VOLUME_INTERRUPTED_WRITE. It contains the identification of a volume group that has experienced an interrupted write failure." , required = false)
	@XmlElement(required = false)
	private String volFailInterruptedWrite;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAILED_VOLUME_INTERRUPTED_WRITE. It contains the identification of a volume group that has experienced an interrupted write failure. */
	public String getVolFailInterruptedWrite() {
		return this.volFailInterruptedWrite;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAILED_VOLUME_INTERRUPTED_WRITE. It contains the identification of a volume group that has experienced an interrupted write failure. */
	public void setVolFailInterruptedWrite(String x) {
		this.volFailInterruptedWrite = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAILED_VOLUME_MULTI_RAID. It contains the identification of a volume group that has been marked failed due to an excessive number of drive failures. This failure indication applies specifically to volume groups containing volumes of different RAID levels. It is not supported in the current release of the firmware. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAILED_VOLUME_MULTI_RAID. It contains the identification of a volume group that has been marked failed due to an excessive number of drive failures. This failure indication applies specifically to volume groups containing volumes of different RAID levels. It is not supported in the current release of the firmware." , required = false)
	@XmlElement(required = false)
	private String volFailMultiRaid;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAILED_VOLUME_MULTI_RAID. It contains the identification of a volume group that has been marked failed due to an excessive number of drive failures. This failure indication applies specifically to volume groups containing volumes of different RAID levels. It is not supported in the current release of the firmware. */
	public String getVolFailMultiRaid() {
		return this.volFailMultiRaid;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAILED_VOLUME_MULTI_RAID. It contains the identification of a volume group that has been marked failed due to an excessive number of drive failures. This failure indication applies specifically to volume groups containing volumes of different RAID levels. It is not supported in the current release of the firmware. */
	public void setVolFailMultiRaid(String x) {
		this.volFailMultiRaid = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_FAN_UNKNOWN_STAT. It contains the identification of the fan that has failed with unknown status. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_FAN_UNKNOWN_STAT. It contains the identification of the fan that has failed with unknown status." , required = false)
	@XmlElement(required = false)
	private String fanStatUnknown;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_FAN_UNKNOWN_STAT. It contains the identification of the fan that has failed with unknown status. */
	public String getFanStatUnknown() {
		return this.fanStatUnknown;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_FAN_UNKNOWN_STAT. It contains the identification of the fan that has failed with unknown status. */
	public void setFanStatUnknown(String x) {
		this.fanStatUnknown = x;
	}

	/** This field is present only if recFailureType is equal to REC_FOREIGN_DRIVE_HAS_INCONSISTENT_ROLE. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the drive having the inconsistent role, and the volumeGroup field is a reference to the volume group referring to that drive. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if recFailureType is equal to REC_FOREIGN_DRIVE_HAS_INCONSISTENT_ROLE. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the drive having the inconsistent role, and the volumeGroup field is a reference to the volume group referring to that drive." , required = false)
	@XmlElement(required = false)
	private PvgRecoveryData foreignDriveHasInconsistentRole;

	/** @return This field is present only if recFailureType is equal to REC_FOREIGN_DRIVE_HAS_INCONSISTENT_ROLE. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the drive having the inconsistent role, and the volumeGroup field is a reference to the volume group referring to that drive. */
	public PvgRecoveryData getForeignDriveHasInconsistentRole() {
		return this.foreignDriveHasInconsistentRole;
	}
	/** @param x This field is present only if recFailureType is equal to REC_FOREIGN_DRIVE_HAS_INCONSISTENT_ROLE. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the drive having the inconsistent role, and the volumeGroup field is a reference to the volume group referring to that drive. */
	public void setForeignDriveHasInconsistentRole(PvgRecoveryData x) {
		this.foreignDriveHasInconsistentRole = x;
	}

	/** This field is present only if recFailureType is equal to REC_FOREIGN_DRIVE_INCONSISTENT. It identifies the inconsistent foreign drive. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if recFailureType is equal to REC_FOREIGN_DRIVE_INCONSISTENT. It identifies the inconsistent foreign drive." , required = false)
	@XmlElement(required = false)
	private String foreignDriveInconsistent;

	/** @return This field is present only if recFailureType is equal to REC_FOREIGN_DRIVE_INCONSISTENT. It identifies the inconsistent foreign drive. */
	public String getForeignDriveInconsistent() {
		return this.foreignDriveInconsistent;
	}
	/** @param x This field is present only if recFailureType is equal to REC_FOREIGN_DRIVE_INCONSISTENT. It identifies the inconsistent foreign drive. */
	public void setForeignDriveInconsistent(String x) {
		this.foreignDriveInconsistent = x;
	}

	/** This field is present only if recFailureType is equal to REC_FOREIGN_DRIVE_REFERS_TO_NATIVE_DRIVE. It identifies the drive that caused the problem to be recognized (the first-inserted drive of what appears to be an incoming foreign volume group). */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if recFailureType is equal to REC_FOREIGN_DRIVE_REFERS_TO_NATIVE_DRIVE. It identifies the drive that caused the problem to be recognized (the first-inserted drive of what appears to be an incoming foreign volume group)." , required = false)
	@XmlElement(required = false)
	private String foreignDriveRefersToNativeDrive;

	/** @return This field is present only if recFailureType is equal to REC_FOREIGN_DRIVE_REFERS_TO_NATIVE_DRIVE. It identifies the drive that caused the problem to be recognized (the first-inserted drive of what appears to be an incoming foreign volume group). */
	public String getForeignDriveRefersToNativeDrive() {
		return this.foreignDriveRefersToNativeDrive;
	}
	/** @param x This field is present only if recFailureType is equal to REC_FOREIGN_DRIVE_REFERS_TO_NATIVE_DRIVE. It identifies the drive that caused the problem to be recognized (the first-inserted drive of what appears to be an incoming foreign volume group). */
	public void setForeignDriveRefersToNativeDrive(String x) {
		this.foreignDriveRefersToNativeDrive = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_GHOST_VOLUME. It contains the identification of the missing volume. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_GHOST_VOLUME. It contains the identification of the missing volume." , required = false)
	@XmlElement(required = false)
	private String ghostVolume;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_GHOST_VOLUME. It contains the identification of the missing volume. */
	public String getGhostVolume() {
		return this.ghostVolume;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_GHOST_VOLUME. It contains the identification of the missing volume. */
	public void setGhostVolume(String x) {
		this.ghostVolume = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_GOLD_KEY_NOT_COMPLIANT. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_GOLD_KEY_NOT_COMPLIANT." , required = false)
	@XmlElement(required = false)
	private FeatureState goldkeyFeature;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_GOLD_KEY_NOT_COMPLIANT. */
	public FeatureState getGoldkeyFeature() {
		return this.goldkeyFeature;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_GOLD_KEY_NOT_COMPLIANT. */
	public void setGoldkeyFeature(FeatureState x) {
		this.goldkeyFeature = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_HOST_BOARD_FAULT (or the numerically-equivalent REC_FAILED_HOST_IO_CARD). It identifies the failed host board. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_HOST_BOARD_FAULT (or the numerically-equivalent REC_FAILED_HOST_IO_CARD). It identifies the failed host board." , required = false)
	@XmlElement(required = false)
	private String failedHostBoard;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_HOST_BOARD_FAULT (or the numerically-equivalent REC_FAILED_HOST_IO_CARD). It identifies the failed host board. */
	public String getFailedHostBoard() {
		return this.failedHostBoard;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_HOST_BOARD_FAULT (or the numerically-equivalent REC_FAILED_HOST_IO_CARD). It identifies the failed host board. */
	public void setFailedHostBoard(String x) {
		this.failedHostBoard = x;
	}

	/** This field is present only if the recFailureType is equal to REC_HOST_BOARD_ID_MISMATCH. It identifies a host board on the other controller that has a mismatched identifier, and which caused the other controller to lock down. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the recFailureType is equal to REC_HOST_BOARD_ID_MISMATCH. It identifies a host board on the other controller that has a mismatched identifier, and which caused the other controller to lock down." , required = false)
	@XmlElement(required = false)
	private String hostBoardIdMismatch;

	/** @return This field is present only if the recFailureType is equal to REC_HOST_BOARD_ID_MISMATCH. It identifies a host board on the other controller that has a mismatched identifier, and which caused the other controller to lock down. */
	public String getHostBoardIdMismatch() {
		return this.hostBoardIdMismatch;
	}
	/** @param x This field is present only if the recFailureType is equal to REC_HOST_BOARD_ID_MISMATCH. It identifies a host board on the other controller that has a mismatched identifier, and which caused the other controller to lock down. */
	public void setHostBoardIdMismatch(String x) {
		this.hostBoardIdMismatch = x;
	}

	/** This field is only present if the value of the recFailureType is equal to REC_HOST_BOARD_UNKNOWN_STAT. It is a reference to the host board for which the status is unknown. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is only present if the value of the recFailureType is equal to REC_HOST_BOARD_UNKNOWN_STAT. It is a reference to the host board for which the status is unknown." , required = false)
	@XmlElement(required = false)
	private String hostBoardStatUnknown;

	/** @return This field is only present if the value of the recFailureType is equal to REC_HOST_BOARD_UNKNOWN_STAT. It is a reference to the host board for which the status is unknown. */
	public String getHostBoardStatUnknown() {
		return this.hostBoardStatUnknown;
	}
	/** @param x This field is only present if the value of the recFailureType is equal to REC_HOST_BOARD_UNKNOWN_STAT. It is a reference to the host board for which the status is unknown. */
	public void setHostBoardStatUnknown(String x) {
		this.hostBoardStatUnknown = x;
	}

	/** This field is only present if the value of recFailureType is equal to REC_HOTSPARE_DRIVE_MISSING. It is a reference to a standby hot spare drive that is missing from the configuration. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is only present if the value of recFailureType is equal to REC_HOTSPARE_DRIVE_MISSING. It is a reference to a standby hot spare drive that is missing from the configuration." , required = false)
	@XmlElement(required = false)
	private String missingHotSpareDriveRef;

	/** @return This field is only present if the value of recFailureType is equal to REC_HOTSPARE_DRIVE_MISSING. It is a reference to a standby hot spare drive that is missing from the configuration. */
	public String getMissingHotSpareDriveRef() {
		return this.missingHotSpareDriveRef;
	}
	/** @param x This field is only present if the value of recFailureType is equal to REC_HOTSPARE_DRIVE_MISSING. It is a reference to a standby hot spare drive that is missing from the configuration. */
	public void setMissingHotSpareDriveRef(String x) {
		this.missingHotSpareDriveRef = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ICC_CRU_UNKNOWN_STAT. It contains the identification of the interconnect CRU that has unknown status. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ICC_CRU_UNKNOWN_STAT. It contains the identification of the interconnect CRU that has unknown status." , required = false)
	@XmlElement(required = false)
	private String iccCruStatUnknown;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ICC_CRU_UNKNOWN_STAT. It contains the identification of the interconnect CRU that has unknown status. */
	public String getIccCruStatUnknown() {
		return this.iccCruStatUnknown;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ICC_CRU_UNKNOWN_STAT. It contains the identification of the interconnect CRU that has unknown status. */
	public void setIccCruStatUnknown(String x) {
		this.iccCruStatUnknown = x;
	}

	/** This field is present only if the recFailureType is equal to REC_ICC_MISSING. It identifies a controller enclosure having a missing interconnect canister, which caused the other controller to lock down. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the recFailureType is equal to REC_ICC_MISSING. It identifies a controller enclosure having a missing interconnect canister, which caused the other controller to lock down." , required = false)
	@XmlElement(required = false)
	private String iccMissing;

	/** @return This field is present only if the recFailureType is equal to REC_ICC_MISSING. It identifies a controller enclosure having a missing interconnect canister, which caused the other controller to lock down. */
	public String getIccMissing() {
		return this.iccMissing;
	}
	/** @param x This field is present only if the recFailureType is equal to REC_ICC_MISSING. It identifies a controller enclosure having a missing interconnect canister, which caused the other controller to lock down. */
	public void setIccMissing(String x) {
		this.iccMissing = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_IMPAIRED_VOLUME. It contains the identification of a volume that has been marked impaired due to the detection of an internal consistency problem. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_IMPAIRED_VOLUME. It contains the identification of a volume that has been marked impaired due to the detection of an internal consistency problem." , required = false)
	@XmlElement(required = false)
	private String volImpaired;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_IMPAIRED_VOLUME. It contains the identification of a volume that has been marked impaired due to the detection of an internal consistency problem. */
	public String getVolImpaired() {
		return this.volImpaired;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_IMPAIRED_VOLUME. It contains the identification of a volume that has been marked impaired due to the detection of an internal consistency problem. */
	public void setVolImpaired(String x) {
		this.volImpaired = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_IMPENDING_DRIVE_FAILURE_RISK_HIGH. It contains the identification of a volume group containing a drive for which the risk of impending failure is considered to be "high". Failure risk levels are determined by built-in drive algorithms for early failure detection. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_IMPENDING_DRIVE_FAILURE_RISK_HIGH. It contains the identification of a volume group containing a drive for which the risk of impending failure is considered to be \"high\". Failure risk levels are determined by built-in drive algorithms for early failure detection." , required = false)
	@XmlElement(required = false)
	private String driveFailImpendingHigh;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_IMPENDING_DRIVE_FAILURE_RISK_HIGH. It contains the identification of a volume group containing a drive for which the risk of impending failure is considered to be "high". Failure risk levels are determined by built-in drive algorithms for early failure detection. */
	public String getDriveFailImpendingHigh() {
		return this.driveFailImpendingHigh;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_IMPENDING_DRIVE_FAILURE_RISK_HIGH. It contains the identification of a volume group containing a drive for which the risk of impending failure is considered to be "high". Failure risk levels are determined by built-in drive algorithms for early failure detection. */
	public void setDriveFailImpendingHigh(String x) {
		this.driveFailImpendingHigh = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_IMPENDING_DRIVE_FAILURE_RISK_LOW. It contains the identification of a drive for which an impending failure condition has been detected. This failure type is only used for drives that are not assigned to any volume group. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_IMPENDING_DRIVE_FAILURE_RISK_LOW. It contains the identification of a drive for which an impending failure condition has been detected. This failure type is only used for drives that are not assigned to any volume group." , required = false)
	@XmlElement(required = false)
	private String driveFailImpendingLow;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_IMPENDING_DRIVE_FAILURE_RISK_LOW. It contains the identification of a drive for which an impending failure condition has been detected. This failure type is only used for drives that are not assigned to any volume group. */
	public String getDriveFailImpendingLow() {
		return this.driveFailImpendingLow;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_IMPENDING_DRIVE_FAILURE_RISK_LOW. It contains the identification of a drive for which an impending failure condition has been detected. This failure type is only used for drives that are not assigned to any volume group. */
	public void setDriveFailImpendingLow(String x) {
		this.driveFailImpendingLow = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_IMPENDING_DRIVE_FAILURE_RISK_MED. It contains the identification of a volume group containing a drive for which the risk of impending failure is considered to be "medium". */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_IMPENDING_DRIVE_FAILURE_RISK_MED. It contains the identification of a volume group containing a drive for which the risk of impending failure is considered to be \"medium\"." , required = false)
	@XmlElement(required = false)
	private String driveFailImpendingMed;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_IMPENDING_DRIVE_FAILURE_RISK_MED. It contains the identification of a volume group containing a drive for which the risk of impending failure is considered to be "medium". */
	public String getDriveFailImpendingMed() {
		return this.driveFailImpendingMed;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_IMPENDING_DRIVE_FAILURE_RISK_MED. It contains the identification of a volume group containing a drive for which the risk of impending failure is considered to be "medium". */
	public void setDriveFailImpendingMed(String x) {
		this.driveFailImpendingMed = x;
	}

	/** This field is present only if recFailureType is equal to REC_INCOMPATIBLE_FAILED_LEGACY_DRIVE. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to a legacy failed or in-use hot spare drive; the volumeGroup field is a reference to the drive's parent volume group, or a null reference if the drive is unassigned. Also, it is safe to assume that the drives identified in the object graph as belonging to the volume group are valid. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if recFailureType is equal to REC_INCOMPATIBLE_FAILED_LEGACY_DRIVE. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to a legacy failed or in-use hot spare drive; the volumeGroup field is a reference to the drive's parent volume group, or a null reference if the drive is unassigned. Also, it is safe to assume that the drives identified in the object graph as belonging to the volume group are valid." , required = false)
	@XmlElement(required = false)
	private PvgRecoveryData incompatibleFailedLegacyDrive;

	/** @return This field is present only if recFailureType is equal to REC_INCOMPATIBLE_FAILED_LEGACY_DRIVE. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to a legacy failed or in-use hot spare drive; the volumeGroup field is a reference to the drive's parent volume group, or a null reference if the drive is unassigned. Also, it is safe to assume that the drives identified in the object graph as belonging to the volume group are valid. */
	public PvgRecoveryData getIncompatibleFailedLegacyDrive() {
		return this.incompatibleFailedLegacyDrive;
	}
	/** @param x This field is present only if recFailureType is equal to REC_INCOMPATIBLE_FAILED_LEGACY_DRIVE. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to a legacy failed or in-use hot spare drive; the volumeGroup field is a reference to the drive's parent volume group, or a null reference if the drive is unassigned. Also, it is safe to assume that the drives identified in the object graph as belonging to the volume group are valid. */
	public void setIncompatibleFailedLegacyDrive(PvgRecoveryData x) {
		this.incompatibleFailedLegacyDrive = x;
	}

	/** This field is present only if the recFailureType is equal to REC_LD_FW_VERSION_MISMATCH. It identifies the controller firmware version recorded on the drives (the native controller firmware version) when a newly inserted Simplex controller has been locked down due to a mismatch between it's reported controller firmware version and the native controller firmware version. Download the reported native controller firmware version to the locked down controller to recover from this failure. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the recFailureType is equal to REC_LD_FW_VERSION_MISMATCH. It identifies the controller firmware version recorded on the drives (the native controller firmware version) when a newly inserted Simplex controller has been locked down due to a mismatch between it's reported controller firmware version and the native controller firmware version. Download the reported native controller firmware version to the locked down controller to recover from this failure." , required = false)
	@XmlElement(required = false)
	private LockdownCtrlFwVersion ldFwVersionMismatch;

	/** @return This field is present only if the recFailureType is equal to REC_LD_FW_VERSION_MISMATCH. It identifies the controller firmware version recorded on the drives (the native controller firmware version) when a newly inserted Simplex controller has been locked down due to a mismatch between it's reported controller firmware version and the native controller firmware version. Download the reported native controller firmware version to the locked down controller to recover from this failure. */
	public LockdownCtrlFwVersion getLdFwVersionMismatch() {
		return this.ldFwVersionMismatch;
	}
	/** @param x This field is present only if the recFailureType is equal to REC_LD_FW_VERSION_MISMATCH. It identifies the controller firmware version recorded on the drives (the native controller firmware version) when a newly inserted Simplex controller has been locked down due to a mismatch between it's reported controller firmware version and the native controller firmware version. Download the reported native controller firmware version to the locked down controller to recover from this failure. */
	public void setLdFwVersionMismatch(LockdownCtrlFwVersion x) {
		this.ldFwVersionMismatch = x;
	}

	/** This "field" is present if the recFailureType value has no associated reference. It means that, there is no data in the structure other than the failure type itself. This is true for the following recFailureType values: */
	@io.swagger.annotations.ApiModelProperty(value ="This \"field\" is present if the recFailureType value has no associated reference. It means that, there is no data in the structure other than the failure type itself. This is true for the following recFailureType values:" , required = false)
	@XmlElement(required = false)
	private String legacyVgNotOptimal;

	/** @return This "field" is present if the recFailureType value has no associated reference. It means that, there is no data in the structure other than the failure type itself. This is true for the following recFailureType values: */
	public String getLegacyVgNotOptimal() {
		return this.legacyVgNotOptimal;
	}
	/** @param x This "field" is present if the recFailureType value has no associated reference. It means that, there is no data in the structure other than the failure type itself. This is true for the following recFailureType values: */
	public void setLegacyVgNotOptimal(String x) {
		this.legacyVgNotOptimal = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_LINK_SPEED_DETECTION_MISMATCH. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_LINK_SPEED_DETECTION_MISMATCH." , required = false)
	@XmlElement(required = false)
	private LinkSpeedDetectionError linkSpeedDetectionError;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_LINK_SPEED_DETECTION_MISMATCH. */
	public LinkSpeedDetectionError getLinkSpeedDetectionError() {
		return this.linkSpeedDetectionError;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_LINK_SPEED_DETECTION_MISMATCH. */
	public void setLinkSpeedDetectionError(LinkSpeedDetectionError x) {
		this.linkSpeedDetectionError = x;
	}

	/** This field is present only if the recFailureType is equal to REC_LINK_SPEED_MISMATCH. It identifies a controller that is locked down due to detection of a mismatch between an enclosure link speed setting and link speeds that the controller is able to support. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the recFailureType is equal to REC_LINK_SPEED_MISMATCH. It identifies a controller that is locked down due to detection of a mismatch between an enclosure link speed setting and link speeds that the controller is able to support." , required = false)
	@XmlElement(required = false)
	private String linkSpeedMismatch;

	/** @return This field is present only if the recFailureType is equal to REC_LINK_SPEED_MISMATCH. It identifies a controller that is locked down due to detection of a mismatch between an enclosure link speed setting and link speeds that the controller is able to support. */
	public String getLinkSpeedMismatch() {
		return this.linkSpeedMismatch;
	}
	/** @param x This field is present only if the recFailureType is equal to REC_LINK_SPEED_MISMATCH. It identifies a controller that is locked down due to detection of a mismatch between an enclosure link speed setting and link speeds that the controller is able to support. */
	public void setLinkSpeedMismatch(String x) {
		this.linkSpeedMismatch = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_LOST_REDUNDANCY_DRIVE. It contains the identification of the drive that has lost redundancy. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_LOST_REDUNDANCY_DRIVE. It contains the identification of the drive that has lost redundancy." , required = false)
	@XmlElement(required = false)
	private DriveLostRedundancyFailure driveRedundancyFailure;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_LOST_REDUNDANCY_DRIVE. It contains the identification of the drive that has lost redundancy. */
	public DriveLostRedundancyFailure getDriveRedundancyFailure() {
		return this.driveRedundancyFailure;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_LOST_REDUNDANCY_DRIVE. It contains the identification of the drive that has lost redundancy. */
	public void setDriveRedundancyFailure(DriveLostRedundancyFailure x) {
		this.driveRedundancyFailure = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_LOST_REDUNDANCY_ESM. It contains the identification of the ESM card that has lost redundancy. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_LOST_REDUNDANCY_ESM. It contains the identification of the ESM card that has lost redundancy." , required = false)
	@XmlElement(required = false)
	private EsmLostRedundancyFailure esmRedundancyFailure;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_LOST_REDUNDANCY_ESM. It contains the identification of the ESM card that has lost redundancy. */
	public EsmLostRedundancyFailure getEsmRedundancyFailure() {
		return this.esmRedundancyFailure;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_LOST_REDUNDANCY_ESM. It contains the identification of the ESM card that has lost redundancy. */
	public void setEsmRedundancyFailure(EsmLostRedundancyFailure x) {
		this.esmRedundancyFailure = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_LOST_REDUNDANCY_TRAY. It contains the identification of the tray that has lost redundancy. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_LOST_REDUNDANCY_TRAY. It contains the identification of the tray that has lost redundancy." , required = false)
	@XmlElement(required = false)
	private TrayLostRedundancyFailure trayRedundancyFailure;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_LOST_REDUNDANCY_TRAY. It contains the identification of the tray that has lost redundancy. */
	public TrayLostRedundancyFailure getTrayRedundancyFailure() {
		return this.trayRedundancyFailure;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_LOST_REDUNDANCY_TRAY. It contains the identification of the tray that has lost redundancy. */
	public void setTrayRedundancyFailure(TrayLostRedundancyFailure x) {
		this.trayRedundancyFailure = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_MAX_TEMP_EXCEEDED. It contains the identification of the thermal sensor component that is reporting a temperature above the maximum level. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_MAX_TEMP_EXCEEDED. It contains the identification of the thermal sensor component that is reporting a temperature above the maximum level." , required = false)
	@XmlElement(required = false)
	private String maxTempWarn;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_MAX_TEMP_EXCEEDED. It contains the identification of the thermal sensor component that is reporting a temperature above the maximum level. */
	public String getMaxTempWarn() {
		return this.maxTempWarn;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_MAX_TEMP_EXCEEDED. It contains the identification of the thermal sensor component that is reporting a temperature above the maximum level. */
	public void setMaxTempWarn(String x) {
		this.maxTempWarn = x;
	}

	/** This field is equal to present only if the RecoveryFailureType value is equal to REC_MEM_PARITY_ERROR. It contains the identification of the controller that has failed due to a persistent memory parity error. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is equal to present only if the RecoveryFailureType value is equal to REC_MEM_PARITY_ERROR. It contains the identification of the controller that has failed due to a persistent memory parity error." , required = false)
	@XmlElement(required = false)
	private String memParityError;

	/** @return This field is equal to present only if the RecoveryFailureType value is equal to REC_MEM_PARITY_ERROR. It contains the identification of the controller that has failed due to a persistent memory parity error. */
	public String getMemParityError() {
		return this.memParityError;
	}
	/** @param x This field is equal to present only if the RecoveryFailureType value is equal to REC_MEM_PARITY_ERROR. It contains the identification of the controller that has failed due to a persistent memory parity error. */
	public void setMemParityError(String x) {
		this.memParityError = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_METADATA_OFFLINE. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_METADATA_OFFLINE." , required = false)
	@XmlElement(required = false)
	private MetadataOffline metadataOffline;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_METADATA_OFFLINE. */
	public MetadataOffline getMetadataOffline() {
		return this.metadataOffline;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_METADATA_OFFLINE. */
	public void setMetadataOffline(MetadataOffline x) {
		this.metadataOffline = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_MINIHUB_SPEED_MISMATCH. It contains the identification of the drive side minihub with the data rate mismatch. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_MINIHUB_SPEED_MISMATCH. It contains the identification of the drive side minihub with the data rate mismatch." , required = false)
	@XmlElement(required = false)
	private String minihubRef;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_MINIHUB_SPEED_MISMATCH. It contains the identification of the drive side minihub with the data rate mismatch. */
	public String getMinihubRef() {
		return this.minihubRef;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_MINIHUB_SPEED_MISMATCH. It contains the identification of the drive side minihub with the data rate mismatch. */
	public void setMinihubRef(String x) {
		this.minihubRef = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_MIRROR_DUAL_PRIMARY. It contains the identification of the mirror relationship. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_MIRROR_DUAL_PRIMARY. It contains the identification of the mirror relationship." , required = false)
	@XmlElement(required = false)
	private DualMirrorPrimary dualMirrorPrimary;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_MIRROR_DUAL_PRIMARY. It contains the identification of the mirror relationship. */
	public DualMirrorPrimary getDualMirrorPrimary() {
		return this.dualMirrorPrimary;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_MIRROR_DUAL_PRIMARY. It contains the identification of the mirror relationship. */
	public void setDualMirrorPrimary(DualMirrorPrimary x) {
		this.dualMirrorPrimary = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_MIRROR_DUAL_SECONDARY. It contains the identification of the mirror relationship. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_MIRROR_DUAL_SECONDARY. It contains the identification of the mirror relationship." , required = false)
	@XmlElement(required = false)
	private DualMirrorSecondary dualMirrorSecondary;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_MIRROR_DUAL_SECONDARY. It contains the identification of the mirror relationship. */
	public DualMirrorSecondary getDualMirrorSecondary() {
		return this.dualMirrorSecondary;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_MIRROR_DUAL_SECONDARY. It contains the identification of the mirror relationship. */
	public void setDualMirrorSecondary(DualMirrorSecondary x) {
		this.dualMirrorSecondary = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_MIRROR_UNSYNCHRONIZED. It contains the identification of the mirror relationship. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_MIRROR_UNSYNCHRONIZED. It contains the identification of the mirror relationship." , required = false)
	@XmlElement(required = false)
	private MirrorUnsynchronized mirrorUnsynchronized;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_MIRROR_UNSYNCHRONIZED. It contains the identification of the mirror relationship. */
	public MirrorUnsynchronized getMirrorUnsynchronized() {
		return this.mirrorUnsynchronized;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_MIRROR_UNSYNCHRONIZED. It contains the identification of the mirror relationship. */
	public void setMirrorUnsynchronized(MirrorUnsynchronized x) {
		this.mirrorUnsynchronized = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_MISMATCHED_DRIVE_TYPE. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_MISMATCHED_DRIVE_TYPE." , required = false)
	@XmlElement(required = false)
	private FeatureState mixeddrivetypesFeature;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_MISMATCHED_DRIVE_TYPE. */
	public FeatureState getMixeddrivetypesFeature() {
		return this.mixeddrivetypesFeature;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_MISMATCHED_DRIVE_TYPE. */
	public void setMixeddrivetypesFeature(FeatureState x) {
		this.mixeddrivetypesFeature = x;
	}

	/** This field is present only if recFailureType is equal to REC_NATIVE_VG_FOREIGN_DRIVE_MUTUAL_REF. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the foreign drive; the volumeGroup field is a reference to the native volume group. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if recFailureType is equal to REC_NATIVE_VG_FOREIGN_DRIVE_MUTUAL_REF. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the foreign drive; the volumeGroup field is a reference to the native volume group." , required = false)
	@XmlElement(required = false)
	private PvgRecoveryData nativeVgForeignDriveMutualRef;

	/** @return This field is present only if recFailureType is equal to REC_NATIVE_VG_FOREIGN_DRIVE_MUTUAL_REF. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the foreign drive; the volumeGroup field is a reference to the native volume group. */
	public PvgRecoveryData getNativeVgForeignDriveMutualRef() {
		return this.nativeVgForeignDriveMutualRef;
	}
	/** @param x This field is present only if recFailureType is equal to REC_NATIVE_VG_FOREIGN_DRIVE_MUTUAL_REF. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the foreign drive; the volumeGroup field is a reference to the native volume group. */
	public void setNativeVgForeignDriveMutualRef(PvgRecoveryData x) {
		this.nativeVgForeignDriveMutualRef = x;
	}

	/** This field is present only if recFailureType is equal to REC_NATIVE_VG_REFERS_TO_FOREIGN_DRIVE. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the foreign drive, and the volumeGroup field is a reference to the native volume group. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if recFailureType is equal to REC_NATIVE_VG_REFERS_TO_FOREIGN_DRIVE. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the foreign drive, and the volumeGroup field is a reference to the native volume group." , required = false)
	@XmlElement(required = false)
	private PvgRecoveryData nativeVgRefersToForeignDrive;

	/** @return This field is present only if recFailureType is equal to REC_NATIVE_VG_REFERS_TO_FOREIGN_DRIVE. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the foreign drive, and the volumeGroup field is a reference to the native volume group. */
	public PvgRecoveryData getNativeVgRefersToForeignDrive() {
		return this.nativeVgRefersToForeignDrive;
	}
	/** @param x This field is present only if recFailureType is equal to REC_NATIVE_VG_REFERS_TO_FOREIGN_DRIVE. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the foreign drive, and the volumeGroup field is a reference to the native volume group. */
	public void setNativeVgRefersToForeignDrive(PvgRecoveryData x) {
		this.nativeVgRefersToForeignDrive = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_NET_SETUP_ERROR. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_NET_SETUP_ERROR." , required = false)
	@XmlElement(required = false)
	private String networkSetupError;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_NET_SETUP_ERROR. */
	public String getNetworkSetupError() {
		return this.networkSetupError;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_NET_SETUP_ERROR. */
	public void setNetworkSetupError(String x) {
		this.networkSetupError = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_NOMINAL_TEMP_EXCEEDED. It contains the identification of the thermal sensor component that is reporting a temperature above the nominal level. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_NOMINAL_TEMP_EXCEEDED. It contains the identification of the thermal sensor component that is reporting a temperature above the nominal level." , required = false)
	@XmlElement(required = false)
	private String nominalTempWarn;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_NOMINAL_TEMP_EXCEEDED. It contains the identification of the thermal sensor component that is reporting a temperature above the nominal level. */
	public String getNominalTempWarn() {
		return this.nominalTempWarn;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_NOMINAL_TEMP_EXCEEDED. It contains the identification of the thermal sensor component that is reporting a temperature above the nominal level. */
	public void setNominalTempWarn(String x) {
		this.nominalTempWarn = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_NON_FRU_BATTERY_NEAR_EXPIRATION (or its equivalent REC_INTEGRATED_BATTERY_NEAR_EXPIRATION). It contains the identification of the controller with the battery warning. Note that the "non-FRU" terminology is really misleading since this case applies only when the battery is in a FRU (as opposed to a CRU). */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_NON_FRU_BATTERY_NEAR_EXPIRATION (or its equivalent REC_INTEGRATED_BATTERY_NEAR_EXPIRATION). It contains the identification of the controller with the battery warning. Note that the \"non-FRU\" terminology is really misleading since this case applies only when the battery is in a FRU (as opposed to a CRU)." , required = false)
	@XmlElement(required = false)
	private String nonFruBatteryWarn;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_NON_FRU_BATTERY_NEAR_EXPIRATION (or its equivalent REC_INTEGRATED_BATTERY_NEAR_EXPIRATION). It contains the identification of the controller with the battery warning. Note that the "non-FRU" terminology is really misleading since this case applies only when the battery is in a FRU (as opposed to a CRU). */
	public String getNonFruBatteryWarn() {
		return this.nonFruBatteryWarn;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_NON_FRU_BATTERY_NEAR_EXPIRATION (or its equivalent REC_INTEGRATED_BATTERY_NEAR_EXPIRATION). It contains the identification of the controller with the battery warning. Note that the "non-FRU" terminology is really misleading since this case applies only when the battery is in a FRU (as opposed to a CRU). */
	public void setNonFruBatteryWarn(String x) {
		this.nonFruBatteryWarn = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_NON_FRU_FAILED_BATTERY (or its equivalent REC_FAILED_INTEGRATED_BATTERY). It contains the identification of the controller with the failed battery. Note that the "non-FRU" terminology is really misleading since this case applies only when the battery is in a FRU (as opposed to a CRU). */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_NON_FRU_FAILED_BATTERY (or its equivalent REC_FAILED_INTEGRATED_BATTERY). It contains the identification of the controller with the failed battery. Note that the \"non-FRU\" terminology is really misleading since this case applies only when the battery is in a FRU (as opposed to a CRU)." , required = false)
	@XmlElement(required = false)
	private String nonFruBatteryFail;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_NON_FRU_FAILED_BATTERY (or its equivalent REC_FAILED_INTEGRATED_BATTERY). It contains the identification of the controller with the failed battery. Note that the "non-FRU" terminology is really misleading since this case applies only when the battery is in a FRU (as opposed to a CRU). */
	public String getNonFruBatteryFail() {
		return this.nonFruBatteryFail;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_NON_FRU_FAILED_BATTERY (or its equivalent REC_FAILED_INTEGRATED_BATTERY). It contains the identification of the controller with the failed battery. Note that the "non-FRU" terminology is really misleading since this case applies only when the battery is in a FRU (as opposed to a CRU). */
	public void setNonFruBatteryFail(String x) {
		this.nonFruBatteryFail = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_NON_FRU_REMOVED_BATTERY (or its equivalent REC_REMOVED_INTEGRATED_BATTERY). It contains the identification of the FRU'd battery that was removed. Note that the "non-FRU" terminology is really misleading since this case applies only when the battery is in a FRU (as opposed to a CRU). */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_NON_FRU_REMOVED_BATTERY (or its equivalent REC_REMOVED_INTEGRATED_BATTERY). It contains the identification of the FRU'd battery that was removed. Note that the \"non-FRU\" terminology is really misleading since this case applies only when the battery is in a FRU (as opposed to a CRU)." , required = false)
	@XmlElement(required = false)
	private String nonFruBatteryRemoved;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_NON_FRU_REMOVED_BATTERY (or its equivalent REC_REMOVED_INTEGRATED_BATTERY). It contains the identification of the FRU'd battery that was removed. Note that the "non-FRU" terminology is really misleading since this case applies only when the battery is in a FRU (as opposed to a CRU). */
	public String getNonFruBatteryRemoved() {
		return this.nonFruBatteryRemoved;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_NON_FRU_REMOVED_BATTERY (or its equivalent REC_REMOVED_INTEGRATED_BATTERY). It contains the identification of the FRU'd battery that was removed. Note that the "non-FRU" terminology is really misleading since this case applies only when the battery is in a FRU (as opposed to a CRU). */
	public void setNonFruBatteryRemoved(String x) {
		this.nonFruBatteryRemoved = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_NON_PREFERRED_PATH. It contains the identification of the controller that is the preferred owner of the volume(s) that have been switched to the non-preferred owner due to some sort of I/O path error. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_NON_PREFERRED_PATH. It contains the identification of the controller that is the preferred owner of the volume(s) that have been switched to the non-preferred owner due to some sort of I/O path error." , required = false)
	@XmlElement(required = false)
	private NotOnPreferredPath nonPreferredPath;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_NON_PREFERRED_PATH. It contains the identification of the controller that is the preferred owner of the volume(s) that have been switched to the non-preferred owner due to some sort of I/O path error. */
	public NotOnPreferredPath getNonPreferredPath() {
		return this.nonPreferredPath;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_NON_PREFERRED_PATH. It contains the identification of the controller that is the preferred owner of the volume(s) that have been switched to the non-preferred owner due to some sort of I/O path error. */
	public void setNonPreferredPath(NotOnPreferredPath x) {
		this.nonPreferredPath = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_OFFLINE_CTL. It contains the identification of a controller that has been placed offline. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_OFFLINE_CTL. It contains the identification of a controller that has been placed offline." , required = false)
	@XmlElement(required = false)
	private String offlineCtl;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_OFFLINE_CTL. It contains the identification of a controller that has been placed offline. */
	public String getOfflineCtl() {
		return this.offlineCtl;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_OFFLINE_CTL. It contains the identification of a controller that has been placed offline. */
	public void setOfflineCtl(String x) {
		this.offlineCtl = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_OFFLINE_VOLUME_GROUP. It contains the identification of a volume group that has been marked offline. This can occur due to either an explicit user request, or the physical insertion of drives from another storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_OFFLINE_VOLUME_GROUP. It contains the identification of a volume group that has been marked offline. This can occur due to either an explicit user request, or the physical insertion of drives from another storage array." , required = false)
	@XmlElement(required = false)
	private String volGroupOffline;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_OFFLINE_VOLUME_GROUP. It contains the identification of a volume group that has been marked offline. This can occur due to either an explicit user request, or the physical insertion of drives from another storage array. */
	public String getVolGroupOffline() {
		return this.volGroupOffline;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_OFFLINE_VOLUME_GROUP. It contains the identification of a volume group that has been marked offline. This can occur due to either an explicit user request, or the physical insertion of drives from another storage array. */
	public void setVolGroupOffline(String x) {
		this.volGroupOffline = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_PARTITIONS_NOT_COMPLIANT. It contains the identification of the storage partitions feature that is not in compliance. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_PARTITIONS_NOT_COMPLIANT. It contains the identification of the storage partitions feature that is not in compliance." , required = false)
	@XmlElement(required = false)
	private FeatureState spmFeature;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_PARTITIONS_NOT_COMPLIANT. It contains the identification of the storage partitions feature that is not in compliance. */
	public FeatureState getSpmFeature() {
		return this.spmFeature;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_PARTITIONS_NOT_COMPLIANT. It contains the identification of the storage partitions feature that is not in compliance. */
	public void setSpmFeature(FeatureState x) {
		this.spmFeature = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_PASSIVE_CTL. It contains the identification of a controller that has been placed into the "passive" mode of operation. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_PASSIVE_CTL. It contains the identification of a controller that has been placed into the \"passive\" mode of operation." , required = false)
	@XmlElement(required = false)
	private String passiveCtl;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_PASSIVE_CTL. It contains the identification of a controller that has been placed into the "passive" mode of operation. */
	public String getPassiveCtl() {
		return this.passiveCtl;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_PASSIVE_CTL. It contains the identification of a controller that has been placed into the "passive" mode of operation. */
	public void setPassiveCtl(String x) {
		this.passiveCtl = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_PATH_DEGRADED. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_PATH_DEGRADED." , required = false)
	@XmlElement(required = false)
	private PathDegradedFailure pathDegradedFailure;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_PATH_DEGRADED. */
	public PathDegradedFailure getPathDegradedFailure() {
		return this.pathDegradedFailure;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_PATH_DEGRADED. */
	public void setPathDegradedFailure(PathDegradedFailure x) {
		this.pathDegradedFailure = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_PERFORMANCE_TIER_NOT_COMPLIANT. It indicates that the performance tier feature is out of compliance. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_PERFORMANCE_TIER_NOT_COMPLIANT. It indicates that the performance tier feature is out of compliance." , required = false)
	@XmlElement(required = false)
	private FeatureState performanceTierFeature;

	/** @return This field is present only if the value of recFailureType is equal to REC_PERFORMANCE_TIER_NOT_COMPLIANT. It indicates that the performance tier feature is out of compliance. */
	public FeatureState getPerformanceTierFeature() {
		return this.performanceTierFeature;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_PERFORMANCE_TIER_NOT_COMPLIANT. It indicates that the performance tier feature is out of compliance. */
	public void setPerformanceTierFeature(FeatureState x) {
		this.performanceTierFeature = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_POWER_SUPPLY_UNKNOWN_STAT. It contains the identification of the power supply that has failed with unknown status. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_POWER_SUPPLY_UNKNOWN_STAT. It contains the identification of the power supply that has failed with unknown status." , required = false)
	@XmlElement(required = false)
	private String powerSupplyStatUnknown;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_POWER_SUPPLY_UNKNOWN_STAT. It contains the identification of the power supply that has failed with unknown status. */
	public String getPowerSupplyStatUnknown() {
		return this.powerSupplyStatUnknown;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_POWER_SUPPLY_UNKNOWN_STAT. It contains the identification of the power supply that has failed with unknown status. */
	public void setPowerSupplyStatUnknown(String x) {
		this.powerSupplyStatUnknown = x;
	}

	/** This field is present only if the recFailureType value is equal to REC_PROC_MEM_TOO_SMALL_FOR_CACHE. It identifies a controller that does not have enough processor memory for managing the amount of cache memory it has. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the recFailureType value is equal to REC_PROC_MEM_TOO_SMALL_FOR_CACHE. It identifies a controller that does not have enough processor memory for managing the amount of cache memory it has." , required = false)
	@XmlElement(required = false)
	private String procMemTooSmallForCache;

	/** @return This field is present only if the recFailureType value is equal to REC_PROC_MEM_TOO_SMALL_FOR_CACHE. It identifies a controller that does not have enough processor memory for managing the amount of cache memory it has. */
	public String getProcMemTooSmallForCache() {
		return this.procMemTooSmallForCache;
	}
	/** @param x This field is present only if the recFailureType value is equal to REC_PROC_MEM_TOO_SMALL_FOR_CACHE. It identifies a controller that does not have enough processor memory for managing the amount of cache memory it has. */
	public void setProcMemTooSmallForCache(String x) {
		this.procMemTooSmallForCache = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_RAID6_NOT_COMPLIANT. It is a FeatureState structure indicating that the RAID 6 feature is out of compliance. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_RAID6_NOT_COMPLIANT. It is a FeatureState structure indicating that the RAID 6 feature is out of compliance." , required = false)
	@XmlElement(required = false)
	private FeatureState raid6Feature;

	/** @return This field is present only if the value of recFailureType is equal to REC_RAID6_NOT_COMPLIANT. It is a FeatureState structure indicating that the RAID 6 feature is out of compliance. */
	public FeatureState getRaid6Feature() {
		return this.raid6Feature;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_RAID6_NOT_COMPLIANT. It is a FeatureState structure indicating that the RAID 6 feature is out of compliance. */
	public void setRaid6Feature(FeatureState x) {
		this.raid6Feature = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_REDUNDANT_PS_REQUIRED. It contains the identification of the support CRU that is lacking a required power supply component. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_REDUNDANT_PS_REQUIRED. It contains the identification of the support CRU that is lacking a required power supply component." , required = false)
	@XmlElement(required = false)
	private String incorrectSupportCru;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_REDUNDANT_PS_REQUIRED. It contains the identification of the support CRU that is lacking a required power supply component. */
	public String getIncorrectSupportCru() {
		return this.incorrectSupportCru;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_REDUNDANT_PS_REQUIRED. It contains the identification of the support CRU that is lacking a required power supply component. */
	public void setIncorrectSupportCru(String x) {
		this.incorrectSupportCru = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_NO_ARRAY. It contains the identification of the remote volume. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_NO_ARRAY. It contains the identification of the remote volume." , required = false)
	@XmlElement(required = false)
	private RemoteVolNoArray remoteVolNoArray;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_NO_ARRAY. It contains the identification of the remote volume. */
	public RemoteVolNoArray getRemoteVolNoArray() {
		return this.remoteVolNoArray;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_NO_ARRAY. It contains the identification of the remote volume. */
	public void setRemoteVolNoArray(RemoteVolNoArray x) {
		this.remoteVolNoArray = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_NO_FABRIC. It contains the identification of the remote volume. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_NO_FABRIC. It contains the identification of the remote volume." , required = false)
	@XmlElement(required = false)
	private RemoteVolNoFabric remoteVolNoFabric;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_NO_FABRIC. It contains the identification of the remote volume. */
	public RemoteVolNoFabric getRemoteVolNoFabric() {
		return this.remoteVolNoFabric;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_NO_FABRIC. It contains the identification of the remote volume. */
	public void setRemoteVolNoFabric(RemoteVolNoFabric x) {
		this.remoteVolNoFabric = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_NO_LUN. It contains the identification of the remote volume. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_NO_LUN. It contains the identification of the remote volume." , required = false)
	@XmlElement(required = false)
	private RemoteVolNoLUN remoteVolNoLUN;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_NO_LUN. It contains the identification of the remote volume. */
	public RemoteVolNoLUN getRemoteVolNoLUN() {
		return this.remoteVolNoLUN;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_NO_LUN. It contains the identification of the remote volume. */
	public void setRemoteVolNoLUN(RemoteVolNoLUN x) {
		this.remoteVolNoLUN = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_WWN_CHANGE_FAILED. It contains the identification of the remote volume. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_WWN_CHANGE_FAILED. It contains the identification of the remote volume." , required = false)
	@XmlElement(required = false)
	private RemoteVolWWNChangeFailed remoteVolWWNChangeFailed;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_WWN_CHANGE_FAILED. It contains the identification of the remote volume. */
	public RemoteVolWWNChangeFailed getRemoteVolWWNChangeFailed() {
		return this.remoteVolWWNChangeFailed;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_REMOTE_WWN_CHANGE_FAILED. It contains the identification of the remote volume. */
	public void setRemoteVolWWNChangeFailed(RemoteVolWWNChangeFailed x) {
		this.remoteVolWWNChangeFailed = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_REMOVED_ALARM. It contains the identification of the alarm that was removed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_REMOVED_ALARM. It contains the identification of the alarm that was removed." , required = false)
	@XmlElement(required = false)
	private String alarmRemoved;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_REMOVED_ALARM. It contains the identification of the alarm that was removed. */
	public String getAlarmRemoved() {
		return this.alarmRemoved;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_REMOVED_ALARM. It contains the identification of the alarm that was removed. */
	public void setAlarmRemoved(String x) {
		this.alarmRemoved = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_REMOVED_BATTERY. It contains the identification of the battery that was removed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_REMOVED_BATTERY. It contains the identification of the battery that was removed." , required = false)
	@XmlElement(required = false)
	private String batteryRemoved;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_REMOVED_BATTERY. It contains the identification of the battery that was removed. */
	public String getBatteryRemoved() {
		return this.batteryRemoved;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_REMOVED_BATTERY. It contains the identification of the battery that was removed. */
	public void setBatteryRemoved(String x) {
		this.batteryRemoved = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_REMOVED_BATTERY_PACK. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_REMOVED_BATTERY_PACK." , required = false)
	@XmlElement(required = false)
	private String batteryPackRemoved;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_REMOVED_BATTERY_PACK. */
	public String getBatteryPackRemoved() {
		return this.batteryPackRemoved;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_REMOVED_BATTERY_PACK. */
	public void setBatteryPackRemoved(String x) {
		this.batteryPackRemoved = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_REMOVED_ESM. It contains the identification of the ESM canister that was removed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_REMOVED_ESM. It contains the identification of the ESM canister that was removed." , required = false)
	@XmlElement(required = false)
	private String esmRemoved;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_REMOVED_ESM. It contains the identification of the ESM canister that was removed. */
	public String getEsmRemoved() {
		return this.esmRemoved;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_REMOVED_ESM. It contains the identification of the ESM canister that was removed. */
	public void setEsmRemoved(String x) {
		this.esmRemoved = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_REMOVED_FAN. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_REMOVED_FAN." , required = false)
	@XmlElement(required = false)
	private String fanRemoved;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_REMOVED_FAN. */
	public String getFanRemoved() {
		return this.fanRemoved;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_REMOVED_FAN. */
	public void setFanRemoved(String x) {
		this.fanRemoved = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_REMOVED_ICC_CRU. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_REMOVED_ICC_CRU." , required = false)
	@XmlElement(required = false)
	private String iccCruRemoved;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_REMOVED_ICC_CRU. */
	public String getIccCruRemoved() {
		return this.iccCruRemoved;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_REMOVED_ICC_CRU. */
	public void setIccCruRemoved(String x) {
		this.iccCruRemoved = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_REMOVED_POWER_SUPPLY. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_REMOVED_POWER_SUPPLY." , required = false)
	@XmlElement(required = false)
	private String powerSupplyRemoved;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_REMOVED_POWER_SUPPLY. */
	public String getPowerSupplyRemoved() {
		return this.powerSupplyRemoved;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_REMOVED_POWER_SUPPLY. */
	public void setPowerSupplyRemoved(String x) {
		this.powerSupplyRemoved = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_REMOVED_SUPPORT_CRU. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_REMOVED_SUPPORT_CRU." , required = false)
	@XmlElement(required = false)
	private String supportCruRemoved;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_REMOVED_SUPPORT_CRU. */
	public String getSupportCruRemoved() {
		return this.supportCruRemoved;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_REMOVED_SUPPORT_CRU. */
	public void setSupportCruRemoved(String x) {
		this.supportCruRemoved = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_REMOVED_TEMP_SENSOR. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_REMOVED_TEMP_SENSOR." , required = false)
	@XmlElement(required = false)
	private String tempSensorRemoved;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_REMOVED_TEMP_SENSOR. */
	public String getTempSensorRemoved() {
		return this.tempSensorRemoved;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_REMOVED_TEMP_SENSOR. */
	public void setTempSensorRemoved(String x) {
		this.tempSensorRemoved = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_REPLACED_DRIVE_WRONG_TYPE. It indicates that a failed drive has been replaced with a drive of the wrong type. The failure type list will contain one entry of this type for each wrong replacement drive in the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_REPLACED_DRIVE_WRONG_TYPE. It indicates that a failed drive has been replaced with a drive of the wrong type. The failure type list will contain one entry of this type for each wrong replacement drive in the storage array." , required = false)
	@XmlElement(required = false)
	private String replacedDriveWrongType;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_REPLACED_DRIVE_WRONG_TYPE. It indicates that a failed drive has been replaced with a drive of the wrong type. The failure type list will contain one entry of this type for each wrong replacement drive in the storage array. */
	public String getReplacedDriveWrongType() {
		return this.replacedDriveWrongType;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_REPLACED_DRIVE_WRONG_TYPE. It indicates that a failed drive has been replaced with a drive of the wrong type. The failure type list will contain one entry of this type for each wrong replacement drive in the storage array. */
	public void setReplacedDriveWrongType(String x) {
		this.replacedDriveWrongType = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_REPOSITORY_FULL. It contains the identification of the repository that is full. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_REPOSITORY_FULL. It contains the identification of the repository that is full." , required = false)
	@XmlElement(required = false)
	private FullRepository repositoryFull;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_REPOSITORY_FULL. It contains the identification of the repository that is full. */
	public FullRepository getRepositoryFull() {
		return this.repositoryFull;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_REPOSITORY_FULL. It contains the identification of the repository that is full. */
	public void setRepositoryFull(FullRepository x) {
		this.repositoryFull = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_REPOSITORY_OVER_THRESHOLD. It contains the identification of the repository volume that is over the threshold. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_REPOSITORY_OVER_THRESHOLD. It contains the identification of the repository volume that is over the threshold." , required = false)
	@XmlElement(required = false)
	private String repositoryOverThreshold;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_REPOSITORY_OVER_THRESHOLD. It contains the identification of the repository volume that is over the threshold. */
	public String getRepositoryOverThreshold() {
		return this.repositoryOverThreshold;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_REPOSITORY_OVER_THRESHOLD. It contains the identification of the repository volume that is over the threshold. */
	public void setRepositoryOverThreshold(String x) {
		this.repositoryOverThreshold = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_RPA_ERR_CTL. It contains the identification of the controller with the RPA parity error. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_RPA_ERR_CTL. It contains the identification of the controller with the RPA parity error." , required = false)
	@XmlElement(required = false)
	private String rpaParityError;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_RPA_ERR_CTL. It contains the identification of the controller with the RPA parity error. */
	public String getRpaParityError() {
		return this.rpaParityError;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_RPA_ERR_CTL. It contains the identification of the controller with the RPA parity error. */
	public void setRpaParityError(String x) {
		this.rpaParityError = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_RVM_NOT_COMPLIANT. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_RVM_NOT_COMPLIANT." , required = false)
	@XmlElement(required = false)
	private FeatureState rvmFeature;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_RVM_NOT_COMPLIANT. */
	public FeatureState getRvmFeature() {
		return this.rvmFeature;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_RVM_NOT_COMPLIANT. */
	public void setRvmFeature(FeatureState x) {
		this.rvmFeature = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_SAS_PORT_DEGRADED. It supplies information about a degraded SAS port, including the parent device and the attached device. An entry of this type appears once in the failure type list for each degraded port in the array. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_SAS_PORT_DEGRADED. It supplies information about a degraded SAS port, including the parent device and the attached device. An entry of this type appears once in the failure type list for each degraded port in the array." , required = false)
	@XmlElement(required = false)
	private SasPort degradedSasPort;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_SAS_PORT_DEGRADED. It supplies information about a degraded SAS port, including the parent device and the attached device. An entry of this type appears once in the failure type list for each degraded port in the array. */
	public SasPort getDegradedSasPort() {
		return this.degradedSasPort;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_SAS_PORT_DEGRADED. It supplies information about a degraded SAS port, including the parent device and the attached device. An entry of this type appears once in the failure type list for each degraded port in the array. */
	public void setDegradedSasPort(SasPort x) {
		this.degradedSasPort = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_SAS_PORT_FAILED. It supplies information about a failed SAS port, including the parent device and the attached device. An entry of this type appears once in the failure type list for each failed port in the array. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_SAS_PORT_FAILED. It supplies information about a failed SAS port, including the parent device and the attached device. An entry of this type appears once in the failure type list for each failed port in the array." , required = false)
	@XmlElement(required = false)
	private SasPort failedSasPort;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_SAS_PORT_FAILED. It supplies information about a failed SAS port, including the parent device and the attached device. An entry of this type appears once in the failure type list for each failed port in the array. */
	public SasPort getFailedSasPort() {
		return this.failedSasPort;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_SAS_PORT_FAILED. It supplies information about a failed SAS port, including the parent device and the attached device. An entry of this type appears once in the failure type list for each failed port in the array. */
	public void setFailedSasPort(SasPort x) {
		this.failedSasPort = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_SAS_PORT_MISWIRED. It identifies the SAS port from which the miswire originates. The type of miswire is identified by a field in the SasPort structure. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_SAS_PORT_MISWIRED. It identifies the SAS port from which the miswire originates. The type of miswire is identified by a field in the SasPort structure." , required = false)
	@XmlElement(required = false)
	private SasPort miswiredSasPort;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_SAS_PORT_MISWIRED. It identifies the SAS port from which the miswire originates. The type of miswire is identified by a field in the SasPort structure. */
	public SasPort getMiswiredSasPort() {
		return this.miswiredSasPort;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_SAS_PORT_MISWIRED. It identifies the SAS port from which the miswire originates. The type of miswire is identified by a field in the SasPort structure. */
	public void setMiswiredSasPort(SasPort x) {
		this.miswiredSasPort = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_SNAPSHOT_FAILED. It contains the identification of the snapshot volume that failed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_SNAPSHOT_FAILED. It contains the identification of the snapshot volume that failed." , required = false)
	@XmlElement(required = false)
	private SnapshotFailure snapFail;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_SNAPSHOT_FAILED. It contains the identification of the snapshot volume that failed. */
	public SnapshotFailure getSnapFail() {
		return this.snapFail;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_SNAPSHOT_FAILED. It contains the identification of the snapshot volume that failed. */
	public void setSnapFail(SnapshotFailure x) {
		this.snapFail = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_SNAPSHOT_NOT_COMPLIANT. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_SNAPSHOT_NOT_COMPLIANT." , required = false)
	@XmlElement(required = false)
	private FeatureState snapshotFeature;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_SNAPSHOT_NOT_COMPLIANT. */
	public FeatureState getSnapshotFeature() {
		return this.snapshotFeature;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_SNAPSHOT_NOT_COMPLIANT. */
	public void setSnapshotFeature(FeatureState x) {
		this.snapshotFeature = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_SPEED_NEG_ERROR. It indicates that a Fibre Channel speed negotiation error has occurred. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_SPEED_NEG_ERROR. It indicates that a Fibre Channel speed negotiation error has occurred." , required = false)
	@XmlElement(required = false)
	private SpeedNegError speedNegError;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_SPEED_NEG_ERROR. It indicates that a Fibre Channel speed negotiation error has occurred. */
	public SpeedNegError getSpeedNegError() {
		return this.speedNegError;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_SPEED_NEG_ERROR. It indicates that a Fibre Channel speed negotiation error has occurred. */
	public void setSpeedNegError(SpeedNegError x) {
		this.speedNegError = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_SUBMODEL_MISMATCH. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_SUBMODEL_MISMATCH." , required = false)
	@XmlElement(required = false)
	private String submodelMismatch;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_SUBMODEL_MISMATCH. */
	public String getSubmodelMismatch() {
		return this.submodelMismatch;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_SUBMODEL_MISMATCH. */
	public void setSubmodelMismatch(String x) {
		this.submodelMismatch = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_SUBMODEL_NOT_SET. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_SUBMODEL_NOT_SET." , required = false)
	@XmlElement(required = false)
	private String submodelNotSet;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_SUBMODEL_NOT_SET. */
	public String getSubmodelNotSet() {
		return this.submodelNotSet;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_SUBMODEL_NOT_SET. */
	public void setSubmodelNotSet(String x) {
		this.submodelNotSet = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_SUBMODEL_NOT_SUPPORTED. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_SUBMODEL_NOT_SUPPORTED." , required = false)
	@XmlElement(required = false)
	private String submodelNotSupported;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_SUBMODEL_NOT_SUPPORTED. */
	public String getSubmodelNotSupported() {
		return this.submodelNotSupported;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_SUBMODEL_NOT_SUPPORTED. */
	public void setSubmodelNotSupported(String x) {
		this.submodelNotSupported = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_SUPPORT_CRU_NOINPUT. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_SUPPORT_CRU_NOINPUT." , required = false)
	@XmlElement(required = false)
	private String supportCruNoInput;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_SUPPORT_CRU_NOINPUT. */
	public String getSupportCruNoInput() {
		return this.supportCruNoInput;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_SUPPORT_CRU_NOINPUT. */
	public void setSupportCruNoInput(String x) {
		this.supportCruNoInput = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_SUPPORT_CRU_UNKNOWN_STAT. It contains the identification of the support CRU that has unknown status. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_SUPPORT_CRU_UNKNOWN_STAT. It contains the identification of the support CRU that has unknown status." , required = false)
	@XmlElement(required = false)
	private String supportCruStatUnknown;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_SUPPORT_CRU_UNKNOWN_STAT. It contains the identification of the support CRU that has unknown status. */
	public String getSupportCruStatUnknown() {
		return this.supportCruStatUnknown;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_SUPPORT_CRU_UNKNOWN_STAT. It contains the identification of the support CRU that has unknown status. */
	public void setSupportCruStatUnknown(String x) {
		this.supportCruStatUnknown = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_TEMP_SENSOR_UNKNOWN_STAT. It contains the identification of the temperature sensor that has failed with unknown status. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_TEMP_SENSOR_UNKNOWN_STAT. It contains the identification of the temperature sensor that has failed with unknown status." , required = false)
	@XmlElement(required = false)
	private String tempSensorStatUnknown;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_TEMP_SENSOR_UNKNOWN_STAT. It contains the identification of the temperature sensor that has failed with unknown status. */
	public String getTempSensorStatUnknown() {
		return this.tempSensorStatUnknown;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_TEMP_SENSOR_UNKNOWN_STAT. It contains the identification of the temperature sensor that has failed with unknown status. */
	public void setTempSensorStatUnknown(String x) {
		this.tempSensorStatUnknown = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_TRANS_MOD_UNKNOWN_STAT. It contains the identification of the transceiver module that has failed with unknown status. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_TRANS_MOD_UNKNOWN_STAT. It contains the identification of the transceiver module that has failed with unknown status." , required = false)
	@XmlElement(required = false)
	private String transceiverModuleStatUnknown;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_TRANS_MOD_UNKNOWN_STAT. It contains the identification of the transceiver module that has failed with unknown status. */
	public String getTransceiverModuleStatUnknown() {
		return this.transceiverModuleStatUnknown;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_TRANS_MOD_UNKNOWN_STAT. It contains the identification of the transceiver module that has failed with unknown status. */
	public void setTransceiverModuleStatUnknown(String x) {
		this.transceiverModuleStatUnknown = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_TRAYID_CONFLICT. It contains the identification of the drive trays that have conflicting tray IDs. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_TRAYID_CONFLICT. It contains the identification of the drive trays that have conflicting tray IDs." , required = false)
	@XmlElement(required = false)
	private TrayRefList trayIDConflicts;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_TRAYID_CONFLICT. It contains the identification of the drive trays that have conflicting tray IDs. */
	public TrayRefList getTrayIDConflicts() {
		return this.trayIDConflicts;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_TRAYID_CONFLICT. It contains the identification of the drive trays that have conflicting tray IDs. */
	public void setTrayIDConflicts(TrayRefList x) {
		this.trayIDConflicts = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_TRAYID_MISMATCH. It contains the identification of the tray that has IDs that do not match. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_TRAYID_MISMATCH. It contains the identification of the tray that has IDs that do not match." , required = false)
	@XmlElement(required = false)
	private String trayIDMismatch;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_TRAYID_MISMATCH. It contains the identification of the tray that has IDs that do not match. */
	public String getTrayIDMismatch() {
		return this.trayIDMismatch;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_TRAYID_MISMATCH. It contains the identification of the tray that has IDs that do not match. */
	public void setTrayIDMismatch(String x) {
		this.trayIDMismatch = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_UNCERTIFIED_DRIVE. It contains the identification of a drive whose type/model is not certified for use within the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_UNCERTIFIED_DRIVE. It contains the identification of a drive whose type/model is not certified for use within the storage array." , required = false)
	@XmlElement(required = false)
	private String driveUncertified;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_UNCERTIFIED_DRIVE. It contains the identification of a drive whose type/model is not certified for use within the storage array. */
	public String getDriveUncertified() {
		return this.driveUncertified;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_UNCERTIFIED_DRIVE. It contains the identification of a drive whose type/model is not certified for use within the storage array. */
	public void setDriveUncertified(String x) {
		this.driveUncertified = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_UNCERTIFIED_ESM. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_UNCERTIFIED_ESM." , required = false)
	@XmlElement(required = false)
	private String esmUncertified;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_UNCERTIFIED_ESM. */
	public String getEsmUncertified() {
		return this.esmUncertified;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_UNCERTIFIED_ESM. */
	public void setEsmUncertified(String x) {
		this.esmUncertified = x;
	}

	/** This field is present if the value of recFailureType is equal to REC_UNSUPPORTED_CACHE_MEMORY_SIZE. It identifies a controller having a cache of unsupported size. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the value of recFailureType is equal to REC_UNSUPPORTED_CACHE_MEMORY_SIZE. It identifies a controller having a cache of unsupported size." , required = false)
	@XmlElement(required = false)
	private String cacheMemorySizeUnsupported;

	/** @return This field is present if the value of recFailureType is equal to REC_UNSUPPORTED_CACHE_MEMORY_SIZE. It identifies a controller having a cache of unsupported size. */
	public String getCacheMemorySizeUnsupported() {
		return this.cacheMemorySizeUnsupported;
	}
	/** @param x This field is present if the value of recFailureType is equal to REC_UNSUPPORTED_CACHE_MEMORY_SIZE. It identifies a controller having a cache of unsupported size. */
	public void setCacheMemorySizeUnsupported(String x) {
		this.cacheMemorySizeUnsupported = x;
	}

	/** This field is present only if the recFailureType is equal to REC_UNSUPPORTED_HOST_BOARD. It identifies an unsupported host board that is responsible for the other controller locking down. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the recFailureType is equal to REC_UNSUPPORTED_HOST_BOARD. It identifies an unsupported host board that is responsible for the other controller locking down." , required = false)
	@XmlElement(required = false)
	private String unsupportedHostBoard;

	/** @return This field is present only if the recFailureType is equal to REC_UNSUPPORTED_HOST_BOARD. It identifies an unsupported host board that is responsible for the other controller locking down. */
	public String getUnsupportedHostBoard() {
		return this.unsupportedHostBoard;
	}
	/** @param x This field is present only if the recFailureType is equal to REC_UNSUPPORTED_HOST_BOARD. It identifies an unsupported host board that is responsible for the other controller locking down. */
	public void setUnsupportedHostBoard(String x) {
		this.unsupportedHostBoard = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_UNSUPPORTED_MINIHUB. It contains the identification of the unsupported minihub. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_UNSUPPORTED_MINIHUB. It contains the identification of the unsupported minihub." , required = false)
	@XmlElement(required = false)
	private String miniHubUnsupported;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_UNSUPPORTED_MINIHUB. It contains the identification of the unsupported minihub. */
	public String getMiniHubUnsupported() {
		return this.miniHubUnsupported;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_UNSUPPORTED_MINIHUB. It contains the identification of the unsupported minihub. */
	public void setMiniHubUnsupported(String x) {
		this.miniHubUnsupported = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_UNSUPPORTED_TRAY. It contains the identification of the unsupported tray. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_UNSUPPORTED_TRAY. It contains the identification of the unsupported tray." , required = false)
	@XmlElement(required = false)
	private String unsupportedTray;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_UNSUPPORTED_TRAY. It contains the identification of the unsupported tray. */
	public String getUnsupportedTray() {
		return this.unsupportedTray;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_UNSUPPORTED_TRAY. It contains the identification of the unsupported tray. */
	public void setUnsupportedTray(String x) {
		this.unsupportedTray = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_UPS_ON_BATTERY. It contains the identification of the UPS component that has switched to battery power. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_UPS_ON_BATTERY. It contains the identification of the UPS component that has switched to battery power." , required = false)
	@XmlElement(required = false)
	private String upsOnBattery;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_UPS_ON_BATTERY. It contains the identification of the UPS component that has switched to battery power. */
	public String getUpsOnBattery() {
		return this.upsOnBattery;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_UPS_ON_BATTERY. It contains the identification of the UPS component that has switched to battery power. */
	public void setUpsOnBattery(String x) {
		this.upsOnBattery = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_USM_DATABASE_FULL. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_USM_DATABASE_FULL." , required = false)
	@XmlElement(required = false)
	private UsmError usmDbFullError;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_USM_DATABASE_FULL. */
	public UsmError getUsmDbFullError() {
		return this.usmDbFullError;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_USM_DATABASE_FULL. */
	public void setUsmDbFullError(UsmError x) {
		this.usmDbFullError = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_USM_UNREADABLE_SECTORS_EXIST. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_USM_UNREADABLE_SECTORS_EXIST." , required = false)
	@XmlElement(required = false)
	private UsmError usmExistError;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_USM_UNREADABLE_SECTORS_EXIST. */
	public UsmError getUsmExistError() {
		return this.usmExistError;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_USM_UNREADABLE_SECTORS_EXIST. */
	public void setUsmExistError(UsmError x) {
		this.usmExistError = x;
	}

	/** This field is present only if recFailureType is equal to REC_VG_CLONED. It identifies the cloned volume group. Also, it is safe to assume that the drives identified in the object graph as belonging to the volume group are valid. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if recFailureType is equal to REC_VG_CLONED. It identifies the cloned volume group. Also, it is safe to assume that the drives identified in the object graph as belonging to the volume group are valid." , required = false)
	@XmlElement(required = false)
	private String vgCloned;

	/** @return This field is present only if recFailureType is equal to REC_VG_CLONED. It identifies the cloned volume group. Also, it is safe to assume that the drives identified in the object graph as belonging to the volume group are valid. */
	public String getVgCloned() {
		return this.vgCloned;
	}
	/** @param x This field is present only if recFailureType is equal to REC_VG_CLONED. It identifies the cloned volume group. Also, it is safe to assume that the drives identified in the object graph as belonging to the volume group are valid. */
	public void setVgCloned(String x) {
		this.vgCloned = x;
	}

	/** This field is present only if recFailureType is equal to REC_VG_DRIVE_PART_OF_MULTIPLE_VGS. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the foreign drive; the volumeGroup field is a reference to the primary affected volume group (the one that needs to have its drives removed). Also, it is safe to assume that the drives identified in the object graph as belonging to the volume group are valid. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if recFailureType is equal to REC_VG_DRIVE_PART_OF_MULTIPLE_VGS. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the foreign drive; the volumeGroup field is a reference to the primary affected volume group (the one that needs to have its drives removed). Also, it is safe to assume that the drives identified in the object graph as belonging to the volume group are valid." , required = false)
	@XmlElement(required = false)
	private PvgRecoveryData vgDrivePartOfMultipleVgs;

	/** @return This field is present only if recFailureType is equal to REC_VG_DRIVE_PART_OF_MULTIPLE_VGS. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the foreign drive; the volumeGroup field is a reference to the primary affected volume group (the one that needs to have its drives removed). Also, it is safe to assume that the drives identified in the object graph as belonging to the volume group are valid. */
	public PvgRecoveryData getVgDrivePartOfMultipleVgs() {
		return this.vgDrivePartOfMultipleVgs;
	}
	/** @param x This field is present only if recFailureType is equal to REC_VG_DRIVE_PART_OF_MULTIPLE_VGS. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the foreign drive; the volumeGroup field is a reference to the primary affected volume group (the one that needs to have its drives removed). Also, it is safe to assume that the drives identified in the object graph as belonging to the volume group are valid. */
	public void setVgDrivePartOfMultipleVgs(PvgRecoveryData x) {
		this.vgDrivePartOfMultipleVgs = x;
	}

	/** This field is present only if recFailureType is equal to REC_VG_HAS_DRIVE_PART_OF_MULTIPLE_VGS. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the problem drive (the one having DriveStatusCause of DRIVE_CAUSE_INCOMPATIBLE_VG_HAS_DRIVE_PART_OF_MULTIPLE_VGS); the volumeGroup field is a reference to the foreign volume group. Also, it is safe to assume that the drives identified in the object graph as belonging to the foreign volume group are valid. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if recFailureType is equal to REC_VG_HAS_DRIVE_PART_OF_MULTIPLE_VGS. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the problem drive (the one having DriveStatusCause of DRIVE_CAUSE_INCOMPATIBLE_VG_HAS_DRIVE_PART_OF_MULTIPLE_VGS); the volumeGroup field is a reference to the foreign volume group. Also, it is safe to assume that the drives identified in the object graph as belonging to the foreign volume group are valid." , required = false)
	@XmlElement(required = false)
	private PvgRecoveryData vgHasDrivePartOfMultipleVgs;

	/** @return This field is present only if recFailureType is equal to REC_VG_HAS_DRIVE_PART_OF_MULTIPLE_VGS. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the problem drive (the one having DriveStatusCause of DRIVE_CAUSE_INCOMPATIBLE_VG_HAS_DRIVE_PART_OF_MULTIPLE_VGS); the volumeGroup field is a reference to the foreign volume group. Also, it is safe to assume that the drives identified in the object graph as belonging to the foreign volume group are valid. */
	public PvgRecoveryData getVgHasDrivePartOfMultipleVgs() {
		return this.vgHasDrivePartOfMultipleVgs;
	}
	/** @param x This field is present only if recFailureType is equal to REC_VG_HAS_DRIVE_PART_OF_MULTIPLE_VGS. It identifies the data that is pertinent to this recovery scenario. The drive field in this structure is a reference to the problem drive (the one having DriveStatusCause of DRIVE_CAUSE_INCOMPATIBLE_VG_HAS_DRIVE_PART_OF_MULTIPLE_VGS); the volumeGroup field is a reference to the foreign volume group. Also, it is safe to assume that the drives identified in the object graph as belonging to the foreign volume group are valid. */
	public void setVgHasDrivePartOfMultipleVgs(PvgRecoveryData x) {
		this.vgHasDrivePartOfMultipleVgs = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_VOLCOPY_FAILED. It contains the identification of the failed volume copy. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_VOLCOPY_FAILED. It contains the identification of the failed volume copy." , required = false)
	@XmlElement(required = false)
	private String failedVolumeCopy;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_VOLCOPY_FAILED. It contains the identification of the failed volume copy. */
	public String getFailedVolumeCopy() {
		return this.failedVolumeCopy;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_VOLCOPY_FAILED. It contains the identification of the failed volume copy. */
	public void setFailedVolumeCopy(String x) {
		this.failedVolumeCopy = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_VOLCOPY_NOT_COMPLIANT. The volume copy feature is out of compliance. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_VOLCOPY_NOT_COMPLIANT. The volume copy feature is out of compliance." , required = false)
	@XmlElement(required = false)
	private FeatureState volcopyFeature;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_VOLCOPY_NOT_COMPLIANT. The volume copy feature is out of compliance. */
	public FeatureState getVolcopyFeature() {
		return this.volcopyFeature;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_VOLCOPY_NOT_COMPLIANT. The volume copy feature is out of compliance. */
	public void setVolcopyFeature(FeatureState x) {
		this.volcopyFeature = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_VOLUME_GROUP_INCOMPLETE. It is a reference to a volume group that has transitioned to "incomplete" state. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_VOLUME_GROUP_INCOMPLETE. It is a reference to a volume group that has transitioned to \"incomplete\" state." , required = false)
	@XmlElement(required = false)
	private String incompleteVolumeGroupRef;

	/** @return This field is present only if the value of recFailureType is equal to REC_VOLUME_GROUP_INCOMPLETE. It is a reference to a volume group that has transitioned to "incomplete" state. */
	public String getIncompleteVolumeGroupRef() {
		return this.incompleteVolumeGroupRef;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_VOLUME_GROUP_INCOMPLETE. It is a reference to a volume group that has transitioned to "incomplete" state. */
	public void setIncompleteVolumeGroupRef(String x) {
		this.incompleteVolumeGroupRef = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_VOLUME_GROUP_MISSING. It is a reference to a volume group that has transitioned to "missing" state. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_VOLUME_GROUP_MISSING. It is a reference to a volume group that has transitioned to \"missing\" state." , required = false)
	@XmlElement(required = false)
	private String missingVolumeGroupRef;

	/** @return This field is present only if the value of recFailureType is equal to REC_VOLUME_GROUP_MISSING. It is a reference to a volume group that has transitioned to "missing" state. */
	public String getMissingVolumeGroupRef() {
		return this.missingVolumeGroupRef;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_VOLUME_GROUP_MISSING. It is a reference to a volume group that has transitioned to "missing" state. */
	public void setMissingVolumeGroupRef(String x) {
		this.missingVolumeGroupRef = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_VOLUME_GROUP_PARTIALLY_COMPLETE. It is a reference to a volume group that has transitioned to "partial" state. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_VOLUME_GROUP_PARTIALLY_COMPLETE. It is a reference to a volume group that has transitioned to \"partial\" state." , required = false)
	@XmlElement(required = false)
	private String partialPresentVolumeGroupRef;

	/** @return This field is present only if the value of recFailureType is equal to REC_VOLUME_GROUP_PARTIALLY_COMPLETE. It is a reference to a volume group that has transitioned to "partial" state. */
	public String getPartialPresentVolumeGroupRef() {
		return this.partialPresentVolumeGroupRef;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_VOLUME_GROUP_PARTIALLY_COMPLETE. It is a reference to a volume group that has transitioned to "partial" state. */
	public void setPartialPresentVolumeGroupRef(String x) {
		this.partialPresentVolumeGroupRef = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_VOLUME_HOT_SPARE_IN_USE. It contains the identification of a volume group that has experienced a drive failure, but has acquired a hot spare drive as a temporary replacement. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_VOLUME_HOT_SPARE_IN_USE. It contains the identification of a volume group that has experienced a drive failure, but has acquired a hot spare drive as a temporary replacement." , required = false)
	@XmlElement(required = false)
	private String volHotSpareInUse;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_VOLUME_HOT_SPARE_IN_USE. It contains the identification of a volume group that has experienced a drive failure, but has acquired a hot spare drive as a temporary replacement. */
	public String getVolHotSpareInUse() {
		return this.volHotSpareInUse;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_VOLUME_HOT_SPARE_IN_USE. It contains the identification of a volume group that has experienced a drive failure, but has acquired a hot spare drive as a temporary replacement. */
	public void setVolHotSpareInUse(String x) {
		this.volHotSpareInUse = x;
	}

	/** This field is only valid when recFailureType is equal to REC_INVALID_HOST_TYPE_INDEX. It is a reference to a Host in the storage partitions topology that has an invalid host type index, or a null reference if the problem applies to the default host type. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is only valid when recFailureType is equal to REC_INVALID_HOST_TYPE_INDEX. It is a reference to a Host in the storage partitions topology that has an invalid host type index, or a null reference if the problem applies to the default host type." , required = false)
	@XmlElement(required = false)
	private String hostRef;

	/** @return This field is only valid when recFailureType is equal to REC_INVALID_HOST_TYPE_INDEX. It is a reference to a Host in the storage partitions topology that has an invalid host type index, or a null reference if the problem applies to the default host type. */
	public String getHostRef() {
		return this.hostRef;
	}
	/** @param x This field is only valid when recFailureType is equal to REC_INVALID_HOST_TYPE_INDEX. It is a reference to a Host in the storage partitions topology that has an invalid host type index, or a null reference if the problem applies to the default host type. */
	public void setHostRef(String x) {
		this.hostRef = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_SECURITY_GET_KEY. It contains a list of drive references for the drives that are locked down and a lockKeyIDRef of the lockKey that is needed to unlock the drives. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_SECURITY_GET_KEY. It contains a list of drive references for the drives that are locked down and a lockKeyIDRef of the lockKey that is needed to unlock the drives." , required = false)
	@XmlElement(required = false)
	private SecurityKeyNeeded securityKeyNeeded;

	/** @return This field is present only if the value of recFailureType is equal to REC_SECURITY_GET_KEY. It contains a list of drive references for the drives that are locked down and a lockKeyIDRef of the lockKey that is needed to unlock the drives. */
	public SecurityKeyNeeded getSecurityKeyNeeded() {
		return this.securityKeyNeeded;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_SECURITY_GET_KEY. It contains a list of drive references for the drives that are locked down and a lockKeyIDRef of the lockKey that is needed to unlock the drives. */
	public void setSecurityKeyNeeded(SecurityKeyNeeded x) {
		this.securityKeyNeeded = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_SECURITY_NOT_COMPLIANT. The security feature is out of compliance. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_SECURITY_NOT_COMPLIANT. The security feature is out of compliance." , required = false)
	@XmlElement(required = false)
	private FeatureState fdeFeature;

	/** @return This field is present only if the value of recFailureType is equal to REC_SECURITY_NOT_COMPLIANT. The security feature is out of compliance. */
	public FeatureState getFdeFeature() {
		return this.fdeFeature;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_SECURITY_NOT_COMPLIANT. The security feature is out of compliance. */
	public void setFdeFeature(FeatureState x) {
		this.fdeFeature = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_REMOVED_CONTROLLER. The identification of the missing controller is returned. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_REMOVED_CONTROLLER. The identification of the missing controller is returned." , required = false)
	@XmlElement(required = false)
	private String removedCtrl;

	/** @return This field is present only if the value of recFailureType is equal to REC_REMOVED_CONTROLLER. The identification of the missing controller is returned. */
	public String getRemovedCtrl() {
		return this.removedCtrl;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_REMOVED_CONTROLLER. The identification of the missing controller is returned. */
	public void setRemovedCtrl(String x) {
		this.removedCtrl = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_UNSUCCESS_ISOLATION_REDUN_MISMATCH. The identification of the drive for which the redundancy mismatch was unsuccessfully isolated is returned. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_UNSUCCESS_ISOLATION_REDUN_MISMATCH. The identification of the drive for which the redundancy mismatch was unsuccessfully isolated is returned." , required = false)
	@XmlElement(required = false)
	private String driveUnsuccessIsolationRedunMismatch;

	/** @return This field is present only if the value of recFailureType is equal to REC_UNSUCCESS_ISOLATION_REDUN_MISMATCH. The identification of the drive for which the redundancy mismatch was unsuccessfully isolated is returned. */
	public String getDriveUnsuccessIsolationRedunMismatch() {
		return this.driveUnsuccessIsolationRedunMismatch;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_UNSUCCESS_ISOLATION_REDUN_MISMATCH. The identification of the drive for which the redundancy mismatch was unsuccessfully isolated is returned. */
	public void setDriveUnsuccessIsolationRedunMismatch(String x) {
		this.driveUnsuccessIsolationRedunMismatch = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_THRES_EXCDED_MISMATCH_CORRECTED. The identification of the drive for which the PFA threshold was exceeded but the redundancy mismatch corrected is returned. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_THRES_EXCDED_MISMATCH_CORRECTED. The identification of the drive for which the PFA threshold was exceeded but the redundancy mismatch corrected is returned." , required = false)
	@XmlElement(required = false)
	private String driveThresExcdedMismatchCorrected;

	/** @return This field is present only if the value of recFailureType is equal to REC_THRES_EXCDED_MISMATCH_CORRECTED. The identification of the drive for which the PFA threshold was exceeded but the redundancy mismatch corrected is returned. */
	public String getDriveThresExcdedMismatchCorrected() {
		return this.driveThresExcdedMismatchCorrected;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_THRES_EXCDED_MISMATCH_CORRECTED. The identification of the drive for which the PFA threshold was exceeded but the redundancy mismatch corrected is returned. */
	public void setDriveThresExcdedMismatchCorrected(String x) {
		this.driveThresExcdedMismatchCorrected = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_INACTIVE_HOST_PORT The identification of the inactive host port is returned. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_INACTIVE_HOST_PORT The identification of the inactive host port is returned." , required = false)
	@XmlElement(required = false)
	private String inactiveHostPort;

	/** @return This field is present only if the value of recFailureType is equal to REC_INACTIVE_HOST_PORT The identification of the inactive host port is returned. */
	public String getInactiveHostPort() {
		return this.inactiveHostPort;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_INACTIVE_HOST_PORT The identification of the inactive host port is returned. */
	public void setInactiveHostPort(String x) {
		this.inactiveHostPort = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_INACTIVE_INITIATOR. The identification of the inactive initiator is returned. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_INACTIVE_INITIATOR. The identification of the inactive initiator is returned." , required = false)
	@XmlElement(required = false)
	private String inactiveInitiator;

	/** @return This field is present only if the value of recFailureType is equal to REC_INACTIVE_INITIATOR. The identification of the inactive initiator is returned. */
	public String getInactiveInitiator() {
		return this.inactiveInitiator;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_INACTIVE_INITIATOR. The identification of the inactive initiator is returned. */
	public void setInactiveInitiator(String x) {
		this.inactiveInitiator = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_PROTECTION_INFORMATION_NOT_COMPLIANT. It indicates that the T10 Protection Information feature is out of compliance. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_PROTECTION_INFORMATION_NOT_COMPLIANT. It indicates that the T10 Protection Information feature is out of compliance." , required = false)
	@XmlElement(required = false)
	private FeatureState protectionInformationFeature;

	/** @return This field is present only if the value of recFailureType is equal to REC_PROTECTION_INFORMATION_NOT_COMPLIANT. It indicates that the T10 Protection Information feature is out of compliance. */
	public FeatureState getProtectionInformationFeature() {
		return this.protectionInformationFeature;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_PROTECTION_INFORMATION_NOT_COMPLIANT. It indicates that the T10 Protection Information feature is out of compliance. */
	public void setProtectionInformationFeature(FeatureState x) {
		this.protectionInformationFeature = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_PROTECTION_INFORMATION_NOT_SUPPORTED. The identification of the volume group with the protected volumes that cannot be supported by the storage array is returned. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_PROTECTION_INFORMATION_NOT_SUPPORTED. The identification of the volume group with the protected volumes that cannot be supported by the storage array is returned." , required = false)
	@XmlElement(required = false)
	private String protectionInformationNotSupported;

	/** @return This field is present only if the value of recFailureType is equal to REC_PROTECTION_INFORMATION_NOT_SUPPORTED. The identification of the volume group with the protected volumes that cannot be supported by the storage array is returned. */
	public String getProtectionInformationNotSupported() {
		return this.protectionInformationNotSupported;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_PROTECTION_INFORMATION_NOT_SUPPORTED. The identification of the volume group with the protected volumes that cannot be supported by the storage array is returned. */
	public void setProtectionInformationNotSupported(String x) {
		this.protectionInformationNotSupported = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_REPLACED_INSUFFICIENT_DRIVE_CAPACITY. It is a reference to an inserted drive that has insufficient capacity for the user data of the drive it is replacing. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_REPLACED_INSUFFICIENT_DRIVE_CAPACITY. It is a reference to an inserted drive that has insufficient capacity for the user data of the drive it is replacing." , required = false)
	@XmlElement(required = false)
	private String driveCapacityInsufficient;

	/** @return This field is present only if the value of recFailureType is equal to REC_REPLACED_INSUFFICIENT_DRIVE_CAPACITY. It is a reference to an inserted drive that has insufficient capacity for the user data of the drive it is replacing. */
	public String getDriveCapacityInsufficient() {
		return this.driveCapacityInsufficient;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_REPLACED_INSUFFICIENT_DRIVE_CAPACITY. It is a reference to an inserted drive that has insufficient capacity for the user data of the drive it is replacing. */
	public void setDriveCapacityInsufficient(String x) {
		this.driveCapacityInsufficient = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_DRAWER_OPENED. It is a reference to the open or removed drawer. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_DRAWER_OPENED. It is a reference to the open or removed drawer." , required = false)
	@XmlElement(required = false)
	private String openDrawerRef;

	/** @return This field is present only if the value of recFailureType is equal to REC_DRAWER_OPENED. It is a reference to the open or removed drawer. */
	public String getOpenDrawerRef() {
		return this.openDrawerRef;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_DRAWER_OPENED. It is a reference to the open or removed drawer. */
	public void setOpenDrawerRef(String x) {
		this.openDrawerRef = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_DRAWER_FAILED. It is a reference to the failed drawer. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_DRAWER_FAILED. It is a reference to the failed drawer." , required = false)
	@XmlElement(required = false)
	private String failedDrawerRef;

	/** @return This field is present only if the value of recFailureType is equal to REC_DRAWER_FAILED. It is a reference to the failed drawer. */
	public String getFailedDrawerRef() {
		return this.failedDrawerRef;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_DRAWER_FAILED. It is a reference to the failed drawer. */
	public void setFailedDrawerRef(String x) {
		this.failedDrawerRef = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_SSD_AT_END_OF_LIFE. It is a reference to the SSD drive that is at end of life. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_SSD_AT_END_OF_LIFE. It is a reference to the SSD drive that is at end of life." , required = false)
	@XmlElement(required = false)
	private String driveRef;

	/** @return This field is present only if the value of recFailureType is equal to REC_SSD_AT_END_OF_LIFE. It is a reference to the SSD drive that is at end of life. */
	public String getDriveRef() {
		return this.driveRef;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_SSD_AT_END_OF_LIFE. It is a reference to the SSD drive that is at end of life. */
	public void setDriveRef(String x) {
		this.driveRef = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_SSD_NOT_COMPLIANT. It indicates that the Solid State Disk Support feature is out of compliance. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_SSD_NOT_COMPLIANT. It indicates that the Solid State Disk Support feature is out of compliance." , required = false)
	@XmlElement(required = false)
	private FeatureState solidStateDisksFeature;

	/** @return This field is present only if the value of recFailureType is equal to REC_SSD_NOT_COMPLIANT. It indicates that the Solid State Disk Support feature is out of compliance. */
	public FeatureState getSolidStateDisksFeature() {
		return this.solidStateDisksFeature;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_SSD_NOT_COMPLIANT. It indicates that the Solid State Disk Support feature is out of compliance. */
	public void setSolidStateDisksFeature(FeatureState x) {
		this.solidStateDisksFeature = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_FIBRE_TRUNK_MISWIRE. It contains a structure that identifies both the incorrect and required cabling. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_FIBRE_TRUNK_MISWIRE. It contains a structure that identifies both the incorrect and required cabling." , required = false)
	@XmlElement(required = false)
	private FibreTrunkMiswire fibreTrunkMiswire;

	/** @return This field is present only if the value of recFailureType is equal to REC_FIBRE_TRUNK_MISWIRE. It contains a structure that identifies both the incorrect and required cabling. */
	public FibreTrunkMiswire getFibreTrunkMiswire() {
		return this.fibreTrunkMiswire;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_FIBRE_TRUNK_MISWIRE. It contains a structure that identifies both the incorrect and required cabling. */
	public void setFibreTrunkMiswire(FibreTrunkMiswire x) {
		this.fibreTrunkMiswire = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_FIBRE_TRUNK_INCOMPATIBLE_ESM. It contains a reference to an ESM that does not support trunking. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_FIBRE_TRUNK_INCOMPATIBLE_ESM. It contains a reference to an ESM that does not support trunking." , required = false)
	@XmlElement(required = false)
	private String fibreTrunkIncompatibleEsm;

	/** @return This field is present only if the value of recFailureType is equal to REC_FIBRE_TRUNK_INCOMPATIBLE_ESM. It contains a reference to an ESM that does not support trunking. */
	public String getFibreTrunkIncompatibleEsm() {
		return this.fibreTrunkIncompatibleEsm;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_FIBRE_TRUNK_INCOMPATIBLE_ESM. It contains a reference to an ESM that does not support trunking. */
	public void setFibreTrunkIncompatibleEsm(String x) {
		this.fibreTrunkIncompatibleEsm = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_DRIVE_SLOT_LIMIT_NOT_COMPLIANT. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_DRIVE_SLOT_LIMIT_NOT_COMPLIANT." , required = false)
	@XmlElement(required = false)
	private FeatureState driveSlotLimitFeature;

	/** @return This field is present only if the value of recFailureType is equal to REC_DRIVE_SLOT_LIMIT_NOT_COMPLIANT. */
	public FeatureState getDriveSlotLimitFeature() {
		return this.driveSlotLimitFeature;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_DRIVE_SLOT_LIMIT_NOT_COMPLIANT. */
	public void setDriveSlotLimitFeature(FeatureState x) {
		this.driveSlotLimitFeature = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_SECURITY_GET_NEW_KEY. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_SECURITY_GET_NEW_KEY." , required = false)
	@XmlElement(required = false)
	private int newKeySequence;

	/** @return This field is present only if the value of recFailureType is equal to REC_SECURITY_GET_NEW_KEY. */
	public int getNewKeySequence() {
		return this.newKeySequence;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_SECURITY_GET_NEW_KEY. */
	public void setNewKeySequence(int x) {
		this.newKeySequence = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_EXTERNAL_KMS_NOT_COMPLIANT. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_EXTERNAL_KMS_NOT_COMPLIANT." , required = false)
	@XmlElement(required = false)
	private FeatureState fdeProxyKeyMgmtFeature;

	/** @return This field is present only if the value of recFailureType is equal to REC_EXTERNAL_KMS_NOT_COMPLIANT. */
	public FeatureState getFdeProxyKeyMgmtFeature() {
		return this.fdeProxyKeyMgmtFeature;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_EXTERNAL_KMS_NOT_COMPLIANT. */
	public void setFdeProxyKeyMgmtFeature(FeatureState x) {
		this.fdeProxyKeyMgmtFeature = x;
	}

	/** This field is present only if the value of the RecoveryFailureType entry is equal to REC_SBB_VALIDATION_FAILURE. It contains the identification of the component that failed validation. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of the RecoveryFailureType entry is equal to REC_SBB_VALIDATION_FAILURE. It contains the identification of the component that failed validation." , required = false)
	@XmlElement(required = false)
	private String sbbValidationFailure;

	/** @return This field is present only if the value of the RecoveryFailureType entry is equal to REC_SBB_VALIDATION_FAILURE. It contains the identification of the component that failed validation. */
	public String getSbbValidationFailure() {
		return this.sbbValidationFailure;
	}
	/** @param x This field is present only if the value of the RecoveryFailureType entry is equal to REC_SBB_VALIDATION_FAILURE. It contains the identification of the component that failed validation. */
	public void setSbbValidationFailure(String x) {
		this.sbbValidationFailure = x;
	}

	/** This field is present only if the value of the RecoveryFailureType entry is equal to REC_INVALID_POWER_SUPPLY. It is a reference to a power supply that has failed validation. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of the RecoveryFailureType entry is equal to REC_INVALID_POWER_SUPPLY. It is a reference to a power supply that has failed validation." , required = false)
	@XmlElement(required = false)
	private String powerSupplyInvalid;

	/** @return This field is present only if the value of the RecoveryFailureType entry is equal to REC_INVALID_POWER_SUPPLY. It is a reference to a power supply that has failed validation. */
	public String getPowerSupplyInvalid() {
		return this.powerSupplyInvalid;
	}
	/** @param x This field is present only if the value of the RecoveryFailureType entry is equal to REC_INVALID_POWER_SUPPLY. It is a reference to a power supply that has failed validation. */
	public void setPowerSupplyInvalid(String x) {
		this.powerSupplyInvalid = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_ENCLOSURE_THERMAL_SHUTDOWN. It contains the identification of the tray that is powering down due to an over-temperature or under-temperature threshold condition. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_ENCLOSURE_THERMAL_SHUTDOWN. It contains the identification of the tray that is powering down due to an over-temperature or under-temperature threshold condition." , required = false)
	@XmlElement(required = false)
	private String enclosureThermalShutdown;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_ENCLOSURE_THERMAL_SHUTDOWN. It contains the identification of the tray that is powering down due to an over-temperature or under-temperature threshold condition. */
	public String getEnclosureThermalShutdown() {
		return this.enclosureThermalShutdown;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_ENCLOSURE_THERMAL_SHUTDOWN. It contains the identification of the tray that is powering down due to an over-temperature or under-temperature threshold condition. */
	public void setEnclosureThermalShutdown(String x) {
		this.enclosureThermalShutdown = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_UNSUPPORTED_PROTOCOL_CONNECTION. It identifies the drive using an unsupported protocol connection. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_UNSUPPORTED_PROTOCOL_CONNECTION. It identifies the drive using an unsupported protocol connection." , required = false)
	@XmlElement(required = false)
	private String unsupportedProtocolConnection;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_UNSUPPORTED_PROTOCOL_CONNECTION. It identifies the drive using an unsupported protocol connection. */
	public String getUnsupportedProtocolConnection() {
		return this.unsupportedProtocolConnection;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_UNSUPPORTED_PROTOCOL_CONNECTION. It identifies the drive using an unsupported protocol connection. */
	public void setUnsupportedProtocolConnection(String x) {
		this.unsupportedProtocolConnection = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_FAILED_TWI_BUS. It contains a reference to the tray with a failed TWI bus. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_FAILED_TWI_BUS. It contains a reference to the tray with a failed TWI bus." , required = false)
	@XmlElement(required = false)
	private String twiBusFailed;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_FAILED_TWI_BUS. It contains a reference to the tray with a failed TWI bus. */
	public String getTwiBusFailed() {
		return this.twiBusFailed;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_FAILED_TWI_BUS. It contains a reference to the tray with a failed TWI bus. */
	public void setTwiBusFailed(String x) {
		this.twiBusFailed = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_MISMATCHED_MIDPLANE_EEPROMS. It contains a reference to the tray in which the midplane EEPROMs are mismatched. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_MISMATCHED_MIDPLANE_EEPROMS. It contains a reference to the tray in which the midplane EEPROMs are mismatched." , required = false)
	@XmlElement(required = false)
	private String mismatchedEepromContents;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_MISMATCHED_MIDPLANE_EEPROMS. It contains a reference to the tray in which the midplane EEPROMs are mismatched. */
	public String getMismatchedEepromContents() {
		return this.mismatchedEepromContents;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_MISMATCHED_MIDPLANE_EEPROMS. It contains a reference to the tray in which the midplane EEPROMs are mismatched. */
	public void setMismatchedEepromContents(String x) {
		this.mismatchedEepromContents = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_UNSUPPORTED_CAPACITY. It contains a reference to the drive with an unsupported capacity. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_UNSUPPORTED_CAPACITY. It contains a reference to the drive with an unsupported capacity." , required = false)
	@XmlElement(required = false)
	private String unsupportedCapacityDrive;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_UNSUPPORTED_CAPACITY. It contains a reference to the drive with an unsupported capacity. */
	public String getUnsupportedCapacityDrive() {
		return this.unsupportedCapacityDrive;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_UNSUPPORTED_CAPACITY. It contains a reference to the drive with an unsupported capacity. */
	public void setUnsupportedCapacityDrive(String x) {
		this.unsupportedCapacityDrive = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_EVALUATION_LICENSE_EXPIRATION_IMMINENT. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_EVALUATION_LICENSE_EXPIRATION_IMMINENT." , required = false)
	@XmlElement(required = false)
	private String evalExpirationImminent;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_EVALUATION_LICENSE_EXPIRATION_IMMINENT. */
	public String getEvalExpirationImminent() {
		return this.evalExpirationImminent;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_EVALUATION_LICENSE_EXPIRATION_IMMINENT. */
	public void setEvalExpirationImminent(String x) {
		this.evalExpirationImminent = x;
	}

	/** Obsolete. This field is present only if the value of RecoveryFailureType value is equal to REC_EXTERNAL_KMS_KEY_INVALID. */
	@io.swagger.annotations.ApiModelProperty(value ="Obsolete. This field is present only if the value of RecoveryFailureType value is equal to REC_EXTERNAL_KMS_KEY_INVALID." , required = false)
	@XmlElement(required = false)
	private String keyInvalid;

	/** @return Obsolete. This field is present only if the value of RecoveryFailureType value is equal to REC_EXTERNAL_KMS_KEY_INVALID. */
	public String getKeyInvalid() {
		return this.keyInvalid;
	}
	/** @param x Obsolete. This field is present only if the value of RecoveryFailureType value is equal to REC_EXTERNAL_KMS_KEY_INVALID. */
	public void setKeyInvalid(String x) {
		this.keyInvalid = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_MULTIPLE_MISMATCHED_KEY_IDS_FOUND. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_MULTIPLE_MISMATCHED_KEY_IDS_FOUND." , required = false)
	@XmlElement(required = false)
	private String multipleMismatchedKeys;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_MULTIPLE_MISMATCHED_KEY_IDS_FOUND. */
	public String getMultipleMismatchedKeys() {
		return this.multipleMismatchedKeys;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_MULTIPLE_MISMATCHED_KEY_IDS_FOUND. */
	public void setMultipleMismatchedKeys(String x) {
		this.multipleMismatchedKeys = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_SECURITY_KEY_VALIDATION_LOCK. It identifies a controller that will no longer accept key validation requests. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_SECURITY_KEY_VALIDATION_LOCK. It identifies a controller that will no longer accept key validation requests." , required = false)
	@XmlElement(required = false)
	private String keyValidationLock;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_SECURITY_KEY_VALIDATION_LOCK. It identifies a controller that will no longer accept key validation requests. */
	public String getKeyValidationLock() {
		return this.keyValidationLock;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_SECURITY_KEY_VALIDATION_LOCK. It identifies a controller that will no longer accept key validation requests. */
	public void setKeyValidationLock(String x) {
		this.keyValidationLock = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_CACHE_DATA_LOSS. It identifies a controller that has lost data in cache; along with a list of volumes that are offline as a result. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_CACHE_DATA_LOSS. It identifies a controller that has lost data in cache; along with a list of volumes that are offline as a result." , required = false)
	@XmlElement(required = false)
	private ControllerVolumeList cacheDataLoss;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_CACHE_DATA_LOSS. It identifies a controller that has lost data in cache; along with a list of volumes that are offline as a result. */
	public ControllerVolumeList getCacheDataLoss() {
		return this.cacheDataLoss;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_CACHE_DATA_LOSS. It identifies a controller that has lost data in cache; along with a list of volumes that are offline as a result. */
	public void setCacheDataLoss(ControllerVolumeList x) {
		this.cacheDataLoss = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_FEATURE_NOT_COMPLIANT. It identifies the feature that is out of compliance.. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_FEATURE_NOT_COMPLIANT. It identifies the feature that is out of compliance.." , required = false)
	@XmlElement(required = false)
	private String featureOutOfCompliance;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_FEATURE_NOT_COMPLIANT. It identifies the feature that is out of compliance.. */
	public String getFeatureOutOfCompliance() {
		return this.featureOutOfCompliance;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_FEATURE_NOT_COMPLIANT. It identifies the feature that is out of compliance.. */
	public void setFeatureOutOfCompliance(String x) {
		this.featureOutOfCompliance = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_INCOMPATIBLE_PI_TYPE. It identifies the drive that is incompatible. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_INCOMPATIBLE_PI_TYPE. It identifies the drive that is incompatible." , required = false)
	@XmlElement(required = false)
	private String driveIncompatiblePItype;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_INCOMPATIBLE_PI_TYPE. It identifies the drive that is incompatible. */
	public String getDriveIncompatiblePItype() {
		return this.driveIncompatiblePItype;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_INCOMPATIBLE_PI_TYPE. It identifies the drive that is incompatible. */
	public void setDriveIncompatiblePItype(String x) {
		this.driveIncompatiblePItype = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_DRAWER_DEGRADED. It identifies the degraded drawer. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_DRAWER_DEGRADED. It identifies the degraded drawer." , required = false)
	@XmlElement(required = false)
	private String degradedDrawerRef;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_DRAWER_DEGRADED. It identifies the degraded drawer. */
	public String getDegradedDrawerRef() {
		return this.degradedDrawerRef;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_DRAWER_DEGRADED. It identifies the degraded drawer. */
	public void setDegradedDrawerRef(String x) {
		this.degradedDrawerRef = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_IOC_DIAG_FAIL. It identifies the controller that failed IOC diagnostic testing. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_IOC_DIAG_FAIL. It identifies the controller that failed IOC diagnostic testing." , required = false)
	@XmlElement(required = false)
	private String ctlrIocDiagFailed;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_IOC_DIAG_FAIL. It identifies the controller that failed IOC diagnostic testing. */
	public String getCtlrIocDiagFailed() {
		return this.ctlrIocDiagFailed;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_IOC_DIAG_FAIL. It identifies the controller that failed IOC diagnostic testing. */
	public void setCtlrIocDiagFailed(String x) {
		this.ctlrIocDiagFailed = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_INVALID_SATA_FLASH_CONFIGURATION. It identifies a controller with an invalid SATA flash drive configuration. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_INVALID_SATA_FLASH_CONFIGURATION. It identifies a controller with an invalid SATA flash drive configuration." , required = false)
	@XmlElement(required = false)
	private String invalidSataFlashConfig;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_INVALID_SATA_FLASH_CONFIGURATION. It identifies a controller with an invalid SATA flash drive configuration. */
	public String getInvalidSataFlashConfig() {
		return this.invalidSataFlashConfig;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_INVALID_SATA_FLASH_CONFIGURATION. It identifies a controller with an invalid SATA flash drive configuration. */
	public void setInvalidSataFlashConfig(String x) {
		this.invalidSataFlashConfig = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_OFFLINE_CTL_IOC_FAIL. It identifies the controller that failed IOC diagnostic testing and which is now offline. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_OFFLINE_CTL_IOC_FAIL. It identifies the controller that failed IOC diagnostic testing and which is now offline." , required = false)
	@XmlElement(required = false)
	private String offlineCtlrIocDiagFailed;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_OFFLINE_CTL_IOC_FAIL. It identifies the controller that failed IOC diagnostic testing and which is now offline. */
	public String getOfflineCtlrIocDiagFailed() {
		return this.offlineCtlrIocDiagFailed;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_OFFLINE_CTL_IOC_FAIL. It identifies the controller that failed IOC diagnostic testing and which is now offline. */
	public void setOfflineCtlrIocDiagFailed(String x) {
		this.offlineCtlrIocDiagFailed = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_SAS_PHY_DISABLED_LOCAL_WIDE_PORT_DEGRADED. It identifies the channel. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_SAS_PHY_DISABLED_LOCAL_WIDE_PORT_DEGRADED. It identifies the channel." , required = false)
	@XmlElement(required = false)
	private int chanSasPhyDisabledLocalWidePortDegraded;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_SAS_PHY_DISABLED_LOCAL_WIDE_PORT_DEGRADED. It identifies the channel. */
	public int getChanSasPhyDisabledLocalWidePortDegraded() {
		return this.chanSasPhyDisabledLocalWidePortDegraded;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_SAS_PHY_DISABLED_LOCAL_WIDE_PORT_DEGRADED. It identifies the channel. */
	public void setChanSasPhyDisabledLocalWidePortDegraded(int x) {
		this.chanSasPhyDisabledLocalWidePortDegraded = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_SAS_PHY_DISABLED_SHARED_WIDE_PORT_DEGRADED. It identifies the channel. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_SAS_PHY_DISABLED_SHARED_WIDE_PORT_DEGRADED. It identifies the channel." , required = false)
	@XmlElement(required = false)
	private int chanSasPhyDisabledSharedWidePortDegraded;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_SAS_PHY_DISABLED_SHARED_WIDE_PORT_DEGRADED. It identifies the channel. */
	public int getChanSasPhyDisabledSharedWidePortDegraded() {
		return this.chanSasPhyDisabledSharedWidePortDegraded;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_SAS_PHY_DISABLED_SHARED_WIDE_PORT_DEGRADED. It identifies the channel. */
	public void setChanSasPhyDisabledSharedWidePortDegraded(int x) {
		this.chanSasPhyDisabledSharedWidePortDegraded = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_DRAWER_INVALID. It identifies the invalid (unsupported) drawer. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_DRAWER_INVALID. It identifies the invalid (unsupported) drawer." , required = false)
	@XmlElement(required = false)
	private String drawerInvalid;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_DRAWER_INVALID. It identifies the invalid (unsupported) drawer. */
	public String getDrawerInvalid() {
		return this.drawerInvalid;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_DRAWER_INVALID. It identifies the invalid (unsupported) drawer. */
	public void setDrawerInvalid(String x) {
		this.drawerInvalid = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_DRAWER_REMOVED. It identifies the drawer that has been removed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_DRAWER_REMOVED. It identifies the drawer that has been removed." , required = false)
	@XmlElement(required = false)
	private String drawerRemoved;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_DRAWER_REMOVED. It identifies the drawer that has been removed. */
	public String getDrawerRemoved() {
		return this.drawerRemoved;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_DRAWER_REMOVED. It identifies the drawer that has been removed. */
	public void setDrawerRemoved(String x) {
		this.drawerRemoved = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_UNSUPPORTED_INTERPOSER_FW_VERSION. It identifies a drive that has an unsupported interposer firmware version. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_UNSUPPORTED_INTERPOSER_FW_VERSION. It identifies a drive that has an unsupported interposer firmware version." , required = false)
	@XmlElement(required = false)
	private String driveUnsupportedInterposerFwVersion;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_UNSUPPORTED_INTERPOSER_FW_VERSION. It identifies a drive that has an unsupported interposer firmware version. */
	public String getDriveUnsupportedInterposerFwVersion() {
		return this.driveUnsupportedInterposerFwVersion;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_UNSUPPORTED_INTERPOSER_FW_VERSION. It identifies a drive that has an unsupported interposer firmware version. */
	public void setDriveUnsupportedInterposerFwVersion(String x) {
		this.driveUnsupportedInterposerFwVersion = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_REDUNDANCY_GROUP_NOT_CONSISTENT_DURING_RECONFIG. It identifies a volume that has been taken offline due to the detection of an internal consistency problem. After the reconfiguration completes the data will be consistent, but may be corrupt. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_REDUNDANCY_GROUP_NOT_CONSISTENT_DURING_RECONFIG. It identifies a volume that has been taken offline due to the detection of an internal consistency problem. After the reconfiguration completes the data will be consistent, but may be corrupt." , required = false)
	@XmlElement(required = false)
	private String volumeOfflineDuringReconfig;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_REDUNDANCY_GROUP_NOT_CONSISTENT_DURING_RECONFIG. It identifies a volume that has been taken offline due to the detection of an internal consistency problem. After the reconfiguration completes the data will be consistent, but may be corrupt. */
	public String getVolumeOfflineDuringReconfig() {
		return this.volumeOfflineDuringReconfig;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_REDUNDANCY_GROUP_NOT_CONSISTENT_DURING_RECONFIG. It identifies a volume that has been taken offline due to the detection of an internal consistency problem. After the reconfiguration completes the data will be consistent, but may be corrupt. */
	public void setVolumeOfflineDuringReconfig(String x) {
		this.volumeOfflineDuringReconfig = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_SNAPSHOT_ROLLBACK_PAUSED. It is a reference to a snapshot that is currently paused. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_SNAPSHOT_ROLLBACK_PAUSED. It is a reference to a snapshot that is currently paused." , required = false)
	@XmlElement(required = false)
	private String snapRollbackPaused;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_SNAPSHOT_ROLLBACK_PAUSED. It is a reference to a snapshot that is currently paused. */
	public String getSnapRollbackPaused() {
		return this.snapRollbackPaused;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_SNAPSHOT_ROLLBACK_PAUSED. It is a reference to a snapshot that is currently paused. */
	public void setSnapRollbackPaused(String x) {
		this.snapRollbackPaused = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_PIT_ROLLBACK_PAUSED. It contains a reference to the PiT Group with a paused rollback operation. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_PIT_ROLLBACK_PAUSED. It contains a reference to the PiT Group with a paused rollback operation." , required = false)
	@XmlElement(required = false)
	private String pitRollbackPaused;

	/** @return This field is present only if the value of recFailureType is equal to REC_PIT_ROLLBACK_PAUSED. It contains a reference to the PiT Group with a paused rollback operation. */
	public String getPitRollbackPaused() {
		return this.pitRollbackPaused;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_PIT_ROLLBACK_PAUSED. It contains a reference to the PiT Group with a paused rollback operation. */
	public void setPitRollbackPaused(String x) {
		this.pitRollbackPaused = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_PIT_GROUP_REPOSITORY_OVER_THRESHOLD. It contains a reference to a PiT Group with a repository capacity over the warning threshold. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_PIT_GROUP_REPOSITORY_OVER_THRESHOLD. It contains a reference to a PiT Group with a repository capacity over the warning threshold." , required = false)
	@XmlElement(required = false)
	private String pitGroupOverWarnThreshold;

	/** @return This field is present only if the value of recFailureType is equal to REC_PIT_GROUP_REPOSITORY_OVER_THRESHOLD. It contains a reference to a PiT Group with a repository capacity over the warning threshold. */
	public String getPitGroupOverWarnThreshold() {
		return this.pitGroupOverWarnThreshold;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_PIT_GROUP_REPOSITORY_OVER_THRESHOLD. It contains a reference to a PiT Group with a repository capacity over the warning threshold. */
	public void setPitGroupOverWarnThreshold(String x) {
		this.pitGroupOverWarnThreshold = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_PIT_VIEW_REPOSITORY_OVER_THRESHOLD. It contains a reference to a PiT View with a repository over the warning threshold. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_PIT_VIEW_REPOSITORY_OVER_THRESHOLD. It contains a reference to a PiT View with a repository over the warning threshold." , required = false)
	@XmlElement(required = false)
	private String pitViewOverWarnThreshold;

	/** @return This field is present only if the value of recFailureType is equal to REC_PIT_VIEW_REPOSITORY_OVER_THRESHOLD. It contains a reference to a PiT View with a repository over the warning threshold. */
	public String getPitViewOverWarnThreshold() {
		return this.pitViewOverWarnThreshold;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_PIT_VIEW_REPOSITORY_OVER_THRESHOLD. It contains a reference to a PiT View with a repository over the warning threshold. */
	public void setPitViewOverWarnThreshold(String x) {
		this.pitViewOverWarnThreshold = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_PIT_GROUP_REPOSITORY_FULL. It contains a reference to a PiT Group with a full repository. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_PIT_GROUP_REPOSITORY_FULL. It contains a reference to a PiT Group with a full repository." , required = false)
	@XmlElement(required = false)
	private String pitGroupRepositoryFull;

	/** @return This field is present only if the value of recFailureType is equal to REC_PIT_GROUP_REPOSITORY_FULL. It contains a reference to a PiT Group with a full repository. */
	public String getPitGroupRepositoryFull() {
		return this.pitGroupRepositoryFull;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_PIT_GROUP_REPOSITORY_FULL. It contains a reference to a PiT Group with a full repository. */
	public void setPitGroupRepositoryFull(String x) {
		this.pitGroupRepositoryFull = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_PIT_VIEW_REPOSITORY_FULL. It contains a reference to a PiT View with a full repository. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_PIT_VIEW_REPOSITORY_FULL. It contains a reference to a PiT View with a full repository." , required = false)
	@XmlElement(required = false)
	private String pitViewRepositoryFull;

	/** @return This field is present only if the value of recFailureType is equal to REC_PIT_VIEW_REPOSITORY_FULL. It contains a reference to a PiT View with a full repository. */
	public String getPitViewRepositoryFull() {
		return this.pitViewRepositoryFull;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_PIT_VIEW_REPOSITORY_FULL. It contains a reference to a PiT View with a full repository. */
	public void setPitViewRepositoryFull(String x) {
		this.pitViewRepositoryFull = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_PIT_GROUP_FAILED. It contains a reference to a PiT Group that has failed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_PIT_GROUP_FAILED. It contains a reference to a PiT Group that has failed." , required = false)
	@XmlElement(required = false)
	private String pitGroupFailed;

	/** @return This field is present only if the value of recFailureType is equal to REC_PIT_GROUP_FAILED. It contains a reference to a PiT Group that has failed. */
	public String getPitGroupFailed() {
		return this.pitGroupFailed;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_PIT_GROUP_FAILED. It contains a reference to a PiT Group that has failed. */
	public void setPitGroupFailed(String x) {
		this.pitGroupFailed = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_PIT_VIEW_FAILED. It contains a reference to a PiT View that has failed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_PIT_VIEW_FAILED. It contains a reference to a PiT View that has failed." , required = false)
	@XmlElement(required = false)
	private String pitViewFailed;

	/** @return This field is present only if the value of recFailureType is equal to REC_PIT_VIEW_FAILED. It contains a reference to a PiT View that has failed. */
	public String getPitViewFailed() {
		return this.pitViewFailed;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_PIT_VIEW_FAILED. It contains a reference to a PiT View that has failed. */
	public void setPitViewFailed(String x) {
		this.pitViewFailed = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_PIT_PURGED. It contains a reference to a PiT that has been purged to free PiT group repository capacity. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_PIT_PURGED. It contains a reference to a PiT that has been purged to free PiT group repository capacity." , required = false)
	@XmlElement(required = false)
	private String pitPurged;

	/** @return This field is present only if the value of recFailureType is equal to REC_PIT_PURGED. It contains a reference to a PiT that has been purged to free PiT group repository capacity. */
	public String getPitPurged() {
		return this.pitPurged;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_PIT_PURGED. It contains a reference to a PiT that has been purged to free PiT group repository capacity. */
	public void setPitPurged(String x) {
		this.pitPurged = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ARVM_DEGRADED_MIRROR_GROUP. It contains information about a mirror group fault condition. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ARVM_DEGRADED_MIRROR_GROUP. It contains information about a mirror group fault condition." , required = false)
	@XmlElement(required = false)
	private AsyncMirrorGroupFaultIndication degradedAsyncMirrorGroup;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ARVM_DEGRADED_MIRROR_GROUP. It contains information about a mirror group fault condition. */
	public AsyncMirrorGroupFaultIndication getDegradedAsyncMirrorGroup() {
		return this.degradedAsyncMirrorGroup;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ARVM_DEGRADED_MIRROR_GROUP. It contains information about a mirror group fault condition. */
	public void setDegradedAsyncMirrorGroup(AsyncMirrorGroupFaultIndication x) {
		this.degradedAsyncMirrorGroup = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SYNC_INTERVAL_TIME_OVER_THRESHOLD. It contains information about a mirror group fault condition. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SYNC_INTERVAL_TIME_OVER_THRESHOLD. It contains information about a mirror group fault condition." , required = false)
	@XmlElement(required = false)
	private AsyncMirrorGroupFaultIndication syncIntervalTimeExceeded;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SYNC_INTERVAL_TIME_OVER_THRESHOLD. It contains information about a mirror group fault condition. */
	public AsyncMirrorGroupFaultIndication getSyncIntervalTimeExceeded() {
		return this.syncIntervalTimeExceeded;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SYNC_INTERVAL_TIME_OVER_THRESHOLD. It contains information about a mirror group fault condition. */
	public void setSyncIntervalTimeExceeded(AsyncMirrorGroupFaultIndication x) {
		this.syncIntervalTimeExceeded = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ARVM_FAILED_MIRROR. It identifies the Async Mirror Group member that failed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ARVM_FAILED_MIRROR. It identifies the Async Mirror Group member that failed." , required = false)
	@XmlElement(required = false)
	private String failedAsyncMirror;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ARVM_FAILED_MIRROR. It identifies the Async Mirror Group member that failed. */
	public String getFailedAsyncMirror() {
		return this.failedAsyncMirror;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ARVM_FAILED_MIRROR. It identifies the Async Mirror Group member that failed. */
	public void setFailedAsyncMirror(String x) {
		this.failedAsyncMirror = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ARVM_REPOSITORY_OVER_WARN_THRESHOLD. It contains information about a mirror group member fault condition. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ARVM_REPOSITORY_OVER_WARN_THRESHOLD. It contains information about a mirror group member fault condition." , required = false)
	@XmlElement(required = false)
	private AsyncMirrorGroupMemberFaultIndication asyncMirrorRepositoryOverWarnThreshold;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ARVM_REPOSITORY_OVER_WARN_THRESHOLD. It contains information about a mirror group member fault condition. */
	public AsyncMirrorGroupMemberFaultIndication getAsyncMirrorRepositoryOverWarnThreshold() {
		return this.asyncMirrorRepositoryOverWarnThreshold;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ARVM_REPOSITORY_OVER_WARN_THRESHOLD. It contains information about a mirror group member fault condition. */
	public void setAsyncMirrorRepositoryOverWarnThreshold(AsyncMirrorGroupMemberFaultIndication x) {
		this.asyncMirrorRepositoryOverWarnThreshold = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ARVM_MIRROR_GROUP_ROLE_CONFLICT. It identifies the Async Mirror Group with a role conflict. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ARVM_MIRROR_GROUP_ROLE_CONFLICT. It identifies the Async Mirror Group with a role conflict." , required = false)
	@XmlElement(required = false)
	private String roleConflictMirrorGroup;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ARVM_MIRROR_GROUP_ROLE_CONFLICT. It identifies the Async Mirror Group with a role conflict. */
	public String getRoleConflictMirrorGroup() {
		return this.roleConflictMirrorGroup;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ARVM_MIRROR_GROUP_ROLE_CONFLICT. It identifies the Async Mirror Group with a role conflict. */
	public void setRoleConflictMirrorGroup(String x) {
		this.roleConflictMirrorGroup = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ARVM_MIRROR_GROUP_RECOVERY_POINT_LOST. It identifies the Async Mirror Group that lost a recovery point. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ARVM_MIRROR_GROUP_RECOVERY_POINT_LOST. It identifies the Async Mirror Group that lost a recovery point." , required = false)
	@XmlElement(required = false)
	private String recoveryPointLostGroup;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ARVM_MIRROR_GROUP_RECOVERY_POINT_LOST. It identifies the Async Mirror Group that lost a recovery point. */
	public String getRecoveryPointLostGroup() {
		return this.recoveryPointLostGroup;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ARVM_MIRROR_GROUP_RECOVERY_POINT_LOST. It identifies the Async Mirror Group that lost a recovery point. */
	public void setRecoveryPointLostGroup(String x) {
		this.recoveryPointLostGroup = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_INCOMPATIBLE_VOLUME_GROUP_SECURITY. It identifies the volume group with incompatible security. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_INCOMPATIBLE_VOLUME_GROUP_SECURITY. It identifies the volume group with incompatible security." , required = false)
	@XmlElement(required = false)
	private String incompatibleVolumeGroupSecurity;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_INCOMPATIBLE_VOLUME_GROUP_SECURITY. It identifies the volume group with incompatible security. */
	public String getIncompatibleVolumeGroupSecurity() {
		return this.incompatibleVolumeGroupSecurity;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_INCOMPATIBLE_VOLUME_GROUP_SECURITY. It identifies the volume group with incompatible security. */
	public void setIncompatibleVolumeGroupSecurity(String x) {
		this.incompatibleVolumeGroupSecurity = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ARVM_ORPHAN_GROUP. It identifies the orphaned mirror group. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ARVM_ORPHAN_GROUP. It identifies the orphaned mirror group." , required = false)
	@XmlElement(required = false)
	private String orphanMirrorGroup;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ARVM_ORPHAN_GROUP. It identifies the orphaned mirror group. */
	public String getOrphanMirrorGroup() {
		return this.orphanMirrorGroup;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ARVM_ORPHAN_GROUP. It identifies the orphaned mirror group. */
	public void setOrphanMirrorGroup(String x) {
		this.orphanMirrorGroup = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ARVM_ORPHAN_MEMBER. It identifies the orphaned member. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ARVM_ORPHAN_MEMBER. It identifies the orphaned member." , required = false)
	@XmlElement(required = false)
	private String orphanMirrorMember;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ARVM_ORPHAN_MEMBER. It identifies the orphaned member. */
	public String getOrphanMirrorMember() {
		return this.orphanMirrorMember;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ARVM_ORPHAN_MEMBER. It identifies the orphaned member. */
	public void setOrphanMirrorMember(String x) {
		this.orphanMirrorMember = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_PARTIALLY_PRESENT. It contains the identification of the Disk Pool that has transitioned to Partial state.. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_PARTIALLY_PRESENT. It contains the identification of the Disk Pool that has transitioned to Partial state.." , required = false)
	@XmlElement(required = false)
	private String diskPoolStatePartial;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_PARTIALLY_PRESENT. It contains the identification of the Disk Pool that has transitioned to Partial state.. */
	public String getDiskPoolStatePartial() {
		return this.diskPoolStatePartial;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_PARTIALLY_PRESENT. It contains the identification of the Disk Pool that has transitioned to Partial state.. */
	public void setDiskPoolStatePartial(String x) {
		this.diskPoolStatePartial = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_INCOMPLETE. It contains the identification of the Disk Pool that has transitioned to Incomplete state. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_INCOMPLETE. It contains the identification of the Disk Pool that has transitioned to Incomplete state." , required = false)
	@XmlElement(required = false)
	private String diskPoolStateIncomplete;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_INCOMPLETE. It contains the identification of the Disk Pool that has transitioned to Incomplete state. */
	public String getDiskPoolStateIncomplete() {
		return this.diskPoolStateIncomplete;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_INCOMPLETE. It contains the identification of the Disk Pool that has transitioned to Incomplete state. */
	public void setDiskPoolStateIncomplete(String x) {
		this.diskPoolStateIncomplete = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_MISSING. It contains the identification of the Disk Pool that has transitioned to Missing state. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_MISSING. It contains the identification of the Disk Pool that has transitioned to Missing state." , required = false)
	@XmlElement(required = false)
	private String diskPoolStateMissing;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_MISSING. It contains the identification of the Disk Pool that has transitioned to Missing state. */
	public String getDiskPoolStateMissing() {
		return this.diskPoolStateMissing;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_MISSING. It contains the identification of the Disk Pool that has transitioned to Missing state. */
	public void setDiskPoolStateMissing(String x) {
		this.diskPoolStateMissing = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_RECONSTRUCTION_DRIVE_COUNT_BELOW_THRESHOLD. It contains the identification of the Disk Pool with space reserved for reconstructions that has fallen below the reconstruction reserved disk count value. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_RECONSTRUCTION_DRIVE_COUNT_BELOW_THRESHOLD. It contains the identification of the Disk Pool with space reserved for reconstructions that has fallen below the reconstruction reserved disk count value." , required = false)
	@XmlElement(required = false)
	private String diskPoolReconstruction;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_RECONSTRUCTION_DRIVE_COUNT_BELOW_THRESHOLD. It contains the identification of the Disk Pool with space reserved for reconstructions that has fallen below the reconstruction reserved disk count value. */
	public String getDiskPoolReconstruction() {
		return this.diskPoolReconstruction;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_RECONSTRUCTION_DRIVE_COUNT_BELOW_THRESHOLD. It contains the identification of the Disk Pool with space reserved for reconstructions that has fallen below the reconstruction reserved disk count value. */
	public void setDiskPoolReconstruction(String x) {
		this.diskPoolReconstruction = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_UTILIZATION_WARNING. It contains the identification of the Disk Pool that has exceeded the Utilization Threshold Warning attribute. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_UTILIZATION_WARNING. It contains the identification of the Disk Pool that has exceeded the Utilization Threshold Warning attribute." , required = false)
	@XmlElement(required = false)
	private String diskPoolUtilizationWarning;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_UTILIZATION_WARNING. It contains the identification of the Disk Pool that has exceeded the Utilization Threshold Warning attribute. */
	public String getDiskPoolUtilizationWarning() {
		return this.diskPoolUtilizationWarning;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_UTILIZATION_WARNING. It contains the identification of the Disk Pool that has exceeded the Utilization Threshold Warning attribute. */
	public void setDiskPoolUtilizationWarning(String x) {
		this.diskPoolUtilizationWarning = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_UTILIZATION_CRITICAL. It contains the identification of the Disk Pool that has exceeded the Utilization Threshold Critical attribute. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_UTILIZATION_CRITICAL. It contains the identification of the Disk Pool that has exceeded the Utilization Threshold Critical attribute." , required = false)
	@XmlElement(required = false)
	private String diskPoolUtilizationCritical;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_UTILIZATION_CRITICAL. It contains the identification of the Disk Pool that has exceeded the Utilization Threshold Critical attribute. */
	public String getDiskPoolUtilizationCritical() {
		return this.diskPoolUtilizationCritical;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_UTILIZATION_CRITICAL. It contains the identification of the Disk Pool that has exceeded the Utilization Threshold Critical attribute. */
	public void setDiskPoolUtilizationCritical(String x) {
		this.diskPoolUtilizationCritical = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_PENDING_PIT_CREATION_FAILED. It contains a reference to the PiT Group. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_PENDING_PIT_CREATION_FAILED. It contains a reference to the PiT Group." , required = false)
	@XmlElement(required = false)
	private String pitGroupPendingCreateFailed;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_PENDING_PIT_CREATION_FAILED. It contains a reference to the PiT Group. */
	public String getPitGroupPendingCreateFailed() {
		return this.pitGroupPendingCreateFailed;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_PENDING_PIT_CREATION_FAILED. It contains a reference to the PiT Group. */
	public void setPitGroupPendingCreateFailed(String x) {
		this.pitGroupPendingCreateFailed = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_PENDING_CGPIT_CREATION_FAILED. It contains a reference to the PiT Consistency Group. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_PENDING_CGPIT_CREATION_FAILED. It contains a reference to the PiT Consistency Group." , required = false)
	@XmlElement(required = false)
	private String cgPendingCreateFailed;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_PENDING_CGPIT_CREATION_FAILED. It contains a reference to the PiT Consistency Group. */
	public String getCgPendingCreateFailed() {
		return this.cgPendingCreateFailed;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_PENDING_CGPIT_CREATION_FAILED. It contains a reference to the PiT Consistency Group. */
	public void setCgPendingCreateFailed(String x) {
		this.cgPendingCreateFailed = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_TPV_REPOSITORY_OVER_THRESHOLD. It identifies a thin volume with a repository over the threshold value. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_TPV_REPOSITORY_OVER_THRESHOLD. It identifies a thin volume with a repository over the threshold value." , required = false)
	@XmlElement(required = false)
	private String thinVolumeOverThreshold;

	/** @return This field is present only if the value of recFailureType is equal to REC_TPV_REPOSITORY_OVER_THRESHOLD. It identifies a thin volume with a repository over the threshold value. */
	public String getThinVolumeOverThreshold() {
		return this.thinVolumeOverThreshold;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_TPV_REPOSITORY_OVER_THRESHOLD. It identifies a thin volume with a repository over the threshold value. */
	public void setThinVolumeOverThreshold(String x) {
		this.thinVolumeOverThreshold = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_TPV_REPOSITORY_FULL. It identifies a thin volume with a full repository. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_TPV_REPOSITORY_FULL. It identifies a thin volume with a full repository." , required = false)
	@XmlElement(required = false)
	private String thinVolumeRepositoryFull;

	/** @return This field is present only if the value of recFailureType is equal to REC_TPV_REPOSITORY_FULL. It identifies a thin volume with a full repository. */
	public String getThinVolumeRepositoryFull() {
		return this.thinVolumeRepositoryFull;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_TPV_REPOSITORY_FULL. It identifies a thin volume with a full repository. */
	public void setThinVolumeRepositoryFull(String x) {
		this.thinVolumeRepositoryFull = x;
	}

	/** This field is present only if the value of recFailureType is equal to REC_TPV_FAILED. It identifies a thin volume that is in a failed state. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of recFailureType is equal to REC_TPV_FAILED. It identifies a thin volume that is in a failed state." , required = false)
	@XmlElement(required = false)
	private String thinVolumeFailed;

	/** @return This field is present only if the value of recFailureType is equal to REC_TPV_FAILED. It identifies a thin volume that is in a failed state. */
	public String getThinVolumeFailed() {
		return this.thinVolumeFailed;
	}
	/** @param x This field is present only if the value of recFailureType is equal to REC_TPV_FAILED. It identifies a thin volume that is in a failed state. */
	public void setThinVolumeFailed(String x) {
		this.thinVolumeFailed = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SECONDARY_REPOSITORY_FULL. It contains a reference to the secondary repository mirror member that has reached the full point. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SECONDARY_REPOSITORY_FULL. It contains a reference to the secondary repository mirror member that has reached the full point." , required = false)
	@XmlElement(required = false)
	private String fullSecondaryRepositoryMirrorMember;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SECONDARY_REPOSITORY_FULL. It contains a reference to the secondary repository mirror member that has reached the full point. */
	public String getFullSecondaryRepositoryMirrorMember() {
		return this.fullSecondaryRepositoryMirrorMember;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SECONDARY_REPOSITORY_FULL. It contains a reference to the secondary repository mirror member that has reached the full point. */
	public void setFullSecondaryRepositoryMirrorMember(String x) {
		this.fullSecondaryRepositoryMirrorMember = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SYNC_INTERNALLY_SUSPENDED. It identifies an async mirror group that has been suspended by the controller due to an error condition. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SYNC_INTERNALLY_SUSPENDED. It identifies an async mirror group that has been suspended by the controller due to an error condition." , required = false)
	@XmlElement(required = false)
	private String suspendedMirrorGroup;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SYNC_INTERNALLY_SUSPENDED. It identifies an async mirror group that has been suspended by the controller due to an error condition. */
	public String getSuspendedMirrorGroup() {
		return this.suspendedMirrorGroup;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SYNC_INTERNALLY_SUSPENDED. It identifies an async mirror group that has been suspended by the controller due to an error condition. */
	public void setSuspendedMirrorGroup(String x) {
		this.suspendedMirrorGroup = x;
	}

	/** It contains metadata for the stable store database backup that is in recovery mode. */
	@io.swagger.annotations.ApiModelProperty(value ="It contains metadata for the stable store database backup that is in recovery mode." , required = false)
	@XmlElement(required = false)
	private DatabaseMetadata databaseMetadata;

	/** @return It contains metadata for the stable store database backup that is in recovery mode. */
	public DatabaseMetadata getDatabaseMetadata() {
		return this.databaseMetadata;
	}
	/** @param x It contains metadata for the stable store database backup that is in recovery mode. */
	public void setDatabaseMetadata(DatabaseMetadata x) {
		this.databaseMetadata = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ARVM_PRIMARY_REPOSITORY_FULL. It contains information about the primary repository mirror member that has reached the full point. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ARVM_PRIMARY_REPOSITORY_FULL. It contains information about the primary repository mirror member that has reached the full point." , required = false)
	@XmlElement(required = false)
	private AsyncMirrorGroupMemberFaultIndication fullPrimaryRepositoryMirrorMember;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ARVM_PRIMARY_REPOSITORY_FULL. It contains information about the primary repository mirror member that has reached the full point. */
	public AsyncMirrorGroupMemberFaultIndication getFullPrimaryRepositoryMirrorMember() {
		return this.fullPrimaryRepositoryMirrorMember;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ARVM_PRIMARY_REPOSITORY_FULL. It contains information about the primary repository mirror member that has reached the full point. */
	public void setFullPrimaryRepositoryMirrorMember(AsyncMirrorGroupMemberFaultIndication x) {
		this.fullPrimaryRepositoryMirrorMember = x;
	}

	/** This field is present only if the value of the recFailureType is equal to REC_INCOMPATIBLE_SATA_DRIVE. It is a reference to a SATA drive that is incompatible because it does not support SMART Command Transfer (SCT) commands. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of the recFailureType is equal to REC_INCOMPATIBLE_SATA_DRIVE. It is a reference to a SATA drive that is incompatible because it does not support SMART Command Transfer (SCT) commands." , required = false)
	@XmlElement(required = false)
	private String sataSCTCmndUnsupported;

	/** @return This field is present only if the value of the recFailureType is equal to REC_INCOMPATIBLE_SATA_DRIVE. It is a reference to a SATA drive that is incompatible because it does not support SMART Command Transfer (SCT) commands. */
	public String getSataSCTCmndUnsupported() {
		return this.sataSCTCmndUnsupported;
	}
	/** @param x This field is present only if the value of the recFailureType is equal to REC_INCOMPATIBLE_SATA_DRIVE. It is a reference to a SATA drive that is incompatible because it does not support SMART Command Transfer (SCT) commands. */
	public void setSataSCTCmndUnsupported(String x) {
		this.sataSCTCmndUnsupported = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_CAPACITY_DEPLETED. It identifies the Disk Pool with depleted capacity. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_CAPACITY_DEPLETED. It identifies the Disk Pool with depleted capacity." , required = false)
	@XmlElement(required = false)
	private String diskPoolCapacityDepleted;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_CAPACITY_DEPLETED. It identifies the Disk Pool with depleted capacity. */
	public String getDiskPoolCapacityDepleted() {
		return this.diskPoolCapacityDepleted;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_CAPACITY_DEPLETED. It identifies the Disk Pool with depleted capacity. */
	public void setDiskPoolCapacityDepleted(String x) {
		this.diskPoolCapacityDepleted = x;
	}

	/** This field is present only if the value of the recFailureType is equal to REC_DRIVE_INCOMPATIBLE_MODEL_NUMBER_UNSUPPORTED. It is a reference to a SATA drive that is incompatible because of the model number. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of the recFailureType is equal to REC_DRIVE_INCOMPATIBLE_MODEL_NUMBER_UNSUPPORTED. It is a reference to a SATA drive that is incompatible because of the model number." , required = false)
	@XmlElement(required = false)
	private String driveModelNumberUnsupported;

	/** @return This field is present only if the value of the recFailureType is equal to REC_DRIVE_INCOMPATIBLE_MODEL_NUMBER_UNSUPPORTED. It is a reference to a SATA drive that is incompatible because of the model number. */
	public String getDriveModelNumberUnsupported() {
		return this.driveModelNumberUnsupported;
	}
	/** @param x This field is present only if the value of the recFailureType is equal to REC_DRIVE_INCOMPATIBLE_MODEL_NUMBER_UNSUPPORTED. It is a reference to a SATA drive that is incompatible because of the model number. */
	public void setDriveModelNumberUnsupported(String x) {
		this.driveModelNumberUnsupported = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_FLASH_CACHE_NON_OPTIMAL_DRIVES. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_FLASH_CACHE_NON_OPTIMAL_DRIVES." , required = false)
	@XmlElement(required = false)
	private FlashCacheRecoveryData flashCacheNonOptimalDrives;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_FLASH_CACHE_NON_OPTIMAL_DRIVES. */
	public FlashCacheRecoveryData getFlashCacheNonOptimalDrives() {
		return this.flashCacheNonOptimalDrives;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_FLASH_CACHE_NON_OPTIMAL_DRIVES. */
	public void setFlashCacheNonOptimalDrives(FlashCacheRecoveryData x) {
		this.flashCacheNonOptimalDrives = x;
	}

	/** This field is present if the RecoveryFailureType value is equal to REC_FLASH_CACHE_HOT_SPARE_IN_USE. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present if the RecoveryFailureType value is equal to REC_FLASH_CACHE_HOT_SPARE_IN_USE." , required = false)
	@XmlElement(required = false)
	private FlashCacheRecoveryData flashCacheHotSpareInUse;

	/** @return This field is present if the RecoveryFailureType value is equal to REC_FLASH_CACHE_HOT_SPARE_IN_USE. */
	public FlashCacheRecoveryData getFlashCacheHotSpareInUse() {
		return this.flashCacheHotSpareInUse;
	}
	/** @param x This field is present if the RecoveryFailureType value is equal to REC_FLASH_CACHE_HOT_SPARE_IN_USE. */
	public void setFlashCacheHotSpareInUse(FlashCacheRecoveryData x) {
		this.flashCacheHotSpareInUse = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ALL_DRIVES_BYPASSED_INCOMPATIBLE_NVSRAM. It identifies the controller in a Native SATA array that has a duplex NVSRAM setting and all drives appear as bypassed. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ALL_DRIVES_BYPASSED_INCOMPATIBLE_NVSRAM. It identifies the controller in a Native SATA array that has a duplex NVSRAM setting and all drives appear as bypassed." , required = false)
	@XmlElement(required = false)
	private String nativeSATAIncompatibleNVSRAM;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ALL_DRIVES_BYPASSED_INCOMPATIBLE_NVSRAM. It identifies the controller in a Native SATA array that has a duplex NVSRAM setting and all drives appear as bypassed. */
	public String getNativeSATAIncompatibleNVSRAM() {
		return this.nativeSATAIncompatibleNVSRAM;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ALL_DRIVES_BYPASSED_INCOMPATIBLE_NVSRAM. It identifies the controller in a Native SATA array that has a duplex NVSRAM setting and all drives appear as bypassed. */
	public void setNativeSATAIncompatibleNVSRAM(String x) {
		this.nativeSATAIncompatibleNVSRAM = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_DRIVE_FAILURE. It identifies the Disk Pool with at least one failed drive. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_DRIVE_FAILURE. It identifies the Disk Pool with at least one failed drive." , required = false)
	@XmlElement(required = false)
	private String diskPoolDriveFailure;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_DRIVE_FAILURE. It identifies the Disk Pool with at least one failed drive. */
	public String getDiskPoolDriveFailure() {
		return this.diskPoolDriveFailure;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_DRIVE_FAILURE. It identifies the Disk Pool with at least one failed drive. */
	public void setDiskPoolDriveFailure(String x) {
		this.diskPoolDriveFailure = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_INSUFFICIENT_MEMORY. It identifies the controller where access to disk pool volumes is prohibited because of insufficient memory. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_INSUFFICIENT_MEMORY. It identifies the controller where access to disk pool volumes is prohibited because of insufficient memory." , required = false)
	@XmlElement(required = false)
	private String diskPoolInsufficientMemory;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_INSUFFICIENT_MEMORY. It identifies the controller where access to disk pool volumes is prohibited because of insufficient memory. */
	public String getDiskPoolInsufficientMemory() {
		return this.diskPoolInsufficientMemory;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_DISK_POOL_INSUFFICIENT_MEMORY. It identifies the controller where access to disk pool volumes is prohibited because of insufficient memory. */
	public void setDiskPoolInsufficientMemory(String x) {
		this.diskPoolInsufficientMemory = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ARVM_ORPHAN_INCOMPLETE_MEMBER. It identifies the orphan incomplete async mirror group member. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ARVM_ORPHAN_INCOMPLETE_MEMBER. It identifies the orphan incomplete async mirror group member." , required = false)
	@XmlElement(required = false)
	private String orphanIncompleteMember;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ARVM_ORPHAN_INCOMPLETE_MEMBER. It identifies the orphan incomplete async mirror group member. */
	public String getOrphanIncompleteMember() {
		return this.orphanIncompleteMember;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ARVM_ORPHAN_INCOMPLETE_MEMBER. It identifies the orphan incomplete async mirror group member. */
	public void setOrphanIncompleteMember(String x) {
		this.orphanIncompleteMember = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SYNC_PAUSED_ALT_STATE. It identifies the AsyncMirrorGroup whose synchronization has been paused. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SYNC_PAUSED_ALT_STATE. It identifies the AsyncMirrorGroup whose synchronization has been paused." , required = false)
	@XmlElement(required = false)
	private String pausedAltStateMirrorGroup;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SYNC_PAUSED_ALT_STATE. It identifies the AsyncMirrorGroup whose synchronization has been paused. */
	public String getPausedAltStateMirrorGroup() {
		return this.pausedAltStateMirrorGroup;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_ARVM_SYNC_PAUSED_ALT_STATE. It identifies the AsyncMirrorGroup whose synchronization has been paused. */
	public void setPausedAltStateMirrorGroup(String x) {
		this.pausedAltStateMirrorGroup = x;
	}

	/** This field is present only if the value of RecoveryFailureType is equal to REC_ARVM_ROLE_CHANGE_PAUSED. It identifies the async mirror group that has had a role change pause due to issues with required data synchronization. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType is equal to REC_ARVM_ROLE_CHANGE_PAUSED. It identifies the async mirror group that has had a role change pause due to issues with required data synchronization." , required = false)
	@XmlElement(required = false)
	private String pausedRoleChangeGroup;

	/** @return This field is present only if the value of RecoveryFailureType is equal to REC_ARVM_ROLE_CHANGE_PAUSED. It identifies the async mirror group that has had a role change pause due to issues with required data synchronization. */
	public String getPausedRoleChangeGroup() {
		return this.pausedRoleChangeGroup;
	}
	/** @param x This field is present only if the value of RecoveryFailureType is equal to REC_ARVM_ROLE_CHANGE_PAUSED. It identifies the async mirror group that has had a role change pause due to issues with required data synchronization. */
	public void setPausedRoleChangeGroup(String x) {
		this.pausedRoleChangeGroup = x;
	}

	/** This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_INCOMPATIBLE_ALIGNMENT_FOR_EMULATION_DRIVE. It identifies an emulation drive with an incompatible alignment. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_INCOMPATIBLE_ALIGNMENT_FOR_EMULATION_DRIVE. It identifies an emulation drive with an incompatible alignment." , required = false)
	@XmlElement(required = false)
	private String driveEmulationIncompatibleAlignment;

	/** @return This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_INCOMPATIBLE_ALIGNMENT_FOR_EMULATION_DRIVE. It identifies an emulation drive with an incompatible alignment. */
	public String getDriveEmulationIncompatibleAlignment() {
		return this.driveEmulationIncompatibleAlignment;
	}
	/** @param x This field is present only if the value of RecoveryFailureType value is equal to REC_DRIVE_INCOMPATIBLE_ALIGNMENT_FOR_EMULATION_DRIVE. It identifies an emulation drive with an incompatible alignment. */
	public void setDriveEmulationIncompatibleAlignment(String x) {
		this.driveEmulationIncompatibleAlignment = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_LOSS_OF_EXTERNAL_REDUNDANCY. It identifies drive channels that are not externally connected.. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_LOSS_OF_EXTERNAL_REDUNDANCY. It identifies drive channels that are not externally connected.." , required = false)
	@XmlElement(required = false)
	private ExternalRedundancyFailure redundancyFail;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_LOSS_OF_EXTERNAL_REDUNDANCY. It identifies drive channels that are not externally connected.. */
	public ExternalRedundancyFailure getRedundancyFail() {
		return this.redundancyFail;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_LOSS_OF_EXTERNAL_REDUNDANCY. It identifies drive channels that are not externally connected.. */
	public void setRedundancyFail(ExternalRedundancyFailure x) {
		this.redundancyFail = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_RVM_WRITE_MODE_INCONSISTENT. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_RVM_WRITE_MODE_INCONSISTENT." , required = false)
	@XmlElement(required = false)
	private String mirrorProxyRef;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_RVM_WRITE_MODE_INCONSISTENT. */
	public String getMirrorProxyRef() {
		return this.mirrorProxyRef;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_RVM_WRITE_MODE_INCONSISTENT. */
	public void setMirrorProxyRef(String x) {
		this.mirrorProxyRef = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_SAS_HOST_MISWIRE. It identifies the SAS port from which the miswire originates. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_SAS_HOST_MISWIRE. It identifies the SAS port from which the miswire originates." , required = false)
	@XmlElement(required = false)
	private SasPort miswiredSasHost;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_SAS_HOST_MISWIRE. It identifies the SAS port from which the miswire originates. */
	public SasPort getMiswiredSasHost() {
		return this.miswiredSasHost;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_SAS_HOST_MISWIRE. It identifies the SAS port from which the miswire originates. */
	public void setMiswiredSasHost(SasPort x) {
		this.miswiredSasHost = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_SAS_CROSS_MISWIRE. It identifies the SAS port that has been disabled. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_SAS_CROSS_MISWIRE. It identifies the SAS port that has been disabled." , required = false)
	@XmlElement(required = false)
	private SasPort miswiredSasCross;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_SAS_CROSS_MISWIRE. It identifies the SAS port that has been disabled. */
	public SasPort getMiswiredSasCross() {
		return this.miswiredSasCross;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_SAS_CROSS_MISWIRE. It identifies the SAS port that has been disabled. */
	public void setMiswiredSasCross(SasPort x) {
		this.miswiredSasCross = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_SAS_LOOP_MISWIRE. It identifies the SAS port that has been disabled. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_SAS_LOOP_MISWIRE. It identifies the SAS port that has been disabled." , required = false)
	@XmlElement(required = false)
	private SasPort miswiredSasLoop;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_SAS_LOOP_MISWIRE. It identifies the SAS port that has been disabled. */
	public SasPort getMiswiredSasLoop() {
		return this.miswiredSasLoop;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_SAS_LOOP_MISWIRE. It identifies the SAS port that has been disabled. */
	public void setMiswiredSasLoop(SasPort x) {
		this.miswiredSasLoop = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_COPY_THEN_FAIL_WAITING_ON_HOT_SPARE: A copy then fail operation is waiting on the user to identify a suitable hot spare drive. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_COPY_THEN_FAIL_WAITING_ON_HOT_SPARE: A copy then fail operation is waiting on the user to identify a suitable hot spare drive." , required = false)
	@XmlElement(required = false)
	private String volGroupWaitingOnHotSpare;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_COPY_THEN_FAIL_WAITING_ON_HOT_SPARE: A copy then fail operation is waiting on the user to identify a suitable hot spare drive. */
	public String getVolGroupWaitingOnHotSpare() {
		return this.volGroupWaitingOnHotSpare;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_COPY_THEN_FAIL_WAITING_ON_HOT_SPARE: A copy then fail operation is waiting on the user to identify a suitable hot spare drive. */
	public void setVolGroupWaitingOnHotSpare(String x) {
		this.volGroupWaitingOnHotSpare = x;
	}

	/** This recovery failure type includes a list of the drives that have gone missing. The drives in the list are identified as a collection of tray/slot combinations. */
	@io.swagger.annotations.ApiModelProperty(value ="This recovery failure type includes a list of the drives that have gone missing. The drives in the list are identified as a collection of tray/slot combinations." , required = false)
	@XmlElement(required = false)
	private TraySlot[] missingAssignedDrives;

	/** @return This recovery failure type includes a list of the drives that have gone missing. The drives in the list are identified as a collection of tray/slot combinations. */
	public TraySlot[] getMissingAssignedDrives() {
		return this.missingAssignedDrives;
	}
	/** @param x This recovery failure type includes a list of the drives that have gone missing. The drives in the list are identified as a collection of tray/slot combinations. */
	public void setMissingAssignedDrives(TraySlot[] x) {
		this.missingAssignedDrives = x;
	}

	@io.swagger.annotations.ApiModelProperty(value ="" , required = false)
	@XmlElement(required = false)
	private String diskPoolWaitingOnHotSpare;

	public String getDiskPoolWaitingOnHotSpare() {
		return this.diskPoolWaitingOnHotSpare;
	}
	public void setDiskPoolWaitingOnHotSpare(String x) {
		this.diskPoolWaitingOnHotSpare = x;
	}

	/** The controller has automatically gone into service mode due to the detection of a PI error. */
	@io.swagger.annotations.ApiModelProperty(value ="The controller has automatically gone into service mode due to the detection of a PI error." , required = false)
	@XmlElement(required = false)
	private String controllerInServiceMode;

	/** @return The controller has automatically gone into service mode due to the detection of a PI error. */
	public String getControllerInServiceMode() {
		return this.controllerInServiceMode;
	}
	/** @param x The controller has automatically gone into service mode due to the detection of a PI error. */
	public void setControllerInServiceMode(String x) {
		this.controllerInServiceMode = x;
	}

	/** The controller has gone into lockdown mode due to the detection of PI errors on all controllers in the array. */
	@io.swagger.annotations.ApiModelProperty(value ="The controller has gone into lockdown mode due to the detection of PI errors on all controllers in the array." , required = false)
	@XmlElement(required = false)
	private String controllerInLockdown;

	/** @return The controller has gone into lockdown mode due to the detection of PI errors on all controllers in the array. */
	public String getControllerInLockdown() {
		return this.controllerInLockdown;
	}
	/** @param x The controller has gone into lockdown mode due to the detection of PI errors on all controllers in the array. */
	public void setControllerInLockdown(String x) {
		this.controllerInLockdown = x;
	}

	/** This data associated with the backend SAS channel to help diagnose the discovery error. */
	@io.swagger.annotations.ApiModelProperty(value ="This data associated with the backend SAS channel to help diagnose the discovery error." , required = false)
	@XmlElement(required = false)
	private SasPort discoveryErrorSasPort;

	/** @return This data associated with the backend SAS channel to help diagnose the discovery error. */
	public SasPort getDiscoveryErrorSasPort() {
		return this.discoveryErrorSasPort;
	}
	/** @param x This data associated with the backend SAS channel to help diagnose the discovery error. */
	public void setDiscoveryErrorSasPort(SasPort x) {
		this.discoveryErrorSasPort = x;
	}

	/** Provides details regarding an NTP resolution failure that is preventing the controller from updating its software clock */
	@io.swagger.annotations.ApiModelProperty(value ="Provides details regarding an NTP resolution failure that is preventing the controller from updating its software clock" , required = false)
	@XmlElement(required = false)
	private ControllerNtpErrorDetails ntpResolutionFailure;

	/** @return Provides details regarding an NTP resolution failure that is preventing the controller from updating its software clock */
	public ControllerNtpErrorDetails getNtpResolutionFailure() {
		return this.ntpResolutionFailure;
	}
	/** @param x Provides details regarding an NTP resolution failure that is preventing the controller from updating its software clock */
	public void setNtpResolutionFailure(ControllerNtpErrorDetails x) {
		this.ntpResolutionFailure = x;
	}

	/** Provides details regarding an NTP query failure that is preventing the controller from updating its software clock */
	@io.swagger.annotations.ApiModelProperty(value ="Provides details regarding an NTP query failure that is preventing the controller from updating its software clock" , required = false)
	@XmlElement(required = false)
	private ControllerNtpErrorDetails ntpQueryFailure;

	/** @return Provides details regarding an NTP query failure that is preventing the controller from updating its software clock */
	public ControllerNtpErrorDetails getNtpQueryFailure() {
		return this.ntpQueryFailure;
	}
	/** @param x Provides details regarding an NTP query failure that is preventing the controller from updating its software clock */
	public void setNtpQueryFailure(ControllerNtpErrorDetails x) {
		this.ntpQueryFailure = x;
	}

	/** Controller reporting the NTP Service failure */
	@io.swagger.annotations.ApiModelProperty(value ="Controller reporting the NTP Service failure" , required = false)
	@XmlElement(required = false)
	private String ntpServiceFailureController;

	/** @return Controller reporting the NTP Service failure */
	public String getNtpServiceFailureController() {
		return this.ntpServiceFailureController;
	}
	/** @param x Controller reporting the NTP Service failure */
	public void setNtpServiceFailureController(String x) {
		this.ntpServiceFailureController = x;
	}

	/** This field is only present if the RecoveryFailureType value is equal to REC_MULTIPATH_CONFIGURATION_ERROR. This field contains a reference to the Host in the storage partitions topology that has the multipath configuration issue. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is only present if the RecoveryFailureType value is equal to REC_MULTIPATH_CONFIGURATION_ERROR. This field contains a reference to the Host in the storage partitions topology that has the multipath configuration issue." , required = false)
	@XmlElement(required = false)
	private String misconfiguredHost;

	/** @return This field is only present if the RecoveryFailureType value is equal to REC_MULTIPATH_CONFIGURATION_ERROR. This field contains a reference to the Host in the storage partitions topology that has the multipath configuration issue. */
	public String getMisconfiguredHost() {
		return this.misconfiguredHost;
	}
	/** @param x This field is only present if the RecoveryFailureType value is equal to REC_MULTIPATH_CONFIGURATION_ERROR. This field contains a reference to the Host in the storage partitions topology that has the multipath configuration issue. */
	public void setMisconfiguredHost(String x) {
		this.misconfiguredHost = x;
	}

	/** This field is only present if the RecoveryFailureType value is equal to REC_HOST_REDUNDANCY_LOST. This field conveys details about the connectivity loss, including indications of the specific host and controller that are not connected. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is only present if the RecoveryFailureType value is equal to REC_HOST_REDUNDANCY_LOST. This field conveys details about the connectivity loss, including indications of the specific host and controller that are not connected." , required = false)
	@XmlElement(required = false)
	private HostRedundancyLossDetails hostRedundancyLossDetails;

	/** @return This field is only present if the RecoveryFailureType value is equal to REC_HOST_REDUNDANCY_LOST. This field conveys details about the connectivity loss, including indications of the specific host and controller that are not connected. */
	public HostRedundancyLossDetails getHostRedundancyLossDetails() {
		return this.hostRedundancyLossDetails;
	}
	/** @param x This field is only present if the RecoveryFailureType value is equal to REC_HOST_REDUNDANCY_LOST. This field conveys details about the connectivity loss, including indications of the specific host and controller that are not connected. */
	public void setHostRedundancyLossDetails(HostRedundancyLossDetails x) {
		this.hostRedundancyLossDetails = x;
	}

	/** Excessive reboots have been detected -- return the controller ref in the Failure Type Entry. */
	@io.swagger.annotations.ApiModelProperty(value ="Excessive reboots have been detected -- return the controller ref in the Failure Type Entry." , required = false)
	@XmlElement(required = false)
	private ExcessiveRebootsDetected excessiveRebootsDetected;

	/** @return Excessive reboots have been detected -- return the controller ref in the Failure Type Entry. */
	public ExcessiveRebootsDetected getExcessiveRebootsDetected() {
		return this.excessiveRebootsDetected;
	}
	/** @param x Excessive reboots have been detected -- return the controller ref in the Failure Type Entry. */
	public void setExcessiveRebootsDetected(ExcessiveRebootsDetected x) {
		this.excessiveRebootsDetected = x;
	}

	/** This field is present only if the RecoveryFailureType value is equal to REC_CACHE_NOT_FLUSHED_ON_ONLY_CTLR. It contains the identification of the controller that fails to flush dirty cache data on failed volume(s) possibly due to offlined drives. The controller should not be replaced to avoid loss of data. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is present only if the RecoveryFailureType value is equal to REC_CACHE_NOT_FLUSHED_ON_ONLY_CTLR. It contains the identification of the controller that fails to flush dirty cache data on failed volume(s) possibly due to offlined drives. The controller should not be replaced to avoid loss of data." , required = false)
	@XmlElement(required = false)
	private ControllerWithDirtyCacheDetails ctlrWithDirtyCacheNotFlushed;

	/** @return This field is present only if the RecoveryFailureType value is equal to REC_CACHE_NOT_FLUSHED_ON_ONLY_CTLR. It contains the identification of the controller that fails to flush dirty cache data on failed volume(s) possibly due to offlined drives. The controller should not be replaced to avoid loss of data. */
	public ControllerWithDirtyCacheDetails getCtlrWithDirtyCacheNotFlushed() {
		return this.ctlrWithDirtyCacheNotFlushed;
	}
	/** @param x This field is present only if the RecoveryFailureType value is equal to REC_CACHE_NOT_FLUSHED_ON_ONLY_CTLR. It contains the identification of the controller that fails to flush dirty cache data on failed volume(s) possibly due to offlined drives. The controller should not be replaced to avoid loss of data. */
	public void setCtlrWithDirtyCacheNotFlushed(ControllerWithDirtyCacheDetails x) {
		this.ctlrWithDirtyCacheNotFlushed = x;
	}

	/** A KMS certificate is nearing its expiration and should be updated prior to expiration to prevent a potential loss of data access. */
	@io.swagger.annotations.ApiModelProperty(value ="A KMS certificate is nearing its expiration and should be updated prior to expiration to prevent a potential loss of data access." , required = false)
	@XmlElement(required = false)
	private KMSCertificateExpirationDetails kmsExpiringCertificate;

	/** @return A KMS certificate is nearing its expiration and should be updated prior to expiration to prevent a potential loss of data access. */
	public KMSCertificateExpirationDetails getKmsExpiringCertificate() {
		return this.kmsExpiringCertificate;
	}
	/** @param x A KMS certificate is nearing its expiration and should be updated prior to expiration to prevent a potential loss of data access. */
	public void setKmsExpiringCertificate(KMSCertificateExpirationDetails x) {
		this.kmsExpiringCertificate = x;
	}

	/** A KMS certificate has expired resulting in a loss of access with the KMIP server. */
	@io.swagger.annotations.ApiModelProperty(value ="A KMS certificate has expired resulting in a loss of access with the KMIP server." , required = false)
	@XmlElement(required = false)
	private KMSCertificateExpirationDetails kmsExpiredCertificate;

	/** @return A KMS certificate has expired resulting in a loss of access with the KMIP server. */
	public KMSCertificateExpirationDetails getKmsExpiredCertificate() {
		return this.kmsExpiredCertificate;
	}
	/** @param x A KMS certificate has expired resulting in a loss of access with the KMIP server. */
	public void setKmsExpiredCertificate(KMSCertificateExpirationDetails x) {
		this.kmsExpiredCertificate = x;
	}

	/** A connection failure occurred while attempting to communicate with the KMIP server. */
	@io.swagger.annotations.ApiModelProperty(value ="A connection failure occurred while attempting to communicate with the KMIP server." , required = false)
	@XmlElement(required = false)
	private ExternalKMSEndpoint kmsConnFailureEndpoint;

	/** @return A connection failure occurred while attempting to communicate with the KMIP server. */
	public ExternalKMSEndpoint getKmsConnFailureEndpoint() {
		return this.kmsConnFailureEndpoint;
	}
	/** @param x A connection failure occurred while attempting to communicate with the KMIP server. */
	public void setKmsConnFailureEndpoint(ExternalKMSEndpoint x) {
		this.kmsConnFailureEndpoint = x;
	}

	/** An error occurred while communicating with the KMIP server. */
	@io.swagger.annotations.ApiModelProperty(value ="An error occurred while communicating with the KMIP server." , required = false)
	@XmlElement(required = false)
	private ExternalKMSEndpoint kmsServerErrorEndpoint;

	/** @return An error occurred while communicating with the KMIP server. */
	public ExternalKMSEndpoint getKmsServerErrorEndpoint() {
		return this.kmsServerErrorEndpoint;
	}
	/** @param x An error occurred while communicating with the KMIP server. */
	public void setKmsServerErrorEndpoint(ExternalKMSEndpoint x) {
		this.kmsServerErrorEndpoint = x;
	}

	/** The Directory Services Server is misconfigured or unreachable. */
	@io.swagger.annotations.ApiModelProperty(value ="The Directory Services Server is misconfigured or unreachable." , required = false)
	@XmlElement(required = false)
	private DirectoryServicesDomain directoryServicesDomain;

	/** @return The Directory Services Server is misconfigured or unreachable. */
	public DirectoryServicesDomain getDirectoryServicesDomain() {
		return this.directoryServicesDomain;
	}
	/** @param x The Directory Services Server is misconfigured or unreachable. */
	public void setDirectoryServicesDomain(DirectoryServicesDomain x) {
		this.directoryServicesDomain = x;
	}

	/** A requirement of the key has not been satisfied on the KMIP server (e.g., key owner has not been set.) */
	@io.swagger.annotations.ApiModelProperty(value ="A requirement of the key has not been satisfied on the KMIP server (e.g., key owner has not been set.)" , required = false)
	@XmlElement(required = false)
	private ExternalKMSEndpoint kmsKeyReqEndpoint;

	/** @return A requirement of the key has not been satisfied on the KMIP server (e.g., key owner has not been set.) */
	public ExternalKMSEndpoint getKmsKeyReqEndpoint() {
		return this.kmsKeyReqEndpoint;
	}
	/** @param x A requirement of the key has not been satisfied on the KMIP server (e.g., key owner has not been set.) */
	public void setKmsKeyReqEndpoint(ExternalKMSEndpoint x) {
		this.kmsKeyReqEndpoint = x;
	}
}
