package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.util.EnumSet;
import java.util.Collections;

public class SYMbolAPI extends ApiDefinition
{
	public SYMbolAPI() {
		super(1398361410, 1, m_TypeTable, m_ProcTable);
	}

	/** This constant specifies an unknown/invalid drive speed. */
	public static final int SPINDLE_SPEED_UNKNOWN = -1;
	/** This constant specifies the number of bytes that are used for firmware version identifiers. */
	public static final int VERSION_BYTES = 4;
	/** This constant specifies the maximum length for an Organization Name used to generate a KMS CSR. */
	public static final int KMS_CSR_MAX_ORGANIZATION_NAME_LENGTH = 128;
	/** This value indicates the default (or recommended value) should be used for the disk pool attribute. Each volume candidate will decide on the optimal reserved space (in drives) to use for reconstructionReservedDriveCount. */
	public static final int DISK_POOL_USE_DEFAULTS = 65535;
	/** This constant specifies the number of bytes that are used in the opaque data of a SYMbolRef. */
	public static final int REF_BYTES = 20;
	/** This constant is used in the dplCoreDumpTag field in DPLCoreDumpData to indicate there is no DPL core dump to retrieve. */
	public static final int DPL_CORE_DUMP_NULL_TAG = 0;
	/** This is the maximum length of the label of a component referred to in the ComponentLocationRelative struct. The ComponentLocationRelative struct is part of the ComponentLocation union which appears in the MelEntry struct. */
	public static final int MAX_COMPONENT_LABEL_LENGTH = 8;
	/** A constant specifying the maximum size (in bytes) allowed for the componentLocation field in a MelEntry */
	public static final int MEL_MAX_COMP_LOCATION_SIZE = 60;
	/** This constant specifies the number of bytes that are present in data type IscsiSessionId. */
	public static final int ISCSI_ISID_BYTES = 6;
	/** The maximum length of the "chassis name" tray attribute. */
	public static final int TRAY_ATTR_CHASSIS_NAME_MAX_LENGTH = 32;
	/** This constant specifies the value of a null DDC (diagnostic data capture) tag. It is used to indicate that there is no diagnostic data available. */
	public static final int DDC_NULL_TAG = 0;
	/** This constant specifies the maximum "chunk size" in bytes that can be used when transferring segments of a diagnostic data capture image to the management client. If necessary, a DDC image may be segmented into blocks that are no larger than this value, and transferred iteratively from controller to client. */
	public static final int MAX_DDC_CHUNK = 131072;
	/** This constant specifies the maximum number of Fibre Channel interfaces per physical drive. */
	public static final int MAX_FIBRE_INTERFACES = 2;
	/** This constant specifies the maximum "chunk size" that can be used when downloading segments of a new firmware image to the array. If necessary, a firmware image must be segmented into blocks that are no larger than this value, and transferred iteratively to the controller. */
	public static final int MAX_FW_CHUNK = 32768;
	/** This constant specifies the maximum tray ID number that may be set for a tray (of any type) using the updateTray procedure. */
	public static final int MAX_CONFIGURABLE_TRAY_ID = 99;
	/** This constant is used for several fields identification purposes. */
	public static final int TLV_OCTETS = 255;
	/** This constant specifies the minimum tray ID number that may be set for the controller tray using the updateTray procedure. This element is now deprecated: It is still supported but will become obsolete at some point in the future. The constant MIN_CONFIGURABLE_TRAY_ID should be used instead. */
	public static final int MIN_ALLOWED_CTRL_TRAY_ID_NUMBER = 0;
	/** This constant specifies the number of bytes in the SFP's Vendor OUI field. */
	public static final int NUMBER_OUI_BYTES = 3;
	/** Indicate that a Host in the storage partitions topology database has an invalid type index. Firmware downgraded with fewer supported host types. */
	public static final int HOST_TYPE_INDEX_INVALID = -1;
	/** This constant is used to specify that a sync completion time threshold has not been set. No warning will be given for lengthy sync intervals. */
	public static final int ARVM_SYNC_COMPLETION_TIME_THRESHOLD_NONE = 0;
	/** This constant specifies the number of bytes that are present in an IP address that conforms to version 4 of the Internet protocol. */
	public static final int IPV4_ADDRESS_BYTES = 4;
	/** This constant specifies the maximum number of test results which is MAX_TEST_ID * MAX_CHANNELS. */
	public static final int MAX_TEST_RESULTS = 18;
	/** This constant specifies the maximum length for a Common Name used to generate a KMS CSR. */
	public static final int KMS_CSR_MAX_COMMON_NAME_LENGTH = 128;
	/** This constant specifies the maximum length for an Organizational Unit Name used to generate a KMS CSR. */
	public static final int KMS_CSR_MAX_ORGANIZATIONAL_UNIT_NAME_LENGTH = 64;
	/** The maximum size of the payload portion of a jumbo ethernet frame. */
	public static final int MAX_ETHERNET_JUMBO_PAYLOAD_SIZE = 9000;
	/** The number of RAID implementation algorithms supported by the firmware. The algorithms are numbered 0,,(NUMBER_OF_ALGORITHMS - 1), and the actual algorithm for a given algorithm number depends on the RAID level. */
	public static final int NUMBER_OF_ALGORITHMS = 6;
	/** This constant is used to initialize the maximum IOPs and maximum MB/s values for the performance limits for a host cluster. A value of zero means that no performance limitations have been set. */
	public static final int CLUSTER_PERFORMANCE_LIMIT_DEFAULT_VALUE = 0;
	/** This constant specifies the maximum number of Major Event Log entries that can be obtained in one transfer operation. If more entries than this need to be obtained, the user must iterate, performing multiple fetches. */
	public static final int MEL_MAX_XFER_COUNT = 64;
	/** This constant specifies the maximum number of trays supported in SYMbol configurations. */
	public static final int MAX_SA_TRAYS = 64;
	/** This constant specifies the maximum value for the VLAN (Virtual LAN) identifier setting of an iSCSI interface. */
	public static final int MAX_VLAN_ID = 4094;
	/** This constant specifies the maximum number of samples allowed for remote volume mirror communication check. */
	public static final int RVM_MAX_SAMPLE_TIMES = 256;
	/** An explicit volume parity check operation failed due to an I/O error. This constant is deprecated (because the function that reports it, getParityCheckProgress, is deprecated.) */
	public static final int PARITY_CHK_IOERROR = -3;
	/** This constant specifies the maximum number of characters allowed for passwords. */
	public static final int PASSWD_MAX_CHARS = 30;
	/** This constant specifies the maximum number of channels (source and destination). */
	public static final int MAX_CHANNELS = 6;
	/** Maximum length of a NVMe Qualified Name (NQN) string. */
	public static final int NVMEOF_NAME_BYTES = 223;
	/** This constant specifies the maximum number of management client records that can be used. */
	public static final int MCR_MAX_RECORD_NUM = 1023;
	/** Length of a time zone identifier. */
	public static final int TZ_ID_LENGTH = 40;
	/** This constant is used where a long-running operation would normally report a percentage complete value, but the operation is not actually running. */
	public static final int PERCENT_COMPLETE_OP_NOT_RUNNING = -1;
	/** This is the max number of parent-child MEL relative component location relationships. */
	public static final int MAX_NUMBER_OF_PARENTS = 4;
	/** This constant specifies the maximum number of characters allowed in a user-assigned label. Such labels are currently supported for volume names and storage array names. */
	public static final int UAL_MAX_CHARS = 30;
	/** This constant specifies the RPC authentication type identifier. */
	public static final int AUTH_SYMBOL = -1430533119;
	/** The maximum length of the "service tag" tray attribute. */
	public static final int TRAY_ATTR_SERVICE_TAG_MAX_LENGTH = 10;
	/** This constant is the maximum number of entries possible in any of the port's Operational, Local, and Remote Priority-base Flow Control Summary tables. An entry will be provided for each application protocol exchanged via Data Center Bridging Capability Exchange (DCBX). */
	public static final int TLV_MAX_PROTOCOL_ENTRIES = 8;
	/** This constant specifies the size of the loopback data pattern. */
	public static final int DIAG_PATTERN_SIZE = 64;
	/** This constant specifies the maximum length of an IP or domain address to a key management server. */
	public static final int KEY_MGMT_SERVER_MAX_URL = 253;
	/** This is the size of the PSID string. */
	public static final int PHYSICAL_SECURITY_ID_SIZE = 32;
	/** The number of the default TCP port where the storage array listens for new iSCSI connections. */
	public static final int ISCSI_DEFAULT_TCP_LISTEN_PORT = 3260;
	/** This constant specifies the number of bytes that are present in data type IscsiName. */
	public static final int ISCSI_NAME_BYTES = 223;
	/** The number of the default TCP port where the iSNS server listens for new connections. */
	public static final int ISNS_SERVER_DEFAULT_TCP_LISTEN_PORT = 3205;
	/** An explicit volume parity check operation was pre-empted. This constant is deprecated (because the function that reports it, getParityCheckProgress, is deprecated.) */
	public static final int PARITY_CHK_INTERRUPTED = -5;
	/** This constant specifies the maximum user-selectable value for an iSCSI TCP listening port number. This value applies for both the storage array and the iSNS server. */
	public static final int MAX_ISCSI_SELECTABLE_TCP_PORT = 65535;
	/** This constant specifies the maximum number of test IDs. */
	public static final int MAX_TEST_ID = 3;
	/** This constant specifies the maximum number of DNS servers that may be configured. */
	public static final int MAX_DNS_SERVER_COUNT = 2;
	/** This constant specifies the maximum size for a collection of snapshots submitted to the disableSnapshotCollection and recreateSnapshotCollection procedures. */
	public static final int MAX_SNAPSHOT_COLLECTION_SIZE = 64;
	/** This constant represents the recovery point timestamp that indicates a recovery point does not exist. */
	public static final int ARVM_NO_RECOVERY_POINT_TIMESTAMP = 0;
	/** This constant specifies the number of byte used to store a SAS address. */
	public static final int SAS_ADDRESS_BYTES = 8;
	/** Smallest volume that can be created: 0 MB in bytes. This functionality is now handled within the firmware and not in SYMbol. */
	public static final int MIN_VOLUME_SIZE = 0;
	/** This constant specifies the maximum number of management client records to transfer at one time. */
	public static final int MCR_MAX_XFER_COUNT = 128;
	/** This constant specifies the maximum length for a State/Province Name used to generate a KMS CSR. */
	public static final int KMS_CSR_MAX_STATE_PROVINCE_NAME_LENGTH = 256;
	/** This constant specifies the length of the value in a Key-Value tag. */
	public static final int KEY_VALUE_TAG_VALUE_LENGTH = 60;
	/** This constant is used to specify an auto-delete limit on PITGroups and PITConsistencyGroup if auto-delete is disabled. */
	public static final int PIT_AUTO_DELETE_DISABLED = 0;
	/** This constant indicates that the percentage endurance used is either inaccessible or not populated in this release. */
	public static final int PERCENTAGE_ENDURANCE_USED_UNKNOWN = -1;
	/** This constant specifies the nvsramVersion field in the StagedFirmware structure. */
	public static final int NVSRAM_VERSION_LENGTH = 17;
	/** This constant specifies the number of bytes that are present in data type MacAddress. */
	public static final int MAC_ADDRESS_BYTES = 6;
	/** Maximum length of the Label field in the ExtendedComponentLocation structure */
	public static final int MAX_EXT_COMP_LOCATION_LABEL_LENGTH = 16;
	/** This constant specifies the maximum tray ID number that may be set for the controller tray using the updateTray procedure. This element is now deprecated: It is still supported but will become obsolete at some point in the future. The constant MAX_CONFIGURABLE_TRAY_ID should be used instead. */
	public static final int MAX_ALLOWED_CTRL_TRAY_ID_NUMBER = 99;
	/** This constant specifies the maximum string length for the firmware prefix. */
	public static final int MAX_FW_PREFIX_LENGTH = 15;
	/** This constant specifies the minimum value for the VLAN (Virtual LAN) identifier setting of an iSCSI interface. */
	public static final int MIN_VLAN_ID = 1;
	/** This constant specifies the maximum length for a Country Name used to generate a KMS CSR. */
	public static final int KMS_CSR_MAX_COUNTRY_NAME_LENGTH = 2;
	/** This constant specifies the current version of the controller structure and substructures. */
	public static final int VERSION_CONTROLLER_STRUCT = 68;
	/** This constant is used where a long-running operation would normally report a time-to-complete value, but the value is not known. */
	public static final int TIME_TO_COMPLETION_UNKNOWN = -1;
	/** This constant specifies the minimum user-selectable value for an iSCSI TCP port number. This value applies for both the storage array and the iSNS server. */
	public static final int MIN_ISCSI_SELECTABLE_TCP_PORT = 49152;
	/** This constant specifies that the SYMbol authentication process is being handled internally to the controller. This authentication type is only allowed from processes internal to a single controller. Procedures with this authentication type will be rejected from any external source (out-of-band through the management ports or in-band through the UTM). */
	public static final int AUTH_SYMBOL_INTERNAL = -1430533117;
	/** This constant specifies the TCP and UDP port number that is used for SYMbol protocol interactions. The specified port has been assigned through the IETF/IANA organization to avoid conflicts with other compliant applications. */
	public static final int PORT = 2463;
	/** The maximum length of the "asset tag" tray attribute. */
	public static final int TRAY_ATTR_ASSET_TAG_MAX_LENGTH = 10;
	/** This constant specifies the number of bytes that are present in the opaque data associated with a HostPort object's name */
	public static final int HOST_PORT_NAME_BYTES = 8;
	/** A request for progress information for an explicit volume parity check operation failed because there is no such operation in progress for the specified volume. This constant is deprecated (because the function that reports it, getParityCheckProgress, is deprecated.) */
	public static final int PARITY_CHK_NOTRUNNING = -4;
	/** This constant specifies the maximum length for a Locality Name used to generate a KMS CSR. */
	public static final int KMS_CSR_MAX_LOCALITY_NAME_LENGTH = 256;
	/** This constant specifies the minimum tray ID number that may be set for a tray (of any type) using the updateTray procedure. */
	public static final int MIN_CONFIGURABLE_TRAY_ID = 0;
	/** This constant specifies the number of bytes in a controller reference. */
	public static final int CONTROLLER_REF_BYTES = 12;
	/** This constant specifies a "wildcard" value that can appear in any byte of a firmware version specifier that is part of the CompatibleFirmware object. When checking to see if it is legal to downgrade from the array's current firmware level to an earlier level, a host application should obtain the array of CompatibleFirmware objects from the controller and see if any element of the array "matches" the firmware level that is to be installed for the downgrade. When checking for a match, the wildcard value is to be interpreted as a "match anything" indicator. */
	public static final int FW_VERSION_WILDCARD = 255;
	/** This constant specifies no timeout on the ARVM connectivity test. */
	public static final int ARVM_CONNECTIVITY_TEST_NO_TIMEOUT = -1;
	/** This constant specifies the minimum value for the outbound packet priority setting of an iSCSI interface. */
	public static final int MIN_OUTBOUND_PACKET_PRIORITY = 1;
	/** This constant is used to specify that synchronization intervals for an asynchronous remote mirror group will be manually started by the user. */
	public static final int ARVM_MANUAL_SYNC_INTERVAL = 0;
	/** This constant specifies the maximum size in bytes of a debug info "chunk" that can be transferred to a management client using the getControllerDebugInformation procedure. */
	public static final int MAX_DEBUG_INFO_CHUNK_SIZE = 5767168;
	/** This constant specifies the maximum number of bytes allowed in a user-assigned label. It is defined to be twice the size of UAL_MAX_CHARS, since SYMbol will always use double-byte characters for label strings. */
	public static final int UAL_MAX_BYTES = 60;
	/** This constant specifies the maximum number of NTP servers that may be configured. */
	public static final int MAX_NTP_SERVER_COUNT = 2;
	/** Maximum number of entries in the parent array in the ComponentRelativeLocation structure. (MEL_MAX_COMP_LOCATION_SIDE - (4*4BYTES)) / (2*4 BYTES) = 5 parents. */
	public static final int MAX_PARENT_DEPTH = 5;
	/** This constant is used where repository utilization would normally report a byte count but the value is not known at the time of the request. */
	public static final int REPOSITORY_UTILIZATION_UNKNOWN = -1;
	/** Number of bytes in an NVMe 128-bit (Extended) Host Identifier. */
	public static final int NVMEOF_HOST_ID_BYTES = 16;
	/** This constant is used to specify that a recovery point age threshold has not been set. No warning will be given due to recovery point age. */
	public static final int ARVM_RECOVERY_POINT_AGE_THRESHOLD_NONE = 0;
	/** This constant is used where the interface requires a channel port number, but the number is unknown. */
	public static final int CHANNEL_PORT_UNKNOWN = -1;
	/** This constant specifies the number of bytes that are present in data type IscsiAlias. */
	public static final int ISCSI_ALIAS_BYTES = 255;
	/** This constant specifies the length of the key for a Key-Value tag. */
	public static final int KEY_VALUE_TAG_KEY_LENGTH = 16;
	/** This constant represents the number of bytes in an Infiniband host port name. */
	public static final int IB_HOST_PORT_NAME_BYTES = 16;
	/** This constant specifies the number of "user groups" defined for the management client record feature. */
	public static final int MCR_TOTAL_GROUP_COUNT = 6;
	/** This constant specifies the maximum value for the outbound packet priority setting of an iSCSI interface. */
	public static final int MAX_OUTBOUND_PACKET_PRIORITY = 7;
	/** The number of the default UDP port used by the array for delivering MEL events to a syslog server. */
	public static final int SYSLOG_DEFAULT_UDP_PORT = 514;
	/** The maximum size of the payload portion of a standard ethernet frame. */
	public static final int MAX_ETHERNET_STANDARD_PAYLOAD_SIZE = 1500;
	/** An explicit volume parity check operation detected the present of a data/parity mismatch. This constant is deprecated (because the function that reports it, getParityCheckProgress, is deprecated.) */
	public static final int PARITY_CHK_MISMATCH = -2;
	/** This constant specifies the number of bytes that are present in an IP address that conforms to version 6 of the Internet protocol. */
	public static final int IPV6_ADDRESS_BYTES = 16;
	/** An explicit volume parity check operation completed successfully, and detected no data/parity mismatches. This constant is deprecated (because the function that reports it, getParityCheckProgress, is deprecated.) */
	public static final int PARITY_CHK_SUCCESSFUL = -1;
	/** This constant specifies no client-imposed/requested limit on the size of the sample list returned by getAsyncMirrorSyncStatistics. It is used with the AsyncMirrorSyncStatisticsRequestDescriptor::sampleLimit field. */
	public static final int ARVM_STATISTICS_SAMPLE_LIST_NO_LIMIT = 0;
	/** This constant specifies that all channels will be used for the loopback data test. */
	public static final int DIAG_ALL_CHANNELS = -1;
	/** This constant specifies the maximum number of bytes allowed for passwords. It is defined to be twice the size of PASSWD_MAX_CHARS, since SYMbol will always use double-byte characters for label strings. */
	public static final int PASSWD_MAX_BYTES = 60;
	/** This constant is used in the iocDumpTag field in iocDumpData to indicate there is no IOC Dump to retrieve. */
	public static final int IOC_DUMP_NULL_TAG = 0;
	/** Used when the tray position is unknown. */
	public static final int TRAY_POSITION_UNKNOWN = -1;
	/** This constant specifies the current version of the tray position structure. */
	public static final int VERSION_TRAY_POSITION_STRUCT = 2;
	/** This constant specifies that SYMbolAuthenticationHMAC256 will be used for the RPC message authentication field. */
	public static final int AUTH_SYMBOL_HMAC256 = -1430533118;
	/** This constant is used where a long-running operation would normally report a percentage complete value, but the current value is unknown at the time of the request. */
	public static final int PERCENT_COMPLETE_UNKNOWN = -3;
	public static final String MANAGEMENT_CLASS = "devmgr.v1140api12.Manager";

	private static TypeSpec[] m_TypeTable;

	private static void __init0() {
		m_TypeTable[0] = new TypeSpec(TypeSpec.TypeCode.BOOLEAN);
		m_TypeTable[1] = new TypeSpec(TypeSpec.TypeCode.BYTE);
		m_TypeTable[2] = new TypeSpec(TypeSpec.TypeCode.DOUBLE);
		m_TypeTable[3] = new TypeSpec(TypeSpec.TypeCode.CHAR);
		m_TypeTable[4] = new TypeSpec(TypeSpec.TypeCode.SHORT);
		m_TypeTable[5] = new TypeSpec(TypeSpec.TypeCode.FLOAT);
		m_TypeTable[6] = new TypeSpec(TypeSpec.TypeCode.LONG);
		m_TypeTable[7] = new TypeSpec(TypeSpec.TypeCode.INT);

		m_TypeTable[8] = new EnumSpec(new EnumValue[] {
			new EnumValue("odx", 2),
			new EnumValue("vaai", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unknown", 0)
		}, FunctionID.class);

		m_TypeTable[9] = new EnumSpec(new EnumValue[] {
			new EnumValue("fcCoax", 5),
			new EnumValue("fJack", 6),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("mu", 9),
			new EnumValue("fcs2cc", 3),
			new EnumValue("mtRj", 8),
			new EnumValue("rj45", 14),
			new EnumValue("fcs1cc", 2),
			new EnumValue("bncortnc", 4),
			new EnumValue("copPigtail", 13),
			new EnumValue("unknown", 0),
			new EnumValue("hssdcii", 12),
			new EnumValue("sc", 1),
			new EnumValue("sg", 10),
			new EnumValue("lc", 7),
			new EnumValue("optPigtail", 11),
			new EnumValue("noSeparableConnector", 15)
		}, SFP_CONNECT_TYPE.class);

		m_TypeTable[10] = new EnumSpec(new EnumValue[] {
			new EnumValue("reboot", 2),
			new EnumValue("other", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("userInitiated", 1),
			new EnumValue("unknown", 0)
		}, IOCDumpReason.class);

		m_TypeTable[11] = new EnumSpec(new EnumValue[] {
			new EnumValue("all", 1),
			new EnumValue("channels", 2),
			new EnumValue("devices", 3),
			new EnumValue("__UNDEFINED", 464378545)
		}, RLSCommand.class);

		m_TypeTable[12] = new EnumSpec(new EnumValue[] {
			new EnumValue("localAuthLockout", 4),
			new EnumValue("auditLog", 1),
			new EnumValue("symAccess", 2),
			new EnumValue("dirServer", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unknown", 0)
		}, InternalMessageType.class);

		m_TypeTable[13] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("readWrite", 1),
			new EnumValue("readOnly", 2),
			new EnumValue("modeUnknown", 0)
		}, PITViewAccessMode.class);

		m_TypeTable[14] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("priority4", 4),
			new EnumValue("priority2", 2),
			new EnumValue("priority3", 3),
			new EnumValue("priority0", 0),
			new EnumValue("priority1", 1),
			new EnumValue("unknown", 5)
		}, MirrorSyncPriority.class);

		m_TypeTable[15] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("chap", 4),
			new EnumValue("none", 2)
		}, AuthenticationMethod.class);

		m_TypeTable[16] = new EnumSpec(new EnumValue[] {
			new EnumValue("symbolAuthHmac256Support", 7),
			new EnumValue("oemSpecificArrayType", 1),
			new EnumValue("databaseRecoveryMode", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("controllerLockedDown", 3),
			new EnumValue("unused", 0),
			new EnumValue("t10PiAnalysisLockdown", 5),
			new EnumValue("veosArray", 6),
			new EnumValue("mgmtApplicationType", 2)
		}, SAAttributeID.class);

		m_TypeTable[17] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("santricity", 1),
			new EnumValue("simplicity", 2),
			new EnumValue("none", 0),
			new EnumValue("santricityOrSimplicity", 3),
			new EnumValue("umw", 4)
		}, MgmtApplicationType.class);

		m_TypeTable[18] = new EnumSpec(new EnumValue[] {
			new EnumValue("controller", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("minihub", 2),
			new EnumValue("esm", 1)
		}, GBICParentType.class);

		m_TypeTable[19] = new EnumSpec(new EnumValue[] {
			new EnumValue("purgepit", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unknown", 0),
			new EnumValue("failbasewrites", 1)
		}, PITRepositoryFullPolicy.class);

		m_TypeTable[20] = new EnumSpec(new EnumValue[] {
			new EnumValue("schedule", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("user", 1),
			new EnumValue("unknown", 0)
		}, PITCreationMethod.class);

		m_TypeTable[21] = new EnumSpec(new EnumValue[] {
			new EnumValue("all", 0),
			new EnumValue("scsi", 1),
			new EnumValue("fibre520b", 5),
			new EnumValue("sas", 6),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("pata", 4),
			new EnumValue("fibre", 2),
			new EnumValue("sata", 3),
			new EnumValue("sas4k", 8),
			new EnumValue("unknown", 7)
		}, PhysicalDriveType.class);

		m_TypeTable[22] = new EnumSpec(new EnumValue[] {
			new EnumValue("unsynchronized", 1),
			new EnumValue("optimal", 0),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("synchronizing", 2),
			new EnumValue("degradedUnsynchronized", 8),
			new EnumValue("failed", 5),
			new EnumValue("failedsuspended", 6),
			new EnumValue("notready", 3),
			new EnumValue("degradedSynchronizing", 7),
			new EnumValue("suspended", 4)
		}, MirrorProxyStatus.class);

		m_TypeTable[23] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("automatic", 2),
			new EnumValue("manual", 1),
			new EnumValue("unknown", 0)
		}, ThinVolumeRepositoryExpansionPolicy.class);

		m_TypeTable[24] = new EnumSpec(new EnumValue[] {
			new EnumValue("pkcs5Sha2Aes", 4),
			new EnumValue("unspecified", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("pkcs5Sha1Des", 1)
		}, EncryptionType.class);

		m_TypeTable[25] = new EnumSpec(new EnumValue[] {
			new EnumValue("exported", 2),
			new EnumValue("incomplete", 6),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("forced", 3),
			new EnumValue("missing", 7),
			new EnumValue("contingent", 1),
			new EnumValue("complete", 4),
			new EnumValue("partial", 5)
		}, VolumeGroupState.class);

		m_TypeTable[26] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("volref", 1),
			new EnumValue("label", 2),
			new EnumValue("unknown", 0)
		}, ConcatVolumeMemberRefType.class);

		m_TypeTable[27] = new EnumSpec(new EnumValue[] {
			new EnumValue("unavailable", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("disabled", 3),
			new EnumValue("inconsistent", 1),
			new EnumValue("enabled", 2),
			new EnumValue("unknown", 0)
		}, FunctionState.class);

		m_TypeTable[28] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("removed", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 2),
			new EnumValue("unknown", 4)
		}, GBICStatus.class);

		m_TypeTable[29] = new EnumSpec(new EnumValue[] {
			new EnumValue("stat", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("dhcp", 2),
			new EnumValue("unknown", 0)
		}, DnsAcquisitionMethod.class);

		m_TypeTable[30] = new EnumSpec(new EnumValue[] {
			new EnumValue("controller", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("drawer", 4),
			new EnumValue("esm", 3),
			new EnumValue("unknown", 1)
		}, SasExpanderParentType.class);

		m_TypeTable[31] = new EnumSpec(new EnumValue[] {
			new EnumValue("scsi", 1),
			new EnumValue("sas", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("fibre", 2),
			new EnumValue("sata", 5),
			new EnumValue("unknown", 3)
		}, DriveType.class);

		m_TypeTable[32] = new EnumSpec(new EnumValue[] {
			new EnumValue("errorSamples", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("requestRecentSamples", 0),
			new EnumValue("requestLongestSamples", 1)
		}, AsyncMirrorSyncStatisticsRequestType.class);

		m_TypeTable[33] = new EnumSpec(new EnumValue[] {
			new EnumValue("defer", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("active", 3),
			new EnumValue("initialize", 1),
			new EnumValue("down", 5),
			new EnumValue("linkArm", 2)
		}, IbLinkState.class);

		m_TypeTable[34] = new EnumSpec(new EnumValue[] {
			new EnumValue("critical", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("background", 3),
			new EnumValue("invalid", 0),
			new EnumValue("degraded", 1)
		}, DiskPoolPriorityType.class);

		m_TypeTable[35] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("simplex", 2),
			new EnumValue("duplex", 1),
			new EnumValue("unknown", 0)
		}, ControllerRedundancyMode.class);

		m_TypeTable[36] = new EnumSpec(new EnumValue[] {
			new EnumValue("raidDiskPool", 7),
			new EnumValue("raid0", 0),
			new EnumValue("raid1", 1),
			new EnumValue("raidAll", -1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("raid6", 6),
			new EnumValue("raidUnsupported", -2),
			new EnumValue("raid3", 3),
			new EnumValue("raid5", 5)
		}, RAIDLevel.class);

		m_TypeTable[37] = new EnumSpec(new EnumValue[] {
			new EnumValue("gbic", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("db9", 2),
			new EnumValue("sfp", 3)
		}, PortType.class);

		m_TypeTable[38] = new EnumSpec(new EnumValue[] {
			new EnumValue("multimedia", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("transactional", 2),
			new EnumValue("filesystem", 3)
		}, VolumeUsage.class);

		m_TypeTable[39] = new EnumSpec(new EnumValue[] {
			new EnumValue("parentUnknown", 0),
			new EnumValue("controller", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("minihub", 1)
		}, DriveChannelParentType.class);

		m_TypeTable[40] = new EnumSpec(new EnumValue[] {
			new EnumValue("acceptDefault", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("overrideToTrue", 2),
			new EnumValue("overrideToFalse", 3),
			new EnumValue("unknown", 0)
		}, EventControlOverride.class);

		m_TypeTable[41] = new EnumSpec(new EnumValue[] {
			new EnumValue("all", 0),
			new EnumValue("controller", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("drive", 2),
			new EnumValue("esm", 3)
		}, ChannelDiagDeviceType.class);

		m_TypeTable[42] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("matched", 1),
			new EnumValue("unmatched", 2)
		}, CheckedPendingHostType.class);

		m_TypeTable[43] = new EnumSpec(new EnumValue[] {
			new EnumValue("all", 3),
			new EnumValue("saved", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("active", 2),
			new EnumValue("unknown", 0)
		}, CounterGroupDataLocation.class);

		m_TypeTable[44] = new EnumSpec(new EnumValue[] {
			new EnumValue("all", 0),
			new EnumValue("byTarget", 1),
			new EnumValue("byInitiator", 2),
			new EnumValue("__UNDEFINED", 464378545)
		}, GetIscsiSessionsType.class);

		m_TypeTable[45] = new EnumSpec(new EnumValue[] {
			new EnumValue("configured", 3),
			new EnumValue("unconfigured", 1),
			new EnumValue("acquiring", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("invalid", 4)
		}, IpConfigState.class);

		m_TypeTable[46] = new EnumSpec(new EnumValue[] {
			new EnumValue("newKeyNeeded", 2),
			new EnumValue("validationNeeded", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("ok", 0),
			new EnumValue("keyNeeded", 1)
		}, SecurityExternalKMSKeyStatus.class);

		m_TypeTable[47] = new EnumSpec(new EnumValue[] {
			new EnumValue("failsnap", 2),
			new EnumValue("failwrites", 1),
			new EnumValue("__UNDEFINED", 464378545)
		}, RepositoryFullPolicy.class);

		m_TypeTable[48] = new EnumSpec(new EnumValue[] {
			new EnumValue("internalCtlrRebooted", 3),
			new EnumValue("userStopped", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("userFcChanges", 2),
			new EnumValue("none", 0),
			new EnumValue("internalCfgChanges", 4)
		}, FlashCacheAnalyticsStatusCause.class);

		m_TypeTable[49] = new EnumSpec(new EnumValue[] {
			new EnumValue("driveside", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("hostside", 1)
		}, ControllerGBICType.class);

		m_TypeTable[50] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("absent", 0),
			new EnumValue("present", 1)
		}, OptionalParameter.class);

		m_TypeTable[51] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("newVol", 1),
			new EnumValue("existingVols", 2),
			new EnumValue("unknown", 0),
			new EnumValue("expansion", 3)
		}, ConcatVolumeCandidateType.class);

		m_TypeTable[52] = new EnumSpec(new EnumValue[] {
			new EnumValue("asup", 5),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("aggregation", 1),
			new EnumValue("apollo", 0),
			new EnumValue("appAware", 4),
			new EnumValue("ssdWearLevelData", 10),
			new EnumValue("ldapConfiguration", 11),
			new EnumValue("asupConfiguration", 6),
			new EnumValue("prefStoreArray", 8),
			new EnumValue("persistentMonitor", 9),
			new EnumValue("smis", 2),
			new EnumValue("groupIdInternal", 3),
			new EnumValue("prefStoreGlobal", 7)
		}, MCR_GROUP_ID.class);

		m_TypeTable[53] = new EnumSpec(new EnumValue[] {
			new EnumValue("all", -1),
			new EnumValue("a1", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("none", -2),
			new EnumValue("b0", 2),
			new EnumValue("a0", 0),
			new EnumValue("b1", 3)
		}, ReservedPortID.class);

		m_TypeTable[54] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("removed", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 2)
		}, InterconnectCRUStatus.class);

		m_TypeTable[55] = new EnumSpec(new EnumValue[] {
			new EnumValue("priorityError", 4),
			new EnumValue("priorityAlert", 3),
			new EnumValue("priorityWarning", 5),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("priorityDefault", -1),
			new EnumValue("priorityNotice", 6),
			new EnumValue("priorityEmergency", 2),
			new EnumValue("priorityDebug", 7),
			new EnumValue("priorityCritical", 0),
			new EnumValue("priorityInfo", 1)
		}, EventPriority.class);

		m_TypeTable[56] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("enable", 1),
			new EnumValue("disable", 2),
			new EnumValue("refresh", 4),
			new EnumValue("mute", 3)
		}, AlarmControl.class);

		m_TypeTable[57] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("port1", 1),
			new EnumValue("port2", 2)
		}, GBICPort.class);

		m_TypeTable[58] = new EnumSpec(new EnumValue[] {
			new EnumValue("horizontal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("vertical", 2)
		}, TrayOrientation.class);

		m_TypeTable[59] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("removed", 3),
			new EnumValue("serviceMode", 5),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 2),
			new EnumValue("degraded", 7),
			new EnumValue("rpaParErr", 4),
			new EnumValue("suspended", 6),
			new EnumValue("unknown", 0)
		}, ControllerStatus.class);

		m_TypeTable[60] = new EnumSpec(new EnumValue[] {
			new EnumValue("component", 1),
			new EnumValue("portComp", 3),
			new EnumValue("unk", 0),
			new EnumValue("intfAlias", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("ntwkAddr", 5),
			new EnumValue("local", 7),
			new EnumValue("macAddr", 4),
			new EnumValue("intfName", 6)
		}, EnhEthChassisIDSubtype.class);

		m_TypeTable[61] = new EnumSpec(new EnumValue[] {
			new EnumValue("controller", 3),
			new EnumValue("thermalSensor", 11),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("drawer", 12),
			new EnumValue("battery", 4),
			new EnumValue("interconnect", 1),
			new EnumValue("minihub", 9),
			new EnumValue("powerSupply", 8),
			new EnumValue("unknown", 0),
			new EnumValue("fan", 7),
			new EnumValue("alarm", 10),
			new EnumValue("drive", 5),
			new EnumValue("esm", 6),
			new EnumValue("supportCru", 2)
		}, RTRType.class);

		m_TypeTable[62] = new EnumSpec(new EnumValue[] {
			new EnumValue("min", 0),
			new EnumValue("max", 3600),
			new EnumValue("__UNDEFINED", 464378545)
		}, VolXferAlertDelayPeriod.class);

		m_TypeTable[63] = new EnumSpec(new EnumValue[] {
			new EnumValue("init", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("active", 4),
			new EnumValue("up", 3),
			new EnumValue("openInit", 2),
			new EnumValue("down", 0)
		}, SocLoopState.class);

		m_TypeTable[64] = new EnumSpec(new EnumValue[] {
			new EnumValue("fatalRecordUnallocated", 12),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("fatalMissingMetadata", 9),
			new EnumValue("fatalFsInvalid", 4),
			new EnumValue("fatalRootOutOfBounds", 5),
			new EnumValue("mirrorNotReady", 18),
			new EnumValue("earlyExecution", 3),
			new EnumValue("fatalCorruptMetadata", 8),
			new EnumValue("fatalOrphanBlock", 13),
			new EnumValue("fatalMirrorMismatch", 17),
			new EnumValue("fatalDupBlockPointers", 6),
			new EnumValue("fatalRecOutOfBounds", 10),
			new EnumValue("ioError", 2),
			new EnumValue("fatalDupRecPointers", 11),
			new EnumValue("ok", 0),
			new EnumValue("fatalFsOffline", 14),
			new EnumValue("noDrives", 15),
			new EnumValue("fatalDirOutOfBounds", 7),
			new EnumValue("noHeap", 1),
			new EnumValue("lockError", 16)
		}, DbmValidationStatus.class);

		m_TypeTable[65] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("resetStatisticsBaseline", 1),
			new EnumValue("unknown", 0),
			new EnumValue("rebalanceLoad", 2)
		}, LoadBalanceAction.class);

		m_TypeTable[66] = new EnumSpec(new EnumValue[] {
			new EnumValue("hic", 1),
			new EnumValue("baseBoard", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unknown", 0)
		}, PortsRefType.class);

		m_TypeTable[67] = new EnumSpec(new EnumValue[] {
			new EnumValue("all", 0),
			new EnumValue("ssd", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("hdd", 2),
			new EnumValue("unknown", 1)
		}, DriveMediaType.class);

		m_TypeTable[68] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("active", 1),
			new EnumValue("disabled", 2),
			new EnumValue("completed", 3),
			new EnumValue("unknown", 0)
		}, ScheduleStatus.class);

		m_TypeTable[69] = new EnumSpec(new EnumValue[] {
			new EnumValue("asThick", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("asThin", 2),
			new EnumValue("unknown", 0)
		}, ThinVolumeReportingPolicy.class);

		m_TypeTable[70] = new EnumSpec(new EnumValue[] {
			new EnumValue("synthesized", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("ssdEndOfLife", 4),
			new EnumValue("driveReported", 2),
			new EnumValue("none", 1),
			new EnumValue("unknown", 0)
		}, DrivePfaReason.class);

		m_TypeTable[71] = new EnumSpec(new EnumValue[] {
			new EnumValue("all", 8),
			new EnumValue("cluster", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("saport", 5),
			new EnumValue("host", 3),
			new EnumValue("none", 1),
			new EnumValue("hostport", 2),
			new EnumValue("hostsaconnection", 7),
			new EnumValue("saportgroup", 6)
		}, LUNMappingType.class);

		m_TypeTable[72] = new EnumSpec(new EnumValue[] {
			new EnumValue("allEmulated", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("mixed", 3),
			new EnumValue("allNative", 1),
			new EnumValue("unknown", 0)
		}, DriveBlockFormat.class);

		m_TypeTable[73] = new EnumSpec(new EnumValue[] {
			new EnumValue("getValue", 1),
			new EnumValue("enableFunction", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("disableFunction", 3),
			new EnumValue("setDefault", 4),
			new EnumValue("unknown", 0)
		}, FunctionAction.class);

		m_TypeTable[74] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("initiator", 1),
			new EnumValue("unknown", 0),
			new EnumValue("target", 2)
		}, ScsiProtocolEndpointRole.class);

		m_TypeTable[75] = new EnumSpec(new EnumValue[] {
			new EnumValue("newRemoteTarget", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("existingRemoteTarget", 1),
			new EnumValue("unknown", 0)
		}, AsyncMirrorGroupConnectionCandidateType.class);

		m_TypeTable[76] = new EnumSpec(new EnumValue[] {
			new EnumValue("controllerTray", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("expansionTrays", 2)
		}, SocCommand.class);

		m_TypeTable[77] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("priority4", 4),
			new EnumValue("priority2", 2),
			new EnumValue("priority3", 3),
			new EnumValue("priority0", 0),
			new EnumValue("priority1", 1)
		}, VolumeCopyPriority.class);

		m_TypeTable[78] = new EnumSpec(new EnumValue[] {
			new EnumValue("expansionTypeManual", 1),
			new EnumValue("contractionTypeAutomatic", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("expansionTypeAutomatic", 2),
			new EnumValue("expansionTypeUnknown", 0)
		}, ThinVolumeRepositoryExpansionType.class);

		m_TypeTable[79] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 0),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("hwFailed", 2),
			new EnumValue("degraded", 1)
		}, DriveChannelState.class);
	}

	private static void __init1() {

		m_TypeTable[80] = new EnumSpec(new EnumValue[] {
			new EnumValue("endDevice", 4),
			new EnumValue("internal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("externalOut", 3),
			new EnumValue("open", 5),
			new EnumValue("unknown", 0),
			new EnumValue("externalIn", 2)
		}, SASPortMode.class);

		m_TypeTable[81] = new EnumSpec(new EnumValue[] {
			new EnumValue("controllerResident", 2),
			new EnumValue("enclosureSlotResident", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("driveCruResident", 1),
			new EnumValue("unknown", 0)
		}, SatType.class);

		m_TypeTable[82] = new EnumSpec(new EnumValue[] {
			new EnumValue("all", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("storageArray", 2),
			new EnumValue("volumeGroups", 3)
		}, ResetConfigType.class);

		m_TypeTable[83] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("fde", 3),
			new EnumValue("fips", 4),
			new EnumValue("mixed", 2),
			new EnumValue("none", 1),
			new EnumValue("unknown", 0)
		}, SecurityLevel.class);

		m_TypeTable[84] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("daily", 1),
			new EnumValue("monthlyDay", 4),
			new EnumValue("weekly", 2),
			new EnumValue("monthlyDate", 3),
			new EnumValue("unknown", 0)
		}, ScheduleMethod.class);

		m_TypeTable[85] = new EnumSpec(new EnumValue[] {
			new EnumValue("notBypassed", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("bypassed", 1)
		}, PortStatus.class);

		m_TypeTable[86] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("success", 0),
			new EnumValue("failure", 1),
			new EnumValue("none", -1)
		}, RuntimeDiagTestStatus.class);

		m_TypeTable[87] = new EnumSpec(new EnumValue[] {
			new EnumValue("high", 4),
			new EnumValue("low", 2),
			new EnumValue("highest", 5),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("invalid", 0),
			new EnumValue("medium", 3),
			new EnumValue("useDefault", 65535),
			new EnumValue("lowest", 1)
		}, DiskPoolOperationPriority.class);

		m_TypeTable[88] = new EnumSpec(new EnumValue[] {
			new EnumValue("srp", 2),
			new EnumValue("notSupported", 0),
			new EnumValue("nvme", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("iser", 1)
		}, InfinibandHICProtocol.class);

		m_TypeTable[89] = new EnumSpec(new EnumValue[] {
			new EnumValue("reasonOther", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("reasonUnknown", 0),
			new EnumValue("reasonAssert", 1),
			new EnumValue("reasonPanic", 2)
		}, DPLCoreDumpReason.class);

		m_TypeTable[90] = new EnumSpec(new EnumValue[] {
			new EnumValue("stopped", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("started", 2),
			new EnumValue("unknown", 0)
		}, FlashCacheAnalyticsStatus.class);

		m_TypeTable[91] = new EnumSpec(new EnumValue[] {
			new EnumValue("incomplete", 4),
			new EnumValue("stopped", 6),
			new EnumValue("optimal", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 3),
			new EnumValue("initialSync", 1),
			new EnumValue("orphan", 5),
			new EnumValue("unknown", 0)
		}, AsyncMirrorGroupMemberState.class);

		m_TypeTable[92] = new EnumSpec(new EnumValue[] {
			new EnumValue("writeCache", 2),
			new EnumValue("virtual", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unknown", 0),
			new EnumValue("readOnlyCache", 1)
		}, FlashCacheType.class);

		m_TypeTable[93] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("readWrite", 2),
			new EnumValue("readOnly", 1),
			new EnumValue("unknown", 0)
		}, SNMPCommunityPermissions.class);

		m_TypeTable[94] = new EnumSpec(new EnumValue[] {
			new EnumValue("normal", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("discovery", 2)
		}, IscsiSessionType.class);

		m_TypeTable[95] = new EnumSpec(new EnumValue[] {
			new EnumValue("type4portIscsi", 10),
			new EnumValue("type4portFcIscsiSamoa", 14),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("type4portFc", 2),
			new EnumValue("type4portEthernet25gb", 25),
			new EnumValue("type2portFc", 5),
			new EnumValue("type4portFc32gb", 26),
			new EnumValue("type4portFcSamoa", 20),
			new EnumValue("type2portFcIscsiSamoa", 13),
			new EnumValue("type2portIb100gb", 24),
			new EnumValue("type20portSwitchedFc", 3),
			new EnumValue("type4portSasGlacier", 12),
			new EnumValue("type4portSasAcadia", 17),
			new EnumValue("type2portSasAcadia", 16),
			new EnumValue("type4portSas3", 23),
			new EnumValue("type2portIscsi", 6),
			new EnumValue("type2portIscsiSamoa", 21),
			new EnumValue("typeUnknown", 1),
			new EnumValue("type8portFc", 9),
			new EnumValue("type2portIb", 8),
			new EnumValue("type4portIscsiSamoa", 22),
			new EnumValue("type2portIscsiZion", 15),
			new EnumValue("type4portSas", 11),
			new EnumValue("type2portIbDenali", 18),
			new EnumValue("type2portFcSamoa", 19),
			new EnumValue("type1portSas", 4),
			new EnumValue("type2portSas", 7)
		}, HostBoardType.class);

		m_TypeTable[96] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("domainName", 1),
			new EnumValue("ipvx", 2),
			new EnumValue("none", 0)
		}, NetworkAddressType.class);

		m_TypeTable[97] = new EnumSpec(new EnumValue[] {
			new EnumValue("dualSharedCrus", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("dualIndividualCrus", 4),
			new EnumValue("singleSharedCru", 1),
			new EnumValue("dualIndividualFrus", 2)
		}, BatteryType.class);

		m_TypeTable[98] = new EnumSpec(new EnumValue[] {
			new EnumValue("driveside", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("hostside", 1)
		}, ControllerSFPType.class);

		m_TypeTable[99] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("onBattery", 2)
		}, UPSStatus.class);

		m_TypeTable[100] = new EnumSpec(new EnumValue[] {
			new EnumValue("speed1000MbitHalfDuplex", 6),
			new EnumValue("speed100MbitHalfDuplex", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("speed1000MbitFullDuplex", 7),
			new EnumValue("speedNone", 0),
			new EnumValue("speed10MbitHalfDuplex", 2),
			new EnumValue("speed100MbitFullDuplex", 5),
			new EnumValue("speedAutoNegotiated", 1),
			new EnumValue("speed10MbitFullDuplex", 3)
		}, EthernetSpeedSetting.class);

		m_TypeTable[101] = new EnumSpec(new EnumValue[] {
			new EnumValue("offline", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("recoveryMode", 4),
			new EnumValue("readWrite", 3),
			new EnumValue("readOnly", 2),
			new EnumValue("unknown", 0)
		}, DatabaseAccessibility.class);

		m_TypeTable[102] = new EnumSpec(new EnumValue[] {
			new EnumValue("critical", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("invalid", 0),
			new EnumValue("warning", 1)
		}, DiskPoolThresholdType.class);

		m_TypeTable[103] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 3),
			new EnumValue("degraded", 2),
			new EnumValue("unknown", 0)
		}, ConcatVolumeStatus.class);

		m_TypeTable[104] = new EnumSpec(new EnumValue[] {
			new EnumValue("secondary", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unknown", 0),
			new EnumValue("primary", 1)
		}, AsyncMirrorGroupRole.class);

		m_TypeTable[105] = new EnumSpec(new EnumValue[] {
			new EnumValue("crc32c", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("none", 2)
		}, DigestMethod.class);

		m_TypeTable[106] = new EnumSpec(new EnumValue[] {
			new EnumValue("tray", 1),
			new EnumValue("controller", 7),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("trayslot", 2),
			new EnumValue("channel", 4),
			new EnumValue("label", 9),
			new EnumValue("minihub", 3),
			new EnumValue("unknown", 0),
			new EnumValue("volumeGrp", 10),
			new EnumValue("volume", 5),
			new EnumValue("ref", 8),
			new EnumValue("diskPool", 11),
			new EnumValue("pit", 6)
		}, ExtendedComponentLocationType.class);

		m_TypeTable[107] = new EnumSpec(new EnumValue[] {
			new EnumValue("deleting", 6),
			new EnumValue("optimal", 1),
			new EnumValue("impaired", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("creating", 5),
			new EnumValue("failed", 3),
			new EnumValue("degraded", 2)
		}, VolumeStatus.class);

		m_TypeTable[108] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 0),
			new EnumValue("noLun", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("noArray", 2),
			new EnumValue("initializing", 4),
			new EnumValue("noFabric", 3),
			new EnumValue("wwnChangeFailed", 5)
		}, RemoteVolumeState.class);

		m_TypeTable[109] = new EnumSpec(new EnumValue[] {
			new EnumValue("needsAttention", 2),
			new EnumValue("diagInProgress", 6),
			new EnumValue("optimal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("notPresent", 3),
			new EnumValue("failed", 5),
			new EnumValue("degraded", 4),
			new EnumValue("unknown", 0)
		}, HostBoardStatus.class);

		m_TypeTable[110] = new EnumSpec(new EnumValue[] {
			new EnumValue("controller", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("drive", 2),
			new EnumValue("esm", 3)
		}, RLSDeviceType.class);

		m_TypeTable[111] = new EnumSpec(new EnumValue[] {
			new EnumValue("remoteMirror", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("allMdatTypes", -1)
		}, MetadataVolType.class);

		m_TypeTable[112] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("priority4", 4),
			new EnumValue("priority2", 2),
			new EnumValue("priority3", 3),
			new EnumValue("priority0", 0),
			new EnumValue("priority1", 1)
		}, VolumeScanPriority.class);

		m_TypeTable[113] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("ibRdma", 1),
			new EnumValue("undefined", 0)
		}, NVMeTransportType.class);

		m_TypeTable[114] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("port3", 3),
			new EnumValue("port4", 4),
			new EnumValue("port1", 1),
			new EnumValue("portUnknown", 0),
			new EnumValue("port2", 2)
		}, SFPPort.class);

		m_TypeTable[115] = new EnumSpec(new EnumValue[] {
			new EnumValue("dataCoreFiles", 5),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("journalLogs", 1),
			new EnumValue("weeklyDiagnostics", 4),
			new EnumValue("miscLogs", 2),
			new EnumValue("dailyDiagnostics", 3),
			new EnumValue("unknownType", 0)
		}, Dom0SupportDataType.class);

		m_TypeTable[116] = new EnumSpec(new EnumValue[] {
			new EnumValue("rollback", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("none", 1)
		}, SnapshotAction.class);

		m_TypeTable[117] = new EnumSpec(new EnumValue[] {
			new EnumValue("sunday", 1),
			new EnumValue("saturday", 64),
			new EnumValue("tuesday", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("wednesday", 8),
			new EnumValue("thursday", 16),
			new EnumValue("friday", 32),
			new EnumValue("notSpecified", 0),
			new EnumValue("monday", 2)
		}, DayOfWeek.class);

		m_TypeTable[118] = new EnumSpec(new EnumValue[] {
			new EnumValue("tray", 28),
			new EnumValue("thermalSensor", 4),
			new EnumValue("gbic", 8),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("storageArray", 29),
			new EnumValue("battery", 2),
			new EnumValue("minihub", 7),
			new EnumValue("powerSupply", 3),
			new EnumValue("sasInterface", 27),
			new EnumValue("unknown", 0),
			new EnumValue("fan", 1),
			new EnumValue("hostIoCard", 15),
			new EnumValue("alarm", 12),
			new EnumValue("procMemDimm", 18),
			new EnumValue("hostboard", 13),
			new EnumValue("cacheBackupDevice", 16),
			new EnumValue("controller", 22),
			new EnumValue("interconnectCru", 10),
			new EnumValue("iscsiInterface", 26),
			new EnumValue("cacheMemDimm", 17),
			new EnumValue("drawer", 30),
			new EnumValue("channelPort", 20),
			new EnumValue("fibreInterface", 24),
			new EnumValue("ibInterface", 25),
			new EnumValue("ups", 6),
			new EnumValue("ethernetInterface", 23),
			new EnumValue("sfp", 9),
			new EnumValue("icSasExpander", 14),
			new EnumValue("drive", 21),
			new EnumValue("esm", 5),
			new EnumValue("supportCru", 11)
		}, ComponentType.class);

		m_TypeTable[119] = new EnumSpec(new EnumValue[] {
			new EnumValue("controller", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("drawer", 3),
			new EnumValue("esm", 2)
		}, SocParentType.class);

		m_TypeTable[120] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("enable", 1),
			new EnumValue("disable", 2),
			new EnumValue("refresh", 3)
		}, RTRControl.class);

		m_TypeTable[121] = new EnumSpec(new EnumValue[] {
			new EnumValue("summary", 1),
			new EnumValue("all", 5),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("latency", 3),
			new EnumValue("channel", 2),
			new EnumValue("drive", 4)
		}, PerformanceRingType.class);

		m_TypeTable[122] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("topology", 1),
			new EnumValue("ctlrDrivePortToHost", 3),
			new EnumValue("ctlrHostPort", 2),
			new EnumValue("none", 0),
			new EnumValue("ctlrDrivePortToEndDevice", 5),
			new EnumValue("esm", 4)
		}, SasMiswireType.class);

		m_TypeTable[123] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("removed", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 2),
			new EnumValue("unknown", 4)
		}, FanStatus.class);

		m_TypeTable[124] = new EnumSpec(new EnumValue[] {
			new EnumValue("volumesPerPartition", 1),
			new EnumValue("solidStateDiskLimit", 61),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("mixedDriveTypes", 8),
			new EnumValue("embeddedSnmpOid", 65),
			new EnumValue("totalNumberOfPitConsistencyGroups", 56),
			new EnumValue("samoaHicProtocol", 68),
			new EnumValue("totalNumberOfArvmMirrorsPerArray", 50),
			new EnumValue("secureVolume", 21),
			new EnumValue("memberVolsPerPitConsistencyGroup", 55),
			new EnumValue("solidStateDisk", 23),
			new EnumValue("ectSelector", 64),
			new EnumValue("raid6", 18),
			new EnumValue("pitGroupsPerVolume", 52),
			new EnumValue("totalNumberOfVolCopies", 14),
			new EnumValue("totalNumberOfSnapshots", 13),
			new EnumValue("driveTrayExpansion", 7),
			new EnumValue("totalNumberOfAsyncMirrorsPerGroup", 49),
			new EnumValue("mgmtApplication", 9),
			new EnumValue("snapshotsPerVolume", 16),
			new EnumValue("asupOnDemand", 66),
			new EnumValue("performanceTier", 12),
			new EnumValue("stateCapture", 19),
			new EnumValue("denali2Protocol", 73),
			new EnumValue("totalNumberOfPitGroups", 53),
			new EnumValue("totalNumberOfRemoteMirrorsPerArray", 62),
			new EnumValue("snapshot", 4),
			new EnumValue("protectionInformation", 22),
			new EnumValue("volumeCopy", 5),
			new EnumValue("storagePartitions", 3),
			new EnumValue("totalNumberOfPitsPerArray", 51),
			new EnumValue("dacstoreCompatId", 67),
			new EnumValue("supportedDriveTrays", 11),
			new EnumValue("vendorSupportedDrives", 38),
			new EnumValue("supportedInterposer", 32),
			new EnumValue("sataStrLen", 20),
			new EnumValue("supportedDrives", 10),
			new EnumValue("targetPortLunMapping", 69),
			new EnumValue("nativeSataDriveSupport", 60),
			new EnumValue("fdeProxyKeyManagement", 31),
			new EnumValue("pitsPerPitGroup", 54),
			new EnumValue("totalNumberOfPitViews", 57),
			new EnumValue("asup", 63),
			new EnumValue("driveSlotLimit", 30),
			new EnumValue("totalNumberOfAsyncMirrorGroups", 48),
			new EnumValue("totalNumberOfThinVolumesPerArray", 58),
			new EnumValue("remoteMirroring", 6),
			new EnumValue("goldKey", 15),
			new EnumValue("flashReadCache", 47),
			new EnumValue("totalNumberOfMirrors", 17),
			new EnumValue("hildaBaseboardProtocol", 72),
			new EnumValue("totalNumberOfVolumes", 2)
		}, FeatureId.class);

		m_TypeTable[125] = new EnumSpec(new EnumValue[] {
			new EnumValue("configAll", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("configNone", 0),
			new EnumValue("partialConfig", 3),
			new EnumValue("traditionalConfig", 1)
		}, DbmRecConfigType.class);

		m_TypeTable[126] = new EnumSpec(new EnumValue[] {
			new EnumValue("iccCru", 4),
			new EnumValue("controller", 1),
			new EnumValue("fan", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("drawer", 6),
			new EnumValue("esm", 2),
			new EnumValue("supportCru", 5)
		}, ParentCruType.class);

		m_TypeTable[127] = new EnumSpec(new EnumValue[] {
			new EnumValue("waiting", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("none", 1),
			new EnumValue("failed", 3),
			new EnumValue("unknown", 0)
		}, PITCreationPendingStatus.class);

		m_TypeTable[128] = new EnumSpec(new EnumValue[] {
			new EnumValue("removed", 5),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("disabled", 2),
			new EnumValue("sounding", 3),
			new EnumValue("muted", 4),
			new EnumValue("enabled", 1),
			new EnumValue("unknown", 0)
		}, AlarmStatus.class);

		m_TypeTable[129] = new EnumSpec(new EnumValue[] {
			new EnumValue("controllerLocal", 0),
			new EnumValue("unknownDevice", 5),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("controllerAlternate", 1),
			new EnumValue("drawer", 6),
			new EnumValue("drive", 2),
			new EnumValue("sfp", 4),
			new EnumValue("esm", 3)
		}, SocConnectedDeviceType.class);

		m_TypeTable[130] = new EnumSpec(new EnumValue[] {
			new EnumValue("transitionHalf", 1),
			new EnumValue("transitionDouble", 2),
			new EnumValue("__UNDEFINED", 464378545)
		}, SegmentSizeTransition.class);

		m_TypeTable[131] = new EnumSpec(new EnumValue[] {
			new EnumValue("unreadable", 255),
			new EnumValue("accessError", 254),
			new EnumValue("nominal", 128),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unknown", 0)
		}, ThermalSensorValue.class);

		m_TypeTable[132] = new EnumSpec(new EnumValue[] {
			new EnumValue("noneFc", 6),
			new EnumValue("providerIwarp", 5),
			new EnumValue("providerRoce", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("providerUnspecified", 1),
			new EnumValue("providerUnknown", 0),
			new EnumValue("providerInfiniband", 2),
			new EnumValue("providerRocev2", 4)
		}, NVMeoFRDMAProvider.class);

		m_TypeTable[133] = new EnumSpec(new EnumValue[] {
			new EnumValue("wallClockTime", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("standardTime", 2),
			new EnumValue("utcTime", 3),
			new EnumValue("unknown", 0)
		}, ClockMode.class);
	}

	private static void __init2() {

		m_TypeTable[134] = new EnumSpec(new EnumValue[] {
			new EnumValue("mixedDriveEnclosureMiswire", 335),
			new EnumValue("mismatchedMidplaneEeproms", 381),
			new EnumValue("esmCodeVersionMismatch", 31),
			new EnumValue("submodelNotSet", 99),
			new EnumValue("externalKmsKeyInvalid", 386),
			new EnumValue("speedNegError", 73),
			new EnumValue("goldKeyNotCompliant", 93),
			new EnumValue("missingDriveLockdown", 455),
			new EnumValue("passiveCtl", 29),
			new EnumValue("impendingDriveFailureRiskMed", 25),
			new EnumValue("failedEsm", 4),
			new EnumValue("batteryUnknownStat", 91),
			new EnumValue("trayidMismatch", 35),
			new EnumValue("cacheNotFlushedOnOnlyCtlr", 477),
			new EnumValue("lossOfExternalRedundancy", 449),
			new EnumValue("featureNotCompliant", 391),
			new EnumValue("linkSpeedDetectionMismatch", 82),
			new EnumValue("writebackCachingDisabled", 329),
			new EnumValue("excessiveRebootsDetected", 476),
			new EnumValue("remoteNoLun", 54),
			new EnumValue("driveIncompatibleSectorSize", 211),
			new EnumValue("pathDegraded", 76),
			new EnumValue("maxTempExceeded", 8),
			new EnumValue("nonFruBatteryNearExpiration", 39),
			new EnumValue("driveTraysNotGroupedTogether", 92),
			new EnumValue("inactiveHostPort", 338),
			new EnumValue("tpvRepositoryOverThreshold", 429),
			new EnumValue("volumeGroupPartiallyComplete", 200),
			new EnumValue("failedTransceiverModule", 37),
			new EnumValue("supportCruUnknownStat", 208),
			new EnumValue("netNtpQueryFail", 466),
			new EnumValue("failedDrive", 23),
			new EnumValue("upsOnBattery", 9),
			new EnumValue("unsupportedHostBoard", 328),
			new EnumValue("piErrorServiceMode", 458),
			new EnumValue("failedVolumeAwaitingInit", 20),
			new EnumValue("arvmFailedMirror", 413),
			new EnumValue("rpaErrCtl", 41),
			new EnumValue("batteryOvertemp", 261),
			new EnumValue("mismatchedMdtSettings", 94),
			new EnumValue("mismatchedDriveType", 78),
			new EnumValue("kmipServerCertificateNearingExpiration", 481),
			new EnumValue("vgHasDrivePartOfMultipleVgs", 225),
			new EnumValue("failedModifyingMultiRaid", 16),
			new EnumValue("replacedDriveWrongType", 107),
			new EnumValue("pitViewFailed", 410),
			new EnumValue("rvmWriteModeInconsistent", 450),
			new EnumValue("pitPurged", 411),
			new EnumValue("arvmPrimaryRepositoryFull", 435),
			new EnumValue("vgCloned", 216),
			new EnumValue("esmFactoryDefaultsMismatch", 120),
			new EnumValue("unsupportedCacheMemorySize", 223),
			new EnumValue("altCtlrBoardIdUnreadable", 250),
			new EnumValue("lostRedundancyDrive", 32),
			new EnumValue("offlineCtl", 28),
			new EnumValue("volcopyFailed", 69),
			new EnumValue("pitViewRepositoryFull", 408),
			new EnumValue("incompatibleFailedLegacyDrive", 220),
			new EnumValue("nativeVgForeignDriveMutualRef", 215),
			new EnumValue("kmipServerConnectionFailure", 486),
			new EnumValue("fibreTrunkIncompatibleEsm", 365),
			new EnumValue("sasPhyDisabledLocalWidePortDegraded", 397),
			new EnumValue("externalKmsNotCompliant", 371),
			new EnumValue("uncertifiedEsm", 83),
			new EnumValue("nominalTempExceeded", 7),
			new EnumValue("multipleMismatchedKeyIdsFound", 387),
			new EnumValue("foreignDriveHasInconsistentRole", 217),
			new EnumValue("flashCacheNonOptimalDrives", 439),
			new EnumValue("removedAlarm", 207),
			new EnumValue("kmipServerDnsError", 483),
			new EnumValue("snapshotRollbackPaused", 403),
			new EnumValue("copyThenFailWaitingOnDdpCapacity", 457),
			new EnumValue("transModUnknownStat", 62),
			new EnumValue("enclosureMisconfigured", 117),
			new EnumValue("drawerRemoved", 400),
			new EnumValue("failedPowerSupply", 2),
			new EnumValue("arvmOrphanIncompleteMember", 445),
			new EnumValue("offlineCtlIocFail", 394),
			new EnumValue("arvmSyncInternallySuspended", 433),
			new EnumValue("impendingDriveFailureRiskLow", 26),
			new EnumValue("iccCruUnknownStat", 206),
			new EnumValue("multipathConfigurationError", 474),
			new EnumValue("submodelMismatch", 100),
			new EnumValue("trayidConflict", 36),
			new EnumValue("supportCruNoinput", 97),
			new EnumValue("baseControllerDiagFailed", 390),
			new EnumValue("directoryServicesConfigError", 480),
			new EnumValue("batteryWarn", 176),
			new EnumValue("volcopyNotCompliant", 70),
			new EnumValue("failedBattery", 6),
			new EnumValue("arvmMirrorGroupRoleConflict", 416),
			new EnumValue("failedMinihub", 3),
			new EnumValue("vgDrivePartOfMultipleVgs", 218),
			new EnumValue("failedHostIoCard", 150),
			new EnumValue("hotspareDriveMissing", 203),
			new EnumValue("diskPoolIncomplete", 422),
			new EnumValue("legacyVgNotOptimal", 230),
			new EnumValue("drawerFailed", 343),
			new EnumValue("pendingPitCreationFailed", 427),
			new EnumValue("fibreTrunkMiswire", 364),
			new EnumValue("diskPoolPartiallyPresent", 421),
			new EnumValue("arvmOrphanGroup", 418),
			new EnumValue("failedTwiBus", 380),
			new EnumValue("securityKeyValidationLock", 388),
			new EnumValue("removedSupportCru", 88),
			new EnumValue("sasDeviceLimitExceeded", 110),
			new EnumValue("kmipServerAuthenticationFailure", 485),
			new EnumValue("piErrorLockdown", 459),
			new EnumValue("diskPoolReconstructionDriveCountBelowThreshold", 424),
			new EnumValue("performanceTierNotCompliant", 209),
			new EnumValue("kmipServerCertificateError", 484),
			new EnumValue("hicConfigurationOoc", 456),
			new EnumValue("drawerDegraded", 393),
			new EnumValue("pitGroupRepositoryOverThreshold", 405),
			new EnumValue("driveBypassedCauseUnknown", 64),
			new EnumValue("minihubSpeedMismatch", 65),
			new EnumValue("tpvRepositoryFull", 430),
			new EnumValue("corruptVpdEeprom", 114),
			new EnumValue("usmUnreadableSectorsExist", 75),
			new EnumValue("drawerOpened", 344),
			new EnumValue("kmipServerError", 487),
			new EnumValue("mirrorDualSecondary", 52),
			new EnumValue("wbCachingForciblyDisabled", 378),
			new EnumValue("fanUnknownStat", 58),
			new EnumValue("adoptionFailedRaidLevelUnsupported", 228),
			new EnumValue("unknownFailure", 0),
			new EnumValue("uncertifiedDrive", 27),
			new EnumValue("cacheBackupDeviceWriteProtected", 252),
			new EnumValue("driveIncompatibleDownrevDacstore", 205),
			new EnumValue("ddcAvailable", 106),
			new EnumValue("failedVolume", 17),
			new EnumValue("snapshotNotCompliant", 48),
			new EnumValue("arvmDegradedMirrorGroup", 412),
			new EnumValue("tpvFailed", 431),
			new EnumValue("powerSupplyUnknownStat", 59),
			new EnumValue("netNtpServiceUnavailable", 467),
			new EnumValue("diskPoolUtilizationCritical", 426),
			new EnumValue("driveIncompatiblePiType", 392),
			new EnumValue("sasCrossMiswire", 452),
			new EnumValue("removedBattery", 67),
			new EnumValue("driveIncompatibleUprevDacstore", 204),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("ldFwVersionMismatch", 301),
			new EnumValue("impairedVolume", 19),
			new EnumValue("volumeHotSpareInUse", 21),
			new EnumValue("multipleConfigDatabasesDetected", 227),
			new EnumValue("sasLoopMiswire", 453),
			new EnumValue("expiredIntegratedBattery", 255),
			new EnumValue("nonPreferredPath", 10),
			new EnumValue("removedFan", 84),
			new EnumValue("protectionInformationNotSupported", 341),
			new EnumValue("failedModifyingVolume", 15),
			new EnumValue("arvmMirrorGroupRecoveryPointLost", 420),
			new EnumValue("unsupportedTray", 72),
			new EnumValue("driveUnsupportedCapacity", 384),
			new EnumValue("lostRedundancyTray", 33),
			new EnumValue("ctlMismatch", 79),
			new EnumValue("thresExcdedMismatchCorrected", 337),
			new EnumValue("foreignDriveInconsistent", 212),
			new EnumValue("snapshotFailed", 44),
			new EnumValue("remoteNoArray", 55),
			new EnumValue("mirrorUnsynchronized", 53),
			new EnumValue("hostBoardIdMismatch", 325),
			new EnumValue("cacheDataLoss", 389),
			new EnumValue("memParityError", 11),
			new EnumValue("removedIccCru", 87),
			new EnumValue("flashCacheHotSpareInUse", 440),
			new EnumValue("ddfDriveOtherVendor", 226),
			new EnumValue("iccMissing", 326),
			new EnumValue("netSetupError", 77),
			new EnumValue("enclosureThermalShutdown", 377),
			new EnumValue("databaseRecoveryMode", 434),
			new EnumValue("channelFailed", 81),
			new EnumValue("mismatchedGoldKeySettings", 95),
			new EnumValue("degradedHostIoCard", 300),
			new EnumValue("pitGroupRepositoryFull", 407),
			new EnumValue("esmUnknownStat", 60),
			new EnumValue("esmMiswire", 46),
			new EnumValue("offlineVolumeGroup", 22),
			new EnumValue("rvmNotCompliant", 49),
			new EnumValue("redundancyGroupNotConsistentDuringReconfig", 402),
			new EnumValue("driveIncompatibleAlignmentForEmulationDrive", 448),
			new EnumValue("sasPortMiswired", 111),
			new EnumValue("diskPoolDriveFailure", 443),
			new EnumValue("arvmSyncPausedAltState", 446),
			new EnumValue("nonFruRemovedBattery", 68),
			new EnumValue("pitViewRepositoryOverThreshold", 406),
			new EnumValue("batteryNearExpiration", 5),
			new EnumValue("invalidHostTypeIndex", 263),
			new EnumValue("arvmRoleChangePaused", 447),
			new EnumValue("hostBoardUnknownStat", 121),
			new EnumValue("failedIccCru", 89),
			new EnumValue("unsuccessIsolationRedunMismatch", 336),
			new EnumValue("dbAdoptionHardLimitExceeded", 229),
			new EnumValue("partitionsNotCompliant", 30),
			new EnumValue("hostRedundancyLost", 475),
			new EnumValue("replacedInsufficientDriveCapacity", 342),
			new EnumValue("repositoryOverThreshold", 42),
			new EnumValue("repositoryFull", 43),
			new EnumValue("invalidSataFlashConfiguration", 395),
			new EnumValue("netNtpResolutionFail", 465),
			new EnumValue("incompatibleVolumeGroupSecurity", 417),
			new EnumValue("diskPoolUtilizationWarning", 425),
			new EnumValue("arvmSecondaryRepositoryFull", 432),
			new EnumValue("driveUnsupportedProtocolConnection", 379),
			new EnumValue("securityKeyInconsistent", 333),
			new EnumValue("arvmRepositoryOverWarnThreshold", 415),
			new EnumValue("failedBatterySystem", 101),
			new EnumValue("linkSpeedMismatch", 327),
			new EnumValue("removedController", 266),
			new EnumValue("copyThenFailWaitingOnHotSpare", 454),
			new EnumValue("driveSlotLimitNotCompliant", 368),
			new EnumValue("diskPoolMissing", 423),
			new EnumValue("invalidPowerSupply", 376),
			new EnumValue("inactiveInitiator", 339),
			new EnumValue("ssdAtEndOfLife", 349),
			new EnumValue("removedEsm", 66),
			new EnumValue("driveBypassedSinglePort", 119),
			new EnumValue("raid6NotCompliant", 210),
			new EnumValue("allDrivesBypassedIncompatibleNvsram", 441),
			new EnumValue("securityAuditLogWarnThresh", 479),
			new EnumValue("ghostVolume", 47),
			new EnumValue("driveTraysNotCompliant", 109),
			new EnumValue("ctlFailedCacheBackupDev", 265),
			new EnumValue("sasPortDiscoveryError", 460),
			new EnumValue("failedVolumeMultiRaid", 18),
			new EnumValue("securityGetKey", 331),
			new EnumValue("nonFruFailedBattery", 40),
			new EnumValue("securityGetNewKey", 370),
			new EnumValue("failedSupportCru", 90),
			new EnumValue("sasHostMiswire", 451),
			new EnumValue("driveUnsupportedInterposerFwVersion", 401),
			new EnumValue("failedI2cBus", 115),
			new EnumValue("evaluationLicenseExpirationImminent", 385),
			new EnumValue("mirrorDualPrimary", 51),
			new EnumValue("failedVolumeInterruptedWrite", 14),
			new EnumValue("impendingDriveFailureRiskHigh", 24),
			new EnumValue("redundantPsRequired", 108),
			new EnumValue("failedFan", 1),
			new EnumValue("removedPowerSupply", 85),
			new EnumValue("removedTempSensor", 86),
			new EnumValue("ctlMiswire", 96),
			new EnumValue("drawerInvalid", 399),
			new EnumValue("volumeGroupIncomplete", 201),
			new EnumValue("kmipServerKeyRequirementNotMet", 488),
			new EnumValue("driveBypassedSpeedMismatch", 63),
			new EnumValue("volumeGroupMissing", 202),
			new EnumValue("securityAuditLogFull", 478),
			new EnumValue("failedDiscreteLine", 80),
			new EnumValue("metadataOffline", 50),
			new EnumValue("pitGroupFailed", 409),
			new EnumValue("kmipServerCertificateExpired", 482),
			new EnumValue("dedicatedMirrorChannelFailed", 224),
			new EnumValue("nativeVgRefersToForeignDrive", 214),
			new EnumValue("lostRedundancyEsm", 34),
			new EnumValue("channelDegraded", 71),
			new EnumValue("sasPhyDisabledSharedWidePortDegraded", 398),
			new EnumValue("expiredBattery", 254),
			new EnumValue("esmHardwareMismatch", 104),
			new EnumValue("cacheBackupDeviceInsufficientCapacity", 253),
			new EnumValue("channelMiswire", 38),
			new EnumValue("pendingCgpitCreationFailed", 428),
			new EnumValue("usmDatabaseFull", 74),
			new EnumValue("diskPoolCapacityDepleted", 437),
			new EnumValue("failedDriveScsiChannel", 12),
			new EnumValue("removedBatteryPack", 102),
			new EnumValue("procMemTooSmallForCache", 259),
			new EnumValue("cacheBackupDeviceFailed", 251),
			new EnumValue("unsupportedMinihub", 45),
			new EnumValue("protectionInformationNotCompliant", 340),
			new EnumValue("securityNotCompliant", 334),
			new EnumValue("insufficientProcMemory", 264),
			new EnumValue("sbbValidationFailure", 374),
			new EnumValue("foreignDriveRefersToNativeDrive", 213),
			new EnumValue("hostBoardFault", 105),
			new EnumValue("remoteNoFabric", 56),
			new EnumValue("remoteWwnChangeFailed", 57),
			new EnumValue("tempSensorUnknownStat", 61),
			new EnumValue("driveIncompatibleModelNumberUnsupported", 438),
			new EnumValue("degradedVolume", 13),
			new EnumValue("sasPortDegraded", 112),
			new EnumValue("cacheMemSizeMismatch", 231),
			new EnumValue("incompatibleSataDrive", 436),
			new EnumValue("pitRollbackPaused", 404),
			new EnumValue("ssdNotCompliant", 347),
			new EnumValue("submodelNotSupported", 98),
			new EnumValue("iocDiagFail", 396),
			new EnumValue("arvmSyncIntervalTimeOverThreshold", 414),
			new EnumValue("ldIncompatibleDatabase", 302),
			new EnumValue("diskPoolInsufficientMemory", 444),
			new EnumValue("batteryConfigMismatch", 103),
			new EnumValue("arvmOrphanMember", 419),
			new EnumValue("sasPortFailed", 113),
			new EnumValue("featureBundleNotCompliant", 118)
		}, RecoveryFailureType.class);

		m_TypeTable[135] = new EnumSpec(new EnumValue[] {
			new EnumValue("november", 1024),
			new EnumValue("may", 16),
			new EnumValue("august", 128),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("february", 2),
			new EnumValue("july", 64),
			new EnumValue("notSpecified", 0),
			new EnumValue("april", 8),
			new EnumValue("march", 4),
			new EnumValue("june", 32),
			new EnumValue("september", 256),
			new EnumValue("january", 1),
			new EnumValue("december", 2048),
			new EnumValue("october", 512)
		}, MonthOfYear.class);

		m_TypeTable[136] = new EnumSpec(new EnumValue[] {
			new EnumValue("type1Protection", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("type2Protection", 2),
			new EnumValue("type3Protection", 3),
			new EnumValue("type0Protection", 0)
		}, ProtectionType.class);

		m_TypeTable[137] = new EnumSpec(new EnumValue[] {
			new EnumValue("paused", 3),
			new EnumValue("inProgress", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("pending", 2),
			new EnumValue("none", 0)
		}, SnapshotRollbackStatus.class);

		m_TypeTable[138] = new EnumSpec(new EnumValue[] {
			new EnumValue("unsupported", 3),
			new EnumValue("optimal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 2),
			new EnumValue("unknown", 4)
		}, MinihubStatus.class);

		m_TypeTable[139] = new EnumSpec(new EnumValue[] {
			new EnumValue("high", 1),
			new EnumValue("highest", 0),
			new EnumValue("low", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("medium", 2),
			new EnumValue("lowest", 4)
		}, RollbackPriority.class);

		m_TypeTable[140] = new EnumSpec(new EnumValue[] {
			new EnumValue("rpFailed", 4),
			new EnumValue("optimal", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("initialSync", 1),
			new EnumValue("degraded", 3),
			new EnumValue("unknown", 0)
		}, AsyncMirrorGroupState.class);

		m_TypeTable[141] = new EnumSpec(new EnumValue[] {
			new EnumValue("notSupported", 6),
			new EnumValue("inProgress", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("stopByInitiator", 4),
			new EnumValue("stopByReset", 5),
			new EnumValue("none", 0),
			new EnumValue("failed", 3),
			new EnumValue("successful", 2),
			new EnumValue("skipped", 7)
		}, FruDiagStatus.class);

		m_TypeTable[142] = new EnumSpec(new EnumValue[] {
			new EnumValue("internal", 0),
			new EnumValue("external", 1),
			new EnumValue("__UNDEFINED", 464378545)
		}, RuntimeDiagTestLevel.class);

		m_TypeTable[143] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 3),
			new EnumValue("degraded", 2),
			new EnumValue("suspended", 4),
			new EnumValue("unknown", 0)
		}, FlashCacheStatus.class);

		m_TypeTable[144] = new EnumSpec(new EnumValue[] {
			new EnumValue("controller", 3),
			new EnumValue("hic", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("minihub", 2),
			new EnumValue("esm", 1),
			new EnumValue("unknown", 0)
		}, ChannelPortParentType.class);

		m_TypeTable[145] = new EnumSpec(new EnumValue[] {
			new EnumValue("driveside", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("hostside", 1)
		}, MinihubType.class);

		m_TypeTable[146] = new EnumSpec(new EnumValue[] {
			new EnumValue("lwlLc", 1),
			new EnumValue("na", 7),
			new EnumValue("swlwoofc", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("eiae", 3),
			new EnumValue("lwlLl", 6),
			new EnumValue("swlwofc", 5),
			new EnumValue("eiee", 2),
			new EnumValue("unknown", 0)
		}, SFP_TRANSMITTER_TYPE.class);

		m_TypeTable[147] = new EnumSpec(new EnumValue[] {
			new EnumValue("sleep", 1),
			new EnumValue("phyTest", 7),
			new EnumValue("linkUp", 5),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("linkErrRec", 6),
			new EnumValue("disabled", 3),
			new EnumValue("polling", 2),
			new EnumValue("cfgTrain", 4),
			new EnumValue("unknown", 0)
		}, IbPhysPortState.class);

		m_TypeTable[148] = new EnumSpec(new EnumValue[] {
			new EnumValue("standard", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("flashcache", 2),
			new EnumValue("unknown", 0)
		}, VolumeGroupUsage.class);

		m_TypeTable[149] = new EnumSpec(new EnumValue[] {
			new EnumValue("speed10meg", 8),
			new EnumValue("speed25gig", 21),
			new EnumValue("speed2pt5Gig", 10),
			new EnumValue("speed30gig", 13),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("speed100gig", 23),
			new EnumValue("speedUnknown", 1),
			new EnumValue("speed60gig", 14),
			new EnumValue("speed15gig", 6),
			new EnumValue("speed40gig", 17),
			new EnumValue("speed1gig", 2),
			new EnumValue("speed4gig", 4),
			new EnumValue("speed16gig", 18),
			new EnumValue("speed2gig", 3),
			new EnumValue("speed3gig", 7),
			new EnumValue("speed12gig", 20),
			new EnumValue("speed10gig", 5),
			new EnumValue("speed20gig", 12),
			new EnumValue("speed8gig", 15),
			new EnumValue("speed100meg", 9),
			new EnumValue("speed56gig", 19),
			new EnumValue("speed32gig", 22),
			new EnumValue("speed5gig", 11),
			new EnumValue("speed6gig", 16)
		}, InterfaceSpeed.class);

		m_TypeTable[150] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 2),
			new EnumValue("purged", 3),
			new EnumValue("unknown", 0)
		}, PITStatus.class);

		m_TypeTable[151] = new EnumSpec(new EnumValue[] {
			new EnumValue("okFollowingRaid6Correction", 8),
			new EnumValue("edcError", 4),
			new EnumValue("mediaError", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("raid6DataError", 9),
			new EnumValue("ok", 0),
			new EnumValue("parityError", 2),
			new EnumValue("timeout", 1),
			new EnumValue("raid6QError", 5),
			new EnumValue("raid6PqError", 6),
			new EnumValue("okFollowingRetry", 7)
		}, ParityStatus.class);
	}

	private static void __init3() {

		m_TypeTable[152] = new EnumSpec(new EnumValue[] {
			new EnumValue("invalidVolumeref", 34),
			new EnumValue("invalidMirrorCandidateVol", 158),
			new EnumValue("maxMappableVolumesExceeded", 634),
			new EnumValue("arvmRemoteResumeFailure", 772),
			new EnumValue("remoteMetadataVolNonexistent", 171),
			new EnumValue("externalKeyNotInMemory", 568),
			new EnumValue("attemptToSetLocal", 103),
			new EnumValue("volumeHasUnreadableSectors", 746),
			new EnumValue("rvmCommStatRecoveredTimeout", 236),
			new EnumValue("partIsUtmLun", 86),
			new EnumValue("channelDiagsNotQuiesced", 441),
			new EnumValue("rawdataTransferNoDrives", 561),
			new EnumValue("dbmRestoreAltCtlNotOffline", 574),
			new EnumValue("portSpeedConflict", 584),
			new EnumValue("copyApptagMismatch", 575),
			new EnumValue("reconfigFailure", 26),
			new EnumValue("rvmQuiescenceInProgress", 246),
			new EnumValue("embeddedEkmsClientCertMissing", 918),
			new EnumValue("batteryMissing", 222),
			new EnumValue("lockkeyFailed", 505),
			new EnumValue("diagInitErr", 117),
			new EnumValue("illegalVolume", 672),
			new EnumValue("controllerNotOptimal", 405),
			new EnumValue("flashcacheNonDaCapableDriveDisallowed", 751),
			new EnumValue("invalidExpansionList", 54),
			new EnumValue("volcopyFeatureDisabled", 215),
			new EnumValue("arvmRemoteThinVolInitError", 808),
			new EnumValue("portRemoved", 287),
			new EnumValue("maxMirrorsExceeded", 157),
			new EnumValue("rvmCommStatInvNumSamplesReqd", 245),
			new EnumValue("arvmRemoteExpansionSynchronizationInProgress", 776),
			new EnumValue("cannotReconfigure", 217),
			new EnumValue("backgroundAutocfg", 263),
			new EnumValue("noDrivesAdopted", 464),
			new EnumValue("volumeNotExist", 10),
			new EnumValue("reservedAddress", 899),
			new EnumValue("downloadNotPermitted", 72),
			new EnumValue("arvmConnectivityTestNameServiceError", 714),
			new EnumValue("metadataAlreadyExists", 160),
			new EnumValue("channelDiagsDeviceBypassFailed", 444),
			new EnumValue("snmpIncompatibleIpv4Address", 809),
			new EnumValue("arvmRoleChangeInProgress", 781),
			new EnumValue("invalidSafeVersion", 94),
			new EnumValue("invalidDrive", 261),
			new EnumValue("prReservationConflict", 219),
			new EnumValue("initiatorConflict", 301),
			new EnumValue("noRepDeletion", 625),
			new EnumValue("volumeGroupNotConfigurable", 409),
			new EnumValue("invalidLun", 107),
			new EnumValue("rvmCommStatChannelFailure", 240),
			new EnumValue("safeControllerNotSubjectToRaid6", 432),
			new EnumValue("volumeGroupNotImportable", 728),
			new EnumValue("downloadCompleteMswOnlyReboot", 908),
			new EnumValue("unsupportedEsmRequest", 818),
			new EnumValue("faultConditionStillExists", 777),
			new EnumValue("regDeleteFailed", 220),
			new EnumValue("ssdMediaScanNotAllowed", 525),
			new EnumValue("usmClearFailed", 259),
			new EnumValue("controllerInServiceMode", 260),
			new EnumValue("arvmRemoteThinNotSupported", 792),
			new EnumValue("debugInfoConfigChanged", 455),
			new EnumValue("noMatchingLockKeyIdFound", 547),
			new EnumValue("autoLoadBalanceUserDisabled", 875),
			new EnumValue("noSuchDebugChunk", 454),
			new EnumValue("volumeNotAvailable", 745),
			new EnumValue("tryAlternate", 13),
			new EnumValue("iocDumpInvalidTag", 817),
			new EnumValue("dpcExclusiveOperationActive", 823),
			new EnumValue("invalidHosttypeString", 285),
			new EnumValue("invalidPitConsistencyGroupViewRef", 653),
			new EnumValue("arvmGroupNotEmpty", 650),
			new EnumValue("viewStopped", 636),
			new EnumValue("embeddedEkmsCertDuplicate", 926),
			new EnumValue("invalidLockKeyId", 569),
			new EnumValue("dataRedundancyRequired", 225),
			new EnumValue("volumeGroupHasFailedDrives", 415),
			new EnumValue("copyGhostSource", 198),
			new EnumValue("numdrivesGroup", 82),
			new EnumValue("diagLoopbackError", 112),
			new EnumValue("externalKmsNotCompliant", 550),
			new EnumValue("invalidFlushAmount", 43),
			new EnumValue("driveSecurityEnabledFailed", 504),
			new EnumValue("incompatibleSecondarySecurity", 702),
			new EnumValue("volsInVgUsingNonSecureCapableFlashcache", 724),
			new EnumValue("maxViewsPerPitExceeded", 630),
			new EnumValue("dbmDbSourceUnavailable", 661),
			new EnumValue("noSparesDeassigned", 55),
			new EnumValue("rvmVersionMismatch", 178),
			new EnumValue("disableEvaluationFeatureNotPermitted", 532),
			new EnumValue("invalidPitViewLabel", 618),
			new EnumValue("arvmRemoteMaxAsyncMirrorGroupsExceeded", 757),
			new EnumValue("arvmRemoteGroupUserLabelExists", 765),
			new EnumValue("embeddedEkmsClientKeyMissing", 917),
			new EnumValue("diagIconSendErr", 116),
			new EnumValue("snmpInvalidCommunityRef", 795),
			new EnumValue("embeddedEkmsServerError", 924),
			new EnumValue("vgNotForceable", 439),
			new EnumValue("isnsDhcpNotSupported", 819),
			new EnumValue("localRoleChangedNotForced", 174),
			new EnumValue("maxSnapsExceeded", 130),
			new EnumValue("mirrorVolNotPrimary", 182),
			new EnumValue("copyTargetLimit", 207),
			new EnumValue("copySourceReservation", 209),
			new EnumValue("invalidPitForView", 656),
			new EnumValue("coredumpBackupInProgress", 788),
			new EnumValue("volumeGroupHasSnapshotRelationship", 436),
			new EnumValue("rvmFeatureDisabled", 154),
			new EnumValue("invalidProtocol", 286),
			new EnumValue("snmpInvalidCommunityName", 793),
			new EnumValue("invalidFibreid", 51),
			new EnumValue("remoteInvalidProtection", 768),
			new EnumValue("remoteRvmFeatureDisabled", 170),
			new EnumValue("partLunCollision", 62),
			new EnumValue("arvmOnlyPrimaryMemberRemoved", 733),
			new EnumValue("noSparesNeeded", 293),
			new EnumValue("quiescenceFailed", 253),
			new EnumValue("maxViewsExceeded", 631),
			new EnumValue("flashError", 28),
			new EnumValue("tooManyPartitions", 89),
			new EnumValue("snmpUnknownSystemVariable", 802),
			new EnumValue("flashcacheFailed", 707),
			new EnumValue("invalidSegmentsize", 40),
			new EnumValue("rvmFeatureDeactivated", 156),
			new EnumValue("ctrlNotInServiceMode", 544),
			new EnumValue("notImplemented", 15),
			new EnumValue("invalidConcatVolRef", 620),
			new EnumValue("copyTargetReservation", 210),
			new EnumValue("lockKeyValidationFailed", 548),
			new EnumValue("copyStartFailed", 213),
			new EnumValue("channelDiagsResultsPartial", 435),
			new EnumValue("rawdataTransferPreparing", 559),
			new EnumValue("flashcacheAlreadySuspended", 603),
			new EnumValue("modesenseError", 39),
			new EnumValue("volumeGroupNotOnline", 401),
			new EnumValue("arvmOnlySecondaryMemberRemoved", 734),
			new EnumValue("copyStopFailed", 214),
			new EnumValue("rvmCommStatDeviceMissing", 242),
			new EnumValue("incompatibleRepositorySecurity", 701),
			new EnumValue("arvmInvalidSecondaryCapacity", 732),
			new EnumValue("esmPartialUpdate", 98),
			new EnumValue("invalidPitViewRef", 619),
			new EnumValue("illegalParam", 4),
			new EnumValue("arvmOrphanGroup", 743),
			new EnumValue("prohibitedBySafeViolation", 437),
			new EnumValue("requiredConditionNotPresent", 278),
			new EnumValue("unlockFailed", 521),
			new EnumValue("obsolete", 258),
			new EnumValue("invalidRollbackPriority", 143),
			new EnumValue("channelDiagsResultsNotAvailable", 445),
			new EnumValue("nvramError", 27),
			new EnumValue("partNodeNonexistent", 59),
			new EnumValue("invalidRecoveryPointAlertThreshold", 719),
			new EnumValue("dltNotCompleted", 275),
			new EnumValue("volumeGroupExported", 407),
			new EnumValue("snmpAgentInitFailed", 806),
			new EnumValue("invalidIscsiConfiguration", 578),
			new EnumValue("driveNotExist", 6),
			new EnumValue("sodInProgress", 248),
			new EnumValue("dpcUnableToPowerUpDrive", 824),
			new EnumValue("volumeGroupHasConcatRelationship", 668),
			new EnumValue("snmpInvalidTrapDestinationRef", 796),
			new EnumValue("dpcFormatActive", 825),
			new EnumValue("authFailParam", 29),
			new EnumValue("notRegistered", 172),
			new EnumValue("arvmAsyncMirrorGroupPresent", 704),
			new EnumValue("keyDoesNotExist", 786),
			new EnumValue("rvmFibreError", 181),
			new EnumValue("drivesDacstoresOverlap", 457),
			new EnumValue("volumeGroupHasIncompatibleDacstores", 422),
			new EnumValue("thresholdBelowUsedCapacity", 678),
			new EnumValue("remoteRoleChangeFailed", 165),
			new EnumValue("channelDiagsAltCommFailed", 442),
			new EnumValue("diskPoolNoSpareDrives", 837),
			new EnumValue("partMappingNonexistent", 64),
			new EnumValue("invalidSyncAlertThreshold", 720),
			new EnumValue("arvmVolumeAlreadyInMirrorRelationship", 691),
			new EnumValue("snmpAgentDisabled", 805),
			new EnumValue("copySourceFormat", 211),
			new EnumValue("invalidPitConsistencyGroupRef", 652),
			new EnumValue("exportingDrivesDatabaseResynchronizing", 466),
			new EnumValue("evalNotSupported", 555),
			new EnumValue("snmpCannotDisableIpv6", 813),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("snmpIncompatibleFirmware", 804),
			new EnumValue("arvmRemoteSynchronizeFailure", 773),
			new EnumValue("snmpCannotDisableIpv4", 812),
			new EnumValue("driveServiceInProgress", 835),
			new EnumValue("externalKmsNotEnabled", 540),
			new EnumValue("reservationConflict", 16),
			new EnumValue("invHostlunMoveHostport", 230),
			new EnumValue("invalidBlob", 520),
			new EnumValue("maxConsistencyGroupMembersExceeded", 633),
			new EnumValue("arvmGroupNotSuspended", 689),
			new EnumValue("cacheconfigError", 76),
			new EnumValue("utmTooManyMaps", 108),
			new EnumValue("defaultUtmCollision", 190),
			new EnumValue("remoteArvmFeatureDeactivated", 741),
			new EnumValue("pitGroupsFeatureDisabled", 748),
			new EnumValue("diskPoolExceedSpareCapacity", 838),
			new EnumValue("rvmActivateDisallowed", 187),
			new EnumValue("hdd4kbSegmentsizeNotAllowed", 836),
			new EnumValue("cannotDisableNoKey", 552),
			new EnumValue("attributeFixedByArvm", 658),
			new EnumValue("volumeNotConfigurable", 408),
			new EnumValue("snmpMaxCommunitiesExceeded", 798),
			new EnumValue("diagConfigErr", 122),
			new EnumValue("iocDumpInProgress", 815),
			new EnumValue("secNotPromoteable", 183),
			new EnumValue("volumeCreationInProgress", 900),
			new EnumValue("invalidRegionid", 50),
			new EnumValue("noDeleteUtmInUse", 106),
			new EnumValue("copyInvalidSourceRef", 200),
			new EnumValue("rvmCommStatNetworkFailure", 241),
			new EnumValue("volumeOffline", 37),
			new EnumValue("copyInvalidTargetRef", 201),
			new EnumValue("raid6FeatureUnsupported", 430),
			new EnumValue("cannotRollback", 590),
			new EnumValue("workloadInvalidRef", 904),
			new EnumValue("arvmRemoteSuspendFailure", 771),
			new EnumValue("arvmConnectivityTestRemoteTimeout", 712),
			new EnumValue("baseVolumeOffline", 151),
			new EnumValue("mirrorDegraded", 269),
			new EnumValue("previouslyEnabledForEval", 553),
			new EnumValue("flashcacheAlreadyExists", 601),
			new EnumValue("evacInProgress", 832),
			new EnumValue("snapNotAvailable", 132),
			new EnumValue("authFailContLockout", 218),
			new EnumValue("flashcacheInvalidAnalyticsState", 774),
			new EnumValue("invalidProtection", 570),
			new EnumValue("invalidCriticalThreshold", 663),
			new EnumValue("remoteInvalidCfgGen", 173),
			new EnumValue("pitInConsistencyGroup", 643),
			new EnumValue("exportingDrivesQuiesced", 468),
			new EnumValue("rawdataTransferCrcError", 563),
			new EnumValue("dbmRestoreNoDrives", 565),
			new EnumValue("localRemoteArrayHasSameWwn", 448),
			new EnumValue("keyInvalidSequence", 542),
			new EnumValue("downloadInProgress", 77),
			new EnumValue("pitGroupInConsistencyGroup", 642),
			new EnumValue("safeMdtNotPremiumFeature", 273),
			new EnumValue("invalidChunksize", 70),
			new EnumValue("copyTargetFormat", 212),
			new EnumValue("invalidLabel", 44),
			new EnumValue("psuFirmwareDownloadFailed", 592),
			new EnumValue("invalidDriveref", 35),
			new EnumValue("volumeGroupNotContingent", 433),
			new EnumValue("invalidKeyValueTagObjectReference", 905),
			new EnumValue("invalidInterfaceref", 300),
			new EnumValue("snmpMaxTrapDestinationsExceeded", 799),
			new EnumValue("duplicateIscsiIpAddress", 583),
			new EnumValue("driveTooSmall", 83),
			new EnumValue("thinProvisioningFeatureDisabled", 747),
			new EnumValue("altRemoved", 22),
			new EnumValue("arvmGroupUserLabelExists", 648),
			new EnumValue("remoteAuthFailPassword", 177),
			new EnumValue("raid6FeatureDisabled", 431),
			new EnumValue("arvmMemberLimitExceeded", 692),
			new EnumValue("invalidCapability", 567),
			new EnumValue("rvmCommStatTimeout", 239),
			new EnumValue("flashcacheAlreadyEnabled", 670),
			new EnumValue("volumeGroupSecure", 508),
			new EnumValue("invalidFreeextentref", 36),
			new EnumValue("exportingDrivesDatabaseFailed", 467),
			new EnumValue("volumeHasVolcopyRelationship", 579),
			new EnumValue("flashcacheNotSuspended", 604),
			new EnumValue("baseVolumeFailed", 150),
			new EnumValue("noLockedDrives", 502),
			new EnumValue("mirrorProtocolMismatch", 703),
			new EnumValue("writeLock", 216),
			new EnumValue("exceedDiskPoolCapacity", 755),
			new EnumValue("flashcacheMaxLimitExceeded", 723),
			new EnumValue("embeddedExternalKeyManagementCertificatesNotInstalled", 913),
			new EnumValue("ghostVolume", 139),
			new EnumValue("dstNotFibre", 147),
			new EnumValue("concatMemberLimitExceeded", 637),
			new EnumValue("partVolumeNonexistent", 61),
			new EnumValue("dssNotAllowed", 615),
			new EnumValue("volumeInUse", 646),
			new EnumValue("dplCoreDumpRestoreInProgress", 708),
			new EnumValue("dveNotAllowed", 614),
			new EnumValue("primaryCacheSizeMismatch", 729),
			new EnumValue("rvmSpmError", 176),
			new EnumValue("numVolumesGroup", 138),
			new EnumValue("invalidVirtualCapacity", 676),
			new EnumValue("repositoryTooSmall", 148),
			new EnumValue("reconfigSmallDacstore", 25),
			new EnumValue("lockdown", 456),
			new EnumValue("copybackInProgress", 784),
			new EnumValue("voltransferError", 74),
			new EnumValue("maxVolumesExceeded", 85),
			new EnumValue("volumeGroupStateNotValid", 404),
			new EnumValue("rawdataTransferNotStarted", 557),
			new EnumValue("reconstructionInProgress", 783),
			new EnumValue("ddcUnavail", 279),
			new EnumValue("copyInactive", 195),
			new EnumValue("invalidCacheModifier", 45),
			new EnumValue("rvmCommStatLoginFailure", 244),
			new EnumValue("flashcacheEnabled", 623),
			new EnumValue("rvmOperNotAllowedOnSec", 224),
			new EnumValue("maxPitsExceeded", 627),
			new EnumValue("remoteTryAlternate", 778),
			new EnumValue("exceedMaxVolumeCapacity", 756),
			new EnumValue("embeddedEkmsClientCertMismatch", 919),
			new EnumValue("featureNotKeyable", 554),
			new EnumValue("alarmNotPresent", 274),
			new EnumValue("channelDiagsRunning", 434),
			new EnumValue("invalidReinitAction", 683),
			new EnumValue("flashcacheSuspended", 669),
			new EnumValue("background", 14),
			new EnumValue("diagInvalidTestId", 119),
			new EnumValue("noValidMirrorCandidate", 168),
			new EnumValue("invalidMirrorvol", 159),
			new EnumValue("dpcVolumeGroupNotRedundant", 821),
			new EnumValue("invalidLoadBalanceAction", 889),
			new EnumValue("partCrteFailTblFull", 102),
			new EnumValue("invHostlunDefineHosttype", 229),
			new EnumValue("flashCacheFdeEnablementDisallowed", 740),
			new EnumValue("snmpTrapDestinationAddressInUse", 801),
			new EnumValue("volumeGroupHasIncompatibleDrive", 449),
			new EnumValue("flashCacheInvalidBaseVol", 739),
			new EnumValue("invalidFlushThreshold", 42),
			new EnumValue("downloadHalted", 255),
			new EnumValue("arvmRoleChangePending", 780),
			new EnumValue("snmpIpv4ConfigError", 814),
			new EnumValue("busy", 3),
			new EnumValue("databaseResyncInProgress", 915),
			new EnumValue("invalidExpansionSize", 682),
			new EnumValue("ok", 1),
			new EnumValue("rvmCommStatRecoveredDelay", 237),
			new EnumValue("invalidRaidlevel", 53),
			new EnumValue("arvmExpansionSynchronizationInProgress", 775),
			new EnumValue("snmpInvalidCommunityPermission", 794),
			new EnumValue("maxTotalMirrorsPerArrayExceeded", 754),
			new EnumValue("concatVolumeFailed", 651),
			new EnumValue("arvmGroupNotPrimary", 686),
			new EnumValue("invalidModeSwitch", 126),
			new EnumValue("dpcPowerCycleAlreadyInProgress", 827),
			new EnumValue("failVolumeVisible", 105),
			new EnumValue("arvmConnectivityTestNetworkError", 711),
			new EnumValue("diagWriteFailure", 111),
			new EnumValue("invalidDriveState", 410),
			new EnumValue("externalKmsDisabledNoKey", 573),
			new EnumValue("noNativeSstor", 453),
			new EnumValue("remoteMaxMirrorsExceeded", 169),
			new EnumValue("invalidLoadBalanceDelay", 890),
			new EnumValue("volumeDead", 17),
			new EnumValue("insuffLocalMirRepResources", 233),
			new EnumValue("arvmGroupHasIncompleteMember", 709),
			new EnumValue("partDupId", 57),
			new EnumValue("volumeGroupInaccessible", 460),
			new EnumValue("authFailReadpassword", 101),
			new EnumValue("csbReserveFailed", 598),
			new EnumValue("requestFailedDueToPiRestrictions", 581),
			new EnumValue("arvmInvalidMirrorState", 690),
			new EnumValue("volumeGroupReconstructing", 412),
			new EnumValue("invalidSetsize", 251),
			new EnumValue("invalidPortname", 127),
			new EnumValue("factoryDefaultDownloadFailed", 586),
			new EnumValue("invalidSyncPriority", 718),
			new EnumValue("arvmMemberStopped", 782),
			new EnumValue("volumeGroupNotExist", 400),
			new EnumValue("diagNotQuiesced", 124),
			new EnumValue("rvmCommunicationError", 180),
			new EnumValue("reconfigLogSpaceError", 459),
			new EnumValue("arvmInvalidAmgRequestWhileSuspended", 735),
			new EnumValue("externalKmsEnabled", 538),
			new EnumValue("keyNotNeeded", 541),
			new EnumValue("csbReleaseFailedInvalidKey", 600),
			new EnumValue("takeRecoveryActionsFirst", 787),
			new EnumValue("mirrorAlreadySuspended", 232),
			new EnumValue("arvmConnectivityTestAmgMemberMismatch", 717),
			new EnumValue("flashcacheMaxCapacityExceeded", 706),
			new EnumValue("arvmConnectivityTestTimeoutExceeded", 722),
			new EnumValue("embeddedExternalKeyManagementEnabled", 912),
			new EnumValue("metadataChildDeletion", 185),
			new EnumValue("invalidReadahead", 46),
			new EnumValue("invalidCacheblksize", 41),
			new EnumValue("dbmRestoreSourceMismatch", 662),
			new EnumValue("invalidProvisionedCapacityQuota", 674),
			new EnumValue("diagLockErr", 121),
			new EnumValue("volumeGroupHasHotspare", 402),
			new EnumValue("volumeGroupReconfiguring", 403),
			new EnumValue("cacheParametersNotChangeable", 705),
			new EnumValue("volsInVgUsingSecureDisabledFlashcache", 725),
			new EnumValue("flashcacheDegradedState", 750),
			new EnumValue("noSparesAssigned", 8),
			new EnumValue("arvmSynchronizeFailure", 695),
			new EnumValue("arvmConnectivityTestTurError", 715),
			new EnumValue("invalidPitRef", 613),
			new EnumValue("memberVolMapped", 639),
			new EnumValue("arvmManualSyncAlreadyInProgress", 736),
			new EnumValue("rawdataBadSeqNum", 566),
			new EnumValue("snmpIncompatibleIpv6Address", 810),
			new EnumValue("allFailed", 256),
			new EnumValue("rawdataTransferReadError", 560),
			new EnumValue("rvmInvalidRemotevol", 247),
			new EnumValue("internalError", 18),
			new EnumValue("cannotExpandConcatMember", 677),
			new EnumValue("invalidRepositoryLabel", 141),
			new EnumValue("notOldestPit", 635),
			new EnumValue("authFailPassword", 30),
			new EnumValue("autocfgInprogress", 264),
			new EnumValue("cdmDatabaseFull", 277),
			new EnumValue("dpcVolumeNotInitialized", 822),
			new EnumValue("sparesSmallUnassigned", 88),
			new EnumValue("invalidEsmref", 290),
			new EnumValue("volumeInitializing", 461),
			new EnumValue("volumeReconfiguring", 11),
			new EnumValue("invalidPitGroupRef", 612),
			new EnumValue("maxConsistencyGroupsExceeded", 632),
			new EnumValue("invalidSubmodelId", 726),
			new EnumValue("invalidSafeKey", 92),
			new EnumValue("insufficientExpansionSpace", 681),
			new EnumValue("duplicateVolMapping", 128),
			new EnumValue("someSparesDeassigned", 56),
			new EnumValue("partLabelInvalid", 58),
			new EnumValue("snapshotNotActive", 589),
			new EnumValue("remoteInternalError", 762),
			new EnumValue("legacyRvmAsyncModeUnsupported", 789),
			new EnumValue("missingData", 252),
			new EnumValue("remoteDatabaseError", 769),
			new EnumValue("embeddedEkmsCertExpired", 920),
			new EnumValue("volumeInaccessible", 463),
			new EnumValue("rekeyInProgress", 523),
			new EnumValue("snapConversionMissingLabel", 699),
			new EnumValue("mediaRepairFailed", 268),
			new EnumValue("numdrivesAdditional", 81),
			new EnumValue("databaseError", 262),
			new EnumValue("snmpCommunityNameInUse", 800),
			new EnumValue("volumeHasSnapshotRelationship", 571),
			new EnumValue("psuFirmwareUpdateNotAllOptimal", 595),
			new EnumValue("arvmResumeFailure", 694),
			new EnumValue("driveDownloadFailed", 96),
			new EnumValue("driveRemoved", 79),
			new EnumValue("channelDiagsLockErr", 440),
			new EnumValue("cacheBackupDevNotExist", 546),
			new EnumValue("notFlashcacheVol", 621),
			new EnumValue("invalidMemberVol", 638),
			new EnumValue("rmtvolOrphanDeletion", 186),
			new EnumValue("driveTypeMismatch", 447),
			new EnumValue("arvmConnectivityTestLoginFailure", 713),
			new EnumValue("invalidPitConsistencyGroupLabel", 607),
			new EnumValue("onlyLocalMirrorDeleted", 167),
			new EnumValue("prohibitedByGoldKeyRestrictions", 271),
			new EnumValue("arvmRemoteGroupNotEmpty", 770),
			new EnumValue("invalidTotalsize", 71),
			new EnumValue("volumeHasMirrorRelationship", 572),
			new EnumValue("invalidCopyPriority", 191),
			new EnumValue("diagTimeout", 113),
			new EnumValue("externalKmsTimeout", 551),
			new EnumValue("portConflict", 284),
			new EnumValue("invalidSecurity", 506),
			new EnumValue("remoteMaxTotalMirrorsPerArrayExceeded", 759),
			new EnumValue("dpcUnreadableSectorsPresent", 826),
			new EnumValue("volumeHasAsyncMirror", 458),
			new EnumValue("baseVolumeFormatting", 152),
			new EnumValue("flashcacheNotEnabled", 624),
			new EnumValue("invalidVolumecopyref", 192),
			new EnumValue("remoteTargetNotFound", 696),
			new EnumValue("volumeGroupHasPitgroupRelationship", 666),
			new EnumValue("embeddedEkmsKeyOwnerRequired", 923),
			new EnumValue("volumeLimitExceeded", 423),
			new EnumValue("invalidTrimCount", 641),
			new EnumValue("spawnError", 73),
			new EnumValue("copySourceReconfig", 204),
			new EnumValue("dependancyError", 276),
			new EnumValue("hosttypeConflict", 283),
			new EnumValue("volumeGroupNotComplete", 414),
			new EnumValue("maxVolMappingExceeded", 63),
			new EnumValue("batteryNotInConfig", 221),
			new EnumValue("prohibitedByMdtRestrictions", 270),
			new EnumValue("volumeGroupHasVolcopyRelationship", 418),
			new EnumValue("diagDriveErr", 120),
			new EnumValue("repositoryReconfiguring", 136),
			new EnumValue("invalidScanperiod", 48),
			new EnumValue("invalidDdcTag", 281),
			new EnumValue("noIscsiSessions", 299),
			new EnumValue("noHeap", 5),
			new EnumValue("invalidIncompleteMemberRef", 685),
			new EnumValue("invalidRequest", 19),
			new EnumValue("volumeGroupHasInsufficientDrives", 427),
			new EnumValue("copyIncompatibleTarget", 197),
			new EnumValue("maxPitGroupsPerBaseExceeded", 628),
			new EnumValue("snapshotFeatureDisabled", 134),
			new EnumValue("arvmThinVolInitError", 807),
			new EnumValue("mustSpecifyExistingVolumes", 721),
			new EnumValue("dpcEnclosureHardwareUnsupported", 828),
			new EnumValue("duplicateDrives", 80),
			new EnumValue("keyValueTagInUse", 903),
			new EnumValue("insufficientRepositoryCapacity", 596),
			new EnumValue("flashcacheInvalidConfigType", 605),
			new EnumValue("someDrivesAdopted", 465),
			new EnumValue("arvmMaxMirrorsPerArrayExceeded", 753),
			new EnumValue("keyValueTagInvalidRef", 901),
			new EnumValue("invalidTrayref", 188),
			new EnumValue("rvmOverIscsiNotSupported", 647),
			new EnumValue("errorWritingToEeprom", 587),
			new EnumValue("repositoryMissing", 140),
			new EnumValue("copyInvalidTargetState", 203),
			new EnumValue("copyIncompatibleSource", 196),
			new EnumValue("arvmGroupDoesNotExist", 649),
			new EnumValue("invalidDlstate", 75),
			new EnumValue("arvmRemoteGroupNotSecondary", 766),
			new EnumValue("parityScanInProgress", 90),
			new EnumValue("cacheSyncFailure", 23),
			new EnumValue("ddcIllegalParam", 280),
			new EnumValue("remoteRvmSpmError", 763),
			new EnumValue("rvmCommStatNotReady", 238),
			new EnumValue("volumeGroupUndergoingCopyback", 413),
			new EnumValue("diagNoAlt", 115),
			new EnumValue("parityScanFailed", 266),
			new EnumValue("arvmConnectivityTestAlreadyInProgress", 710),
			new EnumValue("copyTargetReconfig", 205),
			new EnumValue("metadataVolNonexistent", 153),
			new EnumValue("noKeySet", 522),
			new EnumValue("diagReadFailure", 109),
			new EnumValue("volumeGroupHasReservations", 421),
			new EnumValue("invalidReconpriority", 47),
			new EnumValue("invalidDrives", 249),
			new EnumValue("manualConfigModeSet", 298),
			new EnumValue("invalidSafeId", 91),
			new EnumValue("arvmMaxAsyncMirrorGroupsExceeded", 752),
			new EnumValue("arvmMirrorMemberDoesNotExist", 697),
			new EnumValue("channelDiagsChanSetupFailed", 443),
			new EnumValue("diagInProgress", 114),
			new EnumValue("invalidPitGroupLabel", 606),
			new EnumValue("disableNotPermitted", 288),
			new EnumValue("pitCreatePending", 660),
			new EnumValue("invalidSnapLabel", 142),
			new EnumValue("invalidRequestForEnclosure", 576),
			new EnumValue("arvmRecoveryPointDeletionRequired", 665),
			new EnumValue("rvmCommStatLoginRejected", 243),
			new EnumValue("volumeGroupHasMappedVols", 420),
			new EnumValue("factoryDefaultPartialUpdate", 588),
			new EnumValue("flashcacheUserLabelExists", 730),
			new EnumValue("rvmRemoteArrayError", 179),
			new EnumValue("unsupportedLhaSataEsm", 265),
			new EnumValue("notDualActive", 12),
			new EnumValue("invalidPitAutoDeleteLimit", 608),
			new EnumValue("invalidConcatVolMemberLabel", 610),
			new EnumValue("invalidPitRepositoryFullPolicy", 609),
			new EnumValue("invalidExpansionOperation", 679),
			new EnumValue("someSparesTooSmall", 87),
			new EnumValue("flashcacheDeleted", 622),
			new EnumValue("cannotFormatVolume", 146),
			new EnumValue("remoteRoleChangedLocalFailed", 175),
			new EnumValue("maxPitsPerGroupExceeded", 626),
			new EnumValue("rawdataTransferBadType", 556),
			new EnumValue("invHostlunDefineMapping", 227),
			new EnumValue("invalidWarnThreshold", 144),
			new EnumValue("embeddedEkmsConnectionFailure", 928),
			new EnumValue("insufficientCache", 462),
			new EnumValue("invalidVolumegroupref", 33),
			new EnumValue("localRoleChangeSuccessful", 166),
			new EnumValue("prohibitedByDriveTrayLimit", 289),
			new EnumValue("drivesNotAvailableForRemoval", 811),
			new EnumValue("psuFirmwareUpdateNotAllRedundant", 594),
			new EnumValue("metadataMissing", 161),
			new EnumValue("copyActive", 194),
			new EnumValue("exceedDiskPoolLimit", 749),
			new EnumValue("esmDownloadFailed", 97),
			new EnumValue("maxSnapsPerBaseExceeded", 129),
			new EnumValue("volumeGroupHasFailedVols", 428),
			new EnumValue("maxThinVolumesExceeded", 731),
			new EnumValue("rawdataTransferUserCancelled", 582),
			new EnumValue("prohibitedByFeatureBundleViolation", 294),
			new EnumValue("arvmRemoteMaxMirrorsPerArrayExceeded", 758),
			new EnumValue("memParityError", 31),
			new EnumValue("invalidFile", 24),
			new EnumValue("volumeGroupHasUnsupportedRaidLevel", 425),
			new EnumValue("concatVolMemberTooSmall", 611),
			new EnumValue("defaultHostGroupMappingNotAllowed", 524),
			new EnumValue("flashcacheFeatureDisabled", 602),
			new EnumValue("safeControllerNotSubjectToGoldKey", 272),
			new EnumValue("remoteArvmFeatureDisabled", 742),
			new EnumValue("invalidControllerref", 32),
			new EnumValue("legacyVg", 438),
			new EnumValue("diagNotRunning", 543),
			new EnumValue("arvmMemberFailed", 688),
			new EnumValue("consistencyGroupArvmBindingConflict", 657),
			new EnumValue("arvmRemoteMirrorMemberDoesNotExist", 764),
			new EnumValue("diagSrcLinkDown", 110),
			new EnumValue("priNotDemoteable", 184),
			new EnumValue("noChannel", 223),
			new EnumValue("initiatorRemoved", 302),
			new EnumValue("volumeGroupHasArvmRelationship", 664),
			new EnumValue("dbmDbImageCorrupt", 671),
			new EnumValue("remoteNoHeap", 761),
			new EnumValue("alternateRequiredForOperation", 655),
			new EnumValue("arvmRemoteGroupDoesNotExist", 767),
			new EnumValue("invalidHostTypeIndex", 104),
			new EnumValue("volumeGroupHasNonOptimalVols", 416),
			new EnumValue("arvmFeatureDeactivated", 700),
			new EnumValue("autoLoadBalanceInsufficientStatistics", 876),
			new EnumValue("driveNotUnassigned", 7),
			new EnumValue("diagNoCacheMem", 123),
			new EnumValue("invalidBasevol", 131),
			new EnumValue("invalidSecret", 296),
			new EnumValue("partitionsDisabled", 95),
			new EnumValue("volumeGroupHasCloneOpportunity", 426),
			new EnumValue("uninitialized", 0),
			new EnumValue("mirrorsPresent", 155),
			new EnumValue("rollbackInProgress", 137),
			new EnumValue("arvmConnectivityTestMissingRemoteAmg", 716),
			new EnumValue("rollbackStartFailure", 597),
			new EnumValue("mirrorSyncNotPossible", 591),
			new EnumValue("premiumFeatureLimitExceedsMaximum", 531),
			new EnumValue("keyValueTagInvalidDuplicate", 902),
			new EnumValue("repositoryOffline", 135),
			new EnumValue("lockKeyValidationDisabled", 549),
			new EnumValue("thinVolumeParametersCannotBeModified", 791),
			new EnumValue("arvmManualSyncRetryTooSoon", 737),
			new EnumValue("invalidTrayposLength", 49),
			new EnumValue("invalidRepositoryCapacity", 673),
			new EnumValue("embeddedEkmsAuthenticationFailure", 922),
			new EnumValue("noVolumes", 100),
			new EnumValue("requestFailedDueToLun0Restrictions", 537),
			new EnumValue("repositoryFull", 680),
			new EnumValue("invalidReinitCapacity", 684),
			new EnumValue("mappingInvalidDuplicate", 906),
			new EnumValue("volumeNotOptimal", 38),
			new EnumValue("validationError", 254),
			new EnumValue("driveSpinUpError", 446),
			new EnumValue("notDisabled", 133),
			new EnumValue("learnActiveTryLater", 469),
			new EnumValue("invalidEncryption", 52),
			new EnumValue("rawdataTransferAlreadyStarted", 558),
			new EnumValue("arvmSuspendFailure", 693),
			new EnumValue("cannotMapVolume", 145),
			new EnumValue("partialDeletion", 189),
			new EnumValue("noEvacFound", 833),
			new EnumValue("invalidOffset", 68),
			new EnumValue("iocRestoreInProgress", 816),
			new EnumValue("driveNotOptimal", 78),
			new EnumValue("maxPitGroupsExceeded", 629),
			new EnumValue("diagModeErr", 118),
			new EnumValue("psuFirmwareUpdateMfgDeviceCodeMismatch", 593),
			new EnumValue("maxVolumeCopysExceeded", 208),
			new EnumValue("partialOk", 257),
			new EnumValue("arvmIncorrectVolumeType", 790),
			new EnumValue("invHostlunMoveMapping", 228),
			new EnumValue("insuffRemtMirRepResources", 234),
			new EnumValue("diskPoolNotEmpty", 738),
			new EnumValue("dpcEnclosureFwDownlevel", 829),
			new EnumValue("volumeGroupImportInProgress", 451),
			new EnumValue("externalKmsFailed", 539),
			new EnumValue("utmConflict", 99),
			new EnumValue("volumeGroupHasMirroringMetadata", 419),
			new EnumValue("copySourceZeroCapacity", 226),
			new EnumValue("dbmRestoreWriteError", 564),
			new EnumValue("localRoleChangeFailed", 164),
			new EnumValue("copyTargetTooSmall", 206),
			new EnumValue("invalidAuthMethod", 295),
			new EnumValue("parityRepairFailed", 267),
			new EnumValue("invalidSafeCapability", 93),
			new EnumValue("copyInvalidSourceState", 202),
			new EnumValue("workloadInvalidDuplicate", 909),
			new EnumValue("copyChangeFailed", 193),
			new EnumValue("snmpInvalidSystemVariableValue", 803),
			new EnumValue("perfTierSafeUpgradeDisabled", 429),
			new EnumValue("imageTransferred", 66),
			new EnumValue("arvmInvalidSyncInterval", 760),
			new EnumValue("downloadCompleteNoReboot", 907),
			new EnumValue("metadataOffline", 162),
			new EnumValue("noFdeDrives", 507),
			new EnumValue("invalidPitConsistencyGroupViewLabel", 654),
			new EnumValue("capacityConstrained", 84),
			new EnumValue("secretAlreadyInUse", 297),
			new EnumValue("dqRetrieveNothingToTransfer", 577),
			new EnumValue("partNoHostports", 65),
			new EnumValue("embeddedEkmsProxyNotResponding", 921),
			new EnumValue("premiumFeatureLimitMismatch", 727),
			new EnumValue("embeddedEkmsServerCertMissing", 925),
			new EnumValue("someSparesAssigned", 9),
			new EnumValue("insufficientCapacity", 406),
			new EnumValue("volumeGroupHasPitviewRelationship", 667),
			new EnumValue("invalidExpansionPolicy", 675),
			new EnumValue("volumeGroupHasMirrorRelationship", 417),
			new EnumValue("ghostHasUnreadableSectors", 235),
			new EnumValue("volumeFormatting", 21),
			new EnumValue("rawdataTransferInvalidImage", 562),
			new EnumValue("overrun", 69),
			new EnumValue("iconFailure", 20),
			new EnumValue("pitViewInConsistencyGroup", 644),
			new EnumValue("error", 2),
			new EnumValue("partPortIdInvalid", 60),
			new EnumValue("noHotspareAvailable", 834),
			new EnumValue("copyGhostTarget", 199),
			new EnumValue("fwIncompatible", 231),
			new EnumValue("invalidMemberVolState", 640),
			new EnumValue("adminPasswordNotSet", 785),
			new EnumValue("invalidIpAddress", 797),
			new EnumValue("snapConversionTooManySnaps", 698),
			new EnumValue("repositoryFailed", 149),
			new EnumValue("partPiIncapable", 580),
			new EnumValue("diagUtmNotEnabled", 125),
			new EnumValue("drivesNeedToBeSpunUp", 452),
			new EnumValue("mappingInvalidRef", 910),
			new EnumValue("invalidBundleMigration", 291),
			new EnumValue("dplCoreDumpInvalidTag", 617),
			new EnumValue("arvmGroupNotSecondary", 687),
			new EnumValue("volumeGroupVolumeEncroachesOnDacstore", 450),
			new EnumValue("invalidFeatureref", 545),
			new EnumValue("embeddedEkmsCertInvalid", 927),
			new EnumValue("invalidBundleKey", 292),
			new EnumValue("volumeGroupHasUnknownRaidLevel", 424),
			new EnumValue("operationFailedVolumeCopyClone", 659),
			new EnumValue("fileTooLarge", 67),
			new EnumValue("arvmOrphanMember", 744),
			new EnumValue("illegalOperationOnAllConfigDrives", 914),
			new EnumValue("basevolSizeChanged", 303),
			new EnumValue("csbReleaseFailedNoLock", 599),
			new EnumValue("metadataReconfiguring", 163),
			new EnumValue("incompatibleMemberVol", 645),
			new EnumValue("workloadInUse", 911),
			new EnumValue("invalidSetid", 250),
			new EnumValue("arvmOnlyLocalAmgDeleted", 779),
			new EnumValue("embeddedEkmsKeyserverInfoMissing", 916)
		}, ReturnCode.class);
	}

	private static void __init4() {

		m_TypeTable[153] = new EnumSpec(new EnumValue[] {
			new EnumValue("driveSlotLimitTo136", 63),
			new EnumValue("driveSlotLimitTo256", 47),
			new EnumValue("remoteMirrorsTo128", 31),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("sharedVolume", 1),
			new EnumValue("mixedDriveTypes", 16),
			new EnumValue("driveSlotLimitTo96", 61),
			new EnumValue("none", 0),
			new EnumValue("totalNumberOfArvmMirrorsPerArray", 109),
			new EnumValue("driveSlotLimitTo12", 53),
			new EnumValue("autoCodeSync", 4),
			new EnumValue("secureVolume", 36),
			new EnumValue("driveSlotLimitTo16", 54),
			new EnumValue("storagePoolsTo8", 7),
			new EnumValue("remoteMirrorsTo32", 29),
			new EnumValue("autoLunTransfer", 5),
			new EnumValue("remoteMirrorsTo8", 84),
			new EnumValue("raid6", 22),
			new EnumValue("driveSlotLimitTo180", 65),
			new EnumValue("driveSlotLimitTo300", 94),
			new EnumValue("driveSlotLimitTo144", 64),
			new EnumValue("storagePoolsTo256", 21),
			new EnumValue("driveSlotLimitTo384", 93),
			new EnumValue("storagePoolsTo2", 8),
			new EnumValue("subLunsAllowed", 6),
			new EnumValue("driveTrayExpansion", 18),
			new EnumValue("storagePoolsTo4", 2),
			new EnumValue("stagedDownload", 15),
			new EnumValue("mixedRaidlevel", 3),
			new EnumValue("driveSlotLimitTo48", 57),
			new EnumValue("snapshotsPerVolTo16", 34),
			new EnumValue("performanceTier", 23),
			new EnumValue("storagePoolsTo32", 24),
			new EnumValue("storagePoolsToMax", 9),
			new EnumValue("driveSlotLimitTo272", 67),
			new EnumValue("remoteMirrorsTo64", 30),
			new EnumValue("storagePoolsTo128", 20),
			new EnumValue("driveSlotLimitTo192", 66),
			new EnumValue("protectionInformation", 37),
			new EnumValue("volumeCopy", 14),
			new EnumValue("snapshotsPerVolTo8", 33),
			new EnumValue("driveSlotLimitTo112", 45),
			new EnumValue("bundleMigration", 19),
			new EnumValue("snapshotsPerVolTo2", 35),
			new EnumValue("driveSlotLimitTo72", 60),
			new EnumValue("totalNumberOfPitsPerArray", 110),
			new EnumValue("driveSlotLimitTo32", 56),
			new EnumValue("snapshotsPerVolTo4", 32),
			new EnumValue("remoteMirroringType2", 107),
			new EnumValue("remoteMirrorsTo16", 28),
			new EnumValue("storagePoolsTo64", 10),
			new EnumValue("driveSlotLimitTo360", 95),
			new EnumValue("driveSlotLimitTo480", 49),
			new EnumValue("targetPortLunMapping", 115),
			new EnumValue("storagePoolsType2", 105),
			new EnumValue("fdeProxyKeyManagement", 68),
			new EnumValue("driveSlotLimit", 51),
			new EnumValue("storagePoolsTo512", 27),
			new EnumValue("driveSlotLimitTo120", 46),
			new EnumValue("driveSlotLimitTo240", 113),
			new EnumValue("storagePoolsTo192", 26),
			new EnumValue("driveSlotLimitTo60", 58),
			new EnumValue("snapshotsType2", 114),
			new EnumValue("driveSlotLimitTo448", 48),
			new EnumValue("driveSlotLimitTo64", 59),
			new EnumValue("totalNumberOfThinVolumesPerArray", 111),
			new EnumValue("driveSlotLimitTo128", 62),
			new EnumValue("remoteMirroring", 13),
			new EnumValue("snapshots", 12),
			new EnumValue("driveSlotLimitToMax", 50),
			new EnumValue("driveSlotLimitTo24", 55),
			new EnumValue("goldKey", 17),
			new EnumValue("flashReadCache", 96),
			new EnumValue("storagePoolsTo96", 25),
			new EnumValue("ssdSupport", 38),
			new EnumValue("storagePoolsTo16", 11)
		}, Capability.class);

		m_TypeTable[154] = new EnumSpec(new EnumValue[] {
			new EnumValue("inProgress", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("pending", 2),
			new EnumValue("none", 1),
			new EnumValue("unknown", 0)
		}, AsyncMirrorGroupRoleChangeProgress.class);

		m_TypeTable[155] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("removed", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 2),
			new EnumValue("noinput", 5),
			new EnumValue("unknown", 4)
		}, PowerSupplyStatus.class);

		m_TypeTable[156] = new EnumSpec(new EnumValue[] {
			new EnumValue("stat", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("disabled", 3),
			new EnumValue("dhcp", 2),
			new EnumValue("unknown", 0)
		}, NtpAcquisitionMethod.class);

		m_TypeTable[157] = new EnumSpec(new EnumValue[] {
			new EnumValue("endDate", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unlimited", 1),
			new EnumValue("count", 2),
			new EnumValue("unknown", 0)
		}, RecurrenceType.class);

		m_TypeTable[158] = new EnumSpec(new EnumValue[] {
			new EnumValue("byPassed", 1),
			new EnumValue("inProgress", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("aborted", 5),
			new EnumValue("pending", 2),
			new EnumValue("failed", 4),
			new EnumValue("complete", 0)
		}, PowerSupplyUpdateStatus.class);

		m_TypeTable[159] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("warnThresh", 2),
			new EnumValue("fullPolicyChg", 1),
			new EnumValue("cleared", 0),
			new EnumValue("full", 3)
		}, SecurityAuditLogEvent.class);

		m_TypeTable[160] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("devil", 2),
			new EnumValue("unidentified", 0),
			new EnumValue("polecat", 4),
			new EnumValue("cyclone", 3),
			new EnumValue("otter", 5),
			new EnumValue("badger", 1)
		}, ESMType.class);

		m_TypeTable[161] = new EnumSpec(new EnumValue[] {
			new EnumValue("database", 2),
			new EnumValue("multimedia", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("filesystem", 1),
			new EnumValue("unknown", 0)
		}, FlashCacheConfigType.class);

		m_TypeTable[162] = new EnumSpec(new EnumValue[] {
			new EnumValue("incompatible", 5),
			new EnumValue("optimal", 1),
			new EnumValue("removed", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("writeProtected", 4),
			new EnumValue("failed", 2),
			new EnumValue("unknown", 0)
		}, CacheBackupDeviceStatus.class);

		m_TypeTable[163] = new EnumSpec(new EnumValue[] {
			new EnumValue("opticalSwSx", 7),
			new EnumValue("serialModule", 4),
			new EnumValue("cs12Passive", 2),
			new EnumValue("opticalLw", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("notPresent", 0),
			new EnumValue("opticalSw", 5),
			new EnumValue("cs12Active", 1),
			new EnumValue("opticalLwLxSingleMode", 6)
		}, GBICType.class);

		m_TypeTable[164] = new EnumSpec(new EnumValue[] {
			new EnumValue("scsi", 1),
			new EnumValue("nvme", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unknown", 0)
		}, CommandProtocol.class);

		m_TypeTable[165] = new EnumSpec(new EnumValue[] {
			new EnumValue("portCru", 15),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("initiator", 25),
			new EnumValue("channel", 6),
			new EnumValue("fcTarget", 45),
			new EnumValue("nvmeInitiator", 50),
			new EnumValue("powerSply", 2),
			new EnumValue("fan", 3),
			new EnumValue("cgpit", 40),
			new EnumValue("enclosure", 10),
			new EnumValue("pitConsistencyGroup", 39),
			new EnumValue("host", 31),
			new EnumValue("pit", 38),
			new EnumValue("psuCru", 49),
			new EnumValue("snmpCommunity", 43),
			new EnumValue("interconnectCru", 16),
			new EnumValue("asyncMirrorGroup", 36),
			new EnumValue("snmpTrapDestination", 44),
			new EnumValue("volume", 13),
			new EnumValue("ups", 11),
			new EnumValue("hostBoard", 21),
			new EnumValue("drive", 1),
			new EnumValue("newFormat", 22),
			new EnumValue("relative", 34),
			new EnumValue("blankTwo", 47),
			new EnumValue("flashCache", 42),
			new EnumValue("battery", 9),
			new EnumValue("minihub", 4),
			new EnumValue("unknown", 0),
			new EnumValue("volumeGrp", 14),
			new EnumValue("sfpPort", 20),
			new EnumValue("hostIoCard", 28),
			new EnumValue("alarm", 18),
			new EnumValue("hostPort", 32),
			new EnumValue("fanOnlyCru", 48),
			new EnumValue("cgview", 41),
			new EnumValue("cacheBackupDevice", 29),
			new EnumValue("isnsServer", 27),
			new EnumValue("controller", 8),
			new EnumValue("chip", 12),
			new EnumValue("ctlrSfp", 23),
			new EnumValue("cacheMemDimm", 30),
			new EnumValue("tempSensor", 5),
			new EnumValue("blankOne", 46),
			new EnumValue("drawer", 33),
			new EnumValue("target", 26),
			new EnumValue("channelPort", 19),
			new EnumValue("schedule", 35),
			new EnumValue("ctlrSoc", 24),
			new EnumValue("diskPool", 37),
			new EnumValue("esm", 7),
			new EnumValue("supportCru", 17)
		}, EventComponentType.class);

		m_TypeTable[166] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("manualClear", 2),
			new EnumValue("overwrite", 1),
			new EnumValue("unknown", 0)
		}, SecurityAuditLogFullPolicy.class);

		m_TypeTable[167] = new EnumSpec(new EnumValue[] {
			new EnumValue("timeExpired", 3),
			new EnumValue("incomplete", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("notStarted", 4),
			new EnumValue("cancelled", 2),
			new EnumValue("complete", 0)
		}, ChannelDiagStatus.class);

		m_TypeTable[168] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("maxTempExceed", 3),
			new EnumValue("removed", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("nominalTempExceed", 2),
			new EnumValue("unknown", 5)
		}, ThermalSensorStatus.class);

		m_TypeTable[169] = new EnumSpec(new EnumValue[] {
			new EnumValue("halted", 3),
			new EnumValue("inProgress", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("pending", 5),
			new EnumValue("failed", 4),
			new EnumValue("complete", 2)
		}, VolumeCopyStatus.class);

		m_TypeTable[170] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("count", 3),
			new EnumValue("manual", 2),
			new EnumValue("freeExtent", 1)
		}, CandidateSelectionType.class);

		m_TypeTable[171] = new EnumSpec(new EnumValue[] {
			new EnumValue("primaryError", 3),
			new EnumValue("primaryRepositoryFull", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("reasonUnknown", 0),
			new EnumValue("interruption", 5),
			new EnumValue("secondaryError", 4),
			new EnumValue("configError", 6),
			new EnumValue("secondaryRepositoryFull", 2),
			new EnumValue("userSuspend", 7)
		}, AsyncMirrorSyncTerminationReason.class);

		m_TypeTable[172] = new EnumSpec(new EnumValue[] {
			new EnumValue("dedicated", 2),
			new EnumValue("shared", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unknown", 1),
			new EnumValue("aggregate", 4)
		}, CruType.class);

		m_TypeTable[173] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("capable", 2),
			new EnumValue("none", 1),
			new EnumValue("enabled", 3),
			new EnumValue("unknown", 0)
		}, SecurityType.class);

		m_TypeTable[174] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("overThresh", 3),
			new EnumValue("initializing", 5),
			new EnumValue("failed", 4),
			new EnumValue("unknown", 0),
			new EnumValue("full", 2)
		}, ThinVolumeStatus.class);

		m_TypeTable[175] = new EnumSpec(new EnumValue[] {
			new EnumValue("notification", 4),
			new EnumValue("general", 7),
			new EnumValue("hostEntry", 6),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failure", 2),
			new EnumValue("stateChange", 5),
			new EnumValue("error", 1),
			new EnumValue("command", 3)
		}, EventCategory.class);

		m_TypeTable[176] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("rel", 1),
			new EnumValue("raw", 0)
		}, IscsiStatisticsReportType.class);

		m_TypeTable[177] = new EnumSpec(new EnumValue[] {
			new EnumValue("asynchronousMode", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("consistentAsyncMode", 2),
			new EnumValue("synchronousMode", 0)
		}, MirrorProxyWriteMode.class);

		m_TypeTable[178] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("removed", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 2),
			new EnumValue("unknown", 4)
		}, SFPStatus.class);

		m_TypeTable[179] = new EnumSpec(new EnumValue[] {
			new EnumValue("incorrectConfig", 5),
			new EnumValue("optimal", 1),
			new EnumValue("removed", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 2),
			new EnumValue("noinput", 4),
			new EnumValue("unknown", 0)
		}, SupportCRUStatus.class);

		m_TypeTable[180] = new EnumSpec(new EnumValue[] {
			new EnumValue("all", 0),
			new EnumValue("loopbackData", 2),
			new EnumValue("read", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("write", 3)
		}, RuntimeDiagTestID.class);

		m_TypeTable[181] = new EnumSpec(new EnumValue[] {
			new EnumValue("overThreshold", 4),
			new EnumValue("optimal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 3),
			new EnumValue("unknown", 0),
			new EnumValue("full", 2)
		}, PITGroupStatus.class);

		m_TypeTable[182] = new EnumSpec(new EnumValue[] {
			new EnumValue("type10gig", 32),
			new EnumValue("type56gig", 128),
			new EnumValue("type8gig", 8),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("type32gig", 1024),
			new EnumValue("type4gig", 4),
			new EnumValue("typeUnknown", 0),
			new EnumValue("type2gig", 2),
			new EnumValue("type1gig", 1),
			new EnumValue("type16gig", 16),
			new EnumValue("type20gig", 256),
			new EnumValue("type25gig", 512),
			new EnumValue("type40gig", 64),
			new EnumValue("type100gig", 2048)
		}, SFP_SPEED.class);

		m_TypeTable[183] = new EnumSpec(new EnumValue[] {
			new EnumValue("incompatibleVgCloned", 15),
			new EnumValue("incompatibleUprevDacstore", 8),
			new EnumValue("incompatibleForeignDriveHasInconsistentRole", 18),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("incompatiblePiType", 30),
			new EnumValue("wrongDriveType", 7),
			new EnumValue("incompatibleDdfOtherVendor", 21),
			new EnumValue("none", 1),
			new EnumValue("incompatibleUnsupportedInterposerFwVersion", 32),
			new EnumValue("unsupportedCapacity", 28),
			new EnumValue("srcRelocation", 36),
			new EnumValue("incompatibleForeignVgRefersToNativeDrive", 13),
			new EnumValue("unsupportedProtocolConnection", 27),
			new EnumValue("incompatibleSataDriveSctUnsupported", 33),
			new EnumValue("incompatibleAlignmentForEmulationDrive", 35),
			new EnumValue("insufficientDriveCapacity", 24),
			new EnumValue("incompatibleVgDrivePartOfMultipleVgs", 19),
			new EnumValue("locked", 23),
			new EnumValue("incompatibleDbAdoptionFailure", 22),
			new EnumValue("incompatibleDatabaseValidationFailure", 31),
			new EnumValue("speedMismatch", 5),
			new EnumValue("incompatibleModelNumberUnsupported", 34),
			new EnumValue("userOp", 2),
			new EnumValue("bypassUnknown", 6),
			new EnumValue("incompatibleSectorSizeMismatch", 11),
			new EnumValue("incompatibleDownrevDacstore", 9),
			new EnumValue("incompatibleNativeVgRefersToForeignDrive", 12),
			new EnumValue("pfa", 39),
			new EnumValue("writeOp", 3),
			new EnumValue("incompatibleNativeVgForeignDriveMutualRef", 14),
			new EnumValue("spfa", 40),
			new EnumValue("incompatibleInternalError", 10),
			new EnumValue("incompatibleFailedLegacyDrive", 20),
			new EnumValue("supercapacitorFailure", 25),
			new EnumValue("incompatibleDriveMetadataUnusable", 38),
			new EnumValue("incompatibleForeignDriveInconsistent", 16),
			new EnumValue("invalidLockKeyPresented", 29),
			new EnumValue("uncertified", 4),
			new EnumValue("incompatibleVgHasDrivePartOfMultipleVgs", 17),
			new EnumValue("dstRelocation", 37)
		}, DriveStatusCause.class);

		m_TypeTable[184] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("removed", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("invalid", 6),
			new EnumValue("opened", 3),
			new EnumValue("failed", 2),
			new EnumValue("degraded", 5),
			new EnumValue("unknown", 0)
		}, DrawerStatus.class);

		m_TypeTable[185] = new EnumSpec(new EnumValue[] {
			new EnumValue("paused", 3),
			new EnumValue("idle", 1),
			new EnumValue("userSuspended", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("internallySuspended", 5),
			new EnumValue("active", 2),
			new EnumValue("unknown", 0)
		}, AsyncMirrorSyncActivity.class);

		m_TypeTable[186] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("serviceModeExtended", 2),
			new EnumValue("none", 0),
			new EnumValue("serviceModeBasic", 1)
		}, FruDiagTestType.class);

		m_TypeTable[187] = new EnumSpec(new EnumValue[] {
			new EnumValue("fcToSas", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unknown", 0)
		}, InterposerType.class);

		m_TypeTable[188] = new EnumSpec(new EnumValue[] {
			new EnumValue("flush1500Msec", 5),
			new EnumValue("flush120Sec", 11),
			new EnumValue("flush3600Sec", 14),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("flush1200Sec", 13),
			new EnumValue("flush2Sec", 6),
			new EnumValue("flush20Sec", 9),
			new EnumValue("flush5Sec", 7),
			new EnumValue("flush750Msec", 3),
			new EnumValue("flush1Sec", 4),
			new EnumValue("flush250Msec", 1),
			new EnumValue("flush300Sec", 12),
			new EnumValue("flushImmediate", 0),
			new EnumValue("flush60Sec", 10),
			new EnumValue("flush10Sec", 8),
			new EnumValue("flushInfinite", 15),
			new EnumValue("flush500Msec", 2)
		}, CacheFlushModifier.class);

		m_TypeTable[189] = new EnumSpec(new EnumValue[] {
			new EnumValue("connected", 3),
			new EnumValue("disconnected", 5),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("disconnecting", 4),
			new EnumValue("connecting", 2),
			new EnumValue("uninitialized", 1)
		}, IbRdmaChannelState.class);

		m_TypeTable[190] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("notInErrorMode", 0),
			new EnumValue("t10PiLockdown", 3),
			new EnumValue("t10PiServiceMode", 2),
			new EnumValue("unknown", 1)
		}, ControllerErrorModeType.class);
	}

	private static void __init5() {

		m_TypeTable[191] = new EnumSpec(new EnumValue[] {
			new EnumValue("capabilityIscsi10gbHostCard", 39),
			new EnumValue("capabilityAsupSupport", 63),
			new EnumValue("capabilityFipsDriveSupport", 75),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("capabilityDualPortedSata", 4),
			new EnumValue("capabilityFieldRepCacheMem", 6),
			new EnumValue("capabilityApplicationAwareness", 76),
			new EnumValue("capabilityT10", 35),
			new EnumValue("capabilityBaseControllerDiags", 44),
			new EnumValue("capabilityWembleyEnclosure", 54),
			new EnumValue("capabilityFeatureBundles", 25),
			new EnumValue("capabilityFdeDriveSupport", 5),
			new EnumValue("capabilityImmediateHostTopology", 27),
			new EnumValue("capabilityDriveMgmt", 22),
			new EnumValue("capabilityCacheMemoryDiags", 45),
			new EnumValue("capabilityFtdcTraceHistory", 65),
			new EnumValue("capabilityWlcLogging", 73),
			new EnumValue("capabilityEnhancedLun0Support", 40),
			new EnumValue("capabilityIpv6MgmtPortIpv6", 9),
			new EnumValue("capabilitySetTrayAttributes", 57),
			new EnumValue("capabilityDap520b", 3),
			new EnumValue("capabilityCal6334", 15),
			new EnumValue("capabilityFdeProxyKeyMgmt", 47),
			new EnumValue("capabilityAdvancedFormatSupport", 66),
			new EnumValue("capabilityLockout2tbDrives", 49),
			new EnumValue("capability4knativeAdvancedFormatSupport", 67),
			new EnumValue("capabilityRaid6PrereadRedCheck", 51),
			new EnumValue("capabilityDriveSlotLimit", 46),
			new EnumValue("capabilityDrvChannelDiags", 24),
			new EnumValue("capabilityCoreIscsi", 2),
			new EnumValue("capabilityCacheBackup", 1),
			new EnumValue("capabilitySupportsVirtualization", 34),
			new EnumValue("capabilityParentRelativeStatus", 30),
			new EnumValue("capabilityDriveSideTrunkSupport", 42),
			new EnumValue("capabilityInfusion", 36),
			new EnumValue("capabilityPompanoSupport", 31),
			new EnumValue("capabilityInfinibandSupport", 8),
			new EnumValue("capabilityIosSupport", 48),
			new EnumValue("capabilityDiagDataCapture", 19),
			new EnumValue("capabilityParentRelativeLocation", 29),
			new EnumValue("capabilityEnhancedFormatUnitSupport", 41),
			new EnumValue("capabilityPsuFirmwareUpdate", 60),
			new EnumValue("capabilitySataDriveLockout", 52),
			new EnumValue("capabilityHostContextAgent", 26),
			new EnumValue("capabilityDriveLimitManagement", 37),
			new EnumValue("capabilityDriveMixWithinTray", 23),
			new EnumValue("capabilitySasSupport", 11),
			new EnumValue("capabilityDplCoreDump", 61),
			new EnumValue("capabilityCtrlStateCapture", 18),
			new EnumValue("capabilityEmbeddedSnmpAgent", 64),
			new EnumValue("capabilityGbEthMgmtPort", 7),
			new EnumValue("capabilityIscsiIpv6", 10),
			new EnumValue("capabilityCfgDbAdoption", 16),
			new EnumValue("capabilitySocStatistics", 33),
			new EnumValue("capabilityNone", 0),
			new EnumValue("capabilitySimplex", 12),
			new EnumValue("capabilityDiskPools", 62),
			new EnumValue("capabilitySsdSupport", 43),
			new EnumValue("capabilityRaid6", 32),
			new EnumValue("capabilityHicDiags", 56),
			new EnumValue("capabilityAsupOnDemandSupport", 68),
			new EnumValue("capabilityIscsiTarget", 58),
			new EnumValue("capabilityParentRelativeMel", 50),
			new EnumValue("capabilityIscsiInitiator", 59),
			new EnumValue("capabilityCacheMirroringProtectionInformation", 78),
			new EnumValue("capabilityIocDump", 69),
			new EnumValue("capabilityEmbeddedEkms", 77),
			new EnumValue("capabilitySfpPlus", 38),
			new EnumValue("capabilityCal6141", 14),
			new EnumValue("capabilityOnlineDrvFwDwnld", 28),
			new EnumValue("capabilityCtrlLockdown", 17),
			new EnumValue("capabilityCacheBackupDeviceDiags", 55),
			new EnumValue("capabilityLowAndHighSampling", 71),
			new EnumValue("capabilitySmartBatteryMgmt", 13),
			new EnumValue("capabilityDriveEnclosureMiswires", 21),
			new EnumValue("capabilitySyslogMsgs", 53),
			new EnumValue("capabilityAutoLoadBalancing", 72),
			new EnumValue("capabilityDriveDataRelocation", 20),
			new EnumValue("capabilityDrivePowerCycle", 70)
		}, ProductCapability.class);

		m_TypeTable[192] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("passed", 1),
			new EnumValue("failed", 2),
			new EnumValue("skipped", 0)
		}, DataCheck.class);

		m_TypeTable[193] = new EnumSpec(new EnumValue[] {
			new EnumValue("chassisid", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("timetolive", 3),
			new EnumValue("portid", 2),
			new EnumValue("unknown", 0)
		}, EnhEthTLVType.class);

		m_TypeTable[194] = new EnumSpec(new EnumValue[] {
			new EnumValue("dbmCheck", 4),
			new EnumValue("dplCoreDumpBundle", 6),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("ctrlPerfLogs", 12),
			new EnumValue("dom0SupportData", 16),
			new EnumValue("driveHealthLogs", 11),
			new EnumValue("autoLoadBalanceStatisticsLog", 18),
			new EnumValue("enclosureStateCapture", 5),
			new EnumValue("dq", 1),
			new EnumValue("dbmblk", 2),
			new EnumValue("unknown", 0),
			new EnumValue("retrieveWlcAnalytics", 17),
			new EnumValue("drivePerformanceHistory", 9),
			new EnumValue("iocDump", 10),
			new EnumValue("dbmrec", 3),
			new EnumValue("ioStatistics", 7),
			new EnumValue("fdiDemsLogs", 8)
		}, RawDataTransferType.class);

		m_TypeTable[195] = new EnumSpec(new EnumValue[] {
			new EnumValue("scsiScsi", 1),
			new EnumValue("fibreFibre", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("fibreSata", 3),
			new EnumValue("unknown", 0),
			new EnumValue("fibrePata", 4)
		}, TrayTechnologyType.class);

		m_TypeTable[196] = new EnumSpec(new EnumValue[] {
			new EnumValue("connectingToServer", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("disabled", 1),
			new EnumValue("completed", 4),
			new EnumValue("locatingServer", 2)
		}, IsnsRegistrationState.class);

		m_TypeTable[197] = new EnumSpec(new EnumValue[] {
			new EnumValue("xbb2", 15),
			new EnumValue("sc12", 26),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("pciraid", 4),
			new EnumValue("de6600", 23),
			new EnumValue("de6650", 25),
			new EnumValue("sym1500", 9),
			new EnumValue("sym1200", 7),
			new EnumValue("sym1000", 1),
			new EnumValue("sym2772", 3),
			new EnumValue("fc6900", 16),
			new EnumValue("md1200", 17),
			new EnumValue("fc4600", 10),
			new EnumValue("sc24", 27),
			new EnumValue("ss3600", 11),
			new EnumValue("de1600", 19),
			new EnumValue("md3000", 13),
			new EnumValue("de7600", 24),
			new EnumValue("generic", 5),
			new EnumValue("md1000", 12),
			new EnumValue("md1220", 18),
			new EnumValue("de5600", 20),
			new EnumValue("sym2200", 6),
			new EnumValue("sym2882", 8),
			new EnumValue("de212c", 28),
			new EnumValue("de460c", 30),
			new EnumValue("sym2000", 2),
			new EnumValue("de224c", 29)
		}, TrayType.class);

		m_TypeTable[198] = new EnumSpec(new EnumValue[] {
			new EnumValue("offline", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("active", 1),
			new EnumValue("disabled", 3),
			new EnumValue("failed", 2)
		}, SnapshotStatus.class);

		m_TypeTable[199] = new EnumSpec(new EnumValue[] {
			new EnumValue("copyback", 2),
			new EnumValue("volumeCopy", 18),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("copyThenReplace", 26),
			new EnumValue("remappingDseg", 8),
			new EnumValue("thinDefrag", 28),
			new EnumValue("none", 1),
			new EnumValue("parityScan", 17),
			new EnumValue("pitRollback", 20),
			new EnumValue("snapshotRollback", 19),
			new EnumValue("remappingDrm", 6),
			new EnumValue("asyncMirrorGroupInitialSync", 21),
			new EnumValue("synchronizing", 14),
			new EnumValue("reconstructingCritical", 22),
			new EnumValue("copyThenReplaceAndFail", 27),
			new EnumValue("reconstructing", 4),
			new EnumValue("remappingInternal", 11),
			new EnumValue("remappingDve", 9),
			new EnumValue("initializing", 3),
			new EnumValue("remappingDcedrm", 7),
			new EnumValue("remappingDefrag", 12),
			new EnumValue("deleting", 34),
			new EnumValue("remappingDcedve", 10),
			new EnumValue("creating", 33),
			new EnumValue("remappingDce", 5),
			new EnumValue("copyThenFail", 24),
			new EnumValue("copyThenFailPending", 25),
			new EnumValue("formatting", 13),
			new EnumValue("rebalancing", 23)
		}, VolumeAction.class);

		m_TypeTable[200] = new EnumSpec(new EnumValue[] {
			new EnumValue("standard", 2),
			new EnumValue("unk", 0),
			new EnumValue("perPriority", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("disabled", 1)
		}, EnhEthFlowControlStatus.class);

		m_TypeTable[201] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("learning", 9),
			new EnumValue("failed", 4),
			new EnumValue("replacementRequired", 14),
			new EnumValue("unknown", 6),
			new EnumValue("expired", 11),
			new EnumValue("removed", 5),
			new EnumValue("configMismatch", 8),
			new EnumValue("maintenanceCharging", 13),
			new EnumValue("fullCharging", 2),
			new EnumValue("nearExpiration", 3),
			new EnumValue("notInConfig", 7),
			new EnumValue("overtemp", 10)
		}, BatteryStatus.class);

		m_TypeTable[202] = new EnumSpec(new EnumValue[] {
			new EnumValue("ethernet", 1),
			new EnumValue("__UNDEFINED", 464378545)
		}, NetInterfaceType.class);

		m_TypeTable[203] = new EnumSpec(new EnumValue[] {
			new EnumValue("controllerTray", 4),
			new EnumValue("controller", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("hostboard", 2),
			new EnumValue("cacheDimm", 3),
			new EnumValue("unknown", 0)
		}, LockdownFaultObjectType.class);

		m_TypeTable[204] = new EnumSpec(new EnumValue[] {
			new EnumValue("typeNa", 6),
			new EnumValue("typeMedium", 5),
			new EnumValue("typeShort", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("typeIntermediate", 3),
			new EnumValue("typeVlong", 1),
			new EnumValue("typeLong", 4),
			new EnumValue("typeUnknown", 0)
		}, SFP_LINKL_TYPE.class);

		m_TypeTable[205] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failedRepositories", 1),
			new EnumValue("unknown", 0),
			new EnumValue("specificRepository", 2)
		}, CoWRepositoryAnalysisAction.class);

		m_TypeTable[206] = new EnumSpec(new EnumValue[] {
			new EnumValue("driveside", 1),
			new EnumValue("management", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("hostside", 0)
		}, ChannelType.class);

		m_TypeTable[207] = new EnumSpec(new EnumValue[] {
			new EnumValue("na", 128),
			new EnumValue("tmMiniatureCoax", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("tmVideoCoax", 8),
			new EnumValue("tmSingleMode", 64),
			new EnumValue("twinAxialPair", 1),
			new EnumValue("tmMultiModeM5", 32),
			new EnumValue("tmShieldedTwistedPair", 2),
			new EnumValue("tmMultiModeM6", 16),
			new EnumValue("unknown", 0)
		}, SFP_TRANSMISSION_MEDIA.class);

		m_TypeTable[208] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("verify", 0)
		}, ChannelDiagType.class);

		m_TypeTable[209] = new EnumSpec(new EnumValue[] {
			new EnumValue("traditional", 1),
			new EnumValue("diskPool", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unknown", 0)
		}, VolumeGroupType.class);

		m_TypeTable[210] = new EnumSpec(new EnumValue[] {
			new EnumValue("extUserConfigData", 241),
			new EnumValue("subsystemId", 232),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("nonUserConfigData", 226),
			new EnumValue("subsystemFaultData", 233),
			new EnumValue("bootpData", 240),
			new EnumValue("driveFaultData", 234),
			new EnumValue("hostInterfaceData", 237),
			new EnumValue("userConfig2Data", 244),
			new EnumValue("userConfigData", 238),
			new EnumValue("allRegions", -1),
			new EnumValue("hostManagedData", 236),
			new EnumValue("hostTypeDependentData", 242)
		}, NVSRAMRegionId.class);

		m_TypeTable[211] = new EnumSpec(new EnumValue[] {
			new EnumValue("controller", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("minihub", 2),
			new EnumValue("esm", 1),
			new EnumValue("unknown", 0)
		}, SFPParentType.class);

		m_TypeTable[212] = new EnumSpec(new EnumValue[] {
			new EnumValue("portComp", 2),
			new EnumValue("unk", 0),
			new EnumValue("intfAlias", 1),
			new EnumValue("agentCircuit", 6),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("ntwkAddr", 4),
			new EnumValue("local", 7),
			new EnumValue("macAddr", 3),
			new EnumValue("intfName", 5)
		}, EnhEthPortIDSubtype.class);

		m_TypeTable[213] = new EnumSpec(new EnumValue[] {
			new EnumValue("summary", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("details", 2),
			new EnumValue("unknown", 0)
		}, AutoLoadBalanceStatsLogDataType.class);

		m_TypeTable[214] = new EnumSpec(new EnumValue[] {
			new EnumValue("horizontal", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("vertical", 3),
			new EnumValue("none", 1)
		}, DriveOrientation.class);

		m_TypeTable[215] = new EnumSpec(new EnumValue[] {
			new EnumValue("high", 1),
			new EnumValue("low", 0),
			new EnumValue("__UNDEFINED", 464378545)
		}, StatisticsResolutionType.class);

		m_TypeTable[216] = new EnumSpec(new EnumValue[] {
			new EnumValue("bypDataTimeout", 9),
			new EnumValue("bypSyncLoss", 11),
			new EnumValue("bypRedundant", 15),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("insertedManual", 2),
			new EnumValue("bypLipF8", 8),
			new EnumValue("bypPtbi", 13),
			new EnumValue("bypLipIsol", 12),
			new EnumValue("bypNoFru", 6),
			new EnumValue("bypRxLos", 10),
			new EnumValue("bypCrcThresh", 17),
			new EnumValue("unknown", 0),
			new EnumValue("inserted", 1),
			new EnumValue("diagXmit", 4),
			new EnumValue("bypManual", 14),
			new EnumValue("bypSnoop", 16),
			new EnumValue("bypInvalidOsThresh", 18),
			new EnumValue("bypassed", 5),
			new EnumValue("bypTxFault", 7),
			new EnumValue("loopback", 3)
		}, SocPortState.class);

		m_TypeTable[217] = new EnumSpec(new EnumValue[] {
			new EnumValue("se", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("hvd", 2),
			new EnumValue("lvd", 3)
		}, SCSIDriverType.class);

		m_TypeTable[218] = new EnumSpec(new EnumValue[] {
			new EnumValue("nvmeof", 2),
			new EnumValue("nvme", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unknown", 0)
		}, CommandSetType.class);

		m_TypeTable[219] = new EnumSpec(new EnumValue[] {
			new EnumValue("enabledLegacyRvm", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("disabled", 1),
			new EnumValue("enabledArvm", 3),
			new EnumValue("unknown", 0),
			new EnumValue("enabledAll", 4)
		}, FibreChannelRemoteMirroringState.class);

		m_TypeTable[220] = new EnumSpec(new EnumValue[] {
			new EnumValue("leftToRight", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("topToBottom", 4),
			new EnumValue("rightToLeft", 3),
			new EnumValue("none", 1),
			new EnumValue("frontToBack", 5)
		}, Traversal.class);

		m_TypeTable[221] = new EnumSpec(new EnumValue[] {
			new EnumValue("resnap", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("newpit", 2),
			new EnumValue("newcgpit", 3),
			new EnumValue("unknown", 0)
		}, ScheduleAction.class);

		m_TypeTable[222] = new EnumSpec(new EnumValue[] {
			new EnumValue("rawdataFlushed", 1),
			new EnumValue("dqtraceCurrent", 0),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("rawdataAllIncludePlatform", 3),
			new EnumValue("rawdataAll", 2)
		}, DqTraceID.class);

		m_TypeTable[223] = new EnumSpec(new EnumValue[] {
			new EnumValue("localController", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("alternateController", 5),
			new EnumValue("host", 6),
			new EnumValue("drive", 2),
			new EnumValue("expander", 3),
			new EnumValue("unknown", 1)
		}, SasAttachedDeviceType.class);

		m_TypeTable[224] = new EnumSpec(new EnumValue[] {
			new EnumValue("infiniband", 2),
			new EnumValue("ethernet", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unknown", 0)
		}, PhysicalInterfaceType.class);

		m_TypeTable[225] = new EnumSpec(new EnumValue[] {
			new EnumValue("parent", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("self", 2)
		}, ComponentReplacementMethod.class);

		m_TypeTable[226] = new EnumSpec(new EnumValue[] {
			new EnumValue("stale", 2),
			new EnumValue("optimal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("mismatch", 3),
			new EnumValue("invalid", 4),
			new EnumValue("frozen", 5),
			new EnumValue("unknown", 0),
			new EnumValue("empty", 6)
		}, DatabaseStatus.class);

		m_TypeTable[227] = new EnumSpec(new EnumValue[] {
			new EnumValue("random", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("fixed", 0)
		}, ChannelDiagDataPatternType.class);

		m_TypeTable[228] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("ok", 2),
			new EnumValue("terminated", 1),
			new EnumValue("unknown", 0)
		}, AsyncMirrorSyncCompletionType.class);

		m_TypeTable[229] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("direct", 1),
			new EnumValue("subtractive", 3),
			new EnumValue("table", 2)
		}, SasRoutingType.class);

		m_TypeTable[230] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("none", 0),
			new EnumValue("up", 1),
			new EnumValue("failed", 3),
			new EnumValue("down", 2)
		}, LinkStatus.class);

		m_TypeTable[231] = new EnumSpec(new EnumValue[] {
			new EnumValue("clearHwFailure", 5),
			new EnumValue("adminRequest", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("socNotOperational", 3),
			new EnumValue("socEepromFailure", 4),
			new EnumValue("controllerAction", 6),
			new EnumValue("none", 0),
			new EnumValue("thresholdExceeded", 1)
		}, DriveChannelDegradeReason.class);

		m_TypeTable[232] = new EnumSpec(new EnumValue[] {
			new EnumValue("stopped", 2),
			new EnumValue("overThreshold", 4),
			new EnumValue("optimal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 3),
			new EnumValue("unknown", 0),
			new EnumValue("full", 5)
		}, PITViewStatus.class);

		m_TypeTable[233] = new EnumSpec(new EnumValue[] {
			new EnumValue("mirrorPair", 4),
			new EnumValue("concatMember", 9),
			new EnumValue("volumeCopy", 2),
			new EnumValue("metadata", 3),
			new EnumValue("persistentReservation", 6),
			new EnumValue("pitView", 11),
			new EnumValue("asyncMirrorGroupMember", 8),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("pitGroup", 10),
			new EnumValue("raid6Support", 7),
			new EnumValue("hostMapping", 5),
			new EnumValue("snapshot", 1)
		}, ImportDependencyType.class);

		m_TypeTable[234] = new EnumSpec(new EnumValue[] {
			new EnumValue("incompatible", 7),
			new EnumValue("optimal", 1),
			new EnumValue("removed", 6),
			new EnumValue("unresponsive", 5),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("dataRelocation", 8),
			new EnumValue("bypassed", 4),
			new EnumValue("preFailCopyPending", 10),
			new EnumValue("replaced", 3),
			new EnumValue("preFailCopy", 9),
			new EnumValue("failed", 2)
		}, DriveStatus.class);

		m_TypeTable[235] = new EnumSpec(new EnumValue[] {
			new EnumValue("gbic", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("soldered", 2),
			new EnumValue("sfp", 3),
			new EnumValue("unknown", 0)
		}, SFP_IDENT_TYPE.class);

		m_TypeTable[236] = new EnumSpec(new EnumValue[] {
			new EnumValue("exclAccessRegOnly", 4),
			new EnumValue("writeExclAllReg", 5),
			new EnumValue("exclAccessAllReg", 6),
			new EnumValue("writeExclRegOnly", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("noReservation", 0),
			new EnumValue("writeExcl", 1),
			new EnumValue("exclAccess", 2)
		}, ReservationTypeID.class);

		m_TypeTable[237] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("dayOfMonth13", 4096),
			new EnumValue("dayOfMonth12", 2048),
			new EnumValue("dayOfMonth11", 1024),
			new EnumValue("dayOfMonth10", 512),
			new EnumValue("dayOfMonth31", 1073741824),
			new EnumValue("dayOfMonth30", 536870912),
			new EnumValue("dayOfMonth19", 262144),
			new EnumValue("dayOfMonth18", 131072),
			new EnumValue("dayOfMonthNotSpecified", 0),
			new EnumValue("dayOfMonth17", 65536),
			new EnumValue("dayOfMonth16", 32768),
			new EnumValue("dayOfMonth15", 16384),
			new EnumValue("dayOfMonth14", 8192),
			new EnumValue("dayOfMonth02", 2),
			new EnumValue("dayOfMonth24", 8388608),
			new EnumValue("dayOfMonth01", 1),
			new EnumValue("dayOfMonth23", 4194304),
			new EnumValue("dayOfMonthLast", -2147483648),
			new EnumValue("dayOfMonth22", 2097152),
			new EnumValue("dayOfMonth21", 1048576),
			new EnumValue("dayOfMonth20", 524288),
			new EnumValue("dayOfMonth09", 256),
			new EnumValue("dayOfMonth08", 128),
			new EnumValue("dayOfMonth07", 64),
			new EnumValue("dayOfMonth29", 268435456),
			new EnumValue("dayOfMonth06", 32),
			new EnumValue("dayOfMonth28", 134217728),
			new EnumValue("dayOfMonth05", 16),
			new EnumValue("dayOfMonth27", 67108864),
			new EnumValue("dayOfMonth04", 8),
			new EnumValue("dayOfMonth26", 33554432),
			new EnumValue("dayOfMonth03", 4),
			new EnumValue("dayOfMonth25", 16777216)
		}, DayOfMonth.class);
	}

	private static void __init6() {

		m_TypeTable[238] = new EnumSpec(new EnumValue[] {
			new EnumValue("volume", 3),
			new EnumValue("controller", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("io", 2),
			new EnumValue("implementation", 1),
			new EnumValue("iointerface", 5),
			new EnumValue("drive", 0)
		}, CounterGroupType.class);

		m_TypeTable[239] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("periodic", 1),
			new EnumValue("roleChange", 4),
			new EnumValue("manual", 2),
			new EnumValue("initialSync", 3),
			new EnumValue("unknown", 0)
		}, AsyncMirrorSyncType.class);

		m_TypeTable[240] = new EnumSpec(new EnumValue[] {
			new EnumValue("mirrorPair", 4),
			new EnumValue("concatMember", 9),
			new EnumValue("volumeCopy", 2),
			new EnumValue("metadata", 3),
			new EnumValue("persistentReservation", 6),
			new EnumValue("pitView", 11),
			new EnumValue("asyncMirrorGroupMember", 8),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("pitGroup", 10),
			new EnumValue("raid6Support", 7),
			new EnumValue("hostMapping", 5),
			new EnumValue("snapshot", 1)
		}, ExportDependencyType.class);

		m_TypeTable[241] = new EnumSpec(new EnumValue[] {
			new EnumValue("controller", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("genericTyped", 2),
			new EnumValue("generic", 0)
		}, ObjectReferenceType.class);

		m_TypeTable[242] = new EnumSpec(new EnumValue[] {
			new EnumValue("auto", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("switched", 3),
			new EnumValue("fixed", 2),
			new EnumValue("unknown", 1)
		}, SpeedControl.class);

		m_TypeTable[243] = new EnumSpec(new EnumValue[] {
			new EnumValue("edcError", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("piError", 6),
			new EnumValue("injected", 3),
			new EnumValue("physical", 1),
			new EnumValue("inconsistent", 5),
			new EnumValue("logical", 2)
		}, UsmRecordType.class);

		m_TypeTable[244] = new EnumSpec(new EnumValue[] {
			new EnumValue("bundleDisplay", 7),
			new EnumValue("unspecified", 0),
			new EnumValue("management", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("iom", 4),
			new EnumValue("hypervisor", 2),
			new EnumValue("nvsram", 5),
			new EnumValue("bundle", 6),
			new EnumValue("raid", 1)
		}, CodeModule.class);

		m_TypeTable[245] = new EnumSpec(new EnumValue[] {
			new EnumValue("hostImage", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("dacstoreDisks", 1),
			new EnumValue("onboardRpa", 2),
			new EnumValue("unknown", 0)
		}, DbmDatabaseLocation.class);

		m_TypeTable[246] = new EnumSpec(new EnumValue[] {
			new EnumValue("nameOnly", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("portsOnly", 2),
			new EnumValue("nameAndPorts", 3)
		}, PendingHostMatchType.class);

		m_TypeTable[247] = new EnumSpec(new EnumValue[] {
			new EnumValue("endDevice", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("expander", 2)
		}, SasPortType.class);

		m_TypeTable[248] = new EnumSpec(new EnumValue[] {
			new EnumValue("hirt", 5),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("dirt", 4),
			new EnumValue("ciqr", 2),
			new EnumValue("diqr", 3),
			new EnumValue("acpu0", 0),
			new EnumValue("acpu1", 1)
		}, StatStreamType.class);

		m_TypeTable[249] = new EnumSpec(new EnumValue[] {
			new EnumValue("secondary", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("invalid", 2),
			new EnumValue("primary", 0)
		}, MirrorProxyRole.class);

		m_TypeTable[250] = new EnumSpec(new EnumValue[] {
			new EnumValue("utilizationWarning", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("utilizationCritical", 3),
			new EnumValue("capacityDepleted", 4),
			new EnumValue("utilizationInvalid", 0),
			new EnumValue("utilizationOptimal", 1)
		}, DiskPoolUtilizationState.class);

		m_TypeTable[251] = new EnumSpec(new EnumValue[] {
			new EnumValue("iscsi", 3),
			new EnumValue("unk", 0),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("fcoe", 1),
			new EnumValue("fip", 2)
		}, EnhEthProtocolType.class);

		m_TypeTable[252] = new EnumSpec(new EnumValue[] {
			new EnumValue("syslocation", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("sysname", 1),
			new EnumValue("syscontact", 2),
			new EnumValue("unknown", 0)
		}, SNMPSystemVariableID.class);

		m_TypeTable[253] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 3),
			new EnumValue("degraded", 2),
			new EnumValue("unknown", 0)
		}, SasPortState.class);

		m_TypeTable[254] = new EnumSpec(new EnumValue[] {
			new EnumValue("width12x", 3),
			new EnumValue("width4x", 1),
			new EnumValue("width1x", 0),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("width8x", 2)
		}, IbLinkWidth.class);

		m_TypeTable[255] = new EnumSpec(new EnumValue[] {
			new EnumValue("newRepository", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("only", 1),
			new EnumValue("andResize", 2),
			new EnumValue("unknown", 0)
		}, ThinVolumeReinitializeAction.class);

		m_TypeTable[256] = new EnumSpec(new EnumValue[] {
			new EnumValue("defer", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("active", 3),
			new EnumValue("initialize", 1),
			new EnumValue("arm", 2),
			new EnumValue("down", 5),
			new EnumValue("unknown", 0)
		}, IbPortState.class);

		m_TypeTable[257] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("typeInterface", 0),
			new EnumValue("typeRouter", 1)
		}, IpV6AddressType.class);

		m_TypeTable[258] = new EnumSpec(new EnumValue[] {
			new EnumValue("paused", 4),
			new EnumValue("inProgress", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("pending", 3),
			new EnumValue("none", 1),
			new EnumValue("unknown", 0)
		}, PITRollbackStatus.class);

		m_TypeTable[259] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("configDhcp", 0),
			new EnumValue("configStatic", 1)
		}, IpV4ConfigMethod.class);

		m_TypeTable[260] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("thinProvisioned", 1),
			new EnumValue("thickProvisioned", 2),
			new EnumValue("unknown", 0)
		}, VolumeType.class);

		m_TypeTable[261] = new EnumSpec(new EnumValue[] {
			new EnumValue("basicConnectivityTest", 1),
			new EnumValue("linkLatencyTest", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("connectivityTestUnknown", 0),
			new EnumValue("linkBandwidthTest", 3)
		}, AsyncMirrorGroupConnectivityTestType.class);

		m_TypeTable[262] = new EnumSpec(new EnumValue[] {
			new EnumValue("linear", 0),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("logBase2", 1),
			new EnumValue("logBase10", 2)
		}, HistogramScaleType.class);

		m_TypeTable[263] = new EnumSpec(new EnumValue[] {
			new EnumValue("configStateless", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("configStatic", 0)
		}, IpV6ConfigMethod.class);

		m_TypeTable[264] = new EnumSpec(new EnumValue[] {
			new EnumValue("parent", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("self", 2)
		}, ComponentRemovalMethod.class);

		m_TypeTable[265] = new EnumSpec(new EnumValue[] {
			new EnumValue("clientCertificate", 1),
			new EnumValue("serverCertificate", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("certificateFileTypeUnknown", 0)
		}, KMSCertificateFileType.class);

		m_TypeTable[266] = new EnumSpec(new EnumValue[] {
			new EnumValue("valid", 1),
			new EnumValue("notSupported", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("invalidStuck", 2),
			new EnumValue("invalidExternReset", 3),
			new EnumValue("unknown", 0)
		}, StatisticQualifier.class);

		m_TypeTable[267] = new EnumSpec(new EnumValue[] {
			new EnumValue("unsupported", 5),
			new EnumValue("optimal", 1),
			new EnumValue("removed", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 2),
			new EnumValue("uncertified", 6),
			new EnumValue("unknown", 4)
		}, ESMStatus.class);

		m_TypeTable[268] = new EnumSpec(new EnumValue[] {
			new EnumValue("ethernet", 1),
			new EnumValue("ethernetAndFcSplit", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("none", 0),
			new EnumValue("fc", 2)
		}, HICProtocolType.class);

		m_TypeTable[269] = new EnumSpec(new EnumValue[] {
			new EnumValue("fabLoop", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("fabric", 2),
			new EnumValue("arbLoop", 3),
			new EnumValue("ptp", 1),
			new EnumValue("unknown", 0)
		}, FibreTopologyType.class);

		m_TypeTable[270] = new EnumSpec(new EnumValue[] {
			new EnumValue("port12", 5),
			new EnumValue("port34", 6),
			new EnumValue("expansionAndInternal", 10),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("port7", 7),
			new EnumValue("expansionOnly", 9),
			new EnumValue("port3", 3),
			new EnumValue("minihubInout", 8),
			new EnumValue("port4", 4),
			new EnumValue("port1", 1),
			new EnumValue("portUnknown", 0),
			new EnumValue("port2", 2)
		}, DriveChannelPortType.class);

		m_TypeTable[271] = new EnumSpec(new EnumValue[] {
			new EnumValue("powerFan", 1),
			new EnumValue("fan", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("battery", 2),
			new EnumValue("powerSupply", 4),
			new EnumValue("unknown", 0)
		}, SupportCruType.class);

		m_TypeTable[272] = new EnumSpec(new EnumValue[] {
			new EnumValue("keyLimit", 4),
			new EnumValue("evalDuration", 7),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("shippedEnabled", 1),
			new EnumValue("subjectToGoldKey", 6),
			new EnumValue("supportedValues", 5),
			new EnumValue("keyEnabled", 3),
			new EnumValue("shippedLimit", 2)
		}, FeatureAttrId.class);

		m_TypeTable[273] = new EnumSpec(new EnumValue[] {
			new EnumValue("ipv4", 0),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("ipv6", 1)
		}, IpAddressType.class);

		m_TypeTable[274] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 0),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("configChange", 1),
			new EnumValue("error", 2)
		}, DirectoryServicesStatus.class);

		m_TypeTable[275] = new EnumSpec(new EnumValue[] {
			new EnumValue("individual", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("member", 2),
			new EnumValue("unknown", 0)
		}, PITViewType.class);

		m_TypeTable[276] = new EnumSpec(new EnumValue[] {
			new EnumValue("notImplemented", 0),
			new EnumValue("nvmeof", 8),
			new EnumValue("iscsi", 5),
			new EnumValue("scsi", 1),
			new EnumValue("sas", 4),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("ib", 6),
			new EnumValue("fcoe", 7),
			new EnumValue("fc", 2),
			new EnumValue("sata", 3)
		}, IOInterfaceType.class);

		m_TypeTable[277] = new EnumSpec(new EnumValue[] {
			new EnumValue("unsupported", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("startFailed", 2),
			new EnumValue("complete", 1),
			new EnumValue("timeout", 4),
			new EnumValue("unknown", 0)
		}, IscsiCableDiagCompletionStatus.class);

		m_TypeTable[278] = new EnumSpec(new EnumValue[] {
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("serviceTag", 3),
			new EnumValue("spinUpCount", 5),
			new EnumValue("spinUpDelay", 4),
			new EnumValue("assetTag", 1),
			new EnumValue("chassisName", 2)
		}, TrayAttributeId.class);

		m_TypeTable[279] = new EnumSpec(new EnumValue[] {
			new EnumValue("volume", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("workload", 2),
			new EnumValue("unknown", 0)
		}, KeyValueTagObjectReferenceType.class);

		m_TypeTable[280] = new EnumSpec(new EnumValue[] {
			new EnumValue("hicLoopback", 14),
			new EnumValue("ctlrApcSram", 21),
			new EnumValue("hicContextMemory", 17),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("hicReadWrite", 11),
			new EnumValue("dimmPseudorandom", 5),
			new EnumValue("ctlrRegisterAddress", 19),
			new EnumValue("none", 0),
			new EnumValue("hicDataLines", 12),
			new EnumValue("ctlrApcFifo", 22),
			new EnumValue("hicInterrupt", 13),
			new EnumValue("dimmPatterns", 4),
			new EnumValue("usbflashWriteCycle", 8),
			new EnumValue("usbflashRandom", 10),
			new EnumValue("hicT10pi", 15),
			new EnumValue("ctlrDataCopy", 23),
			new EnumValue("ctlrRaid6", 25),
			new EnumValue("ctlrDataLines", 20),
			new EnumValue("ctlrRaid5", 24),
			new EnumValue("dimmEcc", 2),
			new EnumValue("usbflashWriteProtect", 7),
			new EnumValue("hicRamReadWrite", 26),
			new EnumValue("usbflashWritePatterns", 9),
			new EnumValue("dimmByteEnable", 1),
			new EnumValue("hicExtMemory", 18),
			new EnumValue("hicDma", 16),
			new EnumValue("dimmMarchC", 3),
			new EnumValue("dimmDmaCopy", 6)
		}, FruDiagTestIdentifier.class);

		m_TypeTable[281] = new EnumSpec(new EnumValue[] {
			new EnumValue("hotspareInuse", 1),
			new EnumValue("cacheSizeMismatch", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("missingDrives", 4),
			new EnumValue("none", 0),
			new EnumValue("drivesInaccessible", 2)
		}, FlashCacheStatusCause.class);

		m_TypeTable[282] = new EnumSpec(new EnumValue[] {
			new EnumValue("controller", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("hostboard", 4),
			new EnumValue("drive", 2),
			new EnumValue("expander", 3)
		}, SasPortProviderDeviceType.class);

		m_TypeTable[283] = new EnumSpec(new EnumValue[] {
			new EnumValue("sataFlash", 3),
			new EnumValue("sdFlash", 2),
			new EnumValue("usbFlash", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("unknown", 0)
		}, CacheBackupDeviceType.class);

		m_TypeTable[284] = new EnumSpec(new EnumValue[] {
			new EnumValue("optimal", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("failed", 3),
			new EnumValue("unknown", 0),
			new EnumValue("empty", 2)
		}, DimmStatus.class);

		m_TypeTable[285] = new EnumSpec(new EnumValue[] {
			new EnumValue("okay", 1),
			new EnumValue("partialUpdate", 7),
			new EnumValue("inProgress", 6),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("notAttempted", 4),
			new EnumValue("inProgressRecon", 9),
			new EnumValue("invalidDriveref", 2),
			new EnumValue("pending", 10),
			new EnumValue("invalidState", 5),
			new EnumValue("failedUpdate", 8),
			new EnumValue("duplicateDrive", 3)
		}, DriveDownloadStatus.class);

		m_TypeTable[286] = new EnumSpec(new EnumValue[] {
			new EnumValue("configured", 1),
			new EnumValue("stale", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("advertised", 2),
			new EnumValue("unknown", 0)
		}, IpV6RouterAddressState.class);

		m_TypeTable[287] = new EnumSpec(new EnumValue[] {
			new EnumValue("string", 2),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("tree", 1),
			new EnumValue("device", 0)
		}, SocPortMode.class);

		m_TypeTable[288] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("fdiDemsLogData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, FdiDemsLogRetrieveChunkDetails.class, false);

		m_TypeTable[289] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("componentType", m_TypeTable[165]),
			new TypeBinding("relativePosition", m_TypeTable[7])
		}, ParentRelativeLocation.class, false);

		m_TypeTable[290] = new UnionSpec(true, "completionType", m_TypeTable[228], new AlternateBinding[] {
			new AlternateBinding(1, "terminationReason", m_TypeTable[171])
		}, AsyncMirrorSyncCompletionDetail.class);

		m_TypeTable[291] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("dataStartTime", m_TypeTable[6]),
			new TypeBinding("autoLoadBalanceStatsLogData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, AutoLoadBalanceStatsLogRetrieveChunkDetails.class, false);

		m_TypeTable[292] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channelType", m_TypeTable[206]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("sfpPort", m_TypeTable[7]),
			new TypeBinding("controllerSlot", m_TypeTable[7])
		}, ControllerSfpLocation.class, false);

		m_TypeTable[293] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("portState", m_TypeTable[216]),
			new TypeBinding("portInsertionCount", m_TypeTable[7]),
			new TypeBinding("loopState", m_TypeTable[63]),
			new TypeBinding("loopUpCount", m_TypeTable[7]),
			new TypeBinding("crcErrorCount", m_TypeTable[7]),
			new TypeBinding("relativeFrequencyDriftErrorAverage", m_TypeTable[7]),
			new TypeBinding("loopCycleCount", m_TypeTable[7]),
			new TypeBinding("osErrorCount", m_TypeTable[7]),
			new TypeBinding("portConnectionsAttemptedCount", m_TypeTable[7]),
			new TypeBinding("portConnectionsHeldOffCount", m_TypeTable[7]),
			new TypeBinding("portUtilization", m_TypeTable[7])
		}, SocPortDiagnosticData.class, false);

		m_TypeTable[294] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trayID", m_TypeTable[7]),
			new TypeBinding("numberOfPowerSupplies", m_TypeTable[7]),
			new TypeBinding("inputPower", new ArraySpec(m_TypeTable[7], 0, true, int.class))
		}, TrayPower.class, false);

		m_TypeTable[295] = new SubclassSpec(new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[296] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("phyIdentifier", m_TypeTable[7]),
			new TypeBinding("isOperational", m_TypeTable[0])
		}, SasPhy.class, false);

		m_TypeTable[297] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("subtype", m_TypeTable[60]),
			new TypeBinding("chassisID", new OpaqueSpec(255, true, OpaqueSpec.DataType.BINARY))
		}, ChassisIDTLV.class, false);

		m_TypeTable[298] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("dplCoreDumpData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, DPLCoreDumpRetrieveChunkDetails.class, false);

		m_TypeTable[299] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("wlcAnalyticsData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, WlcAnalyticsChunkDetails.class, false);

		m_TypeTable[300] = new SubclassSpec(new OpaqueSpec(3, false, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[301] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("initialR2t", m_TypeTable[0]),
			new TypeBinding("immediateData", m_TypeTable[0]),
			new TypeBinding("maxOutstandingR2t", m_TypeTable[7]),
			new TypeBinding("maxUnsolicitedFirstDataBurstLength", m_TypeTable[7]),
			new TypeBinding("maxDataBurstLength", m_TypeTable[7]),
			new TypeBinding("dataSequenceInOrder", m_TypeTable[0]),
			new TypeBinding("dataPduInOrder", m_TypeTable[0]),
			new TypeBinding("errorRecoveryLevel", m_TypeTable[7]),
			new TypeBinding("maxConnectionsPerSession", m_TypeTable[7]),
			new TypeBinding("defaultTimeToWait", m_TypeTable[7]),
			new TypeBinding("defaultTimeToRetain", m_TypeTable[7])
		}, IscsiNegotiableSessionSettings.class, false);

		m_TypeTable[302] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("failedChannels", new ArraySpec(m_TypeTable[7], 0, true, int.class))
		}, ChannelFailedFailure.class, false);

		m_TypeTable[303] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("iocDumpTag", m_TypeTable[7]),
			new TypeBinding("captureTime", m_TypeTable[6]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("captureSize", m_TypeTable[7]),
			new TypeBinding("fwVersion", new StringSpec(0)),
			new TypeBinding("iocDumpReason", m_TypeTable[10])
		}, IOCDumpInfo.class, false);

		m_TypeTable[304] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("key", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("value", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, TunnelKeyValue.class, false);

		m_TypeTable[305] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("maxHotSpares", m_TypeTable[7]),
			new TypeBinding("cacheBlockSizes", new ArraySpec(m_TypeTable[7], 0, true, int.class)),
			new TypeBinding("maxDCEDrives", m_TypeTable[7]),
			new TypeBinding("maxReadAheadMultiplier", m_TypeTable[7]),
			new TypeBinding("minMediaScanPeriod", m_TypeTable[7]),
			new TypeBinding("maxMediaScanPeriod", m_TypeTable[7]),
			new TypeBinding("supportedSegSizes", new ArraySpec(m_TypeTable[7], 0, true, int.class)),
			new TypeBinding("numStandardSegSizes", m_TypeTable[7]),
			new TypeBinding("segTransitions", new ArraySpec(m_TypeTable[130], 0, true, SegmentSizeTransition.class)),
			new TypeBinding("mappableLUNCount", m_TypeTable[7]),
			new TypeBinding("maxPartitionCount", m_TypeTable[7]),
			new TypeBinding("maxMappingsPerVolume", m_TypeTable[7]),
			new TypeBinding("maxVolumes", m_TypeTable[7]),
			new TypeBinding("maxSnapshots", m_TypeTable[7]),
			new TypeBinding("maxSnapshotsPerBase", m_TypeTable[7]),
			new TypeBinding("minRepositorySize", m_TypeTable[7]),
			new TypeBinding("maxMirrors", m_TypeTable[7]),
			new TypeBinding("maxVolCopys", m_TypeTable[7]),
			new TypeBinding("maxConcurrentBackgroundCopys", m_TypeTable[7]),
			new TypeBinding("maxUtmLunValue", m_TypeTable[7]),
			new TypeBinding("reserved1", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("battery_not_in_configuration", m_TypeTable[0]),
			new TypeBinding("supportedDriveTypes", new ArraySpec(m_TypeTable[21], 0, true, PhysicalDriveType.class)),
			new TypeBinding("currentMaxMirrors", m_TypeTable[7]),
			new TypeBinding("maxVolumesPerGroup", m_TypeTable[7]),
			new TypeBinding("maxDriveDownloadFiles", m_TypeTable[7]),
			new TypeBinding("maxMgmtClientRecords", m_TypeTable[7]),
			new TypeBinding("maxMgmtClientRecordSize", m_TypeTable[7]),
			new TypeBinding("redundancyMode", m_TypeTable[35]),
			new TypeBinding("maxExpansionDriveTrays", m_TypeTable[7]),
			new TypeBinding("supportedAuthMethods", new ArraySpec(m_TypeTable[15], 0, true, AuthenticationMethod.class)),
			new TypeBinding("maxIscsiIpv6LocalAddressesPerPort", m_TypeTable[7]),
			new TypeBinding("maxIscsiIpv6RoutableAddressesPerPort", m_TypeTable[7]),
			new TypeBinding("absoluteMaxDssSegmentSize", m_TypeTable[7]),
			new TypeBinding("smartBatteryTechnology", m_TypeTable[0]),
			new TypeBinding("writeCachingEnabledDuringLearnCycle", m_TypeTable[0]),
			new TypeBinding("maxSSDsSupported", m_TypeTable[7]),
			new TypeBinding("ssdInterfaceTypeMixingSupported", m_TypeTable[0]),
			new TypeBinding("maxDriveSlots", m_TypeTable[7]),
			new TypeBinding("supportedProtectionTypes", new ArraySpec(m_TypeTable[136], 0, true, ProtectionType.class)),
			new TypeBinding("supportedEventPriorities", new ArraySpec(m_TypeTable[55], 0, true, EventPriority.class)),
			new TypeBinding("maxFlashCacheSize", m_TypeTable[6]),
			new TypeBinding("defaultMediaScanPeriod", m_TypeTable[7])
		}, FeatureParams.class, false);

		m_TypeTable[306] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("maxAPIBufferBytes", m_TypeTable[7])
		}, TunnelingDefaultAttributes.class, false);

		m_TypeTable[307] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("startTime", m_TypeTable[6]),
			new TypeBinding("stopTime", m_TypeTable[6])
		}, Dom0SupportDataJournalStartDetails.class, false);

		m_TypeTable[308] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("firmwareChunkImage", new OpaqueSpec(32768, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("firmwareVersion", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("offset", m_TypeTable[7]),
			new TypeBinding("totalSize", m_TypeTable[7]),
			new TypeBinding("stagedDownload", m_TypeTable[0]),
			new TypeBinding("numberOfFiles", m_TypeTable[7]),
			new TypeBinding("sizeOfStream", m_TypeTable[7])
		}, FirmwareUpdateDescriptor.class, false);

		m_TypeTable[309] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("cfgGen", m_TypeTable[6]),
			new TypeBinding("digest", new OpaqueSpec(20, false, OpaqueSpec.DataType.BINARY))
		}, RemoteArrayAuthenticator.class, false);

		m_TypeTable[310] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("clear", m_TypeTable[0])
		}, WlcAnalyticsStartDetails.class, false);

		m_TypeTable[311] = new SubclassSpec(new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[312] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("retCode", m_TypeTable[152]),
			new TypeBinding("type", m_TypeTable[194])
		}, RawDataRestoreResult.class, false);

		m_TypeTable[313] = new SubclassSpec(new OpaqueSpec(60, true, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[314] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("enableCacheMirroringProtectionInformation", m_TypeTable[0])
		}, CacheMirroringProtectionInformationDescriptor.class, false);

		m_TypeTable[315] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("refToken", new OpaqueSpec(12, false, OpaqueSpec.DataType.BINARY))
		}, null, true);

		m_TypeTable[316] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("kmsCertificateFileType", m_TypeTable[265]),
			new TypeBinding("kmsCertificateFile", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, KMSCertificateFileInstallDescriptor.class, false);

		m_TypeTable[317] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "certificateFile", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, KMSCertificateFileReturn.class);

		m_TypeTable[318] = new SubclassSpec(new OpaqueSpec(6, false, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[319] = new SubclassSpec(new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY), null);
	}

	private static void __init7() {

		m_TypeTable[320] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("regionId", m_TypeTable[210]),
			new TypeBinding("offset", m_TypeTable[7]),
			new TypeBinding("regionData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, NVSRAMUpdateDescriptor.class, false);

		m_TypeTable[321] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("subtype", m_TypeTable[212]),
			new TypeBinding("portID", new OpaqueSpec(255, true, OpaqueSpec.DataType.BINARY))
		}, PortIDTLV.class, false);

		m_TypeTable[322] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerTray", m_TypeTable[7]),
			new TypeBinding("controllerSlot", m_TypeTable[7]),
			new TypeBinding("cacheBackupDeviceSlot", m_TypeTable[7])
		}, CacheBackupDeviceLocation.class, false);

		m_TypeTable[323] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("manufacturer", new StringSpec(0)),
			new TypeBinding("manufactureDate", m_TypeTable[6]),
			new TypeBinding("productId", new StringSpec(0)),
			new TypeBinding("productRevLevel", new StringSpec(0)),
			new TypeBinding("partNumber", new StringSpec(0)),
			new TypeBinding("serialNumber", new StringSpec(0))
		}, CacheBackupDeviceVpd.class, false);

		m_TypeTable[324] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("poolUtilizationWarningThreshold", m_TypeTable[7]),
			new TypeBinding("poolUtilizationCriticalThreshold", m_TypeTable[7]),
			new TypeBinding("degradedReconstructPriority", m_TypeTable[87]),
			new TypeBinding("criticalReconstructPriority", m_TypeTable[87]),
			new TypeBinding("backgroundOperationPriority", m_TypeTable[87]),
			new TypeBinding("maxVolumeSizeInMegabytes", m_TypeTable[6]),
			new TypeBinding("maxDCEDriveCount", m_TypeTable[7]),
			new TypeBinding("reposGranularity", m_TypeTable[6]),
			new TypeBinding("maxTotalDiskPoolSupportInMegabytes", m_TypeTable[6]),
			new TypeBinding("maxVolumeSynchronousCreationInMegabytes", m_TypeTable[6]),
			new TypeBinding("maxDCRDriveCount", m_TypeTable[7])
		}, DiskPoolDefaultAttributes.class, false);

		m_TypeTable[325] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("remoteCommunicationCheckSamples", new ArraySpec(m_TypeTable[7], 0, true, int.class)),
			new TypeBinding("timeout", m_TypeTable[7]),
			new TypeBinding("testStatus", m_TypeTable[152]),
			new TypeBinding("returnCode", m_TypeTable[152])
		}, RemoteCommunicationCheckSampleList.class, false);

		m_TypeTable[326] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("averageEraseCountPercent", m_TypeTable[7]),
			new TypeBinding("spareBlocksRemainingPercent", m_TypeTable[7]),
			new TypeBinding("isWearLifeMonitoringSupported", m_TypeTable[0]),
			new TypeBinding("percentEnduranceUsed", m_TypeTable[7])
		}, SSDWearLife.class, false);

		m_TypeTable[327] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("lastBatteryLearnCycle", m_TypeTable[6]),
			new TypeBinding("nextBatteryLearnCycle", m_TypeTable[6]),
			new TypeBinding("batteryLearnCycleInterval", m_TypeTable[7])
		}, SmartBatteryData.class, false);

		m_TypeTable[328] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("baseTime", m_TypeTable[6]),
			new TypeBinding("readHitOps", m_TypeTable[6]),
			new TypeBinding("readHitBytes", m_TypeTable[6]),
			new TypeBinding("readHitTimeTotal", m_TypeTable[6]),
			new TypeBinding("readHitTimeMax", m_TypeTable[6]),
			new TypeBinding("readOps", m_TypeTable[6]),
			new TypeBinding("readBytes", m_TypeTable[6]),
			new TypeBinding("readTimeTotal", m_TypeTable[6]),
			new TypeBinding("readTimeMax", m_TypeTable[6]),
			new TypeBinding("writeHitOps", m_TypeTable[6]),
			new TypeBinding("writeHitBytes", m_TypeTable[6]),
			new TypeBinding("writeHitTimeTotal", m_TypeTable[6]),
			new TypeBinding("writeHitTimeMax", m_TypeTable[6]),
			new TypeBinding("writeOps", m_TypeTable[6]),
			new TypeBinding("writeBytes", m_TypeTable[6]),
			new TypeBinding("writeTimeTotal", m_TypeTable[6]),
			new TypeBinding("writeTimeMax", m_TypeTable[6]),
			new TypeBinding("otherOps", m_TypeTable[6]),
			new TypeBinding("otherTimeTotal", m_TypeTable[6]),
			new TypeBinding("otherTimeMax", m_TypeTable[6]),
			new TypeBinding("idleTime", m_TypeTable[6]),
			new TypeBinding("errRedundancyChkUnrecoveredReads", m_TypeTable[6]),
			new TypeBinding("errRedundancyChkRecoveredReads", m_TypeTable[6]),
			new TypeBinding("errRedundancyChkIndeterminateReads", m_TypeTable[6]),
			new TypeBinding("readHitTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("readTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("writeHitTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("writeTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("otherTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("flashCacheReadHitOps", m_TypeTable[6]),
			new TypeBinding("flashCacheReadHitBytes", m_TypeTable[6]),
			new TypeBinding("flashCacheReadHitTimeTotal", m_TypeTable[6]),
			new TypeBinding("flashCacheReadHitTimeMax", m_TypeTable[6]),
			new TypeBinding("flashCacheReadHitTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("prefetchHitBytes", m_TypeTable[6]),
			new TypeBinding("prefetchMissBytes", m_TypeTable[6]),
			new TypeBinding("startTime", m_TypeTable[6]),
			new TypeBinding("observedTime", m_TypeTable[6]),
			new TypeBinding("queueDepthTotal", m_TypeTable[6]),
			new TypeBinding("queueDepthMax", m_TypeTable[6]),
			new TypeBinding("randomIosTotal", m_TypeTable[6]),
			new TypeBinding("randomBytesTotal", m_TypeTable[6]),
			new TypeBinding("cacheWriteWaitHitOps", m_TypeTable[6]),
			new TypeBinding("fullStripeWritesBytes", m_TypeTable[6]),
			new TypeBinding("totalIosShipped", m_TypeTable[6]),
			new TypeBinding("totalBlksEvicted", m_TypeTable[6]),
			new TypeBinding("cacheBlksInUse", m_TypeTable[6]),
			new TypeBinding("cacheWriteWaitHitBytes", m_TypeTable[6])
		}, VolumeCounterGroup.class, false);

		m_TypeTable[329] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("time", m_TypeTable[7])
		}, TimeToLiveTLV.class, false);

		m_TypeTable[330] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("count", m_TypeTable[7]),
			new TypeBinding("maxLimit", m_TypeTable[7])
		}, UnreadableSectors.class, false);

		m_TypeTable[331] = new SubclassSpec(new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[332] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("minProvisionedCapacity", m_TypeTable[6]),
			new TypeBinding("maxProvisionedCapacity", m_TypeTable[6]),
			new TypeBinding("minVirtualCapacity", m_TypeTable[6]),
			new TypeBinding("maxVirtualCapacity", m_TypeTable[6]),
			new TypeBinding("minAlertThreshold", m_TypeTable[7]),
			new TypeBinding("defaultAlertThreshold", m_TypeTable[7])
		}, ThinVolumeDefaultAttributes.class, false);

		m_TypeTable[333] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("drivePerformanceHistoryData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, DrivePerformanceHistoryRetrieveChunkDetails.class, false);

		m_TypeTable[334] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("runtimeDiagTestID", m_TypeTable[180]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("usePattern", m_TypeTable[0]),
			new TypeBinding("pattern", new OpaqueSpec(64, false, OpaqueSpec.DataType.BINARY))
		}, RuntimeDiagDescriptor.class, false);

		m_TypeTable[335] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("dataType", m_TypeTable[213]),
			new TypeBinding("logStartTime", m_TypeTable[6])
		}, AutoLoadBalanceStatsLogRetrieveStartDetails.class, false);

		m_TypeTable[336] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("maxCpuUtilization", m_TypeTable[7]),
			new TypeBinding("sumCpuUtilization", m_TypeTable[7]),
			new TypeBinding("ssqCpuUtilization", m_TypeTable[7])
		}, CpuUtilizationStats.class, false);

		m_TypeTable[337] = new SubclassSpec(new OpaqueSpec(60, true, OpaqueSpec.DataType.DBCS), null);

		m_TypeTable[338] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("enable", m_TypeTable[0])
		}, HighResolutionRequestDescriptor.class, false);

		m_TypeTable[339] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("minimumRepositoryCapacityInBytes", m_TypeTable[6]),
			new TypeBinding("maxRepositoryCapacityAsPercentOfMirroredCapacity", m_TypeTable[7]),
			new TypeBinding("defaultRepositoryCapacityAsPercentOfMirroredCapacity", m_TypeTable[7]),
			new TypeBinding("defaultRepositoryUtilizationWarningThreshold", m_TypeTable[7]),
			new TypeBinding("minimumSyncIntervalInMinutes", m_TypeTable[7]),
			new TypeBinding("defaultSyncIntervalInMinutes", m_TypeTable[7]),
			new TypeBinding("defaultSyncCompletionTimeAlertThresholdInMinutes", m_TypeTable[7]),
			new TypeBinding("defaultRecoveryPointAgeAlertThresholdInMinutes", m_TypeTable[7]),
			new TypeBinding("maximumConnectivityTestTimeout", m_TypeTable[7]),
			new TypeBinding("maximumLinkLatencyTestIterations", m_TypeTable[7]),
			new TypeBinding("maximumLinkBandwidthTestIterations", m_TypeTable[7]),
			new TypeBinding("minimumRepositoryCapacityInHundredthsOfPercentOfMirroredCapacity", m_TypeTable[7]),
			new TypeBinding("defaultLinkLatencyTestIterations", m_TypeTable[7]),
			new TypeBinding("defaultLinkBandwidthTestIterations", m_TypeTable[7]),
			new TypeBinding("defaultRecentStatisticsListLength", m_TypeTable[7]),
			new TypeBinding("maxRecentStatisticsListLength", m_TypeTable[7]),
			new TypeBinding("defaultLongestStatisticsListLength", m_TypeTable[7]),
			new TypeBinding("maxLongestStatisticsListLength", m_TypeTable[7]),
			new TypeBinding("defaultErrorStatisticsListLength", m_TypeTable[7]),
			new TypeBinding("maxErrorStatisticsListLength", m_TypeTable[7]),
			new TypeBinding("maxAllowedLinkLatencyInMicroseconds", m_TypeTable[7])
		}, ARVMDefaultAttributes.class, false);

		m_TypeTable[340] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("compress", m_TypeTable[0]),
			new TypeBinding("traceID", m_TypeTable[222]),
			new TypeBinding("flushCurrent", m_TypeTable[0])
		}, DqRetrieveStartDetails.class, false);

		m_TypeTable[341] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("analysisResult", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, CoWRepositoryAnalysisResults.class, false);

		m_TypeTable[342] = new SubclassSpec(new OpaqueSpec(6, false, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[343] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("refToken", new OpaqueSpec(20, false, OpaqueSpec.DataType.BINARY))
		}, null, true);

		m_TypeTable[344] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("interfaceName", new StringSpec(0)),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("enableRlogin", m_TypeTable[0])
		}, RloginUpdateDescriptor.class, false);

		m_TypeTable[345] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mapToLUN", m_TypeTable[0]),
			new TypeBinding("snapShot", m_TypeTable[0]),
			new TypeBinding("format", m_TypeTable[0]),
			new TypeBinding("reconfigure", m_TypeTable[0]),
			new TypeBinding("mirrorPrimary", m_TypeTable[0]),
			new TypeBinding("mirrorSecondary", m_TypeTable[0]),
			new TypeBinding("copySource", m_TypeTable[0]),
			new TypeBinding("copyTarget", m_TypeTable[0]),
			new TypeBinding("readable", m_TypeTable[0]),
			new TypeBinding("writable", m_TypeTable[0]),
			new TypeBinding("rollback", m_TypeTable[0]),
			new TypeBinding("mirrorSync", m_TypeTable[0]),
			new TypeBinding("newImage", m_TypeTable[0]),
			new TypeBinding("allowDVE", m_TypeTable[0]),
			new TypeBinding("allowDSS", m_TypeTable[0]),
			new TypeBinding("concatVolumeMember", m_TypeTable[0]),
			new TypeBinding("flashReadCache", m_TypeTable[0]),
			new TypeBinding("asyncMirrorPrimary", m_TypeTable[0]),
			new TypeBinding("asyncMirrorSecondary", m_TypeTable[0]),
			new TypeBinding("pitGroup", m_TypeTable[0]),
			new TypeBinding("cacheParametersChangeable", m_TypeTable[0]),
			new TypeBinding("allowThinManualExpansion", m_TypeTable[0]),
			new TypeBinding("allowThinGrowthParametersChange", m_TypeTable[0])
		}, VolumePerms.class, false);

		m_TypeTable[346] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("minihubType", m_TypeTable[145]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("controllerSlot", m_TypeTable[7]),
			new TypeBinding("tray", m_TypeTable[7])
		}, MinihubLocation.class, false);

		m_TypeTable[347] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("serialNumber", new StringSpec(0)),
			new TypeBinding("slot", m_TypeTable[7]),
			new TypeBinding("startTime", m_TypeTable[6]),
			new TypeBinding("endTime", m_TypeTable[6]),
			new TypeBinding("testType", m_TypeTable[186]),
			new TypeBinding("testIdentifier", m_TypeTable[280]),
			new TypeBinding("status", m_TypeTable[141]),
			new TypeBinding("errorCode", m_TypeTable[7]),
			new TypeBinding("percentComplete", m_TypeTable[7])
		}, FruDiagReturnData.class, false);

		m_TypeTable[348] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("compressed", m_TypeTable[0]),
			new TypeBinding("dqData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, DqRetrieveChunkDetails.class, false);

		m_TypeTable[349] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("maxCommunities", m_TypeTable[7]),
			new TypeBinding("maxTrapDestinations", m_TypeTable[7]),
			new TypeBinding("maxCommunityNameStringLength", m_TypeTable[7]),
			new TypeBinding("maxSystemVariableStringLength", m_TypeTable[7]),
			new TypeBinding("defaultSystemVariableValue", new StringSpec(0))
		}, EmbeddedSNMPAgentDefaultAttributes.class, false);

		m_TypeTable[350] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("reconstructionReservedDriveCount", m_TypeTable[7])
		}, DiskPoolVolumeCandidateRequestData.class, false);

		m_TypeTable[351] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ignoreConnectivity", m_TypeTable[0]),
			new TypeBinding("bothControllers", m_TypeTable[0])
		}, VolumeOwnershipFailBackRequestDescriptor.class, false);

		m_TypeTable[352] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("lockKeyID", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("passPhrase", new OpaqueSpec(40, false, OpaqueSpec.DataType.BINARY))
		}, KeyIDInfo.class, false);

		m_TypeTable[353] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315])
		}, ExcessiveRebootsDetected.class, false);

		m_TypeTable[354] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("baseTime", m_TypeTable[6]),
			new TypeBinding("readOps", m_TypeTable[6]),
			new TypeBinding("readBytes", m_TypeTable[6]),
			new TypeBinding("readTimeTotal", m_TypeTable[6]),
			new TypeBinding("readTimeMax", m_TypeTable[6]),
			new TypeBinding("writeOps", m_TypeTable[6]),
			new TypeBinding("writeBytes", m_TypeTable[6]),
			new TypeBinding("writeTimeTotal", m_TypeTable[6]),
			new TypeBinding("writeTimeMax", m_TypeTable[6]),
			new TypeBinding("otherOps", m_TypeTable[6]),
			new TypeBinding("otherTimeTotal", m_TypeTable[6]),
			new TypeBinding("otherTimeMax", m_TypeTable[6]),
			new TypeBinding("idleTime", m_TypeTable[6]),
			new TypeBinding("recoveredErrors", m_TypeTable[6]),
			new TypeBinding("unrecoveredErrors", m_TypeTable[6]),
			new TypeBinding("timeouts", m_TypeTable[6]),
			new TypeBinding("retriedIos", m_TypeTable[6]),
			new TypeBinding("readTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("writeTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("otherTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("startTime", m_TypeTable[6]),
			new TypeBinding("observedTime", m_TypeTable[6]),
			new TypeBinding("queueDepthTotal", m_TypeTable[6]),
			new TypeBinding("queueDepthMax", m_TypeTable[6]),
			new TypeBinding("randomIosTotal", m_TypeTable[6]),
			new TypeBinding("randomBytesTotal", m_TypeTable[6]),
			new TypeBinding("cumulativeLBA", m_TypeTable[6]),
			new TypeBinding("cumulativeDeltaLBA", m_TypeTable[6])
		}, DriveCounterGroup.class, false);

		m_TypeTable[355] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ref", m_TypeTable[343]),
			new TypeBinding("label", m_TypeTable[337])
		}, SYMbolRefWithUAL.class, false);

		m_TypeTable[356] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("degradedChannels", new ArraySpec(m_TypeTable[7], 0, true, int.class))
		}, ChannelDegradedFailure.class, false);

		m_TypeTable[357] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("clear", m_TypeTable[0])
		}, IoStatisticsRetrieveStartDetails.class, false);

		m_TypeTable[358] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("targetName", new OpaqueSpec(60, true, OpaqueSpec.DataType.BINARY))
		}, FibreChannelTargetLocation.class, false);

		m_TypeTable[359] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("certificateFileType", m_TypeTable[265]),
			new TypeBinding("expirationTimeOfDay", new OpaqueSpec(32, true, OpaqueSpec.DataType.SBCS)),
			new TypeBinding("expirationTime", m_TypeTable[6])
		}, KMSCertificateExpirationDetails.class, false);

		m_TypeTable[360] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("returnCode", m_TypeTable[152]),
			new TypeBinding("ref", m_TypeTable[343])
		}, ReturnCodeWithRef.class, false);

		m_TypeTable[361] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("reconstructionReservedDriveCount", m_TypeTable[7]),
			new TypeBinding("reconstructionReservedAmt", m_TypeTable[6]),
			new TypeBinding("reconstructionReservedDriveCountCurrent", m_TypeTable[7]),
			new TypeBinding("poolUtilizationWarningThreshold", m_TypeTable[7]),
			new TypeBinding("poolUtilizationCriticalThreshold", m_TypeTable[7]),
			new TypeBinding("poolUtilizationState", m_TypeTable[250]),
			new TypeBinding("unusableCapacity", m_TypeTable[6]),
			new TypeBinding("degradedReconstructPriority", m_TypeTable[87]),
			new TypeBinding("criticalReconstructPriority", m_TypeTable[87]),
			new TypeBinding("backgroundOperationPriority", m_TypeTable[87]),
			new TypeBinding("allocGranularity", m_TypeTable[6])
		}, DiskPoolData.class, false);

		m_TypeTable[362] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("reserved", m_TypeTable[7]),
			new TypeBinding("recordNum", m_TypeTable[7]),
			new TypeBinding("groupId", m_TypeTable[52])
		}, MgmtClientRecordId.class, false);

		m_TypeTable[363] = new SubclassSpec(new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[364] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("omitUnallocatedBlocks", m_TypeTable[0]),
			new TypeBinding("skipBlockCoherencyCheck", m_TypeTable[0]),
			new TypeBinding("skipStructureIntegrityCheck", m_TypeTable[0]),
			new TypeBinding("sourceLocation", m_TypeTable[245])
		}, DbmBlkRetrieveStartDetails.class, false);

		m_TypeTable[365] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("reconPriority", new ArraySpec(m_TypeTable[7], 1, true, int.class)),
			new TypeBinding("preReadRedundancyCheckEnabled", new ArraySpec(m_TypeTable[0], 1, true, boolean.class))
		}, VolumeChangeableProperties.class, false);

		m_TypeTable[366] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("worldWideName", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, SAIdentifier.class, false);

		m_TypeTable[367] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("dbLocation", m_TypeTable[245]),
			new TypeBinding("dbRevision", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("dbID", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("dbGenNumber", m_TypeTable[6]),
			new TypeBinding("diskPoolID", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("dbStatus", m_TypeTable[226]),
			new TypeBinding("dbAccess", m_TypeTable[101])
		}, SpecificDatabaseMetadata.class, false);

		m_TypeTable[368] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("waitForDownload", m_TypeTable[0]),
			new TypeBinding("notReadySenseForQuiescenceInProgress", m_TypeTable[0]),
			new TypeBinding("notReadySenseForQuiescenceInProgress2", m_TypeTable[0]),
			new TypeBinding("checkConditionForVendorUniqueUAConditions", m_TypeTable[0]),
			new TypeBinding("reportDeferredErrors", m_TypeTable[0]),
			new TypeBinding("ignoreForceUnitAccess", m_TypeTable[0]),
			new TypeBinding("ignoreWriteCacheDisable", m_TypeTable[0]),
			new TypeBinding("allowReservationOnUnownedLUNs", m_TypeTable[0]),
			new TypeBinding("worldWideNameInStandardInquiry", m_TypeTable[0]),
			new TypeBinding("propagateHostBusResets", m_TypeTable[0]),
			new TypeBinding("reportSCCDeviceEnable", m_TypeTable[0]),
			new TypeBinding("conditionalFCLogout", m_TypeTable[0]),
			new TypeBinding("forceSCSI2", m_TypeTable[0]),
			new TypeBinding("reportUnconfiguredLUNs", m_TypeTable[0]),
			new TypeBinding("ignoreSyncCache", m_TypeTable[0]),
			new TypeBinding("ignoreUTMLunOwnership", m_TypeTable[0]),
			new TypeBinding("reportLUNPreferredPathInStandardInquiry", m_TypeTable[0]),
			new TypeBinding("autoLUNTransfer", m_TypeTable[0]),
			new TypeBinding("inquiryUnconfiguredDeviceType", m_TypeTable[3]),
			new TypeBinding("inquiryUnownedDeviceType", m_TypeTable[3]),
			new TypeBinding("unownedBlock0Read", m_TypeTable[3]),
			new TypeBinding("retainLogins", m_TypeTable[0]),
			new TypeBinding("hostPortType", m_TypeTable[337]),
			new TypeBinding("maxRestrictedLUNs", m_TypeTable[7]),
			new TypeBinding("reserved1", new OpaqueSpec(4, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("avtExclusionExtentsEnabled", m_TypeTable[0]),
			new TypeBinding("suppressVolOffPreferredPathAlert", m_TypeTable[0]),
			new TypeBinding("hostType", m_TypeTable[337]),
			new TypeBinding("tpgsSupported", m_TypeTable[0]),
			new TypeBinding("volumeFormatOptions", m_TypeTable[0]),
			new TypeBinding("restrictedLun0", m_TypeTable[0]),
			new TypeBinding("usePage2CQuiescenceTimeout", m_TypeTable[0]),
			new TypeBinding("asymmetricLUAccess", m_TypeTable[0]),
			new TypeBinding("ignoreISCSISessionIDInITN", m_TypeTable[0]),
			new TypeBinding("enableLUCheckConditionParallelResponses", m_TypeTable[0]),
			new TypeBinding("disableExplicitTPGS", m_TypeTable[0]),
			new TypeBinding("unownedCheckConditionDuringFWActivation", m_TypeTable[0]),
			new TypeBinding("allowPreferredOwnerReportingSuppression", m_TypeTable[0]),
			new TypeBinding("enableTargetFailback", m_TypeTable[0]),
			new TypeBinding("enableAutoLoadBalance", m_TypeTable[0]),
			new TypeBinding("quiescenceInProgressSenseKey", m_TypeTable[7]),
			new TypeBinding("quiescenceInProgressASC", m_TypeTable[7]),
			new TypeBinding("quiescenceInProgressASCQ", m_TypeTable[7]),
			new TypeBinding("persistentID", m_TypeTable[4])
		}, HostSpecificValues.class, false);

		m_TypeTable[369] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("fwVersion", new StringSpec(0))
		}, LockdownCtrlFwVersion.class, false);

		m_TypeTable[370] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("value", m_TypeTable[6]),
			new TypeBinding("qualifier", m_TypeTable[266])
		}, StatisticalContainer.class, false);

		m_TypeTable[371] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("vendorID", new StringSpec(0)),
			new TypeBinding("productID", new StringSpec(0)),
			new TypeBinding("revision", new StringSpec(0)),
			new TypeBinding("deviceWWN", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("serialNumber", new StringSpec(0)),
			new TypeBinding("partNumber", new StringSpec(0)),
			new TypeBinding("driveFwVersion", new StringSpec(0))
		}, InterposerData.class, false);

		m_TypeTable[372] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("syncType", m_TypeTable[239]),
			new TypeBinding("syncStartTimestamp", m_TypeTable[6]),
			new TypeBinding("completionDetail", m_TypeTable[290]),
			new TypeBinding("owner", m_TypeTable[315]),
			new TypeBinding("sampleStartTimeSeconds", m_TypeTable[6]),
			new TypeBinding("sampleEndTimeSeconds", m_TypeTable[6]),
			new TypeBinding("memberState", m_TypeTable[91]),
			new TypeBinding("repositoryUtilizationWarnThreshold", m_TypeTable[7]),
			new TypeBinding("repositoryUtilizationPercentage", m_TypeTable[7]),
			new TypeBinding("syncIntervalMinutes", m_TypeTable[7]),
			new TypeBinding("syncDurationMinutes", m_TypeTable[7]),
			new TypeBinding("syncCompletionTimeAlertThresholdMinutes", m_TypeTable[7]),
			new TypeBinding("recoveryPointAgeAlertThresholdMinutes", m_TypeTable[7]),
			new TypeBinding("recoveryPointAgeMinutes", m_TypeTable[7]),
			new TypeBinding("cumulativeBytesSent", m_TypeTable[6]),
			new TypeBinding("cumulativeIOTime", m_TypeTable[6]),
			new TypeBinding("totalIOCount", m_TypeTable[7]),
			new TypeBinding("longestResponseTimeMicroSeconds", m_TypeTable[7]),
			new TypeBinding("longestResponseTimeBytes", m_TypeTable[7]),
			new TypeBinding("shortestResponseTimeMicroSeconds", m_TypeTable[7]),
			new TypeBinding("shortestResponseTimeBytes", m_TypeTable[7]),
			new TypeBinding("highestThroughputInBytesPerSecond", m_TypeTable[6]),
			new TypeBinding("lowestThroughputInBytesPerSecond", m_TypeTable[6])
		}, AsyncMirrorPrimarySyncStatisticsSample.class, false);

		m_TypeTable[373] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("communityName", new StringSpec(0)),
			new TypeBinding("communityPermissions", m_TypeTable[93])
		}, SNMPCommunityAddDescriptor.class, false);

		m_TypeTable[374] = new SubclassSpec(new OpaqueSpec(16, false, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[375] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("minLatencyInMicroseconds", m_TypeTable[7]),
			new TypeBinding("maxLatencyInMicroseconds", m_TypeTable[7]),
			new TypeBinding("avgLatencyInMicroseconds", m_TypeTable[7])
		}, AsyncMirrorGroupLinkLatencyTestResults.class, false);

		m_TypeTable[376] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("parentRef", m_TypeTable[315]),
			new TypeBinding("channel", m_TypeTable[7])
		}, SpeedNegError.class, false);

		m_TypeTable[377] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("tray", m_TypeTable[7]),
			new TypeBinding("slot", m_TypeTable[7])
		}, TraySlot.class, false);

		m_TypeTable[378] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("IoStatisticsData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, IoStatisticsRetrieveChunkDetails.class, false);

		m_TypeTable[379] = new SubclassSpec(new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[380] = new SubclassSpec(new OpaqueSpec(40, false, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[381] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("state", m_TypeTable[79])
		}, DriveChannelStateDescriptor.class, false);

		m_TypeTable[382] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("timestamp", m_TypeTable[6]),
			new TypeBinding("reads", m_TypeTable[6]),
			new TypeBinding("readBlocks", m_TypeTable[6]),
			new TypeBinding("writes", m_TypeTable[6]),
			new TypeBinding("writeBlocks", m_TypeTable[6]),
			new TypeBinding("fullCacheHits", m_TypeTable[6]),
			new TypeBinding("fullCacheHitBlocks", m_TypeTable[6]),
			new TypeBinding("partialCacheHits", m_TypeTable[6]),
			new TypeBinding("partialCacheHitBlocks", m_TypeTable[6]),
			new TypeBinding("completeCacheMiss", m_TypeTable[6]),
			new TypeBinding("completeCacheMissBlocks", m_TypeTable[6]),
			new TypeBinding("populateOnReads", m_TypeTable[6]),
			new TypeBinding("populateOnReadBlocks", m_TypeTable[6]),
			new TypeBinding("populateOnWrites", m_TypeTable[6]),
			new TypeBinding("populateOnWriteBlocks", m_TypeTable[6]),
			new TypeBinding("invalidates", m_TypeTable[6]),
			new TypeBinding("recycles", m_TypeTable[6]),
			new TypeBinding("availableBytes", m_TypeTable[6]),
			new TypeBinding("allocatedBytes", m_TypeTable[6]),
			new TypeBinding("populatedCleanBytes", m_TypeTable[6]),
			new TypeBinding("populatedDirtyBytes", m_TypeTable[6])
		}, FlashCacheStatistics.class, false);

		m_TypeTable[383] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("capacityQuota", m_TypeTable[6]),
			new TypeBinding("growthAlertThreshold", m_TypeTable[7]),
			new TypeBinding("repositoryExpansionPolicy", m_TypeTable[23])
		}, ThinVolumeCapacityProvisioningDetails.class, false);

		m_TypeTable[384] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("initiatorName", new OpaqueSpec(60, true, OpaqueSpec.DataType.SBCS))
		}, InitiatorLocation.class, false);

		m_TypeTable[385] = new UnionSpec(true, "type", m_TypeTable[227], new AlternateBinding[] {
			new AlternateBinding(0, "pattern", m_TypeTable[7]),
			new AlternateBinding(1, "randomNumberSeed", m_TypeTable[7])
		}, ChannelDiagDataPatternTypeData.class);

		m_TypeTable[386] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("commonName", new OpaqueSpec(128, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("organizationName", new OpaqueSpec(128, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("organizationalUnitName", new OpaqueSpec(64, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("localityName", new OpaqueSpec(256, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("stateProvinceName", new OpaqueSpec(256, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("countryName", new OpaqueSpec(2, true, OpaqueSpec.DataType.BINARY))
		}, KMSClientCSRDescriptor.class, false);

		m_TypeTable[387] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("enableAutoLoadBalancing", m_TypeTable[0])
		}, AutoLoadBalancingControlDescriptor.class, false);

		m_TypeTable[388] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("transferType", m_TypeTable[194]),
			new TypeBinding("controllerRef", m_TypeTable[315])
		}, RawDataTransferCancelDesc.class, false);

		m_TypeTable[389] = new SubclassSpec(new OpaqueSpec(223, true, OpaqueSpec.DataType.SBCS), null);

		m_TypeTable[390] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("digest", new OpaqueSpec(20, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("salt", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY))
		}, SAViewPasswordDigest.class, false);

		m_TypeTable[391] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("scsiID", m_TypeTable[7]),
			new TypeBinding("speed", m_TypeTable[7]),
			new TypeBinding("scsiType", m_TypeTable[217]),
			new TypeBinding("width", m_TypeTable[7]),
			new TypeBinding("part", new StringSpec(0)),
			new TypeBinding("revision", m_TypeTable[7]),
			new TypeBinding("reserved1", new OpaqueSpec(12, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, SCSIInterface.class, false);

		m_TypeTable[392] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("isEnabled", m_TypeTable[0])
		}, SYMbolAccessChangeDesc.class, false);

		m_TypeTable[393] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "count", m_TypeTable[7])
		}, DiskPoolReductionDriveCountReturn.class);

		m_TypeTable[394] = new UnionSpec(true, "addressType", m_TypeTable[257], new AlternateBinding[] {
			new AlternateBinding(0, "interfaceAddressState", m_TypeTable[45]),
			new AlternateBinding(1, "routerAddressState", m_TypeTable[286])
		}, IpV6AddressState.class);

		m_TypeTable[395] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("functionAction", m_TypeTable[73]),
			new TypeBinding("functionID", m_TypeTable[8])
		}, FunctionStateDescriptor.class, false);

		m_TypeTable[396] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("vendorId", new StringSpec(0)),
			new TypeBinding("productId", new StringSpec(0)),
			new TypeBinding("productRevLevel", new StringSpec(0)),
			new TypeBinding("satType", m_TypeTable[81])
		}, ScsiToAtaTranslatorData.class, false);

		m_TypeTable[397] = new SubclassSpec(new StringSpec(0), null);

		m_TypeTable[398] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("tray", m_TypeTable[343]),
			new TypeBinding("factoryDefaultsData", m_TypeTable[308])
		}, FactoryDefaultsDescriptor.class, false);

		m_TypeTable[399] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channelStatus", m_TypeTable[7]),
			new TypeBinding("cableLength", m_TypeTable[7])
		}, IscsiCableDiagChannelResults.class, false);

		m_TypeTable[400] = new UnionSpec(true, "volumeType", m_TypeTable[260], new AlternateBinding[] {
			new AlternateBinding(1, "capacityProvisioningDetails", m_TypeTable[383])
		}, VolumeTypeParameters.class);
	}

	private static void __init8() {

		m_TypeTable[401] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("phyDriveType", m_TypeTable[21]),
			new TypeBinding("raidLevel", m_TypeTable[36]),
			new TypeBinding("volumeGroupWidth", m_TypeTable[7]),
			new TypeBinding("volumesPerGroup", m_TypeTable[7]),
			new TypeBinding("numberHotSpares", m_TypeTable[7]),
			new TypeBinding("numberUnassignedDrives", m_TypeTable[7]),
			new TypeBinding("segmentSize", m_TypeTable[7]),
			new TypeBinding("readAhead", m_TypeTable[7]),
			new TypeBinding("volumeGroupSecurityType", m_TypeTable[173]),
			new TypeBinding("driveMediaType", m_TypeTable[67]),
			new TypeBinding("onlyProtectionInformationCapable", m_TypeTable[0]),
			new TypeBinding("volumeGroupSecurityLevel", m_TypeTable[83])
		}, AutoConfigTemplate.class, false);

		m_TypeTable[402] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("capability", m_TypeTable[153]),
			new TypeBinding("isEnabled", m_TypeTable[0]),
			new TypeBinding("isCompliant", m_TypeTable[0]),
			new TypeBinding("isWithinLimits", m_TypeTable[0]),
			new TypeBinding("featureId", m_TypeTable[124])
		}, PremiumFeature.class, false);

		m_TypeTable[403] = new UnionSpec(true, "sampleRole", m_TypeTable[104], new AlternateBinding[] {
			new AlternateBinding(1, "primarySample", m_TypeTable[372])
		}, AsyncMirrorSyncStatisticsSample.class);

		m_TypeTable[404] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("validator", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, DbmBlkRestoreStartDetails.class, false);

		m_TypeTable[405] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("id", m_TypeTable[362]),
			new TypeBinding("content", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, MgmtClientRecord.class, false);

		m_TypeTable[406] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("preferredID", m_TypeTable[7]),
			new TypeBinding("portName", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY))
		}, InterfaceUpdateDescriptor.class, false);

		m_TypeTable[407] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "result", m_TypeTable[341])
		}, CoWRepositoryAnalysisResultsReturned.class);

		m_TypeTable[408] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("iterationsPerDevice", m_TypeTable[7]),
			new TypeBinding("maximumErrorsAllowed", m_TypeTable[7]),
			new TypeBinding("dataPatternOption", m_TypeTable[385])
		}, ChannelDiagWrRdVfyParams.class, false);

		m_TypeTable[409] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "ref", m_TypeTable[343])
		}, InstanceReturned.class);

		m_TypeTable[410] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("objectType", m_TypeTable[203]),
			new TypeBinding("objectNumber", m_TypeTable[7])
		}, LockdownFaultLocator.class, false);

		m_TypeTable[411] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("totalSamples", m_TypeTable[6]),
			new TypeBinding("sumSamples", m_TypeTable[6]),
			new TypeBinding("minSample", m_TypeTable[6]),
			new TypeBinding("maxSample", m_TypeTable[6])
		}, HistogramSummary.class, false);

		m_TypeTable[412] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("reconstructionReservedDriveCount", m_TypeTable[7]),
			new TypeBinding("reconstructionReservedAmt", m_TypeTable[6]),
			new TypeBinding("unusableCapacity", m_TypeTable[6])
		}, DiskPoolVolumeCandidateData.class, false);

		m_TypeTable[413] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("startingSeqNum", m_TypeTable[6]),
			new TypeBinding("endingSeqNum", m_TypeTable[6])
		}, MelExtent.class, false);

		m_TypeTable[414] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "dependencyTypes", new ArraySpec(m_TypeTable[233], 0, true, ImportDependencyType.class))
		}, ImportDependenciesReturned.class);

		m_TypeTable[415] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("dplCoreDumpTag", m_TypeTable[7])
		}, DPLCoreDumpRetrieveStartDetails.class, false);

		m_TypeTable[416] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("usageHint", m_TypeTable[38]),
			new TypeBinding("segmentSize", m_TypeTable[7]),
			new TypeBinding("readAhead", m_TypeTable[7])
		}, VolumeUsageHint.class, false);

		m_TypeTable[417] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "count", m_TypeTable[7])
		}, DiskPoolMaxReservedDriveCountReturn.class);

		m_TypeTable[418] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("chunkCRC", m_TypeTable[7]),
			new TypeBinding("blockSize", m_TypeTable[7]),
			new TypeBinding("sstorLBA", new ArraySpec(m_TypeTable[7], 0, true, int.class)),
			new TypeBinding("blockData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, DbmBlkRestoreChunkDetails.class, false);

		m_TypeTable[419] = new UnionSpec(true, "supportDataType", m_TypeTable[115], new AlternateBinding[] {
			new AlternateBinding(1, "dom0SupportDataJournalStartDetails", m_TypeTable[307])
		}, Dom0SupportDataStartDetails.class);

		m_TypeTable[420] = new UnionSpec(true, "type", m_TypeTable[208], new AlternateBinding[] {
			new AlternateBinding(0, "writeReadVerifyParams", m_TypeTable[408])
		}, ChannelDiagTypeParams.class);

		m_TypeTable[421] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("iterations", m_TypeTable[7]),
			new TypeBinding("salt", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("cipherText", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, PKCS5EncryptionData.class, false);

		m_TypeTable[422] = new UnionSpec(true, "type", m_TypeTable[24], new AlternateBinding[] {
			new AlternateBinding(1, "pkcs5Data", m_TypeTable[421]),
			new AlternateBinding(4, "pkcs5AesData", m_TypeTable[421])
		}, EncryptedPassword.class);

		m_TypeTable[423] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("PortA0", m_TypeTable[0]),
			new TypeBinding("PortA1", m_TypeTable[0]),
			new TypeBinding("PortB0", m_TypeTable[0]),
			new TypeBinding("PortB1", m_TypeTable[0])
		}, RegisteredPorts.class, false);

		m_TypeTable[424] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("returnCode", m_TypeTable[152]),
			new TypeBinding("data", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, ReturnCodeWithOpaqueData.class, false);

		m_TypeTable[425] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("testID", m_TypeTable[180]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("testStatus", m_TypeTable[86]),
			new TypeBinding("testLevel", m_TypeTable[142])
		}, RuntimeDiagTestResults.class, false);

		m_TypeTable[426] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("regionId", m_TypeTable[210]),
			new TypeBinding("hostIndex", m_TypeTable[7])
		}, NVSRAMRegionIdAndHostIndex.class, false);

		m_TypeTable[427] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("dom0DataChunk", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("dom0SupportDataType", m_TypeTable[115])
		}, Dom0SupportDataChunkDetails.class, false);

		m_TypeTable[428] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveOrientation", m_TypeTable[214]),
			new TypeBinding("numRows", m_TypeTable[7]),
			new TypeBinding("numColumns", m_TypeTable[7]),
			new TypeBinding("primaryTraversal", m_TypeTable[220]),
			new TypeBinding("secondaryTraversal", m_TypeTable[220])
		}, DriveLayout.class, false);

		m_TypeTable[429] = new UnionSpec(true, "action", m_TypeTable[65], new AlternateBinding[] {
			new AlternateBinding(2, "delaySeconds", m_TypeTable[7])
		}, AutoLoadBalanceRequestDescriptor.class);

		m_TypeTable[430] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeGroupCapacity", m_TypeTable[6]),
			new TypeBinding("volumeCount", m_TypeTable[7]),
			new TypeBinding("volumeCapacity", m_TypeTable[6]),
			new TypeBinding("trayLossProtection", m_TypeTable[0]),
			new TypeBinding("spindleSpeedMatch", m_TypeTable[0]),
			new TypeBinding("spindleSpeed", m_TypeTable[7]),
			new TypeBinding("volumeGroupSecurityType", m_TypeTable[173]),
			new TypeBinding("drawerLossProtection", m_TypeTable[0]),
			new TypeBinding("driveMediaType", m_TypeTable[67]),
			new TypeBinding("protectionInformationCapable", m_TypeTable[0]),
			new TypeBinding("driveBlockFormat", m_TypeTable[72]),
			new TypeBinding("volumeGroupSecurityLevel", m_TypeTable[83])
		}, VolumeGroupSummary.class, false);

		m_TypeTable[431] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("iocDumpTag", m_TypeTable[7])
		}, IOCDumpRetrieveStartDetails.class, false);

		m_TypeTable[432] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channelType", m_TypeTable[206]),
			new TypeBinding("index", m_TypeTable[7]),
			new TypeBinding("controllerSlot", m_TypeTable[7])
		}, ChannelLocation.class, false);

		m_TypeTable[433] = new SubclassSpec(new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[434] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("tcaGuid", m_TypeTable[363]),
			new TypeBinding("queuePairsSupported", m_TypeTable[7]),
			new TypeBinding("completionQueuesSupported", m_TypeTable[7]),
			new TypeBinding("sharedReceiveQueuesSupported", m_TypeTable[7])
		}, HostBoard2PortIbTypeData.class, false);

		m_TypeTable[435] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("autoConfigTemplate", new ArraySpec(m_TypeTable[401], 0, true, AutoConfigTemplate.class))
		}, AutoConfigTemplateList.class, false);

		m_TypeTable[436] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("id", m_TypeTable[7])
		}, SCSIDriveAddress.class, false);

		m_TypeTable[437] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("Asup", m_TypeTable[0]),
			new TypeBinding("OnDemand", m_TypeTable[0]),
			new TypeBinding("RemoteDiags", m_TypeTable[0])
		}, AsupStatus.class, false);

		m_TypeTable[438] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("portStatus", m_TypeTable[85]),
			new TypeBinding("portType", m_TypeTable[37]),
			new TypeBinding("reserved1", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, Port.class, false);

		m_TypeTable[439] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("percentComplete", m_TypeTable[7]),
			new TypeBinding("timeToCompletion", m_TypeTable[7])
		}, VolumeActionProgress.class, false);

		m_TypeTable[440] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("lockKeyID", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("wrappedLockKey", new OpaqueSpec(40, false, OpaqueSpec.DataType.BINARY))
		}, WrappedLockKey.class, false);

		m_TypeTable[441] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315])
		}, ControllerWithDirtyCacheDetails.class, false);

		m_TypeTable[442] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("regionId", m_TypeTable[210]),
			new TypeBinding("regionData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, NVSRAMRegion.class, false);

		m_TypeTable[443] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "dplCoreDumpTag", m_TypeTable[7])
		}, DPLCoreDumpOnDemandReturn.class);

		m_TypeTable[444] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "asupStatus", m_TypeTable[437])
		}, AsupStatusReturned.class);

		m_TypeTable[445] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cacheBlkSize", m_TypeTable[7]),
			new TypeBinding("demandFlushAmount", m_TypeTable[7]),
			new TypeBinding("demandFlushThreshold", m_TypeTable[7]),
			new TypeBinding("reserved1", new OpaqueSpec(12, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("cacheMirroringProtectionInformation", m_TypeTable[0])
		}, SACache.class, false);

		m_TypeTable[446] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("speedDetError", m_TypeTable[0]),
			new TypeBinding("manuallyBypassed", m_TypeTable[0]),
			new TypeBinding("portNumber", m_TypeTable[114])
		}, ChannelPorts.class, false);

		m_TypeTable[447] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("additionalCapacity", m_TypeTable[6])
		}, ConcatVolumeDirectExpansionDescriptor.class, false);

		m_TypeTable[448] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "flashCacheStatistics", m_TypeTable[382])
		}, FlashCacheStatisticsReturned.class);

		m_TypeTable[449] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
		}, InternalMessageResults.class);

		m_TypeTable[450] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("wrapCount", m_TypeTable[7]),
			new TypeBinding("series", new ArraySpec(m_TypeTable[6], 0, true, long.class))
		}, DiscreteTimeSeries.class, false);

		m_TypeTable[451] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("remoteVolWWN", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("remoteVolLabel", m_TypeTable[337]),
			new TypeBinding("capacity", m_TypeTable[6]),
			new TypeBinding("raidLevel", m_TypeTable[36]),
			new TypeBinding("protectionType", m_TypeTable[136])
		}, MirrorVolumeCandidate.class, false);

		m_TypeTable[452] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("concatVolumeMemberCapacityAlignmentSizeInBytes", m_TypeTable[6])
		}, ConcatVolumeDefaultAttributes.class, false);

		m_TypeTable[453] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "lockKey", m_TypeTable[440])
		}, WrappedLockKeyReturn.class);

		m_TypeTable[454] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("domain", new OpaqueSpec(0, true, OpaqueSpec.DataType.SBCS))
		}, DirectoryServicesDomain.class, false);

		m_TypeTable[455] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("baseTime", m_TypeTable[6]),
			new TypeBinding("startTime", m_TypeTable[6]),
			new TypeBinding("observedTime", m_TypeTable[6]),
			new TypeBinding("channelType", m_TypeTable[206]),
			new TypeBinding("channelNumber", m_TypeTable[7]),
			new TypeBinding("readOps", m_TypeTable[6]),
			new TypeBinding("readBytes", m_TypeTable[6]),
			new TypeBinding("readTimeTotal", m_TypeTable[6]),
			new TypeBinding("readTimeMax", m_TypeTable[6]),
			new TypeBinding("writeOps", m_TypeTable[6]),
			new TypeBinding("writeBytes", m_TypeTable[6]),
			new TypeBinding("writeTimeTotal", m_TypeTable[6]),
			new TypeBinding("writeTimeMax", m_TypeTable[6]),
			new TypeBinding("otherOps", m_TypeTable[6]),
			new TypeBinding("otherTimeTotal", m_TypeTable[6]),
			new TypeBinding("otherTimeMax", m_TypeTable[6]),
			new TypeBinding("readTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("writeTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("otherTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("queueDepthTotal", m_TypeTable[6]),
			new TypeBinding("queueDepthMax", m_TypeTable[6]),
			new TypeBinding("channelErrorCounts", m_TypeTable[6])
		}, InterfaceCounterGroup.class, false);

		m_TypeTable[456] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("iocDumpData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, IOCDumpRetrieveChunkDetails.class, false);

		m_TypeTable[457] = new UnionSpec(true, "viewType", m_TypeTable[275], new AlternateBinding[] {
			new AlternateBinding(2, "cgViewRef", m_TypeTable[343])
		}, PITViewMembership.class);

		m_TypeTable[458] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("controller", m_TypeTable[315])
		}, DriveChannelSpecifier.class, false);

		m_TypeTable[459] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("setId", m_TypeTable[7]),
			new TypeBinding("offset", m_TypeTable[7]),
			new TypeBinding("firmwareChunkImage", new OpaqueSpec(32768, true, OpaqueSpec.DataType.BINARY))
		}, DriveFirmwareChunkDescriptor.class, false);

		m_TypeTable[460] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("translatorData", m_TypeTable[396]),
			new TypeBinding("ataDiskModelNumber", new StringSpec(0)),
			new TypeBinding("ataDiskFwRevision", new StringSpec(0))
		}, SataDriveAttributes.class, false);

		m_TypeTable[461] = new SubclassSpec(new OpaqueSpec(255, true, OpaqueSpec.DataType.SBCS), null);

		m_TypeTable[462] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("factoryDefaultsVersion", new StringSpec(0)),
			new TypeBinding("isSupported", m_TypeTable[0])
		}, FactoryDefaultsVersionData.class, false);

		m_TypeTable[463] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("clientIp", m_TypeTable[7]),
			new TypeBinding("arrayId", m_TypeTable[366]),
			new TypeBinding("configGeneration", m_TypeTable[6]),
			new TypeBinding("digest", new OpaqueSpec(20, false, OpaqueSpec.DataType.BINARY))
		}, SYMbolAuthentication.class, false);

		m_TypeTable[464] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hasReadyToRemoveIndicator", m_TypeTable[0]),
			new TypeBinding("readyToRemove", m_TypeTable[0])
		}, RTRAttributeData.class, false);

		m_TypeTable[465] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("vendorName", new StringSpec(0)),
			new TypeBinding("partNumber", new StringSpec(0)),
			new TypeBinding("revisionNumber", new StringSpec(0)),
			new TypeBinding("serialNumber", new StringSpec(0))
		}, VendorPartData.class, false);

		m_TypeTable[466] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("cfgGen", m_TypeTable[6]),
			new TypeBinding("digest", new OpaqueSpec(20, false, OpaqueSpec.DataType.BINARY))
		}, RemoteMirrorAuthenticator.class, false);

		m_TypeTable[467] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("switchPortId", m_TypeTable[300]),
			new TypeBinding("targetPortName", m_TypeTable[319])
		}, FibrePortLogin.class, false);

		m_TypeTable[468] = new UnionSpec(true, "type", m_TypeTable[209], new AlternateBinding[] {
			new AlternateBinding(2, "diskPoolVolumeCandidateRequestData", m_TypeTable[350])
		}, VolumeCandidateRequestTypeData.class);

		m_TypeTable[469] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("oemPriority", m_TypeTable[55]),
			new TypeBinding("defaultNeedsAttention", m_TypeTable[0]),
			new TypeBinding("defaultSendAlert", m_TypeTable[0]),
			new TypeBinding("defaultVisibility", m_TypeTable[0]),
			new TypeBinding("oemNeedsAttention", m_TypeTable[40]),
			new TypeBinding("oemSendAlert", m_TypeTable[40]),
			new TypeBinding("oemVisibility", m_TypeTable[40]),
			new TypeBinding("collectSupportBundle", m_TypeTable[0]),
			new TypeBinding("priorityCaseCreationTrigger", m_TypeTable[0])
		}, EventControl.class, false);

		m_TypeTable[470] = new SubclassSpec(new OpaqueSpec(223, true, OpaqueSpec.DataType.SBCS), null);

		m_TypeTable[471] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("passPhrase", new OpaqueSpec(40, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("lockKey", m_TypeTable[440])
		}, LockKeyBlob.class, false);

		m_TypeTable[472] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("chunkCRC", m_TypeTable[7]),
			new TypeBinding("blockSize", m_TypeTable[7]),
			new TypeBinding("blockConsistencyCheck", m_TypeTable[192]),
			new TypeBinding("structureIntegrityCheck", m_TypeTable[192]),
			new TypeBinding("sstorLBA", new ArraySpec(m_TypeTable[7], 0, true, int.class)),
			new TypeBinding("blockData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("sourceLocation", m_TypeTable[245])
		}, DbmBlkRetrieveChunkDetails.class, false);

		m_TypeTable[473] = new UnionSpec(true, "batteryType", m_TypeTable[97], new AlternateBinding[] {
			new AlternateBinding(4, "cruParentController", m_TypeTable[315]),
			new AlternateBinding(2, "parentController", m_TypeTable[315])
		}, BatteryTypeData.class);

		m_TypeTable[474] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("type", m_TypeTable[194]),
			new TypeBinding("sequenceNumber", m_TypeTable[7]),
			new TypeBinding("controllerRef", m_TypeTable[315])
		}, RawDataRetrieveContinueDesc.class, false);

		m_TypeTable[475] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("invalidDwordCount", m_TypeTable[7]),
			new TypeBinding("runningDisparityErrorCount", m_TypeTable[7]),
			new TypeBinding("lossOfDwordSyncCount", m_TypeTable[7]),
			new TypeBinding("resetProblemCount", m_TypeTable[7])
		}, SasPhyErrorCounts.class, false);

		m_TypeTable[476] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("phyIdentifier", m_TypeTable[7]),
			new TypeBinding("isValid", m_TypeTable[0]),
			new TypeBinding("currentSpeed", m_TypeTable[149]),
			new TypeBinding("maximumSpeed", m_TypeTable[149]),
			new TypeBinding("errorCounts", m_TypeTable[475])
		}, SasPhyData.class, false);

		m_TypeTable[477] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("performLogicalConsistencyCheck", m_TypeTable[0]),
			new TypeBinding("performBlockConsistencyCheck", m_TypeTable[0]),
			new TypeBinding("performClientConsistencyCheck", m_TypeTable[0]),
			new TypeBinding("sourceLocation", m_TypeTable[245])
		}, DbmCheckRetrieveStartDetails.class, false);

		m_TypeTable[478] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cacheBlkSize", m_TypeTable[7]),
			new TypeBinding("demandFlushAmount", m_TypeTable[7]),
			new TypeBinding("demandFlushThreshold", m_TypeTable[7])
		}, SACacheParamsUpdateDescriptor.class, false);

		m_TypeTable[479] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("metadataBytesRequired", m_TypeTable[6]),
			new TypeBinding("cowDataBytesRequired", m_TypeTable[6]),
			new TypeBinding("currentBytesAvailable", m_TypeTable[6])
		}, PITGroupRollbackUtilizationEstimate.class, false);

		m_TypeTable[480] = new UnionSpec(true, "featureAttrId", m_TypeTable[272], new AlternateBinding[] {
			new AlternateBinding(3, "keyEnabled", m_TypeTable[0]),
			new AlternateBinding(4, "keyLimit", m_TypeTable[7]),
			new AlternateBinding(1, "shippedEnabled", m_TypeTable[0]),
			new AlternateBinding(2, "shippedLimit", m_TypeTable[7]),
			new AlternateBinding(6, "subjectToGoldKey", m_TypeTable[0]),
			new AlternateBinding(5, "supportedValues", new ArraySpec(m_TypeTable[397], 0, true, String.class)),
			new AlternateBinding(7, "evaluationDuration", m_TypeTable[7])
		}, FeatureAttribute.class);

		m_TypeTable[481] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "functionState", m_TypeTable[27])
		}, FunctionStateReturned.class);

		m_TypeTable[482] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("maxViewsPerPIT", m_TypeTable[7]),
			new TypeBinding("minimumRepositoryCapacityInBytes", m_TypeTable[6]),
			new TypeBinding("maxPITGroupRepositoryCapacityAsPercentOfBaseCapacity", m_TypeTable[7]),
			new TypeBinding("maxPITViewRepositoryCapacityAsPercentOfBaseCapacity", m_TypeTable[7]),
			new TypeBinding("defaultRepositoryCapacityAsPercentOfBaseCapacity", m_TypeTable[7]),
			new TypeBinding("defaultRepositoryUtilizationWarningThreshold", m_TypeTable[7]),
			new TypeBinding("minimumConcatVolumeCapacityExpansion", m_TypeTable[6])
		}, PITGroupsDefaultAttributes.class, false);

		m_TypeTable[483] = new UnionSpec(true, "ioInterfaceType", m_TypeTable[276], new AlternateBinding[] {
			new AlternateBinding(5, "iscsiAlias", m_TypeTable[461])
		}, ScsiAlias.class);

		m_TypeTable[484] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("baseTime", m_TypeTable[6]),
			new TypeBinding("readHitOps", m_TypeTable[6]),
			new TypeBinding("readHitBytes", m_TypeTable[6]),
			new TypeBinding("readHitTimeTotal", m_TypeTable[6]),
			new TypeBinding("readHitTimeMax", m_TypeTable[6]),
			new TypeBinding("readHitStripes", m_TypeTable[6]),
			new TypeBinding("readHitSegments", m_TypeTable[6]),
			new TypeBinding("readOps", m_TypeTable[6]),
			new TypeBinding("readBytes", m_TypeTable[6]),
			new TypeBinding("readTimeTotal", m_TypeTable[6]),
			new TypeBinding("readTimeMax", m_TypeTable[6]),
			new TypeBinding("readStripes", m_TypeTable[6]),
			new TypeBinding("readSegments", m_TypeTable[6]),
			new TypeBinding("writeHitOps", m_TypeTable[6]),
			new TypeBinding("writeHitBytes", m_TypeTable[6]),
			new TypeBinding("writeHitTimeTotal", m_TypeTable[6]),
			new TypeBinding("writeHitTimeMax", m_TypeTable[6]),
			new TypeBinding("writeHitStripes", m_TypeTable[6]),
			new TypeBinding("writeHitSegments", m_TypeTable[6]),
			new TypeBinding("writeOps", m_TypeTable[6]),
			new TypeBinding("writeBytes", m_TypeTable[6]),
			new TypeBinding("writeTimeTotal", m_TypeTable[6]),
			new TypeBinding("writeTimeMax", m_TypeTable[6]),
			new TypeBinding("writeStripes", m_TypeTable[6]),
			new TypeBinding("writeSegments", m_TypeTable[6]),
			new TypeBinding("otherOps", m_TypeTable[6]),
			new TypeBinding("otherTimeTotal", m_TypeTable[6]),
			new TypeBinding("otherTimeMax", m_TypeTable[6]),
			new TypeBinding("idleTime", m_TypeTable[6]),
			new TypeBinding("writeOpsByAlgorithm", new ArraySpec(m_TypeTable[6], 6, false, long.class)),
			new TypeBinding("readHitTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("readTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("writeHitTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("writeTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("otherTimeTotalSq", m_TypeTable[6]),
			new TypeBinding("errRedundancyChkUnrecoveredReads", m_TypeTable[6]),
			new TypeBinding("errRedundancyChkRecoveredReads", m_TypeTable[6]),
			new TypeBinding("errRedundancyChkIndeterminateReads", m_TypeTable[6]),
			new TypeBinding("flashCacheReadHitOps", m_TypeTable[6]),
			new TypeBinding("flashCacheReadHitBytes", m_TypeTable[6]),
			new TypeBinding("flashCacheReadHitTimeTotal", m_TypeTable[6]),
			new TypeBinding("flashCacheReadHitTimeMax", m_TypeTable[6]),
			new TypeBinding("flashCacheReadHitTimeTotalSq", m_TypeTable[6])
		}, ImplementationCounterGroup.class, false);

		m_TypeTable[485] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("iocDumpEnabled", m_TypeTable[0]),
			new TypeBinding("iocDumpNeedsRetrieved", m_TypeTable[0]),
			new TypeBinding("iocDumpTag", m_TypeTable[7]),
			new TypeBinding("timeStamp", m_TypeTable[6])
		}, IOCDumpData.class, false);

		m_TypeTable[486] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("iocGuid", m_TypeTable[363]),
			new TypeBinding("vendorId", new OpaqueSpec(3, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("ioDeviceId", m_TypeTable[6]),
			new TypeBinding("deviceVersion", m_TypeTable[7]),
			new TypeBinding("subsystemVendorId", new OpaqueSpec(3, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("subsystemId", m_TypeTable[6]),
			new TypeBinding("ioClass", m_TypeTable[7]),
			new TypeBinding("ioSubclass", m_TypeTable[7]),
			new TypeBinding("protocol", m_TypeTable[7]),
			new TypeBinding("protocolVersion", m_TypeTable[7]),
			new TypeBinding("sendMessageQueueDepth", m_TypeTable[7]),
			new TypeBinding("rdmaReadQueueDepth", m_TypeTable[4]),
			new TypeBinding("sendMessageSize", m_TypeTable[6]),
			new TypeBinding("rdmaTransferSize", m_TypeTable[6]),
			new TypeBinding("controllerOpsCapabilityMask", m_TypeTable[4]),
			new TypeBinding("serviceEntries", m_TypeTable[4]),
			new TypeBinding("idString", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, IbIocProfile.class, false);

		m_TypeTable[487] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("perfRingType", m_TypeTable[121]),
			new TypeBinding("numberOfSeconds", m_TypeTable[7]),
			new TypeBinding("numberOfMinutes", m_TypeTable[7]),
			new TypeBinding("onlyUnreadData", m_TypeTable[0])
		}, PerformanceRingStartDetails.class, false);

		m_TypeTable[488] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cgRef", m_TypeTable[343]),
			new TypeBinding("pitSequenceNumber", new ArraySpec(m_TypeTable[6], 0, true, long.class))
		}, PITConsistencyGroupPITDeletionDescriptor.class, false);

		m_TypeTable[489] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("arrayId", m_TypeTable[366]),
			new TypeBinding("cfgGen", m_TypeTable[6]),
			new TypeBinding("operationIdentifier", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, RemoteArrayAuthentication.class, false);

		m_TypeTable[490] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("flashCacheType", m_TypeTable[92]),
			new TypeBinding("flashCacheLabel", m_TypeTable[337])
		}, FlashCacheAnalyticsCreationDescriptor.class, false);

		m_TypeTable[491] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cwob", m_TypeTable[0]),
			new TypeBinding("enterpriseCacheDump", m_TypeTable[0]),
			new TypeBinding("mirrorActive", m_TypeTable[0]),
			new TypeBinding("mirrorEnable", m_TypeTable[0]),
			new TypeBinding("readCacheActive", m_TypeTable[0]),
			new TypeBinding("readCacheEnable", m_TypeTable[0]),
			new TypeBinding("writeCacheActive", m_TypeTable[0]),
			new TypeBinding("writeCacheEnable", m_TypeTable[0]),
			new TypeBinding("cacheFlushModifier", m_TypeTable[188]),
			new TypeBinding("readAheadMultiplier", m_TypeTable[7])
		}, VolumeCache.class, false);

		m_TypeTable[492] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("lockKeyID", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("wrappedLockKey", new OpaqueSpec(40, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("newKeySequence", m_TypeTable[7])
		}, NewLockKey.class, false);

		m_TypeTable[493] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cgRef", m_TypeTable[343]),
			new TypeBinding("retainRepositoryMembers", m_TypeTable[0])
		}, PITConsistencyGroupDeletionDescriptor.class, false);

		m_TypeTable[494] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("rangeBegin", m_TypeTable[362]),
			new TypeBinding("rangeEnd", m_TypeTable[362])
		}, MgmtClientRecordReadDescriptor.class, false);

		m_TypeTable[495] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("regionId", m_TypeTable[210]),
			new TypeBinding("offset", m_TypeTable[7]),
			new TypeBinding("regionData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("hostIndex", m_TypeTable[7])
		}, HostSpecificNVSRAMUpdateDescriptor.class, false);

		m_TypeTable[496] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cgViewRef", m_TypeTable[343]),
			new TypeBinding("newLabel", m_TypeTable[337])
		}, PITConsistencyGroupViewParamsUpdateDescriptor.class, false);

		m_TypeTable[497] = new UnionSpec(true, "interposerType", m_TypeTable[187], "reserved", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY), new AlternateBinding[] {
			new AlternateBinding(1, "fcSasInterposer", m_TypeTable[371])
		}, InterposerTypeData.class);

		m_TypeTable[498] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("opcode", m_TypeTable[7]),
			new TypeBinding("count", m_TypeTable[6])
		}, OpcodeCounter.class, false);

		m_TypeTable[499] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("iocDumpNeedsRetrieved", m_TypeTable[0]),
			new TypeBinding("iocDumpTag", m_TypeTable[7]),
			new TypeBinding("timeStamp", m_TypeTable[6])
		}, CtrlIOCDumpData.class, false);

		m_TypeTable[500] = new UnionSpec(true, "option", m_TypeTable[50], new AlternateBinding[] {
			new AlternateBinding(1, "object", m_TypeTable[343])
		}, OptionalTargetObject.class);

		m_TypeTable[501] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("enable", m_TypeTable[0]),
			new TypeBinding("parityValidationEnable", m_TypeTable[0])
		}, VolumeMediaScanParams.class, false);

		m_TypeTable[502] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("clusterRef", m_TypeTable[343]),
			new TypeBinding("maxIopsPermittedOnCluster", m_TypeTable[6]),
			new TypeBinding("maxMBsPermittedOnCluster", m_TypeTable[6]),
			new TypeBinding("iopsImpactedByLimitationsOnThisCluster", m_TypeTable[6])
		}, ClusterPerformanceLimitationValues.class, false);

		m_TypeTable[503] = new UnionSpec(true, "minihubType", m_TypeTable[145], new AlternateBinding[] {
			new AlternateBinding(1, "parentController", m_TypeTable[315])
		}, MinihubTypeData.class);

		m_TypeTable[504] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostPortRef", m_TypeTable[343]),
			new TypeBinding("hostPortTypeIndex", m_TypeTable[7])
		}, HostPortTypeUpdateDescriptor.class, false);

		m_TypeTable[505] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("handle", m_TypeTable[433]),
			new TypeBinding("numberOfChunks", m_TypeTable[7]),
			new TypeBinding("debugChunkData", new StringSpec(5767168)),
			new TypeBinding("nextChunkToRetrieve", m_TypeTable[7])
		}, DebugInfo.class, false);
	}

	private static void __init9() {

		m_TypeTable[506] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("interfaceName", new StringSpec(0)),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("ip", m_TypeTable[7]),
			new TypeBinding("gatewayIp", m_TypeTable[7]),
			new TypeBinding("subnetMask", m_TypeTable[7])
		}, EthernetParamsUpdateDescriptor.class, false);

		m_TypeTable[507] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("trayId", m_TypeTable[7]),
			new TypeBinding("rackId", m_TypeTable[7])
		}, TrayPosition.class, false);

		m_TypeTable[508] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("lastChunk", m_TypeTable[0]),
			new TypeBinding("logData", new OpaqueSpec(131072, true, OpaqueSpec.DataType.BINARY))
		}, DdcLogData.class, false);

		m_TypeTable[509] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveHealthLogData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, DriveHealthLogsChunkDetails.class, false);

		m_TypeTable[510] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("performanceRingLogData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, PerformanceRingChunkDetails.class, false);

		m_TypeTable[511] = new SubclassSpec(new OpaqueSpec(40, true, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[512] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("targetName", new OpaqueSpec(60, true, OpaqueSpec.DataType.SBCS))
		}, TargetLocation.class, false);

		m_TypeTable[513] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "info", m_TypeTable[303])
		}, IOCDumpInfoReturn.class);

		m_TypeTable[514] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("reserved", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, DrivePerformanceHistoryRetrieveStartDetails.class, false);

		m_TypeTable[515] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "streamId", m_TypeTable[7])
		}, StatStreamIdReturned.class);

		m_TypeTable[516] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ntpErrorController", m_TypeTable[315]),
			new TypeBinding("domainName", new OpaqueSpec(80, false, OpaqueSpec.DataType.SBCS))
		}, ControllerNtpErrorDetails.class, false);

		m_TypeTable[517] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("startTime", m_TypeTable[6]),
			new TypeBinding("currentTime", m_TypeTable[6])
		}, StatisticalTimeData.class, false);

		m_TypeTable[518] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("sysName", new StringSpec(0)),
			new TypeBinding("sysContact", new StringSpec(0)),
			new TypeBinding("sysLocation", new StringSpec(0))
		}, SNMPSystemVariables.class, false);

		m_TypeTable[519] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("protectionInformationCapable", m_TypeTable[0]),
			new TypeBinding("protectionType", m_TypeTable[136])
		}, ProtectionInformationCapabilities.class, false);

		m_TypeTable[520] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trayRef", m_TypeTable[343]),
			new TypeBinding("blockData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, EnclosureStateCaptureRetrieveChunkDetails.class, false);

		m_TypeTable[521] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("protocolType", m_TypeTable[251]),
			new TypeBinding("priority", m_TypeTable[7]),
			new TypeBinding("priorityGroupId", m_TypeTable[7]),
			new TypeBinding("linkBandwidthPercentage", m_TypeTable[7]),
			new TypeBinding("enabled", m_TypeTable[0])
		}, DCBXSummaryData.class, false);

		m_TypeTable[522] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("portIdentifier", m_TypeTable[379])
		}, SasDrivePortAddress.class, false);

		m_TypeTable[523] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("codeModule", m_TypeTable[244]),
			new TypeBinding("versionString", new StringSpec(0))
		}, VersionDescriptor.class, false);

		m_TypeTable[524] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerTray", m_TypeTable[7]),
			new TypeBinding("controllerSlot", m_TypeTable[7]),
			new TypeBinding("cacheMemoryDimmControllerSlot", m_TypeTable[7])
		}, CacheMemoryDimmLocation.class, false);

		m_TypeTable[525] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("componentType", m_TypeTable[118]),
			new TypeBinding("symbolRef", m_TypeTable[343])
		}, TypedSYMbolReference.class, false);

		m_TypeTable[526] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("chunkData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, DbmRecRestoreChunkDetails.class, false);

		m_TypeTable[527] = new SubclassSpec(new StringSpec(0), null);

		m_TypeTable[528] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("keyVersion", m_TypeTable[7]),
			new TypeBinding("capability", m_TypeTable[153]),
			new TypeBinding("saId", m_TypeTable[366]),
			new TypeBinding("digest", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("limit", m_TypeTable[7]),
			new TypeBinding("duration", m_TypeTable[7]),
			new TypeBinding("keyId", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("supportedFeatureBundleId", m_TypeTable[7])
		}, FeatureKey.class, false);

		m_TypeTable[529] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("configGeneration", m_TypeTable[6]),
			new TypeBinding("lastCriticalMelSeqNumber", m_TypeTable[6])
		}, ChangeState.class, false);

		m_TypeTable[530] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("lunMappingRef", m_TypeTable[343]),
			new TypeBinding("lun", m_TypeTable[7]),
			new TypeBinding("mapRef", m_TypeTable[343])
		}, LUNMappingUpdateDescriptor.class, false);

		m_TypeTable[531] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("validationStatus", m_TypeTable[64]),
			new TypeBinding("blockData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("sourceLocation", m_TypeTable[245])
		}, DbmCheckRetrieveChunkDetails.class, false);

		m_TypeTable[532] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("skipStructureIntegrityCheck", m_TypeTable[0]),
			new TypeBinding("sourceLocation", m_TypeTable[245]),
			new TypeBinding("configType", m_TypeTable[125])
		}, DbmRecRetrieveStartDetails.class, false);

		m_TypeTable[533] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("manager", m_TypeTable[315])
		}, VolumeOwnershipUpdateDescriptor.class, false);

		m_TypeTable[534] = new UnionSpec(true, "variable", m_TypeTable[252], new AlternateBinding[] {
			new AlternateBinding(1, "newSysName", new StringSpec(0)),
			new AlternateBinding(2, "newSysContact", new StringSpec(0)),
			new AlternateBinding(3, "newSysLocation", new StringSpec(0))
		}, SNMPSystemVariableValue.class);

		m_TypeTable[535] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "refList", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, ReturnCodeWithRefList.class);

		m_TypeTable[536] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("serviceName", m_TypeTable[511]),
			new TypeBinding("serviceId", m_TypeTable[295])
		}, IbServiceEntry.class, false);

		m_TypeTable[537] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cacheSize", m_TypeTable[7]),
			new TypeBinding("cacheHitPct", m_TypeTable[7]),
			new TypeBinding("totalBaseWrites", m_TypeTable[6]),
			new TypeBinding("totalBaseWriteLatency", m_TypeTable[6]),
			new TypeBinding("totalBaseReadLatency", m_TypeTable[6]),
			new TypeBinding("totalBaseReads", m_TypeTable[6]),
			new TypeBinding("totalFlashCacheReads", m_TypeTable[6]),
			new TypeBinding("totalFlashCacheReadLatency", m_TypeTable[6])
		}, FlashCacheAnalyticsItem.class, false);

		m_TypeTable[538] = new UnionSpec(true, "command", m_TypeTable[76], new AlternateBinding[] {
			new AlternateBinding(1, "localController", m_TypeTable[315])
		}, SocCommandDescriptor.class);

		m_TypeTable[539] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostRef", m_TypeTable[343]),
			new TypeBinding("controllerRef", m_TypeTable[315])
		}, HostRedundancyLossDetails.class, false);

		m_TypeTable[540] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("fipOperational", m_TypeTable[0]),
			new TypeBinding("fcoeOperational", m_TypeTable[0]),
			new TypeBinding("pfcOperational", m_TypeTable[0]),
			new TypeBinding("pgOperational", m_TypeTable[0]),
			new TypeBinding("fcoeBandwidth", m_TypeTable[0]),
			new TypeBinding("iscsiOperational", m_TypeTable[0]),
			new TypeBinding("fcoeFipMismatch", m_TypeTable[0])
		}, EnhEthFeaturesState.class, false);

		m_TypeTable[541] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("deleteGroupOnLastVolDeletion", m_TypeTable[0])
		}, VolumeDeletionDescriptor.class, false);

		m_TypeTable[542] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("nvsram", new ArraySpec(m_TypeTable[442], 0, true, NVSRAMRegion.class))
		}, NVSRAMRegionList.class, false);

		m_TypeTable[543] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("keyValueList", new ArraySpec(m_TypeTable[304], 0, true, TunnelKeyValue.class)),
			new TypeBinding("bodyData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, SymbolTunnelRequest.class, false);

		m_TypeTable[544] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("successfulConnectRequests", m_TypeTable[6]),
			new TypeBinding("connectionFailures", m_TypeTable[6]),
			new TypeBinding("disconnects", m_TypeTable[6]),
			new TypeBinding("commandsGoodStatus", m_TypeTable[6]),
			new TypeBinding("commandsErrorStatus", m_TypeTable[6])
		}, NVMeoFQueueStatistics.class, false);

		m_TypeTable[545] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("saId", m_TypeTable[366])
		}, ControllerDescriptor.class, false);

		m_TypeTable[546] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("itemName", new StringSpec(0)),
			new TypeBinding("itemVersion", new StringSpec(0))
		}, InventoryItem.class, false);

		m_TypeTable[547] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("successfulLogins", m_TypeTable[6]),
			new TypeBinding("loginFailures", m_TypeTable[6]),
			new TypeBinding("successfulLoginAuthentications", m_TypeTable[6]),
			new TypeBinding("authenticationLoginFailures", m_TypeTable[6]),
			new TypeBinding("errorFreePdus", m_TypeTable[6]),
			new TypeBinding("protocolErrorPdus", m_TypeTable[6]),
			new TypeBinding("headerDigestErrors", m_TypeTable[6]),
			new TypeBinding("dataDigestErrors", m_TypeTable[6]),
			new TypeBinding("sessionFailures", m_TypeTable[6]),
			new TypeBinding("connectionFailures", m_TypeTable[6])
		}, IscsiInitiatorStatistics.class, false);

		m_TypeTable[548] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("isEnabled", m_TypeTable[0]),
			new TypeBinding("value", m_TypeTable[7])
		}, SettingControl.class, false);

		m_TypeTable[549] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "iocDumpTag", m_TypeTable[7])
		}, IOCDumpOnDemandReturn.class);

		m_TypeTable[550] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("structureIntegrityCheck", m_TypeTable[192]),
			new TypeBinding("totalImageSize", m_TypeTable[7]),
			new TypeBinding("timestamp", m_TypeTable[7]),
			new TypeBinding("configGen", m_TypeTable[6]),
			new TypeBinding("chunkData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("sourceLocation", m_TypeTable[245]),
			new TypeBinding("configType", m_TypeTable[125])
		}, DbmRecRetrieveChunkDetails.class, false);

		m_TypeTable[551] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("isSupported", m_TypeTable[0]),
			new TypeBinding("factoryDefaultsVersion", new StringSpec(0))
		}, EsmFactoryDefaultsVersionData.class, false);

		m_TypeTable[552] = new UnionSpec(true, "type", m_TypeTable[209], new AlternateBinding[] {
			new AlternateBinding(2, "diskPoolData", m_TypeTable[361])
		}, VolumeGroupTypeData.class);

		m_TypeTable[553] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "type", m_TypeTable[194])
		}, RawDataRetrieveStartResult.class);

		m_TypeTable[554] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mirrorGroup", m_TypeTable[343]),
			new TypeBinding("indication", m_TypeTable[134])
		}, AsyncMirrorGroupFaultIndicationClearDescriptor.class, false);

		m_TypeTable[555] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("lowHighSamplingSupported", m_TypeTable[0]),
			new TypeBinding("lowResolutionPeriod", m_TypeTable[7]),
			new TypeBinding("highResolutionPeriod", m_TypeTable[7])
		}, CumulativeStatisticsDefaultAttributes.class, false);

		m_TypeTable[556] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("target", m_TypeTable[343]),
			new TypeBinding("successfulLogins", m_TypeTable[6]),
			new TypeBinding("loginFailures", m_TypeTable[6]),
			new TypeBinding("successfulLoginAuthentications", m_TypeTable[6]),
			new TypeBinding("authenticationLoginFailures", m_TypeTable[6]),
			new TypeBinding("errorFreePdus", m_TypeTable[6]),
			new TypeBinding("protocolErrorPdus", m_TypeTable[6]),
			new TypeBinding("headerDigestErrors", m_TypeTable[6]),
			new TypeBinding("dataDigestErrors", m_TypeTable[6]),
			new TypeBinding("sessionFailures", m_TypeTable[6]),
			new TypeBinding("connectionFailures", m_TypeTable[6])
		}, IscsiTargetStatistics.class, false);

		m_TypeTable[557] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("previousAuditLogFullPolicy", m_TypeTable[166])
		}, SecurityAuditLogFullPolicyChangeDesc.class, false);

		m_TypeTable[558] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("clusterRef", m_TypeTable[343]),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("isSAControlled", m_TypeTable[0]),
			new TypeBinding("confirmLUNMappingCreation", m_TypeTable[0]),
			new TypeBinding("protectionInformationCapableAccessMethod", m_TypeTable[0]),
			new TypeBinding("isLun0Restricted", m_TypeTable[0])
		}, Cluster.class, false);

		m_TypeTable[559] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("databaseCount", m_TypeTable[7])
		}, UsmError.class, false);

		m_TypeTable[560] = new SubclassSpec(new OpaqueSpec(4, false, OpaqueSpec.DataType.IPV4ADDR), null);

		m_TypeTable[561] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("time", m_TypeTable[7]),
			new TypeBinding("clockMode", m_TypeTable[133]),
			new TypeBinding("month", m_TypeTable[7]),
			new TypeBinding("dayOfMonth", m_TypeTable[7]),
			new TypeBinding("dayOfWeek", m_TypeTable[7])
		}, DaylightSavingsTime.class, false);

		m_TypeTable[562] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("preferredOwner", m_TypeTable[315]),
			new TypeBinding("volumes", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, NotOnPreferredPath.class, false);

		m_TypeTable[563] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mirrorVolumeCandidate", new ArraySpec(m_TypeTable[451], 0, true, MirrorVolumeCandidate.class)),
			new TypeBinding("returnCode", m_TypeTable[152]),
			new TypeBinding("remoteCfgGeneration", m_TypeTable[6])
		}, MirrorVolumeCandidateList.class, false);

		m_TypeTable[564] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("kmsCertificateFileType", m_TypeTable[265])
		}, KMSCertificateFileRetrieveDescriptor.class, false);

		m_TypeTable[565] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("belowRange", m_TypeTable[411]),
			new TypeBinding("inRange", m_TypeTable[411]),
			new TypeBinding("aboveRange", m_TypeTable[411]),
			new TypeBinding("frequencyTable", new ArraySpec(m_TypeTable[6], 0, true, long.class))
		}, Histogram.class, false);

		m_TypeTable[566] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupRef", m_TypeTable[343])
		}, AsyncMirrorGroupRoleChangeCancelDescriptor.class, false);

		m_TypeTable[567] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "supportDataLockKey", m_TypeTable[7]),
			new AlternateBinding(598, "supportDataLockTimeRemaining", m_TypeTable[7])
		}, ReserveSupportDataReturned.class);

		m_TypeTable[568] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("totalVolumeGroups", m_TypeTable[7]),
			new TypeBinding("hotSpareCount", m_TypeTable[7]),
			new TypeBinding("unassignedCount", m_TypeTable[7]),
			new TypeBinding("volumeGroupSummary", new ArraySpec(m_TypeTable[430], 0, true, VolumeGroupSummary.class))
		}, AutoConfigSummary.class, false);

		m_TypeTable[569] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaces", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("bytesTransmitted", m_TypeTable[6]),
			new TypeBinding("bytesReceived", m_TypeTable[6]),
			new TypeBinding("packetsTransmitted", m_TypeTable[6]),
			new TypeBinding("packetsReceived", m_TypeTable[6]),
			new TypeBinding("carrierSenseErrors", m_TypeTable[6]),
			new TypeBinding("singleCollisionFrames", m_TypeTable[6]),
			new TypeBinding("multipleCollisionFrames", m_TypeTable[6]),
			new TypeBinding("lateCollisions", m_TypeTable[6]),
			new TypeBinding("deferredTransmissions", m_TypeTable[6]),
			new TypeBinding("frameTooLongs", m_TypeTable[6]),
			new TypeBinding("txMulticastFrameCount", m_TypeTable[6]),
			new TypeBinding("txBroadcastFrameCount", m_TypeTable[6]),
			new TypeBinding("txPauseFrameCount", m_TypeTable[6]),
			new TypeBinding("txControlFrameCount", m_TypeTable[6]),
			new TypeBinding("txFrameExcessDeferralCount", m_TypeTable[6]),
			new TypeBinding("txFrameAbortCount", m_TypeTable[6]),
			new TypeBinding("txFrameCollisionCount", m_TypeTable[6]),
			new TypeBinding("txFrameDroppedCount", m_TypeTable[6]),
			new TypeBinding("txJumboFrameCount", m_TypeTable[6]),
			new TypeBinding("rxUnknownControlFrameCount", m_TypeTable[6]),
			new TypeBinding("rxPauseFrameCount", m_TypeTable[6]),
			new TypeBinding("rxControlFrameCount", m_TypeTable[6]),
			new TypeBinding("rxFrameLengthErrorCount", m_TypeTable[6]),
			new TypeBinding("rxJabberCount", m_TypeTable[6]),
			new TypeBinding("rxFrameDropedCount", m_TypeTable[6]),
			new TypeBinding("rxFrameCrcErrorCount", m_TypeTable[6]),
			new TypeBinding("rxFrameEncodingErrorCount", m_TypeTable[6]),
			new TypeBinding("rxSmallFrameErrorCount", m_TypeTable[6]),
			new TypeBinding("rxMulticastFrameCount", m_TypeTable[6]),
			new TypeBinding("rxBroadcastFrameCount", m_TypeTable[6])
		}, EthernetPortStatistics.class, false);

		m_TypeTable[570] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("boardSubmodelID", m_TypeTable[7]),
			new TypeBinding("boardID", new StringSpec(0))
		}, LockDownInfo.class, false);

		m_TypeTable[571] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("productCapabilities", new ArraySpec(m_TypeTable[191], 0, true, ProductCapability.class))
		}, ProductCapabilityList.class, false);

		m_TypeTable[572] = new UnionSpec(true, "socParentType", m_TypeTable[119], new AlternateBinding[] {
			new AlternateBinding(1, "parentController", m_TypeTable[315]),
			new AlternateBinding(2, "parentEsm", m_TypeTable[343]),
			new AlternateBinding(3, "parentDrawer", m_TypeTable[343])
		}, SocParent.class);

		m_TypeTable[573] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("port1", m_TypeTable[343]),
			new TypeBinding("port2", m_TypeTable[343])
		}, ChannelPortPair.class, false);

		m_TypeTable[574] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("returnCode", m_TypeTable[152]),
			new TypeBinding("parityStatus", m_TypeTable[151]),
			new TypeBinding("endingLBA", m_TypeTable[6])
		}, ParityScanResponse.class, false);

		m_TypeTable[575] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("targetNodeName", m_TypeTable[389]),
			new TypeBinding("targetPortalGroupTag", m_TypeTable[4])
		}, IscsiTargetPortId.class, false);

		m_TypeTable[576] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostBoardRef", m_TypeTable[343]),
			new TypeBinding("maximumQpairsUsedSimultaneously", m_TypeTable[6]),
			new TypeBinding("minimumQpairsUsedSimultaneously", m_TypeTable[6]),
			new TypeBinding("averageQpairsUsedSimultaneously", m_TypeTable[6]),
			new TypeBinding("maximumDepthOfAnyQpair", m_TypeTable[6]),
			new TypeBinding("minimumDepthOfAnyQpair", m_TypeTable[6]),
			new TypeBinding("averageDepthOfAnyQpair", m_TypeTable[6])
		}, IbTcaStatistics.class, false);

		m_TypeTable[577] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cgRef", m_TypeTable[343]),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("repFullPolicy", m_TypeTable[19]),
			new TypeBinding("fullWarnThreshold", m_TypeTable[7]),
			new TypeBinding("autoDeleteLimit", m_TypeTable[7]),
			new TypeBinding("rollbackPriority", m_TypeTable[139])
		}, PITConsistencyGroupParamsUpdateDescriptor.class, false);

		m_TypeTable[578] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("linkFailureCount", m_TypeTable[7]),
			new TypeBinding("lossOfSyncCount", m_TypeTable[7]),
			new TypeBinding("lossOfSignalCount", m_TypeTable[7]),
			new TypeBinding("primSeqProtocolErr", m_TypeTable[7]),
			new TypeBinding("invalidXmitWord", m_TypeTable[7]),
			new TypeBinding("invalidCRCCount", m_TypeTable[7])
		}, RLSCount.class, false);

		m_TypeTable[579] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupRef", m_TypeTable[343]),
			new TypeBinding("deleteRecoveryPointIfNecessary", m_TypeTable[0])
		}, AsyncMirrorGroupResumeDescriptor.class, false);

		m_TypeTable[580] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("fruDiagTestType", m_TypeTable[186]),
			new TypeBinding("slot", m_TypeTable[7]),
			new TypeBinding("fruDiagTestIdentifier", m_TypeTable[280])
		}, FruDiagDescriptor.class, false);

		m_TypeTable[581] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupRef", m_TypeTable[343]),
			new TypeBinding("force", m_TypeTable[0]),
			new TypeBinding("toRole", m_TypeTable[104]),
			new TypeBinding("noSync", m_TypeTable[0])
		}, AsyncMirrorGroupRoleChangeDescriptor.class, false);

		m_TypeTable[582] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("arrayId", m_TypeTable[366]),
			new TypeBinding("cfgGen", m_TypeTable[6]),
			new TypeBinding("volWwn", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, RemoteMirrorAuthentication.class, false);

		m_TypeTable[583] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("volumeLBA", m_TypeTable[6]),
			new TypeBinding("trayNo", m_TypeTable[7]),
			new TypeBinding("slotNo", m_TypeTable[7]),
			new TypeBinding("driveLBA", m_TypeTable[6]),
			new TypeBinding("timeStamp", m_TypeTable[6]),
			new TypeBinding("recordType", m_TypeTable[243])
		}, UnreadableSectorTableEntry.class, false);

		m_TypeTable[584] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("securityType", m_TypeTable[173]),
			new TypeBinding("protectionInformationCapabilities", m_TypeTable[519]),
			new TypeBinding("usedCapacity", m_TypeTable[6]),
			new TypeBinding("securityLevel", m_TypeTable[83])
		}, FlashCacheWithDrives.class, false);

		m_TypeTable[585] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("mgmtClientAttribute", m_TypeTable[7])
		}, VolumeAttributeUpdateDescriptor.class, false);

		m_TypeTable[586] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("returnCode", m_TypeTable[152]),
			new TypeBinding("isEnabled", m_TypeTable[0])
		}, HighResolutionReturned.class, false);

		m_TypeTable[587] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("filename", new StringSpec(0)),
			new TypeBinding("lineNumber", m_TypeTable[7])
		}, DPLCoreDumpFWLocation.class, false);

		m_TypeTable[588] = new UnionSpec(true, "type", m_TypeTable[95], new AlternateBinding[] {
			new AlternateBinding(8, "dualPortIbTypeData", m_TypeTable[434]),
			new AlternateBinding(18, "dualPortDenaliIbTypeData", m_TypeTable[434])
		}, HostBoardTypeData.class);

		m_TypeTable[589] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("returnCode", m_TypeTable[152]),
			new TypeBinding("statusCode", m_TypeTable[152]),
			new TypeBinding("testResults", new ArraySpec(m_TypeTable[425], 18, false, RuntimeDiagTestResults.class)),
			new TypeBinding("extendedTestResults", new ArraySpec(m_TypeTable[425], 0, true, RuntimeDiagTestResults.class))
		}, RuntimeDiagResults.class, false);

		m_TypeTable[590] = new SubclassSpec(new OpaqueSpec(16, false, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[591] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("loopID", m_TypeTable[7])
		}, FibreDriveAddress.class, false);

		m_TypeTable[592] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("key", new OpaqueSpec(16, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("value", new OpaqueSpec(60, false, OpaqueSpec.DataType.BINARY))
		}, KeyValueTagCreationDescriptor.class, false);

		m_TypeTable[593] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaceRef", m_TypeTable[343]),
			new TypeBinding("symbolErrors", m_TypeTable[6]),
			new TypeBinding("recoveredLinkErrors", m_TypeTable[6]),
			new TypeBinding("unrecoveredLinkErrors", m_TypeTable[6]),
			new TypeBinding("rxPacketErrors", m_TypeTable[6]),
			new TypeBinding("rxEbpDelimitedPackets", m_TypeTable[6]),
			new TypeBinding("txPortDownPacketDiscards", m_TypeTable[6]),
			new TypeBinding("txConstraintErrorPacketDiscards", m_TypeTable[6]),
			new TypeBinding("rxConstraintErrorPacketDiscards", m_TypeTable[6]),
			new TypeBinding("rxSubnetManagementDroppedPackets", m_TypeTable[6]),
			new TypeBinding("txTotalBytes", m_TypeTable[6]),
			new TypeBinding("rxTotalBytes", m_TypeTable[6]),
			new TypeBinding("txTotalPackets", m_TypeTable[6]),
			new TypeBinding("rxTotalPackets", m_TypeTable[6]),
			new TypeBinding("txWaitTime", m_TypeTable[6]),
			new TypeBinding("txUnicastTotalPackets", m_TypeTable[6]),
			new TypeBinding("rxUnicastTotalPackets", m_TypeTable[6]),
			new TypeBinding("txMulticastTotalPackets", m_TypeTable[6]),
			new TypeBinding("rxMulticastTotalPackets", m_TypeTable[6])
		}, IbInterfaceStatistics.class, false);

		m_TypeTable[594] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("snapRepositoryRef", m_TypeTable[343]),
			new TypeBinding("newRepositoryLabel", m_TypeTable[337]),
			new TypeBinding("newPITGroupLabel", m_TypeTable[337])
		}, SnapshotConversionLabel.class, false);

		m_TypeTable[595] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ddcTag", m_TypeTable[7]),
			new TypeBinding("chunkNumber", m_TypeTable[7]),
			new TypeBinding("controllerRef", m_TypeTable[315])
		}, DdcExtent.class, false);

		m_TypeTable[596] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("baseTime", m_TypeTable[6]),
			new TypeBinding("startTime", m_TypeTable[6]),
			new TypeBinding("observedTime", m_TypeTable[6]),
			new TypeBinding("cpuUtilizationStats", new ArraySpec(m_TypeTable[336], 0, true, CpuUtilizationStats.class)),
			new TypeBinding("totalIopsServiced", m_TypeTable[6]),
			new TypeBinding("totalBytesServiced", m_TypeTable[6]),
			new TypeBinding("cacheHitsIopsTotal", m_TypeTable[6]),
			new TypeBinding("cacheHitsBytesTotal", m_TypeTable[6]),
			new TypeBinding("randomIosTotal", m_TypeTable[6]),
			new TypeBinding("randomBytesTotal", m_TypeTable[6]),
			new TypeBinding("readIopsTotal", m_TypeTable[6]),
			new TypeBinding("readBytesTotal", m_TypeTable[6]),
			new TypeBinding("writeIopsTotal", m_TypeTable[6]),
			new TypeBinding("writeBytesTotal", m_TypeTable[6]),
			new TypeBinding("mirrorIopsTotal", m_TypeTable[6]),
			new TypeBinding("mirrorBytesTotal", m_TypeTable[6]),
			new TypeBinding("fullStripeWritesBytes", m_TypeTable[6]),
			new TypeBinding("raid0BytesTransferred", m_TypeTable[6]),
			new TypeBinding("raid1BytesTransferred", m_TypeTable[6]),
			new TypeBinding("raid5BytesTransferred", m_TypeTable[6]),
			new TypeBinding("raid6BytesTransferred", m_TypeTable[6]),
			new TypeBinding("ddpBytesTransferred", m_TypeTable[6]),
			new TypeBinding("maxPossibleBpsUnderCurrentLoad", m_TypeTable[6]),
			new TypeBinding("maxPossibleIopsUnderCurrentLoad", m_TypeTable[6])
		}, ControllerCounterGroup.class, false);

		m_TypeTable[597] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerTray", m_TypeTable[7]),
			new TypeBinding("controllerSlot", m_TypeTable[7]),
			new TypeBinding("hostIoCardControllerSlot", m_TypeTable[7])
		}, HostIoCardLocation.class, false);

		m_TypeTable[598] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("maxReceiveDataSegmentLength", m_TypeTable[7]),
			new TypeBinding("headerDigestMethod", new ArraySpec(m_TypeTable[105], 2, true, DigestMethod.class)),
			new TypeBinding("dataDigestMethod", new ArraySpec(m_TypeTable[105], 2, true, DigestMethod.class)),
			new TypeBinding("receivingMarkers", m_TypeTable[0]),
			new TypeBinding("authMethod", new ArraySpec(m_TypeTable[15], 2, true, AuthenticationMethod.class))
		}, IscsiNegotiableConnectionSettings.class, false);

		m_TypeTable[599] = new UnionSpec(true, "recurrenceType", m_TypeTable[157], new AlternateBinding[] {
			new AlternateBinding(2, "recurrenceCount", m_TypeTable[7]),
			new AlternateBinding(3, "recurrenceEndDate", m_TypeTable[6])
		}, Recurrence.class);

		m_TypeTable[600] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveHealthLogData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, DriveHealthLogsStartDetails.class, false);

		m_TypeTable[601] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("trayPosition", new ArraySpec(m_TypeTable[507], 64, true, TrayPosition.class))
		}, TrayPositionList.class, false);

		m_TypeTable[602] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("sfpIdentType", m_TypeTable[235]),
			new TypeBinding("sfpConnectType", m_TypeTable[9]),
			new TypeBinding("sfpLinkLType", m_TypeTable[204]),
			new TypeBinding("sfpTransmitterType", m_TypeTable[146]),
			new TypeBinding("sfpSpeed", new EnumSetSpec(m_TypeTable[182])),
			new TypeBinding("sfpTransmissionMedia", new EnumSetSpec(m_TypeTable[207])),
			new TypeBinding("manufacturerDate", m_TypeTable[6]),
			new TypeBinding("vendorName", new StringSpec(0)),
			new TypeBinding("vendorPN", new StringSpec(0)),
			new TypeBinding("vendorRev", new StringSpec(0)),
			new TypeBinding("vendorSN", new StringSpec(0)),
			new TypeBinding("vendorOUI", new OpaqueSpec(3, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved1", new OpaqueSpec(12, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, SFPType.class, false);

		m_TypeTable[603] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controller", m_TypeTable[315]),
			new TypeBinding("handle", m_TypeTable[433]),
			new TypeBinding("chunkNumber", m_TypeTable[7])
		}, DebugInfoExtent.class, false);

		m_TypeTable[604] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("diskPoolDefaultAttributes", m_TypeTable[324]),
			new TypeBinding("thinVolDefaultAttributes", m_TypeTable[332]),
			new TypeBinding("pitGroupsDefaultAttributes", m_TypeTable[482]),
			new TypeBinding("arvmDefaultAttributes", m_TypeTable[339]),
			new TypeBinding("concatDefaultAttributes", m_TypeTable[452]),
			new TypeBinding("snmpAgentDefaultAttributes", m_TypeTable[349]),
			new TypeBinding("statisticsDefaultAttributes", m_TypeTable[555]),
			new TypeBinding("tunnelingDefaultAttributes", m_TypeTable[306])
		}, SystemAttributeDefaults.class, false);

		m_TypeTable[605] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("itemRef", m_TypeTable[343]),
			new TypeBinding("containerRef", m_TypeTable[343])
		}, SYMbolRefPair.class, false);

		m_TypeTable[606] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ports", new ArraySpec(m_TypeTable[438], 0, true, Port.class))
		}, PortList.class, false);

		m_TypeTable[607] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("portId", m_TypeTable[7])
		}, SAPortGetDescriptor.class, false);

		m_TypeTable[608] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("isIser", m_TypeTable[0])
		}, InfinibandInterfaceData.class, false);

		m_TypeTable[609] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channelType", m_TypeTable[206]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("soc", m_TypeTable[7]),
			new TypeBinding("port", m_TypeTable[7]),
			new TypeBinding("controllerSlot", m_TypeTable[7])
		}, SocLocation.class, false);

		m_TypeTable[610] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("configState", m_TypeTable[45]),
			new TypeBinding("ipv4Address", m_TypeTable[560]),
			new TypeBinding("ipv4SubnetMask", m_TypeTable[560]),
			new TypeBinding("ipv4GatewayAddress", m_TypeTable[560])
		}, IpV4AddressData.class, false);

		m_TypeTable[611] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("parent", m_TypeTable[572]),
			new TypeBinding("hubMode", m_TypeTable[0]),
			new TypeBinding("managedMode", m_TypeTable[0]),
			new TypeBinding("collectionElapsedTime", m_TypeTable[7])
		}, SocDeviceData.class, false);
	}

	private static void __init10() {

		m_TypeTable[612] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaceRef", m_TypeTable[343])
		}, IscsiCableDiagnosticsDescriptor.class, false);

		m_TypeTable[613] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerATime", m_TypeTable[6]),
			new TypeBinding("controllerBTime", m_TypeTable[6])
		}, ControllerTime.class, false);

		m_TypeTable[614] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("fwVersion", new OpaqueSpec(4, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("compatible", m_TypeTable[0])
		}, CompatibleFirmware.class, false);

		m_TypeTable[615] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ref", m_TypeTable[343]),
			new TypeBinding("trayID", m_TypeTable[7])
		}, TrayUpdateDescriptor.class, false);

		m_TypeTable[616] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("communityRef", m_TypeTable[343]),
			new TypeBinding("communityName", new StringSpec(0)),
			new TypeBinding("communityPermissions", m_TypeTable[93])
		}, SNMPCommunity.class, false);

		m_TypeTable[617] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("lockKeyIDRef", m_TypeTable[343]),
			new TypeBinding("lockKeyID", new OpaqueSpec(0, true, OpaqueSpec.DataType.SBCS))
		}, LockKeyID.class, false);

		m_TypeTable[618] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("totalPower", m_TypeTable[7]),
			new TypeBinding("numberOfTrays", m_TypeTable[7]),
			new TypeBinding("trayPower", new ArraySpec(m_TypeTable[294], 0, true, TrayPower.class))
		}, EnergyStarData.class, false);

		m_TypeTable[619] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("timeOfDay", m_TypeTable[7]),
			new TypeBinding("everyNMinutes", m_TypeTable[7]),
			new TypeBinding("timesPerDay", m_TypeTable[7])
		}, DailySchedule.class, false);

		m_TypeTable[620] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("latencyMeasures", m_TypeTable[375]),
			new TypeBinding("minBandwidthBitsPerSecond", m_TypeTable[6]),
			new TypeBinding("maxBandwidthBitsPerSecond", m_TypeTable[6]),
			new TypeBinding("avgBandwidthBitsPerSecond", m_TypeTable[6]),
			new TypeBinding("negotiatedLinkSpeedBitsPerSecond", m_TypeTable[6])
		}, AsyncMirrorGroupLinkBandwidthTestResults.class, false);

		m_TypeTable[621] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveChannels", new ArraySpec(m_TypeTable[7], 0, true, int.class))
		}, MiswiredDriveChannelList.class, false);

		m_TypeTable[622] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("maximumInterfaceSpeed", new ArraySpec(m_TypeTable[149], 1, true, InterfaceSpeed.class))
		}, HostPortsChangeableAttributes.class, false);

		m_TypeTable[623] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("currentTemp", m_TypeTable[7]),
			new TypeBinding("refTemp", m_TypeTable[7])
		}, DriveTemperature.class, false);

		m_TypeTable[624] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveRef", m_TypeTable[343]),
			new TypeBinding("modeSelectFile", m_TypeTable[0]),
			new TypeBinding("firmwareUpdateDescriptor", m_TypeTable[308])
		}, DriveFirmwareUpdateDescriptor.class, false);

		m_TypeTable[625] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("componentType", m_TypeTable[165]),
			new TypeBinding("trayId", m_TypeTable[7]),
			new TypeBinding("relativePosition", m_TypeTable[7]),
			new TypeBinding("parentSize", m_TypeTable[7]),
			new TypeBinding("parent", new ArraySpec(m_TypeTable[289], 4, false, ParentRelativeLocation.class)),
			new TypeBinding("componentLabel", new OpaqueSpec(8, true, OpaqueSpec.DataType.SBCS))
		}, ComponentRelativeLocation.class, false);

		m_TypeTable[626] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("daysOfWeek", new EnumSetSpec(m_TypeTable[117])),
			new TypeBinding("dailySchedule", m_TypeTable[619])
		}, ScheduleWeekly.class, false);

		m_TypeTable[627] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerGBICType", m_TypeTable[49]),
			new TypeBinding("parentController", m_TypeTable[315]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("reserved1", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, ControllerGBIC.class, false);

		m_TypeTable[628] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("nonChannelErrors", m_TypeTable[7]),
			new TypeBinding("timeoutErrors", m_TypeTable[7]),
			new TypeBinding("controllerDetectedErrors", m_TypeTable[7]),
			new TypeBinding("driveDetectedErrors", m_TypeTable[7]),
			new TypeBinding("linkDownErrors", m_TypeTable[7])
		}, DriveChannelErrorCounts.class, false);

		m_TypeTable[629] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("initiatorNodeName", m_TypeTable[389]),
			new TypeBinding("initiatorSessionId", m_TypeTable[342])
		}, IscsiInitiatorPortId.class, false);

		m_TypeTable[630] = new UnionSpec(true, "portType", m_TypeTable[247], new AlternateBinding[] {
			new AlternateBinding(1, "portIdentifier", m_TypeTable[379]),
			new AlternateBinding(2, "routingType", m_TypeTable[229])
		}, SasPortTypeData.class);

		m_TypeTable[631] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343])
		}, VolumeCopyCandidate.class, false);

		m_TypeTable[632] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("dplCoreDumpTag", m_TypeTable[7]),
			new TypeBinding("dplCoreDumpNeedsRetrieved", m_TypeTable[0]),
			new TypeBinding("dplCoreDumpEnabled", m_TypeTable[0]),
			new TypeBinding("timeStamp", m_TypeTable[6])
		}, DPLCoreDumpData.class, false);

		m_TypeTable[633] = new SubclassSpec(new OpaqueSpec(16, false, OpaqueSpec.DataType.BINARY), null);

		m_TypeTable[634] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("sasExpander", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, SasEsmAttributes.class, false);

		m_TypeTable[635] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("totalImageSize", m_TypeTable[7]),
			new TypeBinding("validator", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("configType", m_TypeTable[125]),
			new TypeBinding("sourceLocation", m_TypeTable[245]),
			new TypeBinding("skipMismatchCheck", m_TypeTable[0])
		}, DbmRecRestoreStartDetails.class, false);

		m_TypeTable[636] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("icmpPingResponseEnabled", m_TypeTable[0]),
			new TypeBinding("unnamedDiscoverySessionsEnabled", m_TypeTable[0]),
			new TypeBinding("isnsServerTcpListenPort", m_TypeTable[7]),
			new TypeBinding("ipv4IsnsServerAddressConfigMethod", m_TypeTable[259]),
			new TypeBinding("ipv4IsnsServerAddress", m_TypeTable[560]),
			new TypeBinding("ipv6IsnsServerAddressConfigMethod", m_TypeTable[263]),
			new TypeBinding("ipv6IsnsServerAddress", m_TypeTable[590]),
			new TypeBinding("isnsRegistrationState", m_TypeTable[196]),
			new TypeBinding("isnsServerRegistrationEnabled", m_TypeTable[0]),
			new TypeBinding("hostPortsConfiguredDHCP", m_TypeTable[0])
		}, IscsiEntityData.class, false);

		m_TypeTable[637] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cgViewRef", m_TypeTable[343]),
			new TypeBinding("pitSequenceNumber", m_TypeTable[6])
		}, PITConsistencyGroupViewRestartDescriptor.class, false);

		m_TypeTable[638] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("retCode", m_TypeTable[152]),
			new TypeBinding("records", new ArraySpec(m_TypeTable[405], 128, true, MgmtClientRecord.class))
		}, MgmtClientRecordReadResult.class, false);

		m_TypeTable[639] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("communityAddDescriptor", new ArraySpec(m_TypeTable[373], 0, true, SNMPCommunityAddDescriptor.class))
		}, SNMPCommunityAddDescriptorList.class, false);

		m_TypeTable[640] = new UnionSpec(true, "action", m_TypeTable[205], new AlternateBinding[] {
			new AlternateBinding(2, "associatedVolume", m_TypeTable[343])
		}, CoWRepositoryAnalysisRequest.class);

		m_TypeTable[641] = new UnionSpec(true, "refType", m_TypeTable[241], new AlternateBinding[] {
			new AlternateBinding(1, "controllerRef", m_TypeTable[315]),
			new AlternateBinding(0, "symbolRef", m_TypeTable[343]),
			new AlternateBinding(2, "typedReference", m_TypeTable[525])
		}, ObjectReference.class);

		m_TypeTable[642] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("reconPriority", m_TypeTable[7])
		}, VolumeParamsUpdateDescriptor.class, false);

		m_TypeTable[643] = new UnionSpec(true, "rtrType", m_TypeTable[61], new AlternateBinding[] {
			new AlternateBinding(10, "alarmRef", m_TypeTable[343]),
			new AlternateBinding(4, "batteryRef", m_TypeTable[343]),
			new AlternateBinding(3, "controllerRef", m_TypeTable[315]),
			new AlternateBinding(5, "driveRef", m_TypeTable[343]),
			new AlternateBinding(6, "esmRef", m_TypeTable[343]),
			new AlternateBinding(7, "fanRef", m_TypeTable[343]),
			new AlternateBinding(1, "interconnectRef", m_TypeTable[343]),
			new AlternateBinding(9, "minihubRef", m_TypeTable[343]),
			new AlternateBinding(8, "powerSupplyRef", m_TypeTable[343]),
			new AlternateBinding(2, "supportCruRef", m_TypeTable[343]),
			new AlternateBinding(11, "thermalSensorRef", m_TypeTable[343]),
			new AlternateBinding(12, "drawerRef", m_TypeTable[343])
		}, RTRObject.class);

		m_TypeTable[644] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mappingRef", m_TypeTable[343])
		}, WorkloadVolumeDeleteMappingDescriptor.class, false);

		m_TypeTable[645] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("records", new ArraySpec(m_TypeTable[405], 128, true, MgmtClientRecord.class))
		}, MgmtClientRecordWriteDescriptor.class, false);

		m_TypeTable[646] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupRef", m_TypeTable[343]),
			new TypeBinding("deleteRecoveryPointIfNecessary", m_TypeTable[0])
		}, AsyncMirrorGroupSynchronizeDescriptor.class, false);

		m_TypeTable[647] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("remoteNodeWWN", m_TypeTable[331]),
			new TypeBinding("associatedSwitchPorts", new ArraySpec(m_TypeTable[300], 0, true, String.class)),
			new TypeBinding("connectedRemoteTargetPorts", new ArraySpec(m_TypeTable[467], 0, true, FibrePortLogin.class))
		}, FibreRemoteTargetConnections.class, false);

		m_TypeTable[648] = new UnionSpec(true, "ioInterfaceType", m_TypeTable[276], new AlternateBinding[] {
			new AlternateBinding(5, "iscsiNodeName", m_TypeTable[389]),
			new AlternateBinding(2, "remoteNodeWWN", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new AlternateBinding(8, "nvmeNodeName", m_TypeTable[470])
		}, ScsiNodeName.class);

		m_TypeTable[649] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("address", m_TypeTable[590]),
			new TypeBinding("addressState", m_TypeTable[394])
		}, IpV6AddressData.class, false);

		m_TypeTable[650] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "ddcLogData", m_TypeTable[508])
		}, DdcLogDataReturned.class);

		m_TypeTable[651] = new UnionSpec(true, "removalMethod", m_TypeTable[264], new AlternateBinding[] {
			new AlternateBinding(2, "rtrAttributes", m_TypeTable[464])
		}, ComponentRemovalData.class);

		m_TypeTable[652] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trapDestinationRef", m_TypeTable[343]),
			new TypeBinding("communityRef", m_TypeTable[343]),
			new TypeBinding("sendAuthenticationFailureTraps", m_TypeTable[0])
		}, SNMPTrapDestinationParamsUpdateDescriptor.class, false);

		m_TypeTable[653] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("initiatorPortId", m_TypeTable[374]),
			new TypeBinding("targetPortId", m_TypeTable[374]),
			new TypeBinding("targetChannelPort", m_TypeTable[343])
		}, IbRdmaChannelEndpoints.class, false);

		m_TypeTable[654] = new UnionSpec(true, "auditLogEvent", m_TypeTable[159], new AlternateBinding[] {
			new AlternateBinding(1, "fullPolicyChange", m_TypeTable[557])
		}, SecurityAuditLogEventData.class);

		m_TypeTable[655] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("status", m_TypeTable[143]),
			new TypeBinding("configType", m_TypeTable[161]),
			new TypeBinding("analyticsStatus", m_TypeTable[90]),
			new TypeBinding("analyticsCause", m_TypeTable[48]),
			new TypeBinding("statusCause", m_TypeTable[281])
		}, FlashCacheBase.class, false);

		m_TypeTable[656] = new UnionSpec(true, "ioInterfaceType", m_TypeTable[276], new AlternateBinding[] {
			new AlternateBinding(2, "portList", m_TypeTable[606])
		}, ESMInterfaceTypeData.class);

		m_TypeTable[657] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("communityRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, SNMPCommunityRefList.class, false);

		m_TypeTable[658] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostPortRef", m_TypeTable[343]),
			new TypeBinding("hostPortName", m_TypeTable[311]),
			new TypeBinding("label", m_TypeTable[337])
		}, HostPortRenameDescriptor.class, false);

		m_TypeTable[659] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("time", m_TypeTable[6]),
			new TypeBinding("totalRequestsServiced", m_TypeTable[7]),
			new TypeBinding("totalBlocksRequested", m_TypeTable[7]),
			new TypeBinding("totalReadRequests", m_TypeTable[7]),
			new TypeBinding("totalReadBlocksRequested", m_TypeTable[7]),
			new TypeBinding("totalWriteRequests", m_TypeTable[7]),
			new TypeBinding("totalWriteBlocksRequested", m_TypeTable[7]),
			new TypeBinding("percentReadRequests", m_TypeTable[7]),
			new TypeBinding("averageBlocksRequested", m_TypeTable[7]),
			new TypeBinding("totalLargeReads", m_TypeTable[7]),
			new TypeBinding("totalLargeReadBlocksRequested", m_TypeTable[7]),
			new TypeBinding("totalLargeWrites", m_TypeTable[7]),
			new TypeBinding("totalLargeWriteBlocksRequested", m_TypeTable[7]),
			new TypeBinding("totalCacheReadChecks", m_TypeTable[7]),
			new TypeBinding("totalCacheReadCheckHits", m_TypeTable[7]),
			new TypeBinding("totalCacheWriteRequests", m_TypeTable[7]),
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("totalCacheWriteHits", m_TypeTable[7]),
			new TypeBinding("totalFlashCacheReadHits", m_TypeTable[7])
		}, VolumePerformance.class, false);

		m_TypeTable[660] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cgRef", m_TypeTable[343]),
			new TypeBinding("pitSequenceNumber", m_TypeTable[6])
		}, PITConsistencyGroupRollbackStartDescriptor.class, false);

		m_TypeTable[661] = new UnionSpec(true, "type", m_TypeTable[209], new AlternateBinding[] {
			new AlternateBinding(2, "diskPoolVolumeCandidateData", m_TypeTable[412])
		}, VolumeCandidateTypeData.class);

		m_TypeTable[662] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerSFPType", m_TypeTable[98]),
			new TypeBinding("parentController", m_TypeTable[315]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("reserved1", new OpaqueSpec(12, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, ControllerSFP.class, false);

		m_TypeTable[663] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("keyVersion", m_TypeTable[7]),
			new TypeBinding("sourceSubmodelId", new StringSpec(0)),
			new TypeBinding("targetSubmodelId", new StringSpec(0)),
			new TypeBinding("saId", m_TypeTable[366]),
			new TypeBinding("digest", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, BundleKey.class, false);

		m_TypeTable[664] = new UnionSpec(true, "extLocType", m_TypeTable[106], new AlternateBinding[] {
			new AlternateBinding(4, "compChannelLoc", m_TypeTable[432]),
			new AlternateBinding(3, "compMinihubLoc", m_TypeTable[346]),
			new AlternateBinding(1, "compTray", m_TypeTable[7]),
			new AlternateBinding(2, "compTraySlot", m_TypeTable[377]),
			new AlternateBinding(5, "compLabel", m_TypeTable[337]),
			new AlternateBinding(6, "pitSequence", m_TypeTable[6]),
			new AlternateBinding(8, "compReference", m_TypeTable[343]),
			new AlternateBinding(7, "controllerReference", m_TypeTable[315]),
			new AlternateBinding(9, "locationLabel", new OpaqueSpec(16, true, OpaqueSpec.DataType.BINARY)),
			new AlternateBinding(10, "volumeGroupLabel", m_TypeTable[337]),
			new AlternateBinding(11, "diskPoolLabel", m_TypeTable[337])
		}, ExtendedComponentLocation.class);

		m_TypeTable[665] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("drives", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, DegradedPath.class, false);

		m_TypeTable[666] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("observationTime", m_TypeTable[6]),
			new TypeBinding("objectRef", m_TypeTable[641]),
			new TypeBinding("histogram", new ArraySpec(m_TypeTable[565], 0, true, Histogram.class))
		}, HistogramBundle.class, false);

		m_TypeTable[667] = new UnionSpec(true, "enhEthTLVType", m_TypeTable[193], new AlternateBinding[] {
			new AlternateBinding(1, "chassisIDTLV", m_TypeTable[297]),
			new AlternateBinding(2, "portIDTLV", m_TypeTable[321]),
			new AlternateBinding(3, "timeToLiveTLV", m_TypeTable[329])
		}, EnhEthTLV.class);

		m_TypeTable[668] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[285]),
			new TypeBinding("percentComplete", m_TypeTable[7])
		}, DriveDownloadDriveStatus.class, false);

		m_TypeTable[669] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("label", m_TypeTable[337])
		}, VolumeLabelUpdateDescriptor.class, false);

		m_TypeTable[670] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "debugInfo", m_TypeTable[505])
		}, DebugInfoReturned.class);

		m_TypeTable[671] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("metaDataList", new ArraySpec(m_TypeTable[367], 0, true, SpecificDatabaseMetadata.class))
		}, DatabaseMetadata.class, false);

		m_TypeTable[672] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("autoConfigTemplate", m_TypeTable[401]),
			new TypeBinding("autoConfigSummary", m_TypeTable[568])
		}, AutoConfigCandidate.class, false);

		m_TypeTable[673] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trayRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, TrayRefList.class, false);

		m_TypeTable[674] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("lunMappingRef", m_TypeTable[343]),
			new TypeBinding("lun", m_TypeTable[7]),
			new TypeBinding("ssid", m_TypeTable[7]),
			new TypeBinding("perms", m_TypeTable[7]),
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("type", m_TypeTable[71]),
			new TypeBinding("mapRef", m_TypeTable[343])
		}, LUNMapping.class, false);

		m_TypeTable[675] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("startTimeStamp", m_TypeTable[6]),
			new TypeBinding("endTimeStamp", m_TypeTable[6]),
			new TypeBinding("totalIoCount", m_TypeTable[7]),
			new TypeBinding("totalIoErrorCount", m_TypeTable[7]),
			new TypeBinding("linkStatus", m_TypeTable[230]),
			new TypeBinding("errorCounts", m_TypeTable[628])
		}, DriveChannelStatistics.class, false);

		m_TypeTable[676] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("forceUpdate", m_TypeTable[0]),
			new TypeBinding("powerSupplyRef", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("firmwareUpdateDescriptor", m_TypeTable[308])
		}, PSUFirmwareUpdateDescriptor.class, false);

		m_TypeTable[677] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("keyValueTagRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, KeyValueTagRefList.class, false);

		m_TypeTable[678] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cgViewRef", m_TypeTable[343])
		}, PITConsistencyGroupViewStopDescriptor.class, false);

		m_TypeTable[679] = new UnionSpec(true, "type", m_TypeTable[144], new AlternateBinding[] {
			new AlternateBinding(3, "controllerRef", m_TypeTable[315]),
			new AlternateBinding(1, "esmRef", m_TypeTable[343]),
			new AlternateBinding(2, "minihubRef", m_TypeTable[343]),
			new AlternateBinding(4, "hicRef", m_TypeTable[343])
		}, ChannelPortParent.class);

		m_TypeTable[680] = new UnionSpec(true, "ioInterfaceType", m_TypeTable[276], new AlternateBinding[] {
			new AlternateBinding(2, "fcPortName", m_TypeTable[311]),
			new AlternateBinding(6, "ibPortName", m_TypeTable[374]),
			new AlternateBinding(4, "sasPortName", m_TypeTable[379])
		}, HostPortLocation.class);

		m_TypeTable[681] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("rangeBegin", m_TypeTable[362]),
			new TypeBinding("rangeEnd", m_TypeTable[362])
		}, MgmtClientRecordDeleteDescriptor.class, false);

		m_TypeTable[682] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("abstractVolRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, AbstractVolRefList.class, false);

		m_TypeTable[683] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, AsyncMirrorGroupRefList.class, false);

		m_TypeTable[684] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trapDestinationRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, SNMPTrapDestinationRefList.class, false);

		m_TypeTable[685] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("retainRepositoryMembers", m_TypeTable[0]),
			new TypeBinding("cgViewRef", m_TypeTable[343])
		}, PITConsistencyGroupViewDeletionDescriptor.class, false);

		m_TypeTable[686] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("resetBatteryAge", m_TypeTable[0]),
			new TypeBinding("component", m_TypeTable[343]),
			new TypeBinding("nextLearnCycleTime", new ArraySpec(m_TypeTable[6], 1, true, long.class))
		}, BatteryParamsUpdateDescriptor.class, false);

		m_TypeTable[687] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "unconfiguredInitiators", new ArraySpec(m_TypeTable[648], 0, true, ScsiNodeName.class))
		}, UnconfiguredInitiatorsReturned.class);

		m_TypeTable[688] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ipv4Address", m_TypeTable[560]),
			new TypeBinding("ipv4AddressConfigMethod", m_TypeTable[259]),
			new TypeBinding("ipv4OutboundPacketPriority", m_TypeTable[548]),
			new TypeBinding("ipv4VlanId", m_TypeTable[548]),
			new TypeBinding("ipv4AddressData", m_TypeTable[610])
		}, InternetProtocolV4Data.class, false);

		m_TypeTable[689] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("description", m_TypeTable[337])
		}, WorkloadCreationDescriptor.class, false);

		m_TypeTable[690] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trayRef", m_TypeTable[343]),
			new TypeBinding("firmwareUpdateDescriptor", m_TypeTable[308])
		}, ESMFirmwareUpdateDescriptor.class, false);

		m_TypeTable[691] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "lockDownInfo", m_TypeTable[570])
		}, LockDownInfoReturned.class);

		m_TypeTable[692] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "fruDiagReturnData", m_TypeTable[347])
		}, FruDiagReturn.class);

		m_TypeTable[693] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trayRef", m_TypeTable[343])
		}, EnclosureStateCaptureRetrieveStartDetails.class, false);

		m_TypeTable[694] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("fileSize", m_TypeTable[7]),
			new TypeBinding("driveList", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, DriveDownloadSet.class, false);

		m_TypeTable[695] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "histogramBundle", m_TypeTable[666])
		}, HistogramBundleReturned.class);

		m_TypeTable[696] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("partData", m_TypeTable[465]),
			new TypeBinding("macAddress", m_TypeTable[318]),
			new TypeBinding("fullDuplex", m_TypeTable[0]),
			new TypeBinding("maximumFramePayloadSize", m_TypeTable[7]),
			new TypeBinding("currentInterfaceSpeed", m_TypeTable[149]),
			new TypeBinding("maximumInterfaceSpeed", m_TypeTable[149]),
			new TypeBinding("linkStatus", m_TypeTable[230]),
			new TypeBinding("supportedInterfaceSpeeds", new ArraySpec(m_TypeTable[149], 0, true, InterfaceSpeed.class)),
			new TypeBinding("autoconfigSupport", m_TypeTable[0]),
			new TypeBinding("copperCableDiagnosticsSupport", m_TypeTable[0])
		}, EthernetInterfaceData.class, false);

		m_TypeTable[697] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupType", m_TypeTable[238]),
			new TypeBinding("objectRef", new ArraySpec(m_TypeTable[641], 0, true, ObjectReference.class)),
			new TypeBinding("dataLocation", m_TypeTable[43]),
			new TypeBinding("statisticsResolution", m_TypeTable[215])
		}, CumulativeStatisticsListDescriptor.class, false);

		m_TypeTable[698] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("newParams", m_TypeTable[501])
		}, VolumeMediaScanParamsUpdateDescriptor.class, false);

		m_TypeTable[699] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostRef", m_TypeTable[343]),
			new TypeBinding("clusterRef", m_TypeTable[343]),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("isSAControlled", m_TypeTable[0]),
			new TypeBinding("confirmLUNMappingCreation", m_TypeTable[0]),
			new TypeBinding("hostTypeIndex", m_TypeTable[7]),
			new TypeBinding("protectionInformationCapableAccessMethod", m_TypeTable[0]),
			new TypeBinding("isLargeBlockFormatHost", m_TypeTable[0]),
			new TypeBinding("isLun0Restricted", m_TypeTable[0])
		}, Host.class, false);

		m_TypeTable[700] = new UnionSpec(true, "addressType", m_TypeTable[273], new AlternateBinding[] {
			new AlternateBinding(0, "ipv4Address", m_TypeTable[560]),
			new AlternateBinding(1, "ipv6Address", m_TypeTable[590])
		}, IpVxAddress.class);

		m_TypeTable[701] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveChannelList", new ArraySpec(m_TypeTable[458], 0, true, DriveChannelSpecifier.class))
		}, ExternalRedundancyFailure.class, false);

		m_TypeTable[702] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("newValues", new ArraySpec(m_TypeTable[534], 0, true, SNMPSystemVariableValue.class))
		}, SNMPSystemVariablesUpdateDescriptor.class, false);

		m_TypeTable[703] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("deviceName", m_TypeTable[379]),
			new TypeBinding("drivePortAddresses", new ArraySpec(m_TypeTable[522], 0, true, SasDrivePortAddress.class))
		}, SasDriveAddress.class, false);

		m_TypeTable[704] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("descriptor", new ArraySpec(m_TypeTable[689], 0, true, WorkloadCreationDescriptor.class))
		}, WorkloadCreationDescriptorList.class, false);

		m_TypeTable[705] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("domain", m_TypeTable[454]),
			new TypeBinding("status", m_TypeTable[274])
		}, DirectoryServicesStatusDesc.class, false);

		m_TypeTable[706] = new UnionSpec(true, "rawDataTransferType", m_TypeTable[194], new AlternateBinding[] {
			new AlternateBinding(2, "dbmBlk", m_TypeTable[404]),
			new AlternateBinding(3, "dbmRec", m_TypeTable[635])
		}, RawDataRestoreStartDetails.class);

		m_TypeTable[707] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaceRef", m_TypeTable[343]),
			new TypeBinding("hostBoardRef", m_TypeTable[343])
		}, IoInterfaceHicMap.class, false);

		m_TypeTable[708] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trapDestinationRef", m_TypeTable[343]),
			new TypeBinding("trapReceiverIpAddress", m_TypeTable[700]),
			new TypeBinding("communityRef", m_TypeTable[343]),
			new TypeBinding("sendAuthenticationFailureTraps", m_TypeTable[0])
		}, SNMPTrapDestination.class, false);

		m_TypeTable[709] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("lun", m_TypeTable[7]),
			new TypeBinding("perms", m_TypeTable[7]),
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("mapRef", m_TypeTable[343])
		}, LUNMappingCreationDescriptor.class, false);

		m_TypeTable[710] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("retCode", m_TypeTable[152]),
			new TypeBinding("driveRef", m_TypeTable[343])
		}, PowerCyclePhysicalDriveDataReturn.class, false);

		m_TypeTable[711] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("retCode", m_TypeTable[152]),
			new TypeBinding("replyData", m_TypeTable[543])
		}, SymbolTunnelReply.class, false);

		m_TypeTable[712] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("startTime", m_TypeTable[6]),
			new TypeBinding("stopTime", m_TypeTable[6]),
			new TypeBinding("analytics", new ArraySpec(m_TypeTable[537], 0, true, FlashCacheAnalyticsItem.class)),
			new TypeBinding("realCacheAnalytics", m_TypeTable[537])
		}, FlashCacheAnalyticsData.class, false);

		m_TypeTable[713] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupLabel", m_TypeTable[337]),
			new TypeBinding("syncIntervalMinutes", m_TypeTable[7]),
			new TypeBinding("syncCompletionTimeAlertThresholdMinutes", m_TypeTable[7]),
			new TypeBinding("recoveryPointAgeAlertThresholdMinutes", m_TypeTable[7]),
			new TypeBinding("repositoryUtilizationWarnThreshold", m_TypeTable[7]),
			new TypeBinding("groupRef", m_TypeTable[343])
		}, AsyncMirrorGroupParamsUpdateDescriptor.class, false);

		m_TypeTable[714] = new TypedefSpec(new ArraySpec(m_TypeTable[649], 0, true, IpV6AddressData.class), IpV6AddressDataBundle.class);

		m_TypeTable[715] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("community", new ArraySpec(m_TypeTable[616], 0, true, SNMPCommunity.class)),
			new TypeBinding("trapDestination", new ArraySpec(m_TypeTable[708], 0, true, SNMPTrapDestination.class)),
			new TypeBinding("systemVariables", m_TypeTable[518])
		}, SNMPAgentBundle.class, false);

		m_TypeTable[716] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeGroupRef", m_TypeTable[343]),
			new TypeBinding("thresholdType", m_TypeTable[102]),
			new TypeBinding("newThresholdValue", m_TypeTable[7])
		}, DiskPoolThresholdUpdateDescriptor.class, false);

		m_TypeTable[717] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("descriptorList", new ArraySpec(m_TypeTable[592], 0, true, KeyValueTagCreationDescriptor.class))
		}, KeyValueTagCreationDescriptorList.class, false);

		m_TypeTable[718] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("attributeId", m_TypeTable[278]),
			new TypeBinding("attributeValue", m_TypeTable[527])
		}, TrayAttribute.class, false);

		m_TypeTable[719] = new UnionSpec(true, "rawDataTransferType", m_TypeTable[194], new AlternateBinding[] {
			new AlternateBinding(2, "dbmBlk", m_TypeTable[418]),
			new AlternateBinding(3, "dbmRec", m_TypeTable[526])
		}, RawDataRestoreChunkDetails.class);

		m_TypeTable[720] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("objectRef", m_TypeTable[641]),
			new TypeBinding("groupType", m_TypeTable[238]),
			new TypeBinding("dataLocation", m_TypeTable[43]),
			new TypeBinding("statisticsResolution", m_TypeTable[215])
		}, CumulativeStatisticsDescriptor.class, false);

		m_TypeTable[721] = new UnionSpec(true, "type", m_TypeTable[126], new AlternateBinding[] {
			new AlternateBinding(1, "parentController", m_TypeTable[315]),
			new AlternateBinding(2, "parentEsm", m_TypeTable[343]),
			new AlternateBinding(3, "parentFan", m_TypeTable[343]),
			new AlternateBinding(4, "parentInterconnectCru", m_TypeTable[343]),
			new AlternateBinding(5, "parentSupportCru", m_TypeTable[343]),
			new AlternateBinding(6, "parentDrawer", m_TypeTable[343])
		}, ParentCru.class);

		m_TypeTable[722] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeGroupRef", m_TypeTable[343]),
			new TypeBinding("priorityType", m_TypeTable[34]),
			new TypeBinding("newPriorityValue", m_TypeTable[87])
		}, DiskPoolPriorityUpdateDescriptor.class, false);

		m_TypeTable[723] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("workloadRef", m_TypeTable[343]),
			new TypeBinding("description", m_TypeTable[337])
		}, Workload.class, false);

		m_TypeTable[724] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("icmpPingResponseEnabled", new ArraySpec(m_TypeTable[0], 1, true, boolean.class)),
			new TypeBinding("unnamedDiscoverySessionsEnabled", new ArraySpec(m_TypeTable[0], 1, true, boolean.class)),
			new TypeBinding("isnsServerTcpListenPort", new ArraySpec(m_TypeTable[7], 1, true, int.class)),
			new TypeBinding("ipv4IsnsServerAddressConfigMethod", new ArraySpec(m_TypeTable[259], 1, true, IpV4ConfigMethod.class)),
			new TypeBinding("ipv4IsnsServerAddress", new ArraySpec(m_TypeTable[560], 1, true, String.class)),
			new TypeBinding("ipv6IsnsServerAddress", new ArraySpec(m_TypeTable[590], 1, true, String.class)),
			new TypeBinding("isnsServerRegistrationEnabled", new ArraySpec(m_TypeTable[0], 1, true, boolean.class))
		}, IscsiEntityChangeableProperties.class, false);

		m_TypeTable[725] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "energyStarData", m_TypeTable[618])
		}, EnergyStarDataReturn.class);

		m_TypeTable[726] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("communityRef", m_TypeTable[343]),
			new TypeBinding("communityPermissions", m_TypeTable[93]),
			new TypeBinding("communityName", new StringSpec(0))
		}, SNMPCommunityParamsUpdateDescriptor.class, false);

		m_TypeTable[727] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("baseTime", m_TypeTable[6]),
			new TypeBinding("opcodeCounters", new ArraySpec(m_TypeTable[498], 0, true, OpcodeCounter.class)),
			new TypeBinding("bytesIn", m_TypeTable[6]),
			new TypeBinding("bytesOut", m_TypeTable[6]),
			new TypeBinding("idleTime", m_TypeTable[6])
		}, IoCounterGroup.class, false);

		m_TypeTable[728] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("portNumber", m_TypeTable[7]),
			new TypeBinding("portGuid", m_TypeTable[363]),
			new TypeBinding("tcaGuid", m_TypeTable[363]),
			new TypeBinding("pkeys", new ArraySpec(m_TypeTable[7], 0, true, int.class))
		}, IbPortPartitionTable.class, false);

		m_TypeTable[729] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("syslogEnabled", m_TypeTable[0]),
			new TypeBinding("syslogServerPortNumber", m_TypeTable[7]),
			new TypeBinding("syslogServerIpAddress", m_TypeTable[700])
		}, SyslogConfiguration.class, false);
	}

	private static void __init11() {

		m_TypeTable[730] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cgViewRef", m_TypeTable[343]),
			new TypeBinding("groupRef", m_TypeTable[343]),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("viewTime", m_TypeTable[6]),
			new TypeBinding("viewSequenceNumber", m_TypeTable[6])
		}, PITConsistencyGroupView.class, false);

		m_TypeTable[731] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("trayId", m_TypeTable[7]),
			new TypeBinding("slot", m_TypeTable[7]),
			new TypeBinding("saId", m_TypeTable[366]),
			new TypeBinding("thisController", m_TypeTable[315]),
			new TypeBinding("allControllers", new ArraySpec(m_TypeTable[315], 0, true, String.class))
		}, AccessibleController.class, false);

		m_TypeTable[732] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaceRef", m_TypeTable[343]),
			new TypeBinding("symbolErrors", m_TypeTable[370]),
			new TypeBinding("recoveredLinkErrors", m_TypeTable[370]),
			new TypeBinding("unrecoveredLinkErrors", m_TypeTable[370]),
			new TypeBinding("rxPacketErrors", m_TypeTable[370]),
			new TypeBinding("rxEbpDelimitedPackets", m_TypeTable[370]),
			new TypeBinding("txPortDownPacketDiscards", m_TypeTable[370]),
			new TypeBinding("txConstraintErrorPacketDiscards", m_TypeTable[370]),
			new TypeBinding("rxConstraintErrorPacketDiscards", m_TypeTable[370]),
			new TypeBinding("rxSubnetManagementDroppedPackets", m_TypeTable[370]),
			new TypeBinding("txTotalBytes", m_TypeTable[370]),
			new TypeBinding("rxTotalBytes", m_TypeTable[370]),
			new TypeBinding("txTotalPackets", m_TypeTable[370]),
			new TypeBinding("rxTotalPackets", m_TypeTable[370]),
			new TypeBinding("txWaitTime", m_TypeTable[370]),
			new TypeBinding("txUnicastTotalPackets", m_TypeTable[370]),
			new TypeBinding("rxUnicastTotalPackets", m_TypeTable[370]),
			new TypeBinding("txMulticastTotalPackets", m_TypeTable[370]),
			new TypeBinding("rxMulticastTotalPackets", m_TypeTable[370])
		}, EnhancedIbInterfaceStatistics.class, false);

		m_TypeTable[733] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("sequenceNum", m_TypeTable[7]),
			new TypeBinding("offline", m_TypeTable[0]),
			new TypeBinding("raidLevel", m_TypeTable[36]),
			new TypeBinding("worldWideName", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("volumeGroupRef", m_TypeTable[343]),
			new TypeBinding("reserved1", new OpaqueSpec(12, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("trayLossProtection", m_TypeTable[0]),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("state", m_TypeTable[25]),
			new TypeBinding("spindleSpeedMatch", m_TypeTable[0]),
			new TypeBinding("spindleSpeed", m_TypeTable[7]),
			new TypeBinding("isInaccessible", m_TypeTable[0]),
			new TypeBinding("securityType", m_TypeTable[173]),
			new TypeBinding("drawerLossProtection", m_TypeTable[0]),
			new TypeBinding("protectionInformationCapable", m_TypeTable[0]),
			new TypeBinding("protectionInformationCapabilities", m_TypeTable[519]),
			new TypeBinding("volumeGroupData", m_TypeTable[552]),
			new TypeBinding("usage", m_TypeTable[148]),
			new TypeBinding("driveBlockFormat", m_TypeTable[72]),
			new TypeBinding("reservedSpaceAllocated", m_TypeTable[0]),
			new TypeBinding("securityLevel", m_TypeTable[83])
		}, VolumeGroup.class, false);

		m_TypeTable[734] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostTypeIndex", new ArraySpec(m_TypeTable[7], 1, true, int.class)),
			new TypeBinding("label", new ArraySpec(m_TypeTable[337], 1, true, String.class)),
			new TypeBinding("clusterRef", new ArraySpec(m_TypeTable[343], 1, true, String.class))
		}, HostChangeableProperties.class, false);

		m_TypeTable[735] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("maxWait", m_TypeTable[7]),
			new TypeBinding("lastKnown", m_TypeTable[529])
		}, ChangeQueryDescriptor.class, false);

		m_TypeTable[736] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("baseVolume", m_TypeTable[343]),
			new TypeBinding("conversionLabels", new ArraySpec(m_TypeTable[594], 0, true, SnapshotConversionLabel.class))
		}, SnapshotConversionDescriptor.class, false);

		m_TypeTable[737] = new UnionSpec(true, "gbicParentType", m_TypeTable[18], new AlternateBinding[] {
			new AlternateBinding(3, "controllerGBIC", m_TypeTable[627]),
			new AlternateBinding(1, "parentEsm", m_TypeTable[343]),
			new AlternateBinding(2, "parentMinihub", m_TypeTable[343])
		}, GBICParentTypeData.class);

		m_TypeTable[738] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("communityUpdateDescriptor", new ArraySpec(m_TypeTable[726], 0, true, SNMPCommunityParamsUpdateDescriptor.class))
		}, SNMPCommunityParamsUpdateDescriptorList.class, false);

		m_TypeTable[739] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("startingLBA", m_TypeTable[6]),
			new TypeBinding("endingLBA", m_TypeTable[6]),
			new TypeBinding("repairMedia", m_TypeTable[0]),
			new TypeBinding("repairParity", m_TypeTable[0]),
			new TypeBinding("priority", m_TypeTable[112]),
			new TypeBinding("timeout", m_TypeTable[7])
		}, VolumeScanDescriptor.class, false);

		m_TypeTable[740] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interposerRef", m_TypeTable[343]),
			new TypeBinding("interposerTypeData", m_TypeTable[497])
		}, Interposer.class, false);

		m_TypeTable[741] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "databaseData", m_TypeTable[671])
		}, DatabaseMetadataReturned.class);

		m_TypeTable[742] = new UnionSpec(true, "rtrType", m_TypeTable[61], new AlternateBinding[] {
			new AlternateBinding(4, "batteryRef", m_TypeTable[343]),
			new AlternateBinding(3, "controllerRef", m_TypeTable[315]),
			new AlternateBinding(5, "driveRef", m_TypeTable[343]),
			new AlternateBinding(6, "esmRef", m_TypeTable[343]),
			new AlternateBinding(7, "fanRef", m_TypeTable[343]),
			new AlternateBinding(1, "interconnectRef", m_TypeTable[343]),
			new AlternateBinding(9, "minihubRef", m_TypeTable[343]),
			new AlternateBinding(8, "powerSupplyRef", m_TypeTable[343]),
			new AlternateBinding(2, "supportCruRef", m_TypeTable[343])
		}, RTRTypeRef.class);

		m_TypeTable[743] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "viewPasswordDigest", m_TypeTable[390])
		}, SAViewPasswordDigestReturned.class);

		m_TypeTable[744] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("featureId", m_TypeTable[124]),
			new TypeBinding("featureAttribute", new ArraySpec(m_TypeTable[480], 0, true, FeatureAttribute.class))
		}, BundledFeature.class, false);

		m_TypeTable[745] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("objectRef", m_TypeTable[641]),
			new TypeBinding("streamType", m_TypeTable[248]),
			new TypeBinding("duration", m_TypeTable[7]),
			new TypeBinding("lowestValue", m_TypeTable[6]),
			new TypeBinding("lowestRange", m_TypeTable[6]),
			new TypeBinding("scaleType", m_TypeTable[262]),
			new TypeBinding("numCategories", m_TypeTable[7])
		}, HistogramDescriptor.class, false);

		m_TypeTable[746] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("timeStamp", m_TypeTable[6]),
			new TypeBinding("interfaceRef", m_TypeTable[343]),
			new TypeBinding("completionStatus", m_TypeTable[277]),
			new TypeBinding("channelResults", new ArraySpec(m_TypeTable[399], 0, true, IscsiCableDiagChannelResults.class))
		}, IscsiCableDiagResults.class, false);

		m_TypeTable[747] = new UnionSpec(true, "authMethod", m_TypeTable[15], new AlternateBinding[] {
			new AlternateBinding(4, "chapSecret", new ArraySpec(m_TypeTable[422], 0, true, EncryptedPassword.class))
		}, AuthMethodTypeData.class);

		m_TypeTable[748] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostBoardRef", m_TypeTable[343]),
			new TypeBinding("iocProfile", m_TypeTable[486]),
			new TypeBinding("serviceEntries", new ArraySpec(m_TypeTable[536], 0, true, IbServiceEntry.class))
		}, IbIocAttributes.class, false);

		m_TypeTable[749] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trayLostRedundancy", m_TypeTable[343]),
			new TypeBinding("workingChannel", m_TypeTable[7]),
			new TypeBinding("failedEsm", m_TypeTable[343])
		}, TrayLostRedundancyFailure.class, false);

		m_TypeTable[750] = new UnionSpec(true, "cruType", m_TypeTable[172], new AlternateBinding[] {
			new AlternateBinding(4, "parentCru", m_TypeTable[721]),
			new AlternateBinding(2, "rtrAttributeData", m_TypeTable[464])
		}, RTRAttributes.class);

		m_TypeTable[751] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("dayOfWeek", m_TypeTable[117]),
			new TypeBinding("dailySchedule", m_TypeTable[619]),
			new TypeBinding("weekNumber", m_TypeTable[7]),
			new TypeBinding("monthsOfYear", new EnumSetSpec(m_TypeTable[135]))
		}, ScheduleMonthlyByDay.class, false);

		m_TypeTable[752] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllers", new ArraySpec(m_TypeTable[315], 0, true, String.class)),
			new TypeBinding("drives", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("esms", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, RLSDevices.class, false);

		m_TypeTable[753] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveToReplace", m_TypeTable[343]),
			new TypeBinding("replacementDrive", m_TypeTable[343]),
			new TypeBinding("failAfterEvacuate", m_TypeTable[0])
		}, CopyThenReplaceDescriptor.class, false);

		m_TypeTable[754] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("timeData", m_TypeTable[517]),
			new TypeBinding("ibInterfaceStatisticsRaw", new ArraySpec(m_TypeTable[593], 0, true, IbInterfaceStatistics.class)),
			new TypeBinding("ibInterfaceStatisticsRel", new ArraySpec(m_TypeTable[593], 0, true, IbInterfaceStatistics.class))
		}, IbBaselinedStatistics.class, false);

		m_TypeTable[755] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("powerSupplyRef", m_TypeTable[343]),
			new TypeBinding("powerSupplyUpdateStatus", m_TypeTable[158])
		}, PSUUpdateStatus.class, false);

		m_TypeTable[756] = new UnionSpec(true, "objectType", m_TypeTable[279], new AlternateBinding[] {
			new AlternateBinding(1, "volume", m_TypeTable[343]),
			new AlternateBinding(2, "workload", m_TypeTable[343])
		}, KeyValueTagObjectReference.class);

		m_TypeTable[757] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostPortName", new ArraySpec(m_TypeTable[311], 1, true, String.class)),
			new TypeBinding("label", new ArraySpec(m_TypeTable[337], 1, true, String.class)),
			new TypeBinding("hostRef", new ArraySpec(m_TypeTable[343], 1, true, String.class))
		}, HostPortChangeableProperties.class, false);

		m_TypeTable[758] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("rtrObject", m_TypeTable[643]),
			new TypeBinding("rtrControl", m_TypeTable[120])
		}, RTRUpdateDescription.class, false);

		m_TypeTable[759] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupRef", m_TypeTable[343]),
			new TypeBinding("worldWideName", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("groupState", m_TypeTable[140]),
			new TypeBinding("localRole", m_TypeTable[104]),
			new TypeBinding("remoteRole", m_TypeTable[104]),
			new TypeBinding("roleChangeProgress", m_TypeTable[154]),
			new TypeBinding("syncIntervalMinutes", m_TypeTable[7]),
			new TypeBinding("syncCompletionTimeAlertThresholdMinutes", m_TypeTable[7]),
			new TypeBinding("recoveryPointAgeAlertThresholdMinutes", m_TypeTable[7]),
			new TypeBinding("repositoryUtilizationWarnThreshold", m_TypeTable[7]),
			new TypeBinding("mirrorChannelRemoteTarget", m_TypeTable[343]),
			new TypeBinding("syncActivity", m_TypeTable[185]),
			new TypeBinding("orphanGroup", m_TypeTable[0])
		}, AsyncMirrorGroup.class, false);

		m_TypeTable[760] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("esmPortRef", m_TypeTable[343]),
			new TypeBinding("loopID", m_TypeTable[7]),
			new TypeBinding("portRef", m_TypeTable[343])
		}, FibreESMAddress.class, false);

		m_TypeTable[761] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostPortRef", m_TypeTable[343]),
			new TypeBinding("hostPortName", m_TypeTable[311]),
			new TypeBinding("reservedPort", m_TypeTable[53]),
			new TypeBinding("registeredPorts", m_TypeTable[423])
		}, Registrant.class, false);

		m_TypeTable[762] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("eventData", m_TypeTable[654]),
			new TypeBinding("currentAuditLogFullPolicy", m_TypeTable[166])
		}, SecurityAuditLogEventDesc.class, false);

		m_TypeTable[763] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("clusterRef", m_TypeTable[343]),
			new TypeBinding("maxIopsOnCluster", m_TypeTable[6]),
			new TypeBinding("maxMBsOnCluster", m_TypeTable[6])
		}, ClusterPerformanceLimitationValuesDescriptor.class, false);

		m_TypeTable[764] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cgRef", m_TypeTable[343]),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("repFullPolicy", m_TypeTable[19]),
			new TypeBinding("fullWarnThreshold", m_TypeTable[7]),
			new TypeBinding("autoDeleteLimit", m_TypeTable[7]),
			new TypeBinding("rollbackPriority", m_TypeTable[139]),
			new TypeBinding("uniqueSequenceNumber", new ArraySpec(m_TypeTable[6], 0, true, long.class)),
			new TypeBinding("creationPendingStatus", m_TypeTable[127])
		}, PITConsistencyGroup.class, false);

		m_TypeTable[765] = new UnionSpec(true, "deviceType", m_TypeTable[41], new AlternateBinding[] {
			new AlternateBinding(1, "controller", m_TypeTable[315]),
			new AlternateBinding(2, "drive", m_TypeTable[343]),
			new AlternateBinding(3, "esm", m_TypeTable[343])
		}, ChannelDiagDevice.class);

		m_TypeTable[766] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("dailySchedule", m_TypeTable[619])
		}, ScheduleDaily.class, false);

		m_TypeTable[767] = new UnionSpec(true, "driveChannelParent", m_TypeTable[39], new AlternateBinding[] {
			new AlternateBinding(2, "controllerRef", m_TypeTable[315]),
			new AlternateBinding(1, "minihubRef", m_TypeTable[343])
		}, DriveChannelParent.class);

		m_TypeTable[768] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("wrappedLockKey", new ArraySpec(m_TypeTable[440], 0, true, WrappedLockKey.class))
		}, WrappedLockKeyList.class, false);

		m_TypeTable[769] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupRef", m_TypeTable[343]),
			new TypeBinding("membersLocalButNotRemote", new ArraySpec(m_TypeTable[337], 0, true, String.class)),
			new TypeBinding("membersRemoteButNotLocal", new ArraySpec(m_TypeTable[337], 0, true, String.class))
		}, AsyncMirrorGroupMemberMismatchList.class, false);

		m_TypeTable[770] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "estimate", m_TypeTable[479])
		}, PITGroupRollbackUtilizationEstimateReturned.class);

		m_TypeTable[771] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("keyValueTagRef", m_TypeTable[343]),
			new TypeBinding("key", new OpaqueSpec(16, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("value", new OpaqueSpec(60, false, OpaqueSpec.DataType.BINARY))
		}, KeyValueTag.class, false);

		m_TypeTable[772] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("workloadRef", m_TypeTable[343]),
			new TypeBinding("volumeRef", m_TypeTable[343])
		}, WorkloadVolumeCreateMappingDescriptor.class, false);

		m_TypeTable[773] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("reserved1", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("codeVersions", new ArraySpec(m_TypeTable[523], 0, true, VersionDescriptor.class))
		}, ExtendedSAData.class, false);

		m_TypeTable[774] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("remoteArrayRef", m_TypeTable[343]),
			new TypeBinding("saId", m_TypeTable[366]),
			new TypeBinding("remoteTargets", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, RemoteArray.class, false);

		m_TypeTable[775] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("endpoints", m_TypeTable[653]),
			new TypeBinding("maximumRdmaMessageSize", m_TypeTable[7]),
			new TypeBinding("pathMaximumTransmissionUnit", m_TypeTable[7]),
			new TypeBinding("maximumQueueDepth", m_TypeTable[7]),
			new TypeBinding("channelState", m_TypeTable[189])
		}, IbRdmaChannel.class, false);

		m_TypeTable[776] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("alarmRef", m_TypeTable[343]),
			new TypeBinding("alarmControl", m_TypeTable[56])
		}, AlarmUpdateDescriptor.class, false);

		m_TypeTable[777] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("driveRef", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("newCapacity", m_TypeTable[6])
		}, VolumeExpansionDescriptor.class, false);

		m_TypeTable[778] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trayRef", m_TypeTable[343]),
			new TypeBinding("trayAttributes", new ArraySpec(m_TypeTable[718], 0, true, TrayAttribute.class))
		}, TrayAttributeUpdateDescriptor.class, false);

		m_TypeTable[779] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "defaults", m_TypeTable[604])
		}, SystemAttributeDefaultsReturned.class);

		m_TypeTable[780] = new UnionSpec(true, "type", m_TypeTable[282], new AlternateBinding[] {
			new AlternateBinding(1, "controller", m_TypeTable[315]),
			new AlternateBinding(2, "drive", m_TypeTable[343]),
			new AlternateBinding(3, "expander", m_TypeTable[343]),
			new AlternateBinding(4, "hostBoardRef", m_TypeTable[343])
		}, SasPortProviderDevice.class);

		m_TypeTable[781] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("responseFromAgent", m_TypeTable[0]),
			new TypeBinding("agentId", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("controllers", new ArraySpec(m_TypeTable[731], 0, true, AccessibleController.class))
		}, DiscoveryResponse.class, false);

		m_TypeTable[782] = new UnionSpec(true, "type", m_TypeTable[110], new AlternateBinding[] {
			new AlternateBinding(1, "controller", m_TypeTable[315]),
			new AlternateBinding(2, "drive", m_TypeTable[343]),
			new AlternateBinding(3, "esm", m_TypeTable[343])
		}, RLSDevice.class);

		m_TypeTable[783] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaces", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("receivedSegments", m_TypeTable[6]),
			new TypeBinding("sentSegments", m_TypeTable[6]),
			new TypeBinding("receivedSegmentsInError", m_TypeTable[6]),
			new TypeBinding("txByteCount", m_TypeTable[6]),
			new TypeBinding("rxByteCount", m_TypeTable[6]),
			new TypeBinding("retransmitTimerExpiredCount", m_TypeTable[6]),
			new TypeBinding("rxDuplicateAckCount", m_TypeTable[6]),
			new TypeBinding("rxAckCount", m_TypeTable[6]),
			new TypeBinding("txDelayedAckCount", m_TypeTable[6]),
			new TypeBinding("txAckCount", m_TypeTable[6]),
			new TypeBinding("rxSegmentOutOfOrderCount", m_TypeTable[6]),
			new TypeBinding("rxWindowProbeCount", m_TypeTable[6]),
			new TypeBinding("rxWindowUpdateCount", m_TypeTable[6])
		}, TcpStatisticalData.class, false);

		m_TypeTable[784] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerARef", m_TypeTable[315]),
			new TypeBinding("controllerBRef", m_TypeTable[315]),
			new TypeBinding("supportCRUARef", m_TypeTable[343]),
			new TypeBinding("supportCRUBRef", m_TypeTable[343]),
			new TypeBinding("batteryPackRef", m_TypeTable[343])
		}, BatteryPackICCFailure.class, false);

		m_TypeTable[785] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("type", m_TypeTable[194]),
			new TypeBinding("finalSequenceNumber", m_TypeTable[7]),
			new TypeBinding("thisSequenceNumber", m_TypeTable[7]),
			new TypeBinding("details", m_TypeTable[719]),
			new TypeBinding("controllerRef", m_TypeTable[315])
		}, RawDataRestoreContinueDesc.class, false);

		m_TypeTable[786] = new UnionSpec(true, "addrType", m_TypeTable[96], new AlternateBinding[] {
			new AlternateBinding(1, "domainName", new OpaqueSpec(0, true, OpaqueSpec.DataType.SBCS)),
			new AlternateBinding(2, "ipvxAddress", m_TypeTable[700])
		}, NetworkAddress.class);

		m_TypeTable[787] = new UnionSpec(true, "dnsAcquisitionType", m_TypeTable[29], new AlternateBinding[] {
			new AlternateBinding(1, "dnsServers", new ArraySpec(m_TypeTable[700], 2, true, IpVxAddress.class))
		}, DnsAcquisitionDescriptor.class);

		m_TypeTable[788] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("workloadRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, WorkloadRefList.class, false);

		m_TypeTable[789] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaceName", new ArraySpec(m_TypeTable[397], 1, true, String.class)),
			new TypeBinding("ipv4Enabled", new ArraySpec(m_TypeTable[0], 1, true, boolean.class)),
			new TypeBinding("ipv4Address", new ArraySpec(m_TypeTable[560], 1, true, String.class)),
			new TypeBinding("ipv4SubnetMask", new ArraySpec(m_TypeTable[560], 1, true, String.class)),
			new TypeBinding("ipv4AddressConfigMethod", new ArraySpec(m_TypeTable[259], 1, true, IpV4ConfigMethod.class)),
			new TypeBinding("ipv6Enabled", new ArraySpec(m_TypeTable[0], 1, true, boolean.class)),
			new TypeBinding("ipv6LocalAddress", new ArraySpec(m_TypeTable[649], 1, true, IpV6AddressData.class)),
			new TypeBinding("ipv6PortStaticRoutableAddress", new ArraySpec(m_TypeTable[649], 1, true, IpV6AddressData.class)),
			new TypeBinding("ipv6AddressConfigMethod", new ArraySpec(m_TypeTable[263], 1, true, IpV6ConfigMethod.class)),
			new TypeBinding("configuredSpeedSetting", new ArraySpec(m_TypeTable[100], 1, true, EthernetSpeedSetting.class))
		}, EthernetInterfaceChangeableProperties.class, false);

		m_TypeTable[790] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("device", m_TypeTable[782]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("loopMapIndex", m_TypeTable[7]),
			new TypeBinding("rlsCount", m_TypeTable[578]),
			new TypeBinding("baselineTime", m_TypeTable[6]),
			new TypeBinding("valid", m_TypeTable[0])
		}, RLSData.class, false);

		m_TypeTable[791] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("lockKeyIDRef", m_TypeTable[343])
		}, SecurityKeyNeeded.class, false);

		m_TypeTable[792] = new UnionSpec(true, "phyDriveType", m_TypeTable[21], new AlternateBinding[] {
			new AlternateBinding(3, "sataDriveAttributes", m_TypeTable[460])
		}, PhysicalDriveTypeData.class);

		m_TypeTable[793] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("daysOfMonth", new EnumSetSpec(m_TypeTable[237])),
			new TypeBinding("monthsOfYear", new EnumSetSpec(m_TypeTable[135])),
			new TypeBinding("dailySchedule", m_TypeTable[619])
		}, ScheduleMonthlyByDate.class, false);

		m_TypeTable[794] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaceRef", m_TypeTable[343]),
			new TypeBinding("totalControllerCount", m_TypeTable[7]),
			new TypeBinding("keepAliveTimeouts", m_TypeTable[6]),
			new TypeBinding("maxIoQueuesConnectFailures", m_TypeTable[6]),
			new TypeBinding("maxControllerConnectFailures", m_TypeTable[6]),
			new TypeBinding("nvmeControllerResets", m_TypeTable[6]),
			new TypeBinding("nvmeControllerShutdowns", m_TypeTable[6]),
			new TypeBinding("adminQueueStatistics", m_TypeTable[544]),
			new TypeBinding("ioQueueStatistics", m_TypeTable[544])
		}, NVMeoFInterfaceStatistics.class, false);

		m_TypeTable[795] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("volumeRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, ControllerVolumeList.class, false);

		m_TypeTable[796] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("endpoints", m_TypeTable[653]),
			new TypeBinding("activeMessages", m_TypeTable[6]),
			new TypeBinding("queuedMessages", m_TypeTable[6]),
			new TypeBinding("txMessages", m_TypeTable[6]),
			new TypeBinding("rxMessages", m_TypeTable[6]),
			new TypeBinding("rdmaOpsStarted", m_TypeTable[6]),
			new TypeBinding("rdmaOpsCompleted", m_TypeTable[6]),
			new TypeBinding("messagesCompletedWithError", m_TypeTable[6]),
			new TypeBinding("maximumObservedMessageSize", m_TypeTable[6]),
			new TypeBinding("maximumObservedQueueDepth", m_TypeTable[6])
		}, IbRdmaChannelStatistics.class, false);

		m_TypeTable[797] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "analyticsData", m_TypeTable[712])
		}, FlashCacheAnalyticsReturned.class);

		m_TypeTable[798] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("registrant", new ArraySpec(m_TypeTable[761], 0, true, Registrant.class))
		}, RegistrantList.class, false);

		m_TypeTable[799] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("removalData", m_TypeTable[651]),
			new TypeBinding("replacementMethod", m_TypeTable[225])
		}, RepairPolicy.class, false);

		m_TypeTable[800] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("parentRef", m_TypeTable[315]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("channelPort", m_TypeTable[7]),
			new TypeBinding("connector", m_TypeTable[9]),
			new TypeBinding("supportedLinkSpeeds", new EnumSetSpec(m_TypeTable[182])),
			new TypeBinding("currentLinkSpeed", m_TypeTable[7]),
			new TypeBinding("manuallyBypassed", m_TypeTable[0]),
			new TypeBinding("supportsSpeed", m_TypeTable[0]),
			new TypeBinding("channelPortRef", m_TypeTable[343])
		}, LinkSpeedDetectionError.class, false);

		m_TypeTable[801] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("deleteDescriptor", new ArraySpec(m_TypeTable[644], 0, true, WorkloadVolumeDeleteMappingDescriptor.class))
		}, WorkloadVolumeDeleteMappingDescriptorList.class, false);

		m_TypeTable[802] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("pending", m_TypeTable[0]),
			new TypeBinding("percentComplete", m_TypeTable[7]),
			new TypeBinding("timeToCompletion", m_TypeTable[7])
		}, InitializationOperation.class, false);

		m_TypeTable[803] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("tzLabel", new OpaqueSpec(40, false, OpaqueSpec.DataType.SBCS)),
			new TypeBinding("tzOffset", m_TypeTable[7]),
			new TypeBinding("dstStart", m_TypeTable[561]),
			new TypeBinding("dstEnd", m_TypeTable[561]),
			new TypeBinding("dstAdjust", m_TypeTable[7])
		}, TimeZoneDescription.class, false);

		m_TypeTable[804] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("returnCode", m_TypeTable[152]),
			new TypeBinding("lunMapping", new ArraySpec(m_TypeTable[674], 0, true, LUNMapping.class))
		}, LUNMappings.class, false);

		m_TypeTable[805] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("maxLimit", m_TypeTable[7]),
			new TypeBinding("database", new ArraySpec(m_TypeTable[583], 0, true, UnreadableSectorTableEntry.class))
		}, UnreadableSectorTableInfo.class, false);

		m_TypeTable[806] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("returnCode", m_TypeTable[152]),
			new TypeBinding("volumeCopyCandidate", new ArraySpec(m_TypeTable[631], 0, true, VolumeCopyCandidate.class))
		}, VolumeCopyCandidateList.class, false);

		m_TypeTable[807] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mappingRef", m_TypeTable[343]),
			new TypeBinding("workloadRef", m_TypeTable[343]),
			new TypeBinding("volumeRef", m_TypeTable[343])
		}, WorkloadVolumeMapping.class, false);

		m_TypeTable[808] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("sectorOffset", m_TypeTable[6]),
			new TypeBinding("rawCapacity", m_TypeTable[6]),
			new TypeBinding("raidLevel", m_TypeTable[36]),
			new TypeBinding("volumeGroupRef", m_TypeTable[343]),
			new TypeBinding("freeExtentRef", m_TypeTable[343]),
			new TypeBinding("reserved1", new OpaqueSpec(12, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, FreeExtent.class, false);

		m_TypeTable[809] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeGroupRef", m_TypeTable[343]),
			new TypeBinding("label", m_TypeTable[337])
		}, VolumeGroupLabelUpdateDescriptor.class, false);

		m_TypeTable[810] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ipv4Address", new ArraySpec(m_TypeTable[560], 0, true, String.class))
		}, NVMeInterfaceChangeableProperties.class, false);

		m_TypeTable[811] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaces", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("ipv4ReceivedPdus", m_TypeTable[6]),
			new TypeBinding("ipv4SentPdus", m_TypeTable[6]),
			new TypeBinding("ipv4ReassembledPackets", m_TypeTable[6]),
			new TypeBinding("ipv4Fragmentation", m_TypeTable[6]),
			new TypeBinding("ipv4FragmentedPdusCreates", m_TypeTable[6]),
			new TypeBinding("ipv4TxByteCount", m_TypeTable[6]),
			new TypeBinding("ipv4RxByteCount", m_TypeTable[6]),
			new TypeBinding("ipv4RxErrorCount", m_TypeTable[6]),
			new TypeBinding("ipv4OverlappedFragCount", m_TypeTable[6]),
			new TypeBinding("ipv4OutOfOrderFragCount", m_TypeTable[6]),
			new TypeBinding("ipv4TimeoutCount", m_TypeTable[6]),
			new TypeBinding("ipv6ReceivedPdus", m_TypeTable[6]),
			new TypeBinding("ipv6SentPdus", m_TypeTable[6]),
			new TypeBinding("ipv6ReassembledPackets", m_TypeTable[6]),
			new TypeBinding("ipv6Fragmentation", m_TypeTable[6]),
			new TypeBinding("ipv6FragmentedPdusCreates", m_TypeTable[6]),
			new TypeBinding("ipv6TxByteCount", m_TypeTable[6]),
			new TypeBinding("ipv6RxByteCount", m_TypeTable[6]),
			new TypeBinding("ipv6RxErrorCount", m_TypeTable[6]),
			new TypeBinding("ipv6OverlappedFragCount", m_TypeTable[6]),
			new TypeBinding("ipv6OutOfOrderFragCount", m_TypeTable[6]),
			new TypeBinding("ipv6TimeoutCount", m_TypeTable[6])
		}, IpEndpointStatistics.class, false);

		m_TypeTable[812] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupRef", m_TypeTable[343]),
			new TypeBinding("requestedTestType", m_TypeTable[261]),
			new TypeBinding("testIterations", m_TypeTable[7]),
			new TypeBinding("timeout", m_TypeTable[7])
		}, AsyncMirrorGroupConnectivityTestDescriptor.class, false);

		m_TypeTable[813] = new UnionSpec(true, "expanderParentType", m_TypeTable[30], new AlternateBinding[] {
			new AlternateBinding(2, "parentController", m_TypeTable[315]),
			new AlternateBinding(3, "parentEsm", m_TypeTable[343]),
			new AlternateBinding(4, "parentDrawer", m_TypeTable[343])
		}, SasExpanderParent.class);

		m_TypeTable[814] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumePerf", new ArraySpec(m_TypeTable[659], 0, true, VolumePerformance.class))
		}, VolumePerformanceList.class, false);

		m_TypeTable[815] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupTag", m_TypeTable[4]),
			new TypeBinding("ipAddress", m_TypeTable[700]),
			new TypeBinding("tcpListenPort", m_TypeTable[7])
		}, TargetPortal.class, false);

		m_TypeTable[816] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeGroupRef", m_TypeTable[343]),
			new TypeBinding("driveRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, VolumeGroupExpansionDescriptor.class, false);

		m_TypeTable[817] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, DriveRefList.class, false);

		m_TypeTable[818] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "iocAttributes", new ArraySpec(m_TypeTable[748], 0, true, IbIocAttributes.class))
		}, IbIocAttributesReturned.class);

		m_TypeTable[819] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("portals", new ArraySpec(m_TypeTable[815], 0, true, TargetPortal.class))
		}, IscsiInitiatorTargetBaseParameters.class, false);

		m_TypeTable[820] = new UnionSpec(true, "type", m_TypeTable[44], new AlternateBinding[] {
			new AlternateBinding(2, "initiatorRef", m_TypeTable[343]),
			new AlternateBinding(1, "targetRef", m_TypeTable[343])
		}, GetIscsiSessionsFilter.class);

		m_TypeTable[821] = new UnionSpec(true, "sfpParentType", m_TypeTable[211], new AlternateBinding[] {
			new AlternateBinding(3, "controllerSFP", m_TypeTable[662]),
			new AlternateBinding(1, "parentEsm", m_TypeTable[343]),
			new AlternateBinding(2, "parentMinihub", m_TypeTable[343])
		}, SFPParentTypeData.class);

		m_TypeTable[822] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("pitRef", m_TypeTable[343]),
			new TypeBinding("pitGroupRef", m_TypeTable[343]),
			new TypeBinding("creationMethod", m_TypeTable[20]),
			new TypeBinding("pitTimestamp", m_TypeTable[6]),
			new TypeBinding("pitSequenceNumber", m_TypeTable[6]),
			new TypeBinding("status", m_TypeTable[150]),
			new TypeBinding("activeCOW", m_TypeTable[0]),
			new TypeBinding("isRollbackSource", m_TypeTable[0]),
			new TypeBinding("pitCapacity", m_TypeTable[6]),
			new TypeBinding("repositoryCapacityUtilization", m_TypeTable[6])
		}, PIT.class, false);

		m_TypeTable[823] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("acquisitionProperties", m_TypeTable[787]),
			new TypeBinding("dhcpAcquiredDnsServers", new ArraySpec(m_TypeTable[700], 2, true, IpVxAddress.class))
		}, ControllerDNSProperties.class, false);

		m_TypeTable[824] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("remoteVolume", m_TypeTable[343]),
			new TypeBinding("numSamples", m_TypeTable[7])
		}, RemoteCommunicationCheckDescriptor.class, false);

		m_TypeTable[825] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("clusterRef", m_TypeTable[343]),
			new TypeBinding("settings", m_TypeTable[734])
		}, HostCreationDescriptor.class, false);
	}

	private static void __init12() {

		m_TypeTable[826] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("associatedObject", m_TypeTable[756])
		}, KeyValueTagMappingDeletionDescriptor.class, false);

		m_TypeTable[827] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveRef", m_TypeTable[343]),
			new TypeBinding("driveTemperature", m_TypeTable[623])
		}, DriveTemperatureData.class, false);

		m_TypeTable[828] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupRef", m_TypeTable[343]),
			new TypeBinding("force", m_TypeTable[0])
		}, AsyncMirrorGroupDeletionDescriptor.class, false);

		m_TypeTable[829] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("snapshotRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, SnapshotRefList.class, false);

		m_TypeTable[830] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("cwob", m_TypeTable[0]),
			new TypeBinding("mirrorEnable", m_TypeTable[0]),
			new TypeBinding("readCacheEnable", m_TypeTable[0]),
			new TypeBinding("writeCacheEnable", m_TypeTable[0]),
			new TypeBinding("cacheFlushModifier", m_TypeTable[188]),
			new TypeBinding("readAheadMultiplier", m_TypeTable[7])
		}, VolumeCacheParamsUpdateDescriptor.class, false);

		m_TypeTable[831] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("settings", m_TypeTable[365])
		}, VolumePropertiesUpdateDescriptor.class, false);

		m_TypeTable[832] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "portPartitionTables", new ArraySpec(m_TypeTable[728], 0, true, IbPortPartitionTable.class))
		}, IbPortPartitionTablesReturned.class);

		m_TypeTable[833] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("policy", m_TypeTable[23])
		}, ThinVolumeExpansionPolicyUpdateDescriptor.class, false);

		m_TypeTable[834] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mirrorGroup", m_TypeTable[343]),
			new TypeBinding("faultTime", m_TypeTable[6])
		}, AsyncMirrorGroupFaultIndication.class, false);

		m_TypeTable[835] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volCopyRef", m_TypeTable[343]),
			new TypeBinding("copyPriority", m_TypeTable[77]),
			new TypeBinding("idleTargetWriteProt", m_TypeTable[0])
		}, VolumeCopyParamsUpdateDescriptor.class, false);

		m_TypeTable[836] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("createDescriptor", new ArraySpec(m_TypeTable[772], 0, true, WorkloadVolumeCreateMappingDescriptor.class))
		}, WorkloadVolumeCreateMappingDescriptorList.class, false);

		m_TypeTable[837] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("scheduleRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, ScheduleRefList.class, false);

		m_TypeTable[838] = new UnionSpec(true, "flashCacheType", m_TypeTable[92], "fcWithDrives", m_TypeTable[584], new AlternateBinding[] {
		}, FlashCacheDriveInfo.class);

		m_TypeTable[839] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("pitGroupRef", m_TypeTable[343]),
			new TypeBinding("pitGroupLabel", m_TypeTable[337]),
			new TypeBinding("repFullPolicy", m_TypeTable[19]),
			new TypeBinding("fullWarnThreshold", m_TypeTable[7]),
			new TypeBinding("autoDeleteLimit", m_TypeTable[7]),
			new TypeBinding("rollbackPriority", m_TypeTable[139])
		}, PITGroupParamsUpdateDescriptor.class, false);

		m_TypeTable[840] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveToReplace", m_TypeTable[343]),
			new TypeBinding("replacementDrive", m_TypeTable[343])
		}, DriveReplacementDescriptor.class, false);

		m_TypeTable[841] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveRef", m_TypeTable[343]),
			new TypeBinding("physicalSecurityID", new OpaqueSpec(32, false, OpaqueSpec.DataType.BINARY))
		}, DrivePhysicalSecurityId.class, false);

		m_TypeTable[842] = new UnionSpec(true, "testType", m_TypeTable[261], new AlternateBinding[] {
			new AlternateBinding(2, "linkTestResults", m_TypeTable[375]),
			new AlternateBinding(3, "bandwidthTestResults", m_TypeTable[620])
		}, AsyncMirrorGroupConnectivityTestResults.class);

		m_TypeTable[843] = new UnionSpec(true, "portRefType", m_TypeTable[66], new AlternateBinding[] {
			new AlternateBinding(1, "hicRef", m_TypeTable[343]),
			new AlternateBinding(2, "baseBoardRef", m_TypeTable[343])
		}, PortsRefTypeData.class);

		m_TypeTable[844] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("manager", m_TypeTable[315]),
			new TypeBinding("capacity", m_TypeTable[6]),
			new TypeBinding("raidLevel", m_TypeTable[36]),
			new TypeBinding("segmentSize", m_TypeTable[7]),
			new TypeBinding("readAhead", m_TypeTable[7]),
			new TypeBinding("offset", m_TypeTable[6]),
			new TypeBinding("volumeGroupNumber", m_TypeTable[7]),
			new TypeBinding("driveCount", m_TypeTable[7]),
			new TypeBinding("driveRefList", m_TypeTable[817]),
			new TypeBinding("volumeGroupLabel", m_TypeTable[337]),
			new TypeBinding("volumeWWN", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("volumeSSID", m_TypeTable[7]),
			new TypeBinding("dssPreallocEnabled", m_TypeTable[0]),
			new TypeBinding("protectionType", m_TypeTable[136]),
			new TypeBinding("allocateReservedSpace", m_TypeTable[0])
		}, RecoverVolumeDescriptor.class, false);

		m_TypeTable[845] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupRef", m_TypeTable[343])
		}, ConsistencyGroup.class, false);

		m_TypeTable[846] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("pitRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, PITRefList.class, false);

		m_TypeTable[847] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("newSegmentSize", m_TypeTable[7])
		}, VolumeSegmentSizingDescriptor.class, false);

		m_TypeTable[848] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("esmLostRedundancy", m_TypeTable[343]),
			new TypeBinding("workingChannel", m_TypeTable[7])
		}, EsmLostRedundancyFailure.class, false);

		m_TypeTable[849] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("thermalSensorRef", m_TypeTable[343]),
			new TypeBinding("currentTemp", m_TypeTable[7])
		}, ThermalSensorData.class, false);

		m_TypeTable[850] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("state", m_TypeTable[79]),
			new TypeBinding("reason", m_TypeTable[231]),
			new TypeBinding("degradingController", m_TypeTable[315]),
			new TypeBinding("statsControllerA", m_TypeTable[675]),
			new TypeBinding("statsControllerB", m_TypeTable[675])
		}, DriveChannel.class, false);

		m_TypeTable[851] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "clusterPerformanceLimitationValues", m_TypeTable[502])
		}, ClusterPerformanceLimitationValuesReturned.class);

		m_TypeTable[852] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("observationTime", m_TypeTable[6]),
			new TypeBinding("objectRef", m_TypeTable[641]),
			new TypeBinding("dts", new ArraySpec(m_TypeTable[450], 0, true, DiscreteTimeSeries.class))
		}, DiscreteTimeSeriesBundle.class, false);

		m_TypeTable[853] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("mirrorProxy", m_TypeTable[343]),
			new TypeBinding("writeMode", m_TypeTable[177]),
			new TypeBinding("consistencyGroupRef", m_TypeTable[343])
		}, MirrorWriteModeDescriptor.class, false);

		m_TypeTable[854] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostPortName", m_TypeTable[311]),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("hostPortTypeIndex", m_TypeTable[7]),
			new TypeBinding("hostRef", m_TypeTable[343]),
			new TypeBinding("settings", m_TypeTable[757])
		}, HostPortCreationDescriptor.class, false);

		m_TypeTable[855] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("pitRef", m_TypeTable[343]),
			new TypeBinding("bytesUsed", m_TypeTable[6])
		}, PITRepositoryUtilization.class, false);

		m_TypeTable[856] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("returnCode", m_TypeTable[152]),
			new TypeBinding("overallRLSTime", m_TypeTable[6]),
			new TypeBinding("controllers", new ArraySpec(m_TypeTable[790], 0, true, RLSData.class)),
			new TypeBinding("drives", new ArraySpec(m_TypeTable[790], 0, true, RLSData.class)),
			new TypeBinding("esms", new ArraySpec(m_TypeTable[790], 0, true, RLSData.class))
		}, RLSResults.class, false);

		m_TypeTable[857] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("drive", m_TypeTable[343]),
			new TypeBinding("volumeGroup", m_TypeTable[343])
		}, PvgRecoveryData.class, false);

		m_TypeTable[858] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "iscsiCableDiagResults", m_TypeTable[746])
		}, IscsiCableDiagnosticsReturn.class);

		m_TypeTable[859] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("stagedFwValid", m_TypeTable[0]),
			new TypeBinding("fwVersion", new OpaqueSpec(4, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("appVersion", new OpaqueSpec(4, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("bootVersion", new OpaqueSpec(4, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("nvsramVersion", new OpaqueSpec(17, false, OpaqueSpec.DataType.SBCS)),
			new TypeBinding("timeStamp", m_TypeTable[6]),
			new TypeBinding("nvsramVersionString", new StringSpec(0)),
			new TypeBinding("codeVersions", new ArraySpec(m_TypeTable[523], 0, true, VersionDescriptor.class))
		}, StagedFirmware.class, false);

		m_TypeTable[860] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("pitGroupRef", m_TypeTable[343]),
			new TypeBinding("retainRepositoryMembers", m_TypeTable[0])
		}, PITGroupDeletionDescriptor.class, false);

		m_TypeTable[861] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("kmsAddress", m_TypeTable[786]),
			new TypeBinding("kmsPort", m_TypeTable[7])
		}, ExternalKMSEndpoint.class, false);

		m_TypeTable[862] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("needsAttention", m_TypeTable[0]),
			new TypeBinding("fixing", m_TypeTable[0]),
			new TypeBinding("saId", m_TypeTable[366]),
			new TypeBinding("managementClassName", new StringSpec(0)),
			new TypeBinding("storageArrayLabel", m_TypeTable[337]),
			new TypeBinding("bootTime", m_TypeTable[6]),
			new TypeBinding("fwVersion", new OpaqueSpec(4, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("appVersion", new OpaqueSpec(4, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("bootVersion", new OpaqueSpec(4, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("nvsramVersion", new StringSpec(0)),
			new TypeBinding("fwPrefix", new StringSpec(15)),
			new TypeBinding("chassisSerialNumber", new StringSpec(0)),
			new TypeBinding("eventConfigurationDataVersion", new StringSpec(0)),
			new TypeBinding("arrayAttributes", new ArraySpec(m_TypeTable[7], 0, true, int.class)),
			new TypeBinding("res4", new ArraySpec(m_TypeTable[7], 0, true, int.class)),
			new TypeBinding("res5", new ArraySpec(m_TypeTable[7], 0, true, int.class)),
			new TypeBinding("res6", new ArraySpec(m_TypeTable[7], 0, true, int.class)),
			new TypeBinding("res7", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("extendedSAData", m_TypeTable[773])
		}, SAData.class, false);

		m_TypeTable[863] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "testResults", m_TypeTable[842]),
			new AlternateBinding(717, "mismatchMembers", m_TypeTable[769])
		}, AsyncMirrorGroupConnectivityTestResultsReturned.class);

		m_TypeTable[864] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("pitGroupRef", m_TypeTable[343]),
			new TypeBinding("pitRef", m_TypeTable[343]),
			new TypeBinding("pending", m_TypeTable[0]),
			new TypeBinding("percentComplete", m_TypeTable[7]),
			new TypeBinding("timeToCompletion", m_TypeTable[7])
		}, PITRollbackOperation.class, false);

		m_TypeTable[865] = new UnionSpec(true, "rawDataTransferType", m_TypeTable[194], new AlternateBinding[] {
			new AlternateBinding(1, "dq", m_TypeTable[348]),
			new AlternateBinding(3, "dbmRec", m_TypeTable[550]),
			new AlternateBinding(2, "dbmBlk", m_TypeTable[472]),
			new AlternateBinding(4, "dbmCheck", m_TypeTable[531]),
			new AlternateBinding(5, "enclosureStateCapture", m_TypeTable[520]),
			new AlternateBinding(6, "dplCoreDump", m_TypeTable[298]),
			new AlternateBinding(7, "ioStatistics", m_TypeTable[378]),
			new AlternateBinding(8, "fdiDemsLog", m_TypeTable[288]),
			new AlternateBinding(9, "drivePerformanceHistory", m_TypeTable[333]),
			new AlternateBinding(10, "iocDump", m_TypeTable[456]),
			new AlternateBinding(11, "driveHealthLogs", m_TypeTable[509]),
			new AlternateBinding(12, "ctrlPerfStats", m_TypeTable[510]),
			new AlternateBinding(16, "dom0DataChunkDetails", m_TypeTable[427]),
			new AlternateBinding(17, "wlcAnalyticsChunkDetails", m_TypeTable[299]),
			new AlternateBinding(18, "autoLoadBalanceStatistics", m_TypeTable[291])
		}, RawDataRetrieveChunkDetails.class);

		m_TypeTable[866] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("capability", m_TypeTable[153]),
			new TypeBinding("isEnabled", m_TypeTable[0]),
			new TypeBinding("isCompliant", m_TypeTable[0]),
			new TypeBinding("isWithinLimits", m_TypeTable[0]),
			new TypeBinding("featureId", m_TypeTable[124]),
			new TypeBinding("featureRef", m_TypeTable[343]),
			new TypeBinding("limit", m_TypeTable[7]),
			new TypeBinding("duration", m_TypeTable[7]),
			new TypeBinding("enabledTime", m_TypeTable[6]),
			new TypeBinding("supportedFeatureBundleId", m_TypeTable[7]),
			new TypeBinding("permanentLicenseApplied", m_TypeTable[0])
		}, FeatureState.class, false);

		m_TypeTable[867] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeGroupRef", m_TypeTable[343]),
			new TypeBinding("driveRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, DiskPoolExpansionDescriptor.class, false);

		m_TypeTable[868] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("drives", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("trayLossProtection", m_TypeTable[0]),
			new TypeBinding("wastedCapacity", m_TypeTable[6]),
			new TypeBinding("spindleSpeedMatch", m_TypeTable[0]),
			new TypeBinding("drawerLossProtection", m_TypeTable[0]),
			new TypeBinding("usableCapacity", m_TypeTable[6]),
			new TypeBinding("driveBlockFormat", m_TypeTable[72])
		}, VolumeGroupExpansionCandidate.class, false);

		m_TypeTable[869] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("defaultHostTypeIndex", new ArraySpec(m_TypeTable[7], 1, true, int.class)),
			new TypeBinding("nextBatteryLearnCycle", new ArraySpec(m_TypeTable[6], 1, true, long.class)),
			new TypeBinding("syslogEnabled", new ArraySpec(m_TypeTable[0], 1, true, boolean.class)),
			new TypeBinding("syslogServerIpAddress", new ArraySpec(m_TypeTable[700], 1, true, IpVxAddress.class)),
			new TypeBinding("syslogServerPortNumber", new ArraySpec(m_TypeTable[7], 1, true, int.class))
		}, StorageArrayChangeableProperties.class, false);

		m_TypeTable[870] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("name", new StringSpec(0)),
			new TypeBinding("bundledFeatures", new ArraySpec(m_TypeTable[744], 0, true, BundledFeature.class)),
			new TypeBinding("bundleSubmodelId", new StringSpec(0))
		}, FeatureBundle.class, false);

		m_TypeTable[871] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupRef", m_TypeTable[343])
		}, AsyncMirrorGroupSuspendDescriptor.class, false);

		m_TypeTable[872] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("connectedPorts", new ArraySpec(m_TypeTable[573], 0, true, ChannelPortPair.class)),
			new TypeBinding("requiredPorts", new ArraySpec(m_TypeTable[573], 0, true, ChannelPortPair.class))
		}, FibreTrunkMiswire.class, false);

		m_TypeTable[873] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("authMethodData", new ArraySpec(m_TypeTable[747], 0, true, AuthMethodTypeData.class))
		}, AuthenticationBundle.class, false);

		m_TypeTable[874] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("lun", m_TypeTable[7]),
			new TypeBinding("clusterRef", m_TypeTable[343]),
			new TypeBinding("hostRef", m_TypeTable[343]),
			new TypeBinding("reservationTypeID", m_TypeTable[236]),
			new TypeBinding("registrantList", m_TypeTable[798]),
			new TypeBinding("ptpl_A", m_TypeTable[0])
		}, PersistentRegistration.class, false);

		m_TypeTable[875] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveLostRedundancy", m_TypeTable[343]),
			new TypeBinding("workingChannel", m_TypeTable[7]),
			new TypeBinding("failedEsm", m_TypeTable[343])
		}, DriveLostRedundancyFailure.class, false);

		m_TypeTable[876] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeGroupRef", m_TypeTable[343]),
			new TypeBinding("newRaidLevel", m_TypeTable[36])
		}, VolumeRAIDMigrationDescriptor.class, false);

		m_TypeTable[877] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("timeData", m_TypeTable[517]),
			new TypeBinding("ibInterfaceStatisticsRaw", new ArraySpec(m_TypeTable[732], 0, true, EnhancedIbInterfaceStatistics.class)),
			new TypeBinding("ibInterfaceStatisticsRel", new ArraySpec(m_TypeTable[732], 0, true, EnhancedIbInterfaceStatistics.class))
		}, EnhancedIbBaselinedStatistics.class, false);

		m_TypeTable[878] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("tcpListenPort", new ArraySpec(m_TypeTable[7], 1, true, int.class)),
			new TypeBinding("ipv4Address", new ArraySpec(m_TypeTable[560], 1, true, String.class)),
			new TypeBinding("ipv4SubnetMask", new ArraySpec(m_TypeTable[560], 1, true, String.class)),
			new TypeBinding("ipv4GatewayAddress", new ArraySpec(m_TypeTable[560], 1, true, String.class)),
			new TypeBinding("ipv4AddressConfigMethod", new ArraySpec(m_TypeTable[259], 1, true, IpV4ConfigMethod.class)),
			new TypeBinding("maximumFramePayloadSize", new ArraySpec(m_TypeTable[7], 1, true, int.class)),
			new TypeBinding("ipv4VlanId", new ArraySpec(m_TypeTable[548], 1, true, SettingControl.class)),
			new TypeBinding("ipv4OutboundPacketPriority", new ArraySpec(m_TypeTable[548], 1, true, SettingControl.class)),
			new TypeBinding("ipv4Enabled", new ArraySpec(m_TypeTable[0], 1, true, boolean.class)),
			new TypeBinding("ipv6Enabled", new ArraySpec(m_TypeTable[0], 1, true, boolean.class)),
			new TypeBinding("ipv6LocalAddresses", new ArraySpec(m_TypeTable[714], 1, true, IpV6AddressDataBundle.class)),
			new TypeBinding("ipv6RoutableAddresses", new ArraySpec(m_TypeTable[714], 1, true, IpV6AddressDataBundle.class)),
			new TypeBinding("ipv6PortRouterAddress", new ArraySpec(m_TypeTable[649], 1, true, IpV6AddressData.class)),
			new TypeBinding("ipv6AddressConfigMethod", new ArraySpec(m_TypeTable[263], 1, true, IpV6ConfigMethod.class)),
			new TypeBinding("ipv6OutboundPacketPriority", new ArraySpec(m_TypeTable[548], 1, true, SettingControl.class)),
			new TypeBinding("ipv6VlanId", new ArraySpec(m_TypeTable[548], 1, true, SettingControl.class)),
			new TypeBinding("ipv6HopLimit", new ArraySpec(m_TypeTable[4], 1, true, short.class)),
			new TypeBinding("ipv6NdReachableTime", new ArraySpec(m_TypeTable[7], 1, true, int.class)),
			new TypeBinding("ipv6NdRetransmitTime", new ArraySpec(m_TypeTable[7], 1, true, int.class)),
			new TypeBinding("ipv6NdStaleTimeout", new ArraySpec(m_TypeTable[7], 1, true, int.class)),
			new TypeBinding("ipv6DuplicateAddressDetectionAttempts", new ArraySpec(m_TypeTable[4], 1, true, short.class)),
			new TypeBinding("maximumInterfaceSpeed", new ArraySpec(m_TypeTable[149], 1, true, InterfaceSpeed.class))
		}, IscsiInterfaceChangeableProperties.class, false);

		m_TypeTable[879] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("saPortRef", m_TypeTable[343]),
			new TypeBinding("saPortGroupRef", m_TypeTable[343]),
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("portId", m_TypeTable[7])
		}, SAPort.class, false);

		m_TypeTable[880] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("saPortGroupRef", m_TypeTable[343]),
			new TypeBinding("label", m_TypeTable[337])
		}, SAPortGroup.class, false);

		m_TypeTable[881] = new UnionSpec(true, "addressType", m_TypeTable[273], new AlternateBinding[] {
			new AlternateBinding(0, "ipv4Data", m_TypeTable[610]),
			new AlternateBinding(1, "ipv6Data", m_TypeTable[649])
		}, IpVxAddressData.class);

		m_TypeTable[882] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("downloadSet", new ArraySpec(m_TypeTable[694], 0, true, DriveDownloadSet.class)),
			new TypeBinding("online", m_TypeTable[0])
		}, DriveFirmwareDownload.class, false);

		m_TypeTable[883] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("remoteNodeWWN", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("baseVolume", m_TypeTable[343]),
			new TypeBinding("remoteNodeName", m_TypeTable[648])
		}, MirrorCandidateDescriptor.class, false);

		m_TypeTable[884] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("settings", m_TypeTable[869])
		}, StorageArrayPropertiesUpdateDescriptor.class, false);

		m_TypeTable[885] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveRef", m_TypeTable[343])
		}, PowerCyclePhysicalDriveDescriptor.class, false);

		m_TypeTable[886] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "rdmaChannels", new ArraySpec(m_TypeTable[775], 0, true, IbRdmaChannel.class))
		}, IbRdmaChannelsReturned.class);

		m_TypeTable[887] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("iscsiInterface", m_TypeTable[343]),
			new TypeBinding("settings", m_TypeTable[878])
		}, IscsiInterfacePropertiesUpdateDescriptor.class, false);

		m_TypeTable[888] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trayRef", m_TypeTable[343]),
			new TypeBinding("slot", m_TypeTable[7]),
			new TypeBinding("locationParent", m_TypeTable[641]),
			new TypeBinding("locationPosition", m_TypeTable[7]),
			new TypeBinding("label", new OpaqueSpec(0, true, OpaqueSpec.DataType.SBCS))
		}, Location.class, false);

		m_TypeTable[889] = new UnionSpec(true, "reason", m_TypeTable[89], new AlternateBinding[] {
			new AlternateBinding(1, "fwLocation", m_TypeTable[587]),
			new AlternateBinding(2, "panicReason", new StringSpec(0))
		}, DPLCoreDumpDetail.class);

		m_TypeTable[890] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("sessionDefaults", m_TypeTable[301]),
			new TypeBinding("connectionDefaults", m_TypeTable[598])
		}, IscsiNegotiationDefaults.class, false);

		m_TypeTable[891] = new UnionSpec(true, "ioInterfaceType", m_TypeTable[276], new AlternateBinding[] {
			new AlternateBinding(2, "portName", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new AlternateBinding(6, "ibPortName", m_TypeTable[374]),
			new AlternateBinding(5, "iscsiPortName", m_TypeTable[575]),
			new AlternateBinding(4, "sasPortName", m_TypeTable[379])
		}, SCSITargetPortId.class);

		m_TypeTable[892] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controller", m_TypeTable[315]),
			new TypeBinding("driveChannel", m_TypeTable[7]),
			new TypeBinding("devices", new ArraySpec(m_TypeTable[765], 0, true, ChannelDiagDevice.class)),
			new TypeBinding("maxTimeInterval", m_TypeTable[7]),
			new TypeBinding("diagParams", m_TypeTable[420])
		}, ChannelDiagnosticDescriptor.class, false);

		m_TypeTable[893] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("worldWideName", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("remoteVolRef", m_TypeTable[343]),
			new TypeBinding("manager", m_TypeTable[315]),
			new TypeBinding("remoteArrayId", m_TypeTable[366]),
			new TypeBinding("remoteNodeWWN", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("remoteVolWWN", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("remoteVolUserLabel", m_TypeTable[337]),
			new TypeBinding("remoteVolState", m_TypeTable[108]),
			new TypeBinding("remoteVolCapacity", m_TypeTable[6]),
			new TypeBinding("volumeHandle", m_TypeTable[7]),
			new TypeBinding("perms", m_TypeTable[345]),
			new TypeBinding("reserved1", new OpaqueSpec(12, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("remoteNodeName", m_TypeTable[648]),
			new TypeBinding("remoteVolSecurityType", m_TypeTable[173])
		}, RemoteVolume.class, false);

		m_TypeTable[894] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("objectRef", m_TypeTable[641]),
			new TypeBinding("streamType", m_TypeTable[248]),
			new TypeBinding("duration", m_TypeTable[7])
		}, DiscreteTimeSeriesDescriptor.class, false);

		m_TypeTable[895] = new UnionSpec(true, "groupType", m_TypeTable[238], new AlternateBinding[] {
			new AlternateBinding(0, "drvCounterGroup", m_TypeTable[354]),
			new AlternateBinding(1, "implCounterGroup", m_TypeTable[484]),
			new AlternateBinding(2, "ioCounterGroup", m_TypeTable[727]),
			new AlternateBinding(3, "volCounterGroup", m_TypeTable[328]),
			new AlternateBinding(4, "controllerCounterGroup", m_TypeTable[596]),
			new AlternateBinding(5, "interfaceCounterGroup", m_TypeTable[455])
		}, CounterGroup.class);

		m_TypeTable[896] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("enabled", m_TypeTable[0]),
			new TypeBinding("volumeHandle", m_TypeTable[7]),
			new TypeBinding("capacity", m_TypeTable[6]),
			new TypeBinding("accessVolumeRef", m_TypeTable[343]),
			new TypeBinding("reserved1", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, AccessVolume.class, false);

		m_TypeTable[897] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("baseVolume", m_TypeTable[343]),
			new TypeBinding("remoteNodeWWN", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("remoteVolWWN", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("syncPriority", m_TypeTable[14]),
			new TypeBinding("remotePassword", m_TypeTable[466]),
			new TypeBinding("writeMode", m_TypeTable[177]),
			new TypeBinding("autoResyncFlag", m_TypeTable[0]),
			new TypeBinding("consistencyGroupRef", m_TypeTable[343]),
			new TypeBinding("remoteNodeName", m_TypeTable[648])
		}, MirrorCreationDescriptor.class, false);

		m_TypeTable[898] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cacheMemoryDimmRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[284]),
			new TypeBinding("capacityInMegabytes", m_TypeTable[7]),
			new TypeBinding("serialNumber", new StringSpec(0)),
			new TypeBinding("partNumber", new StringSpec(0)),
			new TypeBinding("oemPartNumber", new StringSpec(0)),
			new TypeBinding("manufacturerPartNumber", new StringSpec(0)),
			new TypeBinding("manufacturer", new StringSpec(0)),
			new TypeBinding("manufactureDate", m_TypeTable[6]),
			new TypeBinding("repairPolicy", m_TypeTable[799]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("shared", m_TypeTable[0]),
			new TypeBinding("revisionCode", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, CacheMemoryDimm.class, false);

		m_TypeTable[899] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("alias", new ArraySpec(m_TypeTable[483], 1, true, ScsiAlias.class)),
			new TypeBinding("configuredAuthMethods", new ArraySpec(m_TypeTable[873], 1, true, AuthenticationBundle.class))
		}, TargetChangeableProperties.class, false);

		m_TypeTable[900] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("repositoryUsage", m_TypeTable[6]),
			new TypeBinding("snapRef", m_TypeTable[343])
		}, RepositoryUtilization.class, false);

		m_TypeTable[901] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mirrorVolume", m_TypeTable[343])
		}, MirrorUnsynchronized.class, false);

		m_TypeTable[902] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("nvmeInterface", m_TypeTable[343]),
			new TypeBinding("settings", m_TypeTable[810])
		}, NVMeInterfacePropertiesUpdateDescriptor.class, false);

		m_TypeTable[903] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("snapshotRef", m_TypeTable[343]),
			new TypeBinding("pending", m_TypeTable[0]),
			new TypeBinding("percentComplete", m_TypeTable[7]),
			new TypeBinding("timeToCompletion", m_TypeTable[7])
		}, SnapshotRollbackOperation.class, false);

		m_TypeTable[904] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trapReceiverIpAddress", m_TypeTable[700]),
			new TypeBinding("communityRef", m_TypeTable[343]),
			new TypeBinding("sendAuthenticationFailureTraps", m_TypeTable[0])
		}, SNMPTrapDestinationAddDescriptor.class, false);

		m_TypeTable[905] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("overallStatus", m_TypeTable[152]),
			new TypeBinding("driveStatus", new ArraySpec(m_TypeTable[668], 0, true, DriveDownloadDriveStatus.class))
		}, DriveFirmwareStatus.class, false);

		m_TypeTable[906] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("degradedPaths", new ArraySpec(m_TypeTable[665], 0, true, DegradedPath.class))
		}, PathDegradedFailure.class, false);

		m_TypeTable[907] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("tcpPort", m_TypeTable[7]),
			new TypeBinding("ipAddress", m_TypeTable[700])
		}, TcpProtocolEndpoint.class, false);

		m_TypeTable[908] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("drawerRef", m_TypeTable[343]),
			new TypeBinding("isOpen", m_TypeTable[0]),
			new TypeBinding("status", m_TypeTable[184]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("repairPolicy", m_TypeTable[799]),
			new TypeBinding("softwareVersion", new StringSpec(0)),
			new TypeBinding("partNumber", new StringSpec(0)),
			new TypeBinding("serialNumber", new StringSpec(0)),
			new TypeBinding("vendorName", new StringSpec(0)),
			new TypeBinding("manufactureDate", m_TypeTable[6]),
			new TypeBinding("fruType", new StringSpec(0)),
			new TypeBinding("drawerType", new StringSpec(0))
		}, Drawer.class, false);

		m_TypeTable[909] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("settings", m_TypeTable[724])
		}, IscsiEntityPropertiesUpdateDescriptor.class, false);

		m_TypeTable[910] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("type", m_TypeTable[197]),
			new TypeBinding("orientation", m_TypeTable[58]),
			new TypeBinding("numControllerSlots", m_TypeTable[7]),
			new TypeBinding("numDriveSlots", m_TypeTable[7]),
			new TypeBinding("trayId", m_TypeTable[7]),
			new TypeBinding("trayRef", m_TypeTable[343]),
			new TypeBinding("nonRedundantAccess", m_TypeTable[0]),
			new TypeBinding("partNumber", new StringSpec(0)),
			new TypeBinding("serialNumber", new StringSpec(0)),
			new TypeBinding("vendorName", new StringSpec(0)),
			new TypeBinding("manufacturerDate", m_TypeTable[6]),
			new TypeBinding("fruType", new StringSpec(0)),
			new TypeBinding("trayIDMismatch", m_TypeTable[0]),
			new TypeBinding("trayIDConflict", m_TypeTable[0]),
			new TypeBinding("esmVersionMismatch", m_TypeTable[0]),
			new TypeBinding("esmMiswire", m_TypeTable[0]),
			new TypeBinding("drvMHSpeedMismatch", m_TypeTable[0]),
			new TypeBinding("unsupportedTray", m_TypeTable[0]),
			new TypeBinding("workingChannel", m_TypeTable[7]),
			new TypeBinding("maxSpeed", m_TypeTable[149]),
			new TypeBinding("trayTechnologyType", m_TypeTable[195]),
			new TypeBinding("esmGroupError", m_TypeTable[0]),
			new TypeBinding("uncertifiedTray", m_TypeTable[0]),
			new TypeBinding("locateTray", m_TypeTable[0]),
			new TypeBinding("esmHardwareMismatch", m_TypeTable[0]),
			new TypeBinding("hasConfigurableTrayId", m_TypeTable[0]),
			new TypeBinding("frontEndInterfaceTechnology", m_TypeTable[276]),
			new TypeBinding("driveTechnologies", new ArraySpec(m_TypeTable[21], 0, true, PhysicalDriveType.class)),
			new TypeBinding("numDriveCompartments", m_TypeTable[7]),
			new TypeBinding("numDriveSlotsPerCompartment", m_TypeTable[7]),
			new TypeBinding("trayAttributes", new ArraySpec(m_TypeTable[718], 0, true, TrayAttribute.class)),
			new TypeBinding("isMisconfigured", m_TypeTable[0]),
			new TypeBinding("esmFactoryDefaultsMismatch", m_TypeTable[0]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("numDrawers", m_TypeTable[7]),
			new TypeBinding("driveLayout", m_TypeTable[428]),
			new TypeBinding("factoryDefaultsData", m_TypeTable[462]),
			new TypeBinding("locateInProgress", m_TypeTable[0]),
			new TypeBinding("hasTrayIdentityIndicator", m_TypeTable[0])
		}, Tray.class, false);

		m_TypeTable[911] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("backupDeviceRef", m_TypeTable[343]),
			new TypeBinding("backupDeviceControllerSlot", m_TypeTable[7]),
			new TypeBinding("parentController", m_TypeTable[315]),
			new TypeBinding("backupDeviceType", m_TypeTable[283]),
			new TypeBinding("backupDeviceStatus", m_TypeTable[162]),
			new TypeBinding("backupDeviceVpd", m_TypeTable[323]),
			new TypeBinding("backupDeviceCapacity", m_TypeTable[7]),
			new TypeBinding("repairPolicy", m_TypeTable[799]),
			new TypeBinding("physicalLocation", m_TypeTable[888])
		}, CacheBackupDevice.class, false);

		m_TypeTable[912] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("autoConfigCandidate", new ArraySpec(m_TypeTable[672], 0, true, AutoConfigCandidate.class)),
			new TypeBinding("returnCode", m_TypeTable[152])
		}, AutoConfigCandidateList.class, false);

		m_TypeTable[913] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("remoteVolume", m_TypeTable[343])
		}, RemoteVolWWNChangeFailed.class, false);
	}

	private static void __init13() {

		m_TypeTable[914] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("loopID", m_TypeTable[7]),
			new TypeBinding("speed", m_TypeTable[7]),
			new TypeBinding("hardAddress", m_TypeTable[7]),
			new TypeBinding("nodeName", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("portName", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("portId", new OpaqueSpec(3, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("topology", m_TypeTable[269]),
			new TypeBinding("part", new StringSpec(0)),
			new TypeBinding("revision", m_TypeTable[7]),
			new TypeBinding("chanMiswire", m_TypeTable[0]),
			new TypeBinding("esmMiswire", m_TypeTable[0]),
			new TypeBinding("linkStatus", m_TypeTable[230]),
			new TypeBinding("isDegraded", m_TypeTable[0]),
			new TypeBinding("speedControl", m_TypeTable[242]),
			new TypeBinding("maxSpeed", m_TypeTable[7]),
			new TypeBinding("speedNegError", m_TypeTable[0]),
			new TypeBinding("reserved1", new OpaqueSpec(12, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("ddsChannelState", m_TypeTable[7]),
			new TypeBinding("ddsStateReason", m_TypeTable[7]),
			new TypeBinding("ddsStateWho", m_TypeTable[7]),
			new TypeBinding("isLocal", m_TypeTable[0]),
			new TypeBinding("channelPorts", new ArraySpec(m_TypeTable[446], 0, true, ChannelPorts.class)),
			new TypeBinding("currentInterfaceSpeed", m_TypeTable[149]),
			new TypeBinding("maximumInterfaceSpeed", m_TypeTable[149]),
			new TypeBinding("interfaceRef", m_TypeTable[343]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("isTrunkCapable", m_TypeTable[0]),
			new TypeBinding("trunkMiswire", m_TypeTable[0]),
			new TypeBinding("protectionInformationCapable", m_TypeTable[0]),
			new TypeBinding("oneWayMaxRate", m_TypeTable[6]),
			new TypeBinding("bidirectionalMaxRate", m_TypeTable[6])
		}, FibreInterface.class, false);

		m_TypeTable[915] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("connectedRemoteTargetPortals", new ArraySpec(m_TypeTable[815], 0, true, TargetPortal.class))
		}, IscsiRemoteTargetConnections.class, false);

		m_TypeTable[916] = new UnionSpec(true, "driveType", m_TypeTable[31], new AlternateBinding[] {
			new AlternateBinding(2, "fibre", new ArraySpec(m_TypeTable[591], 0, true, FibreDriveAddress.class)),
			new AlternateBinding(4, "sas", m_TypeTable[703]),
			new AlternateBinding(1, "scsi", m_TypeTable[436])
		}, DriveTypeData.class);

		m_TypeTable[917] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeGroupRef", m_TypeTable[343]),
			new TypeBinding("manager", m_TypeTable[315])
		}, VolumeGroupOwnershipUpdateDescriptor.class, false);

		m_TypeTable[918] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trapDestinationUpdateDescriptor", new ArraySpec(m_TypeTable[652], 0, true, SNMPTrapDestinationParamsUpdateDescriptor.class))
		}, SNMPTrapDestinationParamsUpdateDescriptorList.class, false);

		m_TypeTable[919] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controller", m_TypeTable[315]),
			new TypeBinding("baselinedStats", m_TypeTable[877])
		}, EnhancedIbStatisticalData.class, false);

		m_TypeTable[920] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("minihubRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[138]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("minihubData", m_TypeTable[503]),
			new TypeBinding("currentSpeed", m_TypeTable[149]),
			new TypeBinding("maxSpeed", m_TypeTable[149]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("portList", m_TypeTable[606]),
			new TypeBinding("vendorName", new StringSpec(0)),
			new TypeBinding("partNumber", new StringSpec(0)),
			new TypeBinding("serialNumber", new StringSpec(0)),
			new TypeBinding("fruType", new StringSpec(0)),
			new TypeBinding("manufacturerDate", m_TypeTable[6]),
			new TypeBinding("reserved1", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("rtrAttributes", m_TypeTable[750])
		}, Minihub.class, false);

		m_TypeTable[921] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("returnCode", m_TypeTable[152]),
			new TypeBinding("persistentRegistration", new ArraySpec(m_TypeTable[874], 0, true, PersistentRegistration.class))
		}, PersistentRegistrationList.class, false);

		m_TypeTable[922] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("returnCode", m_TypeTable[152]),
			new TypeBinding("driveChannels", new ArraySpec(m_TypeTable[850], 0, true, DriveChannel.class))
		}, DriveChannelList.class, false);

		m_TypeTable[923] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("enhEthTLV", new ArraySpec(m_TypeTable[667], 0, true, EnhEthTLV.class)),
			new TypeBinding("dcbxSummaryData", new ArraySpec(m_TypeTable[521], 8, true, DCBXSummaryData.class))
		}, EnhEthTLVSet.class, false);

		m_TypeTable[924] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("pitGroupBytesUsed", m_TypeTable[6]),
			new TypeBinding("pitGroupBytesAvailable", m_TypeTable[6]),
			new TypeBinding("groupRef", m_TypeTable[343]),
			new TypeBinding("pitUtilization", new ArraySpec(m_TypeTable[855], 0, true, PITRepositoryUtilization.class))
		}, PITGroupRepositoryUtilization.class, false);

		m_TypeTable[925] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("portRef", m_TypeTable[343]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("portType", m_TypeTable[270]),
			new TypeBinding("parentType", m_TypeTable[767])
		}, DriveChannelPort.class, false);

		m_TypeTable[926] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostSAConnectionRef", m_TypeTable[343]),
			new TypeBinding("srcHostId", m_TypeTable[7]),
			new TypeBinding("hostPortRef", m_TypeTable[343]),
			new TypeBinding("saPortRef", m_TypeTable[343]),
			new TypeBinding("online", m_TypeTable[0])
		}, HostSAConnection.class, false);

		m_TypeTable[927] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("rtrRef", m_TypeTable[742]),
			new TypeBinding("rtrControl", m_TypeTable[120])
		}, RTRUpdateDescriptor.class, false);

		m_TypeTable[928] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("worldWideName", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("reserved1", new OpaqueSpec(12, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, GhostVolume.class, false);

		m_TypeTable[929] = new UnionSpec(true, "refType", m_TypeTable[26], new AlternateBinding[] {
			new AlternateBinding(1, "memberVolumeRef", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new AlternateBinding(2, "memberLabel", new ArraySpec(m_TypeTable[337], 0, true, String.class))
		}, ConcatVolumeExistingVolumeCandidate.class);

		m_TypeTable[930] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volume", m_TypeTable[343]),
			new TypeBinding("amountOfIncrease", m_TypeTable[6])
		}, DVEVolume.class, false);

		m_TypeTable[931] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("installedKMSCertificateFile", new ArraySpec(m_TypeTable[265], 0, true, KMSCertificateFileType.class)),
			new TypeBinding("kmsEndpoint", m_TypeTable[861])
		}, EmbeddedExternalKMSInformation.class, false);

		m_TypeTable[932] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("mirrorProxy", m_TypeTable[343]),
			new TypeBinding("allowFlag", m_TypeTable[0])
		}, MirrorAutoResyncDescriptor.class, false);

		m_TypeTable[933] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("remoteVolume", m_TypeTable[343])
		}, RemoteVolNoArray.class, false);

		m_TypeTable[934] = new UnionSpec(true, "type", m_TypeTable[224], new AlternateBinding[] {
			new AlternateBinding(1, "ethernetData", m_TypeTable[696]),
			new AlternateBinding(2, "infinibandData", m_TypeTable[608])
		}, PhysicalInterfaceTypeData.class);

		m_TypeTable[935] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ipAddress", m_TypeTable[700]),
			new TypeBinding("isLockedOut", m_TypeTable[0])
		}, LocalUserAuthFailLockoutDesc.class, false);

		m_TypeTable[936] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ghostVol", new ArraySpec(m_TypeTable[928], 0, true, GhostVolume.class))
		}, GhostVolBundle.class, false);

		m_TypeTable[937] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ipv6LocalAddresses", new ArraySpec(m_TypeTable[649], 0, true, IpV6AddressData.class)),
			new TypeBinding("ipv6RoutableAddresses", new ArraySpec(m_TypeTable[649], 0, true, IpV6AddressData.class)),
			new TypeBinding("ipv6PortRouterAddress", m_TypeTable[649]),
			new TypeBinding("ipv6AddressConfigMethod", m_TypeTable[263]),
			new TypeBinding("ipv6OutboundPacketPriority", m_TypeTable[548]),
			new TypeBinding("ipv6VlanId", m_TypeTable[548]),
			new TypeBinding("ipv6HopLimit", m_TypeTable[4]),
			new TypeBinding("ipv6NdReachableTime", m_TypeTable[7]),
			new TypeBinding("ipv6NdRetransmitTime", m_TypeTable[7]),
			new TypeBinding("ipv6NdStaleTimeout", m_TypeTable[7]),
			new TypeBinding("ipv6DuplicateAddressDetectionAttempts", m_TypeTable[4])
		}, InternetProtocolV6Data.class, false);

		m_TypeTable[938] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("repositoryVolume", m_TypeTable[343]),
			new TypeBinding("fullPolicy", m_TypeTable[47])
		}, FullRepository.class, false);

		m_TypeTable[939] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ethernetInterface", m_TypeTable[343]),
			new TypeBinding("settings", m_TypeTable[789])
		}, EthernetInterfacePropertiesUpdateDescriptor.class, false);

		m_TypeTable[940] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("memberRef", m_TypeTable[343]),
			new TypeBinding("groupRef", m_TypeTable[343]),
			new TypeBinding("primaryVolWWN", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("primaryVolCapacity", m_TypeTable[6]),
			new TypeBinding("primaryVolRAIDLevel", m_TypeTable[36]),
			new TypeBinding("primaryVolProtectionType", m_TypeTable[136]),
			new TypeBinding("primaryVolSecurityType", m_TypeTable[173]),
			new TypeBinding("primaryVolUserLabel", m_TypeTable[337]),
			new TypeBinding("orphanIncompleteMember", m_TypeTable[0]),
			new TypeBinding("primaryVolumeParameters", m_TypeTable[400]),
			new TypeBinding("primaryVolSecurityLevel", m_TypeTable[83])
		}, AsyncMirrorGroupIncompleteMember.class, false);

		m_TypeTable[941] = new SubclassSpec(m_TypeTable[802], VolumeOperation.class);

		m_TypeTable[942] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "psuUpdateStatus", new ArraySpec(m_TypeTable[755], 0, true, PSUUpdateStatus.class))
		}, PSUFirmwareUpdateStatus.class);

		m_TypeTable[943] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("worldWideName", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("snapshotRef", m_TypeTable[343]),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("status", m_TypeTable[198]),
			new TypeBinding("action", m_TypeTable[116]),
			new TypeBinding("currentManager", m_TypeTable[315]),
			new TypeBinding("baseVolume", m_TypeTable[343]),
			new TypeBinding("repositoryVolume", m_TypeTable[343]),
			new TypeBinding("fullWarnThreshold", m_TypeTable[7]),
			new TypeBinding("overWarnThreshold", m_TypeTable[0]),
			new TypeBinding("repositoryFull", m_TypeTable[0]),
			new TypeBinding("repFullPolicy", m_TypeTable[47]),
			new TypeBinding("rollbackPriority", m_TypeTable[7]),
			new TypeBinding("extentStart", m_TypeTable[6]),
			new TypeBinding("extentSize", m_TypeTable[6]),
			new TypeBinding("snapshotTime", m_TypeTable[6]),
			new TypeBinding("perms", m_TypeTable[345]),
			new TypeBinding("childrenInactive", m_TypeTable[0]),
			new TypeBinding("volumeHandle", m_TypeTable[7]),
			new TypeBinding("mgmtClientAttribute", m_TypeTable[7]),
			new TypeBinding("rollbackStatus", m_TypeTable[137])
		}, SnapshotVolume.class, false);

		m_TypeTable[944] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("remoteVolume", m_TypeTable[343])
		}, RemoteVolNoFabric.class, false);

		m_TypeTable[945] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("sourceVolume", m_TypeTable[343]),
			new TypeBinding("targetVolume", m_TypeTable[343]),
			new TypeBinding("idleTargetWriteProt", m_TypeTable[0]),
			new TypeBinding("copyPriority", m_TypeTable[77]),
			new TypeBinding("disableSnapshot", m_TypeTable[0]),
			new TypeBinding("pgRef", m_TypeTable[343])
		}, VolumeCopyCreationDescriptor.class, false);

		m_TypeTable[946] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeGroupRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, VolumeGroupRefList.class, false);

		m_TypeTable[947] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("settings", m_TypeTable[622]),
			new TypeBinding("portsRef", m_TypeTable[843])
		}, HostPortsAttributesUpdateDescriptor.class, false);

		m_TypeTable[948] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("name", m_TypeTable[470]),
			new TypeBinding("hostIdentifier", m_TypeTable[633]),
			new TypeBinding("portIdentifier", m_TypeTable[680])
		}, NVMeInitiatorPortId.class, false);

		m_TypeTable[949] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("retCode", m_TypeTable[152]),
			new TypeBinding("utilization", new ArraySpec(m_TypeTable[900], 0, true, RepositoryUtilization.class))
		}, RepositoryUtilizationList.class, false);

		m_TypeTable[950] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeGroupRef", m_TypeTable[343]),
			new TypeBinding("groupPercentComplete", m_TypeTable[7]),
			new TypeBinding("groupTimeToCompletion", m_TypeTable[7]),
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("volumePercentComplete", m_TypeTable[7]),
			new TypeBinding("volumeTimeToCompletion", m_TypeTable[7])
		}, VolumeGroupOperation.class, false);

		m_TypeTable[951] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("dplCoreDumpTag", m_TypeTable[7]),
			new TypeBinding("captureTime", m_TypeTable[6]),
			new TypeBinding("fullCaptureSize", m_TypeTable[7]),
			new TypeBinding("AltCaptureSize", m_TypeTable[7]),
			new TypeBinding("fwVersion", new StringSpec(0)),
			new TypeBinding("platformType", new StringSpec(0)),
			new TypeBinding("fullCtlr", m_TypeTable[315]),
			new TypeBinding("fullCtlrSerialNumber", new StringSpec(0)),
			new TypeBinding("altCtlr", m_TypeTable[315]),
			new TypeBinding("altCtlrSerialNumber", new StringSpec(0)),
			new TypeBinding("triggerReason", m_TypeTable[7]),
			new TypeBinding("detail", m_TypeTable[889]),
			new TypeBinding("dom0CaptureSize", m_TypeTable[7]),
			new TypeBinding("dom0AltCaptureSize", m_TypeTable[7]),
			new TypeBinding("dom0CaptureTime", m_TypeTable[6]),
			new TypeBinding("dom0AltCaptureTime", m_TypeTable[6])
		}, DPLCoreDumpInfo.class, false);

		m_TypeTable[952] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeGroupRef", m_TypeTable[343]),
			new TypeBinding("driveRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, DiskPoolReductionDescriptor.class, false);

		m_TypeTable[953] = new UnionSpec(true, "candidateSelectionType", m_TypeTable[170], new AlternateBinding[] {
			new AlternateBinding(2, "driveRefList", m_TypeTable[817])
		}, CandidateSelectionTypeData.class);

		m_TypeTable[954] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("remoteVolume", m_TypeTable[343])
		}, RemoteVolNoLUN.class, false);

		m_TypeTable[955] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("portRefA", m_TypeTable[343]),
			new TypeBinding("portRefB", m_TypeTable[343]),
			new TypeBinding("portRefs", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, ControllerMiswireError.class, false);

		m_TypeTable[956] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("retCode", m_TypeTable[152]),
			new TypeBinding("volumeRef", m_TypeTable[343])
		}, VolumeResponse.class, false);

		m_TypeTable[957] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "driveTempData", new ArraySpec(m_TypeTable[827], 0, true, DriveTemperatureData.class))
		}, DriveTemperatureReturned.class);

		m_TypeTable[958] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("concatVolRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[103]),
			new TypeBinding("memberCount", m_TypeTable[7]),
			new TypeBinding("aggregateCapacity", m_TypeTable[6]),
			new TypeBinding("mediaScanParams", m_TypeTable[501]),
			new TypeBinding("volumeHandle", m_TypeTable[7]),
			new TypeBinding("allowedOperations", m_TypeTable[345])
		}, ConcatVolume.class, false);

		m_TypeTable[959] = new UnionSpec(true, "command", m_TypeTable[11], new AlternateBinding[] {
			new AlternateBinding(2, "channels", new ArraySpec(m_TypeTable[7], 0, true, int.class)),
			new AlternateBinding(3, "devices", m_TypeTable[752])
		}, RLSCommandDescriptor.class);

		m_TypeTable[960] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("snapRef", m_TypeTable[343]),
			new TypeBinding("warnThreshold", m_TypeTable[7]),
			new TypeBinding("extentStart", m_TypeTable[6]),
			new TypeBinding("extentSize", m_TypeTable[6]),
			new TypeBinding("repFullPolicy", m_TypeTable[47]),
			new TypeBinding("rollbackPriority", m_TypeTable[7])
		}, SnapshotParamsUpdateDescriptor.class, false);

		m_TypeTable[961] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("memberRef", m_TypeTable[343]),
			new TypeBinding("concatVolRef", m_TypeTable[343]),
			new TypeBinding("storageVolumeRef", m_TypeTable[343]),
			new TypeBinding("parentIndex", m_TypeTable[7])
		}, ConcatVolumeMember.class, false);

		m_TypeTable[962] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeGroupRef", m_TypeTable[343]),
			new TypeBinding("newDriveCount", m_TypeTable[7])
		}, DiskPoolReservedDriveCountUpdateDescriptor.class, false);

		m_TypeTable[963] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("isSwitched", m_TypeTable[0]),
			new TypeBinding("fibreEsmAddress", m_TypeTable[760])
		}, FibreEsmAttributes.class, false);

		m_TypeTable[964] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("object", m_TypeTable[756]),
			new TypeBinding("keyValueTagRefList", m_TypeTable[677])
		}, KeyValueTagMappingSetDescriptor.class, false);

		m_TypeTable[965] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("percentComplete", m_TypeTable[7]),
			new TypeBinding("timeToCompletion", m_TypeTable[7]),
			new TypeBinding("mirrorProxyRef", m_TypeTable[343])
		}, MirrorSyncOperation.class, false);

		m_TypeTable[966] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mirrorProxy", m_TypeTable[343]),
			new TypeBinding("syncPriority", m_TypeTable[14])
		}, MirrorSyncPriorityDescriptor.class, false);

		m_TypeTable[967] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trapReceiverIpAddress", m_TypeTable[700]),
			new TypeBinding("communityName", new StringSpec(0))
		}, SNMPTrapDestinationTestDescriptor.class, false);

		m_TypeTable[968] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("targetRef", m_TypeTable[343]),
			new TypeBinding("nodeName", m_TypeTable[648]),
			new TypeBinding("alias", m_TypeTable[483]),
			new TypeBinding("configuredAuthMethods", m_TypeTable[873]),
			new TypeBinding("portals", new ArraySpec(m_TypeTable[815], 0, true, TargetPortal.class))
		}, Target.class, false);

		m_TypeTable[969] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("details", m_TypeTable[706]),
			new TypeBinding("controllerRef", m_TypeTable[315])
		}, RawDataRestoreStartDesc.class, false);

		m_TypeTable[970] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ipAddress", m_TypeTable[700]),
			new TypeBinding("tcpListenPort", m_TypeTable[7])
		}, IsnsServerLocation.class, false);

		m_TypeTable[971] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveRef", m_TypeTable[343]),
			new TypeBinding("volumeGroupRefList", m_TypeTable[946])
		}, HotSpareCandidate.class, false);

		m_TypeTable[972] = new UnionSpec(true, "ioInterfaceType", m_TypeTable[276], new AlternateBinding[] {
			new AlternateBinding(5, "iSCSIInitiatorTargetBaseParameters", m_TypeTable[819]),
			new AlternateBinding(2, "nodeName", new ArraySpec(m_TypeTable[648], 1, true, ScsiNodeName.class))
		}, InitiatorTargetChangeableProperties.class);

		m_TypeTable[973] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("clientIp", m_TypeTable[700]),
			new TypeBinding("arrayId", m_TypeTable[366]),
			new TypeBinding("configGeneration", m_TypeTable[6]),
			new TypeBinding("digest", new OpaqueSpec(32, false, OpaqueSpec.DataType.BINARY))
		}, SYMbolAuthenticationHMAC256.class, false);

		m_TypeTable[974] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("supportCRURef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[179]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("manufacturerDate", m_TypeTable[6]),
			new TypeBinding("vendorName", new StringSpec(0)),
			new TypeBinding("vendorPN", new StringSpec(0)),
			new TypeBinding("vendorSN", new StringSpec(0)),
			new TypeBinding("fruType", new StringSpec(0)),
			new TypeBinding("readyToRemove", m_TypeTable[0]),
			new TypeBinding("rtrAttributes", m_TypeTable[750]),
			new TypeBinding("configuredComponents", new ArraySpec(m_TypeTable[118], 0, true, ComponentType.class)),
			new TypeBinding("type", m_TypeTable[271]),
			new TypeBinding("repairPolicy", m_TypeTable[799])
		}, SupportCRU.class, false);

		m_TypeTable[975] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("currentInterfaceSpeed", m_TypeTable[149]),
			new TypeBinding("maximumInterfaceSpeed", m_TypeTable[149]),
			new TypeBinding("speedControl", m_TypeTable[242]),
			new TypeBinding("part", new StringSpec(0)),
			new TypeBinding("revision", m_TypeTable[7]),
			new TypeBinding("interfaceRef", m_TypeTable[343]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("protectionInformationCapable", m_TypeTable[0])
		}, SATAInterface.class, false);

		m_TypeTable[976] = new UnionSpec(true, "messageType", m_TypeTable[12], new AlternateBinding[] {
			new AlternateBinding(1, "auditLogEvent", m_TypeTable[762]),
			new AlternateBinding(2, "symbolAccessChangeEvent", m_TypeTable[392]),
			new AlternateBinding(3, "dirServerStatus", m_TypeTable[705]),
			new AlternateBinding(4, "authFailLockoutEvent", m_TypeTable[935])
		}, InternalMessage.class);

		m_TypeTable[977] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("quota", m_TypeTable[6])
		}, ThinVolumeCapacityQuotaUpdateDescriptor.class, false);

		m_TypeTable[978] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("driveRef", m_TypeTable[343]),
			new TypeBinding("inUse", m_TypeTable[0]),
			new TypeBinding("volumeGroupRefList", m_TypeTable[946])
		}, HotSpareCoverage.class, false);

		m_TypeTable[979] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cgRef", m_TypeTable[343]),
			new TypeBinding("memberRef", m_TypeTable[343]),
			new TypeBinding("retainRepositoryMembers", m_TypeTable[0])
		}, PITConsistencyGroupRemoveMemberDescriptor.class, false);

		m_TypeTable[980] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("allLogEntries", m_TypeTable[0]),
			new TypeBinding("oldestEntryTimestamp", m_TypeTable[6]),
			new TypeBinding("allDrives", m_TypeTable[0]),
			new TypeBinding("driveRefs", m_TypeTable[817])
		}, FdiDemsLogRetrieveStartDetails.class, false);

		m_TypeTable[981] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("remoteRef", m_TypeTable[343]),
			new TypeBinding("remoteTargetSettings", m_TypeTable[972])
		}, InitiatorTargetPropertiesUpdateDescriptor.class, false);

		m_TypeTable[982] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("alarmRef", m_TypeTable[343]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("status", m_TypeTable[128]),
			new TypeBinding("isManageable", m_TypeTable[0]),
			new TypeBinding("rtrAttributes", m_TypeTable[750]),
			new TypeBinding("repairPolicy", m_TypeTable[799])
		}, Alarm.class, false);

		m_TypeTable[983] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hotSpareCoverage", new ArraySpec(m_TypeTable[978], 0, true, HotSpareCoverage.class)),
			new TypeBinding("returnCode", m_TypeTable[152])
		}, HotSpareCoverageList.class, false);

		m_TypeTable[984] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("consistencyGroup", new ArraySpec(m_TypeTable[845], 0, true, ConsistencyGroup.class))
		}, ConsistencyGroupBundle.class, false);

		m_TypeTable[985] = new UnionSpec(true, "type", m_TypeTable[129], new AlternateBinding[] {
			new AlternateBinding(1, "alternateController", m_TypeTable[315]),
			new AlternateBinding(0, "localController", m_TypeTable[315]),
			new AlternateBinding(2, "drive", m_TypeTable[343]),
			new AlternateBinding(3, "esm", m_TypeTable[343]),
			new AlternateBinding(4, "sfp", m_TypeTable[343]),
			new AlternateBinding(5, "physicalLocation", m_TypeTable[888]),
			new AlternateBinding(6, "drawer", m_TypeTable[343])
		}, SocConnectedDeviceTypeData.class);

		m_TypeTable[986] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("offline", m_TypeTable[0]),
			new TypeBinding("extremeProtection", m_TypeTable[0]),
			new TypeBinding("volumeHandle", m_TypeTable[7]),
			new TypeBinding("raidLevel", m_TypeTable[36]),
			new TypeBinding("sectorOffset", m_TypeTable[6]),
			new TypeBinding("worldWideName", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("blkSize", m_TypeTable[7]),
			new TypeBinding("capacity", m_TypeTable[6]),
			new TypeBinding("reconPriority", m_TypeTable[7]),
			new TypeBinding("segmentSize", m_TypeTable[7]),
			new TypeBinding("action", m_TypeTable[199]),
			new TypeBinding("cache", m_TypeTable[491]),
			new TypeBinding("mediaScan", m_TypeTable[501]),
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[107]),
			new TypeBinding("volumeGroupRef", m_TypeTable[343]),
			new TypeBinding("currentManager", m_TypeTable[315]),
			new TypeBinding("preferredManager", m_TypeTable[315]),
			new TypeBinding("perms", m_TypeTable[345]),
			new TypeBinding("mgmtClientAttribute", m_TypeTable[7]),
			new TypeBinding("dssPreallocEnabled", m_TypeTable[0]),
			new TypeBinding("dssMaxSegmentSize", m_TypeTable[7]),
			new TypeBinding("preReadRedundancyCheckEnabled", m_TypeTable[0]),
			new TypeBinding("protectionInformationCapable", m_TypeTable[0]),
			new TypeBinding("protectionType", m_TypeTable[136]),
			new TypeBinding("applicationTagOwned", m_TypeTable[0]),
			new TypeBinding("repairedBlockCount", m_TypeTable[7])
		}, Volume.class, false);

		m_TypeTable[987] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("concatVol", m_TypeTable[343]),
			new TypeBinding("trimCount", m_TypeTable[7]),
			new TypeBinding("retainRepositoryMembers", m_TypeTable[0])
		}, ConcatVolumeTrimDescriptor.class, false);

		m_TypeTable[988] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostRef", m_TypeTable[343]),
			new TypeBinding("settings", m_TypeTable[734])
		}, HostPropertiesUpdateDescriptor.class, false);

		m_TypeTable[989] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("percentComplete", m_TypeTable[7]),
			new TypeBinding("timeToCompletion", m_TypeTable[7]),
			new TypeBinding("syncBytes", m_TypeTable[6]),
			new TypeBinding("mirrorRef", m_TypeTable[343]),
			new TypeBinding("trackingBytes", m_TypeTable[6])
		}, AsyncMirrorGroupMemberSyncProgress.class, false);

		m_TypeTable[990] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("initiatorRef", m_TypeTable[343]),
			new TypeBinding("nodeName", m_TypeTable[648]),
			new TypeBinding("alias", m_TypeTable[483]),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("configuredAuthMethods", m_TypeTable[873]),
			new TypeBinding("hostRef", m_TypeTable[343]),
			new TypeBinding("initiatorInactive", m_TypeTable[0])
		}, Initiator.class, false);

		m_TypeTable[991] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("batteryRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[201]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("batteryAge", m_TypeTable[7]),
			new TypeBinding("batteryLifeRemaining", m_TypeTable[7]),
			new TypeBinding("batteryTypeData", m_TypeTable[473]),
			new TypeBinding("reserved1", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("manufacturerDate", m_TypeTable[6]),
			new TypeBinding("vendorName", new StringSpec(0)),
			new TypeBinding("vendorPN", new StringSpec(0)),
			new TypeBinding("vendorSN", new StringSpec(0)),
			new TypeBinding("fruType", new StringSpec(0)),
			new TypeBinding("rtrAttributes", m_TypeTable[750]),
			new TypeBinding("repairPolicy", m_TypeTable[799]),
			new TypeBinding("batteryCanExpire", m_TypeTable[0]),
			new TypeBinding("automaticAgeReset", m_TypeTable[0]),
			new TypeBinding("learnCycleData", m_TypeTable[327])
		}, Battery.class, false);
	}

	private static void __init14() {

		m_TypeTable[992] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("offline", m_TypeTable[0]),
			new TypeBinding("hotSpare", m_TypeTable[0]),
			new TypeBinding("invalidDriveData", m_TypeTable[0]),
			new TypeBinding("available", m_TypeTable[0]),
			new TypeBinding("pfa", m_TypeTable[0]),
			new TypeBinding("driveRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[234]),
			new TypeBinding("cause", m_TypeTable[183]),
			new TypeBinding("interfaceType", m_TypeTable[916]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("manufacturer", new StringSpec(0)),
			new TypeBinding("manufacturerDate", m_TypeTable[6]),
			new TypeBinding("productID", new StringSpec(0)),
			new TypeBinding("serialNumber", new StringSpec(0)),
			new TypeBinding("softwareVersion", new StringSpec(0)),
			new TypeBinding("blkSize", m_TypeTable[7]),
			new TypeBinding("usableCapacity", m_TypeTable[6]),
			new TypeBinding("rawCapacity", m_TypeTable[6]),
			new TypeBinding("worldWideName", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("currentVolumeGroupRef", m_TypeTable[343]),
			new TypeBinding("sparedForDriveRef", m_TypeTable[343]),
			new TypeBinding("mirrorDrive", m_TypeTable[343]),
			new TypeBinding("nonRedundantAccess", m_TypeTable[0]),
			new TypeBinding("workingChannel", m_TypeTable[7]),
			new TypeBinding("volumeGroupIndex", m_TypeTable[7]),
			new TypeBinding("currentSpeed", m_TypeTable[149]),
			new TypeBinding("maxSpeed", m_TypeTable[149]),
			new TypeBinding("uncertified", m_TypeTable[0]),
			new TypeBinding("hasDegradedChannel", m_TypeTable[0]),
			new TypeBinding("degradedChannels", new ArraySpec(m_TypeTable[7], 0, true, int.class)),
			new TypeBinding("phyDriveType", m_TypeTable[21]),
			new TypeBinding("spindleSpeed", m_TypeTable[7]),
			new TypeBinding("rtrAttributes", m_TypeTable[750]),
			new TypeBinding("reserved", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("phyDriveTypeData", m_TypeTable[792]),
			new TypeBinding("pfaReason", m_TypeTable[70]),
			new TypeBinding("bypassSource", new ArraySpec(m_TypeTable[641], 0, true, ObjectReference.class)),
			new TypeBinding("repairPolicy", m_TypeTable[799]),
			new TypeBinding("fdeCapable", m_TypeTable[0]),
			new TypeBinding("fdeEnabled", m_TypeTable[0]),
			new TypeBinding("fdeLocked", m_TypeTable[0]),
			new TypeBinding("lockKeyID", m_TypeTable[343]),
			new TypeBinding("ssdWearLife", m_TypeTable[326]),
			new TypeBinding("driveMediaType", m_TypeTable[67]),
			new TypeBinding("fpgaVersion", new StringSpec(0)),
			new TypeBinding("protectionInformationCapabilities", m_TypeTable[519]),
			new TypeBinding("protectionInformationCapable", m_TypeTable[0]),
			new TypeBinding("protectionType", m_TypeTable[136]),
			new TypeBinding("interposerPresent", m_TypeTable[0]),
			new TypeBinding("interposerRef", m_TypeTable[343]),
			new TypeBinding("currentCommandAgingTimeout", m_TypeTable[7]),
			new TypeBinding("defaultCommandAgingTimeout", m_TypeTable[7]),
			new TypeBinding("driveTemperature", m_TypeTable[623]),
			new TypeBinding("blkSizePhysical", m_TypeTable[7]),
			new TypeBinding("lowestAlignedLBA", m_TypeTable[6]),
			new TypeBinding("removed", m_TypeTable[0]),
			new TypeBinding("locateInProgress", m_TypeTable[0]),
			new TypeBinding("fipsCapable", m_TypeTable[0])
		}, Drive.class, false);

		m_TypeTable[993] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mirrorProxy", m_TypeTable[343]),
			new TypeBinding("forced", m_TypeTable[0]),
			new TypeBinding("toRole", m_TypeTable[249])
		}, MirrorRoleChangeDescriptor.class, false);

		m_TypeTable[994] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaceRef", m_TypeTable[343]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("channelPortRef", m_TypeTable[343]),
			new TypeBinding("localIdentifier", m_TypeTable[7]),
			new TypeBinding("globalIdentifier", m_TypeTable[374]),
			new TypeBinding("linkState", m_TypeTable[33]),
			new TypeBinding("portState", m_TypeTable[256]),
			new TypeBinding("maximumTransmissionUnit", m_TypeTable[7]),
			new TypeBinding("currentSpeed", m_TypeTable[149]),
			new TypeBinding("supportedSpeed", new ArraySpec(m_TypeTable[149], 0, true, InterfaceSpeed.class)),
			new TypeBinding("currentLinkWidth", m_TypeTable[254]),
			new TypeBinding("supportedLinkWidth", new ArraySpec(m_TypeTable[254], 0, true, IbLinkWidth.class)),
			new TypeBinding("currentDataVirtualLanes", m_TypeTable[7]),
			new TypeBinding("maximumDataVirtualLanes", m_TypeTable[7]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("protectionInformationCapable", m_TypeTable[0]),
			new TypeBinding("isSRPSupported", m_TypeTable[0]),
			new TypeBinding("isISERSupported", m_TypeTable[0]),
			new TypeBinding("physPortState", m_TypeTable[147]),
			new TypeBinding("oneWayMaxRate", m_TypeTable[6]),
			new TypeBinding("bidirectionalMaxRate", m_TypeTable[6]),
			new TypeBinding("isNVMeSupported", m_TypeTable[0])
		}, IbInterface.class, false);

		m_TypeTable[995] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("pitGroupRef", m_TypeTable[343]),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("status", m_TypeTable[181]),
			new TypeBinding("baseVolume", m_TypeTable[343]),
			new TypeBinding("repositoryVolume", m_TypeTable[343]),
			new TypeBinding("clusterSize", m_TypeTable[7]),
			new TypeBinding("maxRepositoryCapacity", m_TypeTable[6]),
			new TypeBinding("maxBaseCapacity", m_TypeTable[6]),
			new TypeBinding("unusableRepositoryCapacity", m_TypeTable[6]),
			new TypeBinding("repFullPolicy", m_TypeTable[19]),
			new TypeBinding("fullWarnThreshold", m_TypeTable[7]),
			new TypeBinding("autoDeleteLimit", m_TypeTable[7]),
			new TypeBinding("action", m_TypeTable[199]),
			new TypeBinding("rollbackStatus", m_TypeTable[258]),
			new TypeBinding("rollbackPriority", m_TypeTable[139]),
			new TypeBinding("consistencyGroup", m_TypeTable[0]),
			new TypeBinding("consistencyGroupRef", m_TypeTable[343]),
			new TypeBinding("creationPendingStatus", m_TypeTable[127]),
			new TypeBinding("volumeHandle", m_TypeTable[7])
		}, PITGroup.class, false);

		m_TypeTable[996] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("metadataVolRef", m_TypeTable[343]),
			new TypeBinding("metadataVolType", m_TypeTable[111]),
			new TypeBinding("associatedVolume", m_TypeTable[343]),
			new TypeBinding("preferredManager", m_TypeTable[315]),
			new TypeBinding("perms", m_TypeTable[345]),
			new TypeBinding("offline", m_TypeTable[0]),
			new TypeBinding("reserved1", new OpaqueSpec(4, false, OpaqueSpec.DataType.BINARY))
		}, MetadataVolume.class, false);

		m_TypeTable[997] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("memberRef", m_TypeTable[343]),
			new TypeBinding("syncStatisticsSamples", new ArraySpec(m_TypeTable[403], 0, true, AsyncMirrorSyncStatisticsSample.class))
		}, AsyncMirrorSyncStatistics.class, false);

		m_TypeTable[998] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("parentController", m_TypeTable[315]),
			new TypeBinding("partNumber", new StringSpec(0)),
			new TypeBinding("serialNumber", new StringSpec(0)),
			new TypeBinding("vendorName", new StringSpec(0)),
			new TypeBinding("manufacturerDate", m_TypeTable[6]),
			new TypeBinding("fruType", new StringSpec(0)),
			new TypeBinding("hostBoardId", new StringSpec(0)),
			new TypeBinding("status", m_TypeTable[109]),
			new TypeBinding("type", m_TypeTable[95]),
			new TypeBinding("hostBoardRef", m_TypeTable[343]),
			new TypeBinding("numberOfPorts", m_TypeTable[7]),
			new TypeBinding("hbTypeData", m_TypeTable[588]),
			new TypeBinding("oemPartNumber", new StringSpec(0)),
			new TypeBinding("hostBoardControllerSlot", m_TypeTable[7]),
			new TypeBinding("repairPolicy", m_TypeTable[799]),
			new TypeBinding("physicalLocation", m_TypeTable[888])
		}, HostBoard.class, false);

		m_TypeTable[999] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("descriptorList", new ArraySpec(m_TypeTable[826], 0, true, KeyValueTagMappingDeletionDescriptor.class))
		}, KeyValueTagMappingDeletionDescriptorList.class, false);

		m_TypeTable[1000] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mirrorVolume", m_TypeTable[343])
		}, DualMirrorSecondary.class, false);

		m_TypeTable[1001] = new UnionSpec(true, "eventComponentType", m_TypeTable[165], new AlternateBinding[] {
			new AlternateBinding(18, "alarmLocation", m_TypeTable[377]),
			new AlternateBinding(9, "batteryTray", m_TypeTable[7]),
			new AlternateBinding(29, "cacheBackupDeviceLocation", m_TypeTable[322]),
			new AlternateBinding(30, "cacheMemoryDimmLocation", m_TypeTable[524]),
			new AlternateBinding(6, "channelLoc", m_TypeTable[432]),
			new AlternateBinding(19, "channelPort", m_TypeTable[7]),
			new AlternateBinding(12, "chipLoc", m_TypeTable[377]),
			new AlternateBinding(8, "controllerLoc", m_TypeTable[377]),
			new AlternateBinding(23, "ctlrSfpLocation", m_TypeTable[292]),
			new AlternateBinding(24, "socLocation", m_TypeTable[609]),
			new AlternateBinding(1, "driveLoc", m_TypeTable[377]),
			new AlternateBinding(10, "enclosureTray", m_TypeTable[7]),
			new AlternateBinding(7, "esmTray", m_TypeTable[7]),
			new AlternateBinding(3, "fanTray", m_TypeTable[7]),
			new AlternateBinding(28, "hostIoCardLocation", m_TypeTable[597]),
			new AlternateBinding(25, "initiatorLocation", m_TypeTable[384]),
			new AlternateBinding(16, "interconnectCruLocation", m_TypeTable[377]),
			new AlternateBinding(27, "isnsServerLocation", m_TypeTable[970]),
			new AlternateBinding(4, "minihubLoc", m_TypeTable[346]),
			new AlternateBinding(15, "portCruTray", m_TypeTable[7]),
			new AlternateBinding(2, "powerSupplyTray", m_TypeTable[7]),
			new AlternateBinding(20, "sfpLocation", m_TypeTable[377]),
			new AlternateBinding(17, "supportCruLocation", m_TypeTable[377]),
			new AlternateBinding(26, "targetLocation", m_TypeTable[512]),
			new AlternateBinding(5, "tempSensorTray", m_TypeTable[7]),
			new AlternateBinding(13, "label", m_TypeTable[337]),
			new AlternateBinding(14, "groupNumber", m_TypeTable[7]),
			new AlternateBinding(31, "hostLocation", m_TypeTable[337]),
			new AlternateBinding(32, "hostPortLocation", m_TypeTable[680]),
			new AlternateBinding(33, "drawerLocation", m_TypeTable[377]),
			new AlternateBinding(34, "componentRelativeLocation", m_TypeTable[625]),
			new AlternateBinding(35, "schedule", m_TypeTable[337]),
			new AlternateBinding(37, "diskPool", m_TypeTable[7]),
			new AlternateBinding(36, "asyncMirrorGroup", m_TypeTable[337]),
			new AlternateBinding(38, "pitLabel", m_TypeTable[337]),
			new AlternateBinding(39, "cgLabel", m_TypeTable[337]),
			new AlternateBinding(40, "cgPitLabel", m_TypeTable[337]),
			new AlternateBinding(41, "cgViewLabel", m_TypeTable[337]),
			new AlternateBinding(42, "flashCacheLabel", m_TypeTable[337]),
			new AlternateBinding(43, "communityNameString", m_TypeTable[313]),
			new AlternateBinding(44, "destinationIpAddress", m_TypeTable[313]),
			new AlternateBinding(45, "fcTargetLocation", m_TypeTable[358]),
			new AlternateBinding(48, "fanCruLocation", m_TypeTable[377]),
			new AlternateBinding(49, "powerSupplyCruLocation", m_TypeTable[377]),
			new AlternateBinding(50, "nvmeInitiatorLocation", m_TypeTable[384])
		}, ComponentLocation.class);

		m_TypeTable[1002] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("fanRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[123]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("reserved1", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("rtrAttributes", m_TypeTable[750]),
			new TypeBinding("repairPolicy", m_TypeTable[799])
		}, Fan.class, false);

		m_TypeTable[1003] = new UnionSpec(true, "ntpAcquisitionType", m_TypeTable[156], new AlternateBinding[] {
			new AlternateBinding(1, "ntpServers", new ArraySpec(m_TypeTable[786], 2, true, NetworkAddress.class))
		}, NtpAcquisitionDescriptor.class);

		m_TypeTable[1004] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("metadataVolume", m_TypeTable[343])
		}, MetadataOffline.class, false);

		m_TypeTable[1005] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trapDestinationAddDescriptor", new ArraySpec(m_TypeTable[904], 0, true, SNMPTrapDestinationAddDescriptor.class))
		}, SNMPTrapDestinationAddDescriptorList.class, false);

		m_TypeTable[1006] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("keyValueTagRef", m_TypeTable[343]),
			new TypeBinding("associatedObject", m_TypeTable[756]),
			new TypeBinding("mappingRef", m_TypeTable[343])
		}, KeyValueTagMapping.class, false);

		m_TypeTable[1007] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "dtsBundle", m_TypeTable[852])
		}, DiscreteTimeSeriesBundleReturned.class);

		m_TypeTable[1008] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mirrorVolume", m_TypeTable[343])
		}, MirrorFailed.class, false);

		m_TypeTable[1009] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("gbicRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[28]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("gbicType", m_TypeTable[163]),
			new TypeBinding("gbicPort", m_TypeTable[57]),
			new TypeBinding("parentData", m_TypeTable[737]),
			new TypeBinding("reserved1", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, Gbic.class, false);

		m_TypeTable[1010] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("timeData", m_TypeTable[517]),
			new TypeBinding("nvmeofInterfaceStatisticsRaw", new ArraySpec(m_TypeTable[794], 0, true, NVMeoFInterfaceStatistics.class)),
			new TypeBinding("nvmeofInterfaceStatisticsRel", new ArraySpec(m_TypeTable[794], 0, true, NVMeoFInterfaceStatistics.class))
		}, NVMeoFBaselinedStatistics.class, false);

		m_TypeTable[1011] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("threshold", m_TypeTable[7])
		}, ThinVolumeThresholdUpdateDescriptor.class, false);

		m_TypeTable[1012] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ipAddressData", m_TypeTable[881]),
			new TypeBinding("listeningPort", m_TypeTable[7])
		}, NVMeoFInfinibandProperties.class, false);

		m_TypeTable[1013] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("portRef", m_TypeTable[343]),
			new TypeBinding("portParent", m_TypeTable[679]),
			new TypeBinding("portNumber", m_TypeTable[7]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("channelType", m_TypeTable[206]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("isTrunkActive", m_TypeTable[0])
		}, ChannelPort.class, false);

		m_TypeTable[1014] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hotSpareCandidate", new ArraySpec(m_TypeTable[971], 0, true, HotSpareCandidate.class)),
			new TypeBinding("returnCode", m_TypeTable[152])
		}, HotSpareCandidateList.class, false);

		m_TypeTable[1015] = new UnionSpec(true, "ioInterfaceType", m_TypeTable[276], new AlternateBinding[] {
			new AlternateBinding(5, "iSCSIInitiatorTargetBaseParameters", m_TypeTable[819])
		}, ScsiInitiatorTargetBaseProperties.class);

		m_TypeTable[1016] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupRef", m_TypeTable[343]),
			new TypeBinding("memberRef", m_TypeTable[343]),
			new TypeBinding("retainRepositoryMembers", m_TypeTable[0]),
			new TypeBinding("force", m_TypeTable[0])
		}, AsyncMirrorGroupRemoveMemberDescriptor.class, false);

		m_TypeTable[1017] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("capacity", m_TypeTable[6])
		}, ThinVolumeExpansionDescriptor.class, false);

		m_TypeTable[1018] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("metadataVolRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, MetadataVolRefList.class, false);

		m_TypeTable[1019] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("worldWideName", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("volcopyHandle", m_TypeTable[7]),
			new TypeBinding("volcopyRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[169]),
			new TypeBinding("sourceVolume", m_TypeTable[343]),
			new TypeBinding("targetVolume", m_TypeTable[343]),
			new TypeBinding("currentManager", m_TypeTable[315]),
			new TypeBinding("idleTargetWriteProt", m_TypeTable[0]),
			new TypeBinding("copyCompleteTime", m_TypeTable[6]),
			new TypeBinding("copyStartTime", m_TypeTable[6]),
			new TypeBinding("copyPriority", m_TypeTable[77]),
			new TypeBinding("reserved1", new OpaqueSpec(4, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("cloneCopy", m_TypeTable[0]),
			new TypeBinding("pgRef", m_TypeTable[343])
		}, VolumeCopy.class, false);

		m_TypeTable[1020] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("powerSupplyRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[155]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("partNumber", new StringSpec(0)),
			new TypeBinding("serialNumber", new StringSpec(0)),
			new TypeBinding("vendorName", new StringSpec(0)),
			new TypeBinding("manufacturerDate", m_TypeTable[6]),
			new TypeBinding("fruType", new StringSpec(0)),
			new TypeBinding("reserved1", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("rtrAttributes", m_TypeTable[750]),
			new TypeBinding("repairPolicy", m_TypeTable[799]),
			new TypeBinding("firmwareRevision", new OpaqueSpec(0, true, OpaqueSpec.DataType.SBCS)),
			new TypeBinding("manufacturingDeviceCode", m_TypeTable[7])
		}, PowerSupply.class, false);

		m_TypeTable[1021] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("timeOfReading", m_TypeTable[6]),
			new TypeBinding("ibTcaStatistics", new ArraySpec(m_TypeTable[576], 0, true, IbTcaStatistics.class)),
			new TypeBinding("ibRdmaChannelStatistics", new ArraySpec(m_TypeTable[796], 0, true, IbRdmaChannelStatistics.class))
		}, IbPointInTimeStatistics.class, false);

		m_TypeTable[1022] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("type", m_TypeTable[194]),
			new TypeBinding("lastChunk", m_TypeTable[0]),
			new TypeBinding("thisSequenceNumber", m_TypeTable[7]),
			new TypeBinding("details", m_TypeTable[865]),
			new TypeBinding("percentComplete", m_TypeTable[7])
		}, RawDataRetrieveInfo.class, false);

		m_TypeTable[1023] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("pitGroupRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, PITGroupRefList.class, false);

		m_TypeTable[1024] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("memberRef", m_TypeTable[343]),
			new TypeBinding("mirrorGroup", m_TypeTable[343]),
			new TypeBinding("localVolume", m_TypeTable[343]),
			new TypeBinding("remoteVolume", m_TypeTable[343]),
			new TypeBinding("memberState", m_TypeTable[91]),
			new TypeBinding("lastRecoveryPointTime", m_TypeTable[6]),
			new TypeBinding("overUtilizationWarnThreshold", m_TypeTable[0]),
			new TypeBinding("mirroredLocalCapacity", m_TypeTable[6]),
			new TypeBinding("repositoryVolume", m_TypeTable[343]),
			new TypeBinding("worldWideName", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("volumeHandle", m_TypeTable[7]),
			new TypeBinding("repositoryFull", m_TypeTable[0])
		}, AsyncMirrorGroupMember.class, false);

		m_TypeTable[1025] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeHandle", m_TypeTable[7]),
			new TypeBinding("worldWideName", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("allocationGranularity", m_TypeTable[7]),
			new TypeBinding("capacity", m_TypeTable[6]),
			new TypeBinding("reconPriority", m_TypeTable[7]),
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[174]),
			new TypeBinding("repositoryRef", m_TypeTable[343]),
			new TypeBinding("currentManager", m_TypeTable[315]),
			new TypeBinding("preferredManager", m_TypeTable[315]),
			new TypeBinding("perms", m_TypeTable[345]),
			new TypeBinding("mgmtClientAttribute", m_TypeTable[7]),
			new TypeBinding("preReadRedundancyCheckEnabled", m_TypeTable[0]),
			new TypeBinding("protectionType", m_TypeTable[136]),
			new TypeBinding("applicationTagOwned", m_TypeTable[0]),
			new TypeBinding("maxVirtualCapacity", m_TypeTable[6]),
			new TypeBinding("initialProvisionedCapacity", m_TypeTable[6]),
			new TypeBinding("currentProvisionedCapacity", m_TypeTable[6]),
			new TypeBinding("provisionedCapacityQuota", m_TypeTable[6]),
			new TypeBinding("growthAlertThreshold", m_TypeTable[7]),
			new TypeBinding("expansionPolicy", m_TypeTable[23]),
			new TypeBinding("volumeCache", m_TypeTable[491]),
			new TypeBinding("offline", m_TypeTable[0]),
			new TypeBinding("reportingPolicy", m_TypeTable[69])
		}, ThinVolume.class, false);

		m_TypeTable[1026] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("acquisitionProperties", m_TypeTable[1003]),
			new TypeBinding("dhcpAcquiredNtpServers", new ArraySpec(m_TypeTable[700], 2, true, IpVxAddress.class))
		}, ControllerNTPProperties.class, false);

		m_TypeTable[1027] = new UnionSpec(true, "scheduleMethod", m_TypeTable[84], new AlternateBinding[] {
			new AlternateBinding(1, "daily", m_TypeTable[766]),
			new AlternateBinding(2, "weekly", m_TypeTable[626]),
			new AlternateBinding(3, "monthlyByDate", m_TypeTable[793]),
			new AlternateBinding(4, "monthlyByDay", m_TypeTable[751])
		}, ScheduleCalendar.class);

		m_TypeTable[1028] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ipv4DefaultRouterAddress", new ArraySpec(m_TypeTable[560], 1, true, String.class)),
			new TypeBinding("ipv6DefaultRouterAddress", new ArraySpec(m_TypeTable[649], 1, true, IpV6AddressData.class)),
			new TypeBinding("remoteAccessEnabled", new ArraySpec(m_TypeTable[0], 1, true, boolean.class)),
			new TypeBinding("ntpAcquisitionProperties", new ArraySpec(m_TypeTable[1003], 1, true, NtpAcquisitionDescriptor.class)),
			new TypeBinding("dnsAcquisitionProperties", new ArraySpec(m_TypeTable[787], 1, true, DnsAcquisitionDescriptor.class))
		}, ControllerChangeableProperties.class, false);

		m_TypeTable[1029] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("memberRef", m_TypeTable[343]),
			new TypeBinding("deleteRecoveryPointIfNecessary", m_TypeTable[0])
		}, AsyncMirrorGroupRecoverDescriptor.class, false);

		m_TypeTable[1030] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaceName", new StringSpec(0)),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("speed", m_TypeTable[7]),
			new TypeBinding("ip", m_TypeTable[7]),
			new TypeBinding("alias", new StringSpec(0)),
			new TypeBinding("macAddr", new OpaqueSpec(6, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("gatewayIp", m_TypeTable[7]),
			new TypeBinding("subnetMask", m_TypeTable[7]),
			new TypeBinding("bootpUsed", m_TypeTable[0]),
			new TypeBinding("rloginEnabled", m_TypeTable[0]),
			new TypeBinding("reserved1", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("setupError", m_TypeTable[0]),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("interfaceRef", m_TypeTable[343]),
			new TypeBinding("linkStatus", m_TypeTable[230]),
			new TypeBinding("ipv4Enabled", m_TypeTable[0]),
			new TypeBinding("ipv4Address", m_TypeTable[560]),
			new TypeBinding("ipv4SubnetMask", m_TypeTable[560]),
			new TypeBinding("ipv4AddressConfigMethod", m_TypeTable[259]),
			new TypeBinding("ipv6Enabled", m_TypeTable[0]),
			new TypeBinding("ipv6LocalAddress", m_TypeTable[649]),
			new TypeBinding("ipv6PortStaticRoutableAddress", m_TypeTable[649]),
			new TypeBinding("ipv6PortRoutableAddresses", new ArraySpec(m_TypeTable[649], 0, true, IpV6AddressData.class)),
			new TypeBinding("ipv6AddressConfigMethod", m_TypeTable[263]),
			new TypeBinding("fullDuplex", m_TypeTable[0]),
			new TypeBinding("supportedSpeedSettings", new ArraySpec(m_TypeTable[100], 0, true, EthernetSpeedSetting.class)),
			new TypeBinding("configuredSpeedSetting", m_TypeTable[100]),
			new TypeBinding("currentSpeed", m_TypeTable[149]),
			new TypeBinding("physicalLocation", m_TypeTable[888])
		}, EthernetInterface.class, false);

		m_TypeTable[1031] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("drivePhysicalSecurityIdList", new ArraySpec(m_TypeTable[841], 0, true, DrivePhysicalSecurityId.class))
		}, DrivePhysicalSecurityIdDescriptor.class, false);

		m_TypeTable[1032] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volcopyRef", m_TypeTable[343]),
			new TypeBinding("pending", m_TypeTable[0]),
			new TypeBinding("percentComplete", m_TypeTable[7]),
			new TypeBinding("timeToCompletion", m_TypeTable[7])
		}, VolumeCopyOperation.class, false);

		m_TypeTable[1033] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "info", m_TypeTable[951])
		}, DPLCoreDumpInfoReturn.class);

		m_TypeTable[1034] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("sfpRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[178]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("sfpType", m_TypeTable[602]),
			new TypeBinding("sfpPort", m_TypeTable[114]),
			new TypeBinding("parentData", m_TypeTable[821]),
			new TypeBinding("reserved1", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("sfpPortRef", m_TypeTable[343]),
			new TypeBinding("repairPolicy", m_TypeTable[799])
		}, Sfp.class, false);

		m_TypeTable[1035] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("worldWideName", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("mirrorProxyRef", m_TypeTable[343]),
			new TypeBinding("volumeHandle", m_TypeTable[7]),
			new TypeBinding("localMirrorStatus", m_TypeTable[22]),
			new TypeBinding("remoteMirrorStatus", m_TypeTable[22]),
			new TypeBinding("localRole", m_TypeTable[249]),
			new TypeBinding("remoteRole", m_TypeTable[249]),
			new TypeBinding("localPriority", m_TypeTable[14]),
			new TypeBinding("peerPriority", m_TypeTable[14]),
			new TypeBinding("usableCapacity", m_TypeTable[6]),
			new TypeBinding("currentManager", m_TypeTable[315]),
			new TypeBinding("baseVolume", m_TypeTable[343]),
			new TypeBinding("remoteVolRef", m_TypeTable[343]),
			new TypeBinding("action", m_TypeTable[199]),
			new TypeBinding("reserved1", new OpaqueSpec(12, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("localWriteMode", m_TypeTable[177]),
			new TypeBinding("autoResync", m_TypeTable[0]),
			new TypeBinding("consistencyGroupRef", m_TypeTable[343])
		}, MirrorProxyVolume.class, false);

		m_TypeTable[1036] = new UnionSpec(true, "type", m_TypeTable[240], new AlternateBinding[] {
			new AlternateBinding(3, "metadataRef", m_TypeTable[343]),
			new AlternateBinding(4, "mirrorRef", m_TypeTable[343]),
			new AlternateBinding(1, "snapshotRef", m_TypeTable[343]),
			new AlternateBinding(2, "volcopyRef", m_TypeTable[343]),
			new AlternateBinding(8, "amgMember", m_TypeTable[343]),
			new AlternateBinding(9, "concatVol", m_TypeTable[343]),
			new AlternateBinding(10, "pitGroup", m_TypeTable[343]),
			new AlternateBinding(11, "pitView", m_TypeTable[343])
		}, ExportDependencyTypeData.class);

		m_TypeTable[1037] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("keyValueTag", new ArraySpec(m_TypeTable[771], 0, true, KeyValueTag.class)),
			new TypeBinding("keyValueTagMapping", new ArraySpec(m_TypeTable[1006], 0, true, KeyValueTagMapping.class)),
			new TypeBinding("workload", new ArraySpec(m_TypeTable[723], 0, true, Workload.class)),
			new TypeBinding("workloadVolumeMapping", new ArraySpec(m_TypeTable[807], 0, true, WorkloadVolumeMapping.class))
		}, ApplicationAwarenessBundle.class, false);

		m_TypeTable[1038] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("repositoryVolume", m_TypeTable[343]),
			new TypeBinding("snapshotVolume", m_TypeTable[343]),
			new TypeBinding("repositoryFull", m_TypeTable[0])
		}, SnapshotFailure.class, false);

		m_TypeTable[1039] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("channelPortRef", m_TypeTable[343]),
			new TypeBinding("tcpListenPort", m_TypeTable[7]),
			new TypeBinding("ipv4Enabled", m_TypeTable[0]),
			new TypeBinding("ipv4Data", m_TypeTable[688]),
			new TypeBinding("interfaceData", m_TypeTable[934]),
			new TypeBinding("interfaceRef", m_TypeTable[343]),
			new TypeBinding("ipv6Enabled", m_TypeTable[0]),
			new TypeBinding("ipv6Data", m_TypeTable[937]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("protectionInformationCapable", m_TypeTable[0]),
			new TypeBinding("isIPv6Capable", m_TypeTable[0]),
			new TypeBinding("oneWayMaxRate", m_TypeTable[6]),
			new TypeBinding("bidirectionalMaxRate", m_TypeTable[6])
		}, IscsiInterface.class, false);

		m_TypeTable[1040] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("policy", m_TypeTable[69])
		}, ThinVolumeReportingPolicyUpdateDescriptor.class, false);

		m_TypeTable[1041] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mirrorVolume", m_TypeTable[343])
		}, DualMirrorPrimary.class, false);

		m_TypeTable[1042] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("localEndpoint", m_TypeTable[907]),
			new TypeBinding("remoteEndpoint", m_TypeTable[907])
		}, IscsiConnectionEndpoints.class, false);

		m_TypeTable[1043] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("type", m_TypeTable[78]),
			new TypeBinding("startTime", m_TypeTable[6]),
			new TypeBinding("preExpansionCapacityInBytes", m_TypeTable[6]),
			new TypeBinding("postExpansionCapacityInBytes", m_TypeTable[6])
		}, ThinVolumeRepositoryExpansionHistoryData.class, false);

		m_TypeTable[1044] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("kmsEndpoint", m_TypeTable[861])
		}, ExternalKMSParametersSetDescriptor.class, false);

		m_TypeTable[1045] = new UnionSpec(true, "ioInterfaceType", m_TypeTable[276], new AlternateBinding[] {
			new AlternateBinding(2, "portName", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new AlternateBinding(6, "ibPortName", m_TypeTable[374]),
			new AlternateBinding(5, "iscsiPortName", m_TypeTable[629]),
			new AlternateBinding(4, "sasPortName", m_TypeTable[379]),
			new AlternateBinding(8, "nvmeInitiatorPortId", m_TypeTable[948])
		}, SCSIInitiatorPortId.class);

		m_TypeTable[1046] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("processorMemoryDimmRef", m_TypeTable[343]),
			new TypeBinding("parentController", m_TypeTable[315]),
			new TypeBinding("dimmControllerSlot", m_TypeTable[7]),
			new TypeBinding("status", m_TypeTable[284]),
			new TypeBinding("capacityInMegabytes", m_TypeTable[7]),
			new TypeBinding("serialNumber", new StringSpec(0)),
			new TypeBinding("partNumber", new StringSpec(0)),
			new TypeBinding("oemPartNumber", new StringSpec(0)),
			new TypeBinding("manufacturerPartNumber", new StringSpec(0)),
			new TypeBinding("manufacturer", new StringSpec(0)),
			new TypeBinding("manufactureDate", m_TypeTable[6]),
			new TypeBinding("repairPolicy", m_TypeTable[799]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("revisionCode", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, ProcessorMemoryDimm.class, false);
	}

	private static void __init15() {

		m_TypeTable[1047] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("repositoryProvisionedCapacity", m_TypeTable[6]),
			new TypeBinding("repositoryConsumedCapacity", m_TypeTable[6])
		}, ThinVolumeConsumedCapacity.class, false);

		m_TypeTable[1048] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("initiatorPortId", m_TypeTable[1045]),
			new TypeBinding("targetPortId", m_TypeTable[891]),
			new TypeBinding("hostLabel", m_TypeTable[337])
		}, ITNexus.class, false);

		m_TypeTable[1049] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("flashCacheRef", m_TypeTable[343]),
			new TypeBinding("driveRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, FlashCacheReconfigureDrivesDescriptor.class, false);

		m_TypeTable[1050] = new UnionSpec(true, "type", m_TypeTable[223], new AlternateBinding[] {
			new AlternateBinding(5, "alternateController", m_TypeTable[315]),
			new AlternateBinding(2, "drive", m_TypeTable[343]),
			new AlternateBinding(3, "expander", m_TypeTable[343]),
			new AlternateBinding(6, "remoteHostPortAddress", m_TypeTable[379]),
			new AlternateBinding(4, "localController", m_TypeTable[315]),
			new AlternateBinding(1, "physicalLocation", m_TypeTable[888])
		}, SasAttachedDeviceTypeData.class);

		m_TypeTable[1051] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("calendar", m_TypeTable[1027]),
			new TypeBinding("startDate", m_TypeTable[6]),
			new TypeBinding("recurrence", m_TypeTable[599]),
			new TypeBinding("timezone", m_TypeTable[803])
		}, Schedule.class, false);

		m_TypeTable[1052] = new UnionSpec(true, "endpointRole", m_TypeTable[74], new AlternateBinding[] {
			new AlternateBinding(1, "initiatorId", m_TypeTable[1045]),
			new AlternateBinding(2, "targetId", m_TypeTable[891])
		}, ScsiProtocolEndpoint.class);

		m_TypeTable[1053] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mirrorVolume", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, MirrorVolumeList.class, false);

		m_TypeTable[1054] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "thermalSensorData", new ArraySpec(m_TypeTable[849], 0, true, ThermalSensorData.class))
		}, TrayTemperatureReturned.class);

		m_TypeTable[1055] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("upsRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[99]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("reserved1", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, Ups.class, false);

		m_TypeTable[1056] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("raidLevel", m_TypeTable[36]),
			new TypeBinding("trayLossProtection", m_TypeTable[0]),
			new TypeBinding("rawSize", m_TypeTable[6]),
			new TypeBinding("usableSize", m_TypeTable[6]),
			new TypeBinding("driveCount", m_TypeTable[7]),
			new TypeBinding("freeExtentRef", m_TypeTable[343]),
			new TypeBinding("driveRefList", m_TypeTable[817]),
			new TypeBinding("candidateSelectionType", m_TypeTable[170]),
			new TypeBinding("spindleSpeedMatch", m_TypeTable[0]),
			new TypeBinding("spindleSpeed", m_TypeTable[7]),
			new TypeBinding("phyDriveType", m_TypeTable[21]),
			new TypeBinding("dssPreallocEnabled", m_TypeTable[0]),
			new TypeBinding("securityType", m_TypeTable[173]),
			new TypeBinding("drawerLossProtection", m_TypeTable[0]),
			new TypeBinding("driveMediaType", m_TypeTable[67]),
			new TypeBinding("protectionInformationCapable", m_TypeTable[0]),
			new TypeBinding("protectionInformationCapabilities", m_TypeTable[519]),
			new TypeBinding("volumeCandidateData", m_TypeTable[661]),
			new TypeBinding("driveBlockFormat", m_TypeTable[72]),
			new TypeBinding("allocateReservedSpace", m_TypeTable[0]),
			new TypeBinding("securityLevel", m_TypeTable[83])
		}, VolumeCandidate.class, false);

		m_TypeTable[1057] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("saData", m_TypeTable[862]),
			new TypeBinding("safeId", m_TypeTable[366]),
			new TypeBinding("cache", m_TypeTable[445]),
			new TypeBinding("accessVolume", m_TypeTable[896]),
			new TypeBinding("featureParameters", m_TypeTable[305]),
			new TypeBinding("mediaScanPeriod", m_TypeTable[7]),
			new TypeBinding("capabilities", new ArraySpec(m_TypeTable[153], 0, true, Capability.class)),
			new TypeBinding("premiumFeatures", new ArraySpec(m_TypeTable[402], 0, true, PremiumFeature.class)),
			new TypeBinding("trayPositionList", m_TypeTable[601]),
			new TypeBinding("hostPortType", new ArraySpec(m_TypeTable[337], 0, true, String.class)),
			new TypeBinding("hostSpecificVals", new ArraySpec(m_TypeTable[368], 0, true, HostSpecificValues.class)),
			new TypeBinding("compatibility", new ArraySpec(m_TypeTable[614], 0, true, CompatibleFirmware.class)),
			new TypeBinding("usageHints", new ArraySpec(m_TypeTable[416], 0, true, VolumeUsageHint.class)),
			new TypeBinding("definedPartitionCount", m_TypeTable[7]),
			new TypeBinding("defaultHostPortTypeIndex", m_TypeTable[7]),
			new TypeBinding("remoteAccessID", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("remoteMirroringActive", m_TypeTable[0]),
			new TypeBinding("volXferAlertDelayPeriod", m_TypeTable[7]),
			new TypeBinding("reserved1", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("stagedFirmware", m_TypeTable[859]),
			new TypeBinding("unreadableSectors", m_TypeTable[330]),
			new TypeBinding("driveChannels", new ArraySpec(m_TypeTable[850], 0, true, DriveChannel.class)),
			new TypeBinding("portLocations", new ArraySpec(m_TypeTable[925], 0, true, DriveChannelPort.class)),
			new TypeBinding("ddcTag", m_TypeTable[7]),
			new TypeBinding("featureBundle", m_TypeTable[870]),
			new TypeBinding("featureState", new ArraySpec(m_TypeTable[866], 0, true, FeatureState.class)),
			new TypeBinding("channelPortLocations", new ArraySpec(m_TypeTable[1013], 0, true, ChannelPort.class)),
			new TypeBinding("iscsiEntityData", m_TypeTable[636]),
			new TypeBinding("hostType", new ArraySpec(m_TypeTable[337], 0, true, String.class)),
			new TypeBinding("defaultHostTypeIndex", m_TypeTable[7]),
			new TypeBinding("rvmControllerHostChannel", m_TypeTable[7]),
			new TypeBinding("smartBatteryData", m_TypeTable[327]),
			new TypeBinding("invalidSystemConfig", m_TypeTable[0]),
			new TypeBinding("securityLockKey", m_TypeTable[0]),
			new TypeBinding("lockKeyIDRef", m_TypeTable[343]),
			new TypeBinding("syslogConfiguration", m_TypeTable[729]),
			new TypeBinding("securityExternalKmsEnable", m_TypeTable[0]),
			new TypeBinding("newKeySequence", m_TypeTable[7]),
			new TypeBinding("securityExternalKmsKeyStatus", m_TypeTable[46]),
			new TypeBinding("lockKeyNeededList", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("dplCoreDumpData", m_TypeTable[632]),
			new TypeBinding("fcRVMState", m_TypeTable[219]),
			new TypeBinding("asupEnabled", m_TypeTable[0]),
			new TypeBinding("asupOnDemandEnabled", m_TypeTable[0]),
			new TypeBinding("asupRemoteDiagsEnabled", m_TypeTable[0]),
			new TypeBinding("iocDumpData", m_TypeTable[485]),
			new TypeBinding("driveChannelPortDisabled", m_TypeTable[0]),
			new TypeBinding("VAAIEnabled", m_TypeTable[0]),
			new TypeBinding("ODXEnabled", m_TypeTable[0]),
			new TypeBinding("directExpansionPortInUse", m_TypeTable[0]),
			new TypeBinding("highResolutionStatisticsEnabled", m_TypeTable[0]),
			new TypeBinding("autoLoadBalancingEnabled", m_TypeTable[0]),
			new TypeBinding("reserved3", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("embeddedExternalKMSInformation", m_TypeTable[931]),
			new TypeBinding("isLun0RestrictedForDefaultPartition", m_TypeTable[0])
		}, StorageArray.class, false);

		m_TypeTable[1058] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("thinRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, ThinVolumeRefList.class, false);

		m_TypeTable[1059] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("flashCacheRef", m_TypeTable[343]),
			new TypeBinding("configType", m_TypeTable[161]),
			new TypeBinding("userLabel", m_TypeTable[337])
		}, FlashCacheParamsUpdateDescriptor.class, false);

		m_TypeTable[1060] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "ibStatistics", new ArraySpec(m_TypeTable[919], 0, true, EnhancedIbStatisticalData.class))
		}, EnhancedIbStatisticsReturned.class);

		m_TypeTable[1061] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "defaults", m_TypeTable[890])
		}, IscsiNegotiationDefaultsReturned.class);

		m_TypeTable[1062] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("member", m_TypeTable[343]),
			new TypeBinding("indication", m_TypeTable[134])
		}, AsyncMirrorGroupMemberFaultIndicationClearDescriptor.class, false);

		m_TypeTable[1063] = new UnionSpec(true, "provider", m_TypeTable[132], new AlternateBinding[] {
			new AlternateBinding(2, "ibProperties", m_TypeTable[1012])
		}, NVMeoFProtocolProperties.class);

		m_TypeTable[1064] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mirrorRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, AsyncMirrorGroupMemberRefList.class, false);

		m_TypeTable[1065] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("nodeName", new ArraySpec(m_TypeTable[648], 1, true, ScsiNodeName.class)),
			new TypeBinding("label", new ArraySpec(m_TypeTable[337], 1, true, String.class)),
			new TypeBinding("configuredAuthMethods", new ArraySpec(m_TypeTable[873], 1, true, AuthenticationBundle.class)),
			new TypeBinding("hostRef", new ArraySpec(m_TypeTable[343], 1, true, String.class))
		}, InitiatorChangeableProperties.class, false);

		m_TypeTable[1066] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("flashCacheType", m_TypeTable[92]),
			new TypeBinding("candidate", m_TypeTable[1056]),
			new TypeBinding("flashCacheLabel", m_TypeTable[337]),
			new TypeBinding("enableExisting", m_TypeTable[0])
		}, FlashCacheCreationDescriptor.class, false);

		m_TypeTable[1067] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("thermalSensorRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[168]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("reserved1", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("rtrAttributes", m_TypeTable[750]),
			new TypeBinding("repairPolicy", m_TypeTable[799])
		}, ThermalSensor.class, false);

		m_TypeTable[1068] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "candidates", new ArraySpec(m_TypeTable[868], 0, true, VolumeGroupExpansionCandidate.class))
		}, ExpansionCandidatesReturned.class);

		m_TypeTable[1069] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("metadataVolType", m_TypeTable[111]),
			new TypeBinding("ctl0Label", m_TypeTable[337]),
			new TypeBinding("ctl1Label", m_TypeTable[337]),
			new TypeBinding("candidate", m_TypeTable[1056]),
			new TypeBinding("volumeGroupLabel", m_TypeTable[337]),
			new TypeBinding("protectionType", m_TypeTable[136])
		}, MetadataVolCreationDescriptor.class, false);

		m_TypeTable[1070] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupPercentComplete", m_TypeTable[7]),
			new TypeBinding("groupTimeToCompletion", m_TypeTable[7]),
			new TypeBinding("groupSyncBytes", m_TypeTable[6]),
			new TypeBinding("groupRef", m_TypeTable[343]),
			new TypeBinding("memberProgress", new ArraySpec(m_TypeTable[989], 0, true, AsyncMirrorGroupMemberSyncProgress.class)),
			new TypeBinding("groupTrackingBytes", m_TypeTable[6])
		}, AsyncMirrorGroupSyncProgress.class, false);

		m_TypeTable[1071] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("flashCache", m_TypeTable[343]),
			new TypeBinding("driveRefList", m_TypeTable[817])
		}, FlashCacheRecoveryData.class, false);

		m_TypeTable[1072] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("observationTime", m_TypeTable[6]),
			new TypeBinding("objectRef", m_TypeTable[641]),
			new TypeBinding("counterGroup", new ArraySpec(m_TypeTable[895], 0, true, CounterGroup.class)),
			new TypeBinding("bundleStartTime", m_TypeTable[6]),
			new TypeBinding("bundleEndTime", m_TypeTable[6]),
			new TypeBinding("areMoreStatsAvailable", m_TypeTable[0])
		}, CumulativeStatisticsBundle.class, false);

		m_TypeTable[1073] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("schedRef", m_TypeTable[343]),
			new TypeBinding("schedule", m_TypeTable[1051]),
			new TypeBinding("enabled", m_TypeTable[0])
		}, ScheduleUpdateDescriptor.class, false);

		m_TypeTable[1074] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("flashCache", m_TypeTable[343]),
			new TypeBinding("cachedVolume", m_TypeTable[343]),
			new TypeBinding("flashCacheMapRef", m_TypeTable[343])
		}, FlashCacheMap.class, false);

		m_TypeTable[1075] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("retCode", m_TypeTable[152]),
			new TypeBinding("volumeListResponse", new ArraySpec(m_TypeTable[956], 0, true, VolumeResponse.class))
		}, VolumeListReturned.class, false);

		m_TypeTable[1076] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("target", m_TypeTable[343]),
			new TypeBinding("settings", m_TypeTable[899])
		}, TargetPropertiesUpdateDescriptor.class, false);

		m_TypeTable[1077] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("returnCode", m_TypeTable[152]),
			new TypeBinding("serialNumber", new StringSpec(0)),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("logs", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, DriveLogData.class, false);

		m_TypeTable[1078] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(665, "membersRequiringDeletion", m_TypeTable[1064])
		}, AsyncMirrorGroupActionResult.class);

		m_TypeTable[1079] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("serialNumber", new StringSpec(0)),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("log", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, EnvCardLogData.class, false);

		m_TypeTable[1080] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("pitDataBytes", m_TypeTable[6]),
			new TypeBinding("deltaLogBytes", m_TypeTable[6]),
			new TypeBinding("bytesAvailable", m_TypeTable[6]),
			new TypeBinding("mirrorRef", m_TypeTable[343])
		}, AsyncMirrorRepositoryUtilization.class, false);

		m_TypeTable[1081] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "capacity", new ArraySpec(m_TypeTable[1047], 0, true, ThinVolumeConsumedCapacity.class))
		}, ThinVolumeConsumedCapacityReturned.class);

		m_TypeTable[1082] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("descriptorList", new ArraySpec(m_TypeTable[964], 0, true, KeyValueTagMappingSetDescriptor.class))
		}, KeyValueTagMappingSetDescriptorList.class, false);

		m_TypeTable[1083] = new UnionSpec(true, "rawDataTransferType", m_TypeTable[194], new AlternateBinding[] {
			new AlternateBinding(1, "dq", m_TypeTable[340]),
			new AlternateBinding(3, "dbmRec", m_TypeTable[532]),
			new AlternateBinding(2, "dbmBlk", m_TypeTable[364]),
			new AlternateBinding(4, "dbmCheck", m_TypeTable[477]),
			new AlternateBinding(5, "enclosureStateCapture", m_TypeTable[693]),
			new AlternateBinding(6, "dplCoreDump", m_TypeTable[415]),
			new AlternateBinding(7, "ioStatistics", m_TypeTable[357]),
			new AlternateBinding(8, "fdiDemsLog", m_TypeTable[980]),
			new AlternateBinding(9, "drivePerformanceHistory", m_TypeTable[514]),
			new AlternateBinding(10, "iocDump", m_TypeTable[431]),
			new AlternateBinding(11, "driveHealthLogs", m_TypeTable[600]),
			new AlternateBinding(12, "ctrlPerformanceParms", m_TypeTable[487]),
			new AlternateBinding(16, "dom0SupportDataStartDetails", m_TypeTable[419]),
			new AlternateBinding(17, "wlcAnalyticsStartDetails", m_TypeTable[310]),
			new AlternateBinding(18, "autoLoadBalanceStatisticsLog", m_TypeTable[335])
		}, RawDataRetrieveStartDetails.class);

		m_TypeTable[1084] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("viewRef", m_TypeTable[343]),
			new TypeBinding("retainRepositoryMembers", m_TypeTable[0])
		}, PITViewDeletionDescriptor.class, false);

		m_TypeTable[1085] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("pitViewRef", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, PITViewRefList.class, false);

		m_TypeTable[1086] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("internalMessage", m_TypeTable[976]),
			new TypeBinding("previouslySent", m_TypeTable[0])
		}, InternalMessageDesc.class, false);

		m_TypeTable[1087] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("memberVolumeLabel", m_TypeTable[337]),
			new TypeBinding("memberVolumeGroupLabel", m_TypeTable[337]),
			new TypeBinding("memberCandidate", m_TypeTable[1056]),
			new TypeBinding("memberCapacity", m_TypeTable[6])
		}, ConcatVolumeNewVolumeCandidate.class, false);

		m_TypeTable[1088] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("schedRef", m_TypeTable[343]),
			new TypeBinding("scheduleStatus", m_TypeTable[68]),
			new TypeBinding("action", m_TypeTable[221]),
			new TypeBinding("targetObject", m_TypeTable[343]),
			new TypeBinding("schedule", m_TypeTable[1051]),
			new TypeBinding("creationTime", m_TypeTable[6]),
			new TypeBinding("lastRunTime", m_TypeTable[6]),
			new TypeBinding("nextRunTime", m_TypeTable[6]),
			new TypeBinding("stopTime", m_TypeTable[6])
		}, ScheduleInstance.class, false);

		m_TypeTable[1089] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interconnectCRURef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[54]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("manufacturerDate", m_TypeTable[6]),
			new TypeBinding("vendorName", new StringSpec(0)),
			new TypeBinding("vendorPN", new StringSpec(0)),
			new TypeBinding("vendorSN", new StringSpec(0)),
			new TypeBinding("fruType", new StringSpec(0)),
			new TypeBinding("readyToRemove", m_TypeTable[0]),
			new TypeBinding("rtrAttributes", m_TypeTable[750]),
			new TypeBinding("repairPolicy", m_TypeTable[799])
		}, InterconnectCRU.class, false);

		m_TypeTable[1090] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("dependentVolume", m_TypeTable[343]),
			new TypeBinding("dependency", m_TypeTable[1036]),
			new TypeBinding("isPortable", m_TypeTable[0])
		}, ExportDependency.class, false);

		m_TypeTable[1091] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("mirrorMember", m_TypeTable[343]),
			new TypeBinding("faultTime", m_TypeTable[6]),
			new TypeBinding("percentComplete", m_TypeTable[7])
		}, AsyncMirrorGroupMemberFaultIndication.class, false);

		m_TypeTable[1092] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("repositoryUtilization", new ArraySpec(m_TypeTable[1080], 0, true, AsyncMirrorRepositoryUtilization.class))
		}, AsyncMirrorRepositoryUtilizationList.class, false);

		m_TypeTable[1093] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("action", m_TypeTable[221]),
			new TypeBinding("targetObject", m_TypeTable[500]),
			new TypeBinding("schedule", m_TypeTable[1051]),
			new TypeBinding("enabled", m_TypeTable[0])
		}, ScheduleCreationDescriptor.class, false);

		m_TypeTable[1094] = new UnionSpec(true, "ioInterfaceType", m_TypeTable[276], new AlternateBinding[] {
			new AlternateBinding(5, "iscsiConnectionDetail", m_TypeTable[915]),
			new AlternateBinding(2, "fibreConnectionDetail", m_TypeTable[647])
		}, ScsiRemoteTargetConnections.class);

		m_TypeTable[1095] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaces", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("enhancedEthernetFlowControlStatus", m_TypeTable[200]),
			new TypeBinding("enhEthFeaturesState", m_TypeTable[540]),
			new TypeBinding("localTLVs", m_TypeTable[923]),
			new TypeBinding("operationalTLVs", m_TypeTable[923]),
			new TypeBinding("remoteTLVs", m_TypeTable[923])
		}, EnhancedEthernetStatistics.class, false);

		m_TypeTable[1096] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("repositoryUtilization", new ArraySpec(m_TypeTable[924], 0, true, PITGroupRepositoryUtilization.class))
		}, PITGroupRepositoryUtilizationList.class, false);

		m_TypeTable[1097] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("candidateSelectionType", m_TypeTable[953]),
			new TypeBinding("raidLevel", m_TypeTable[36]),
			new TypeBinding("phyDriveType", m_TypeTable[21]),
			new TypeBinding("dssPreallocEnabled", m_TypeTable[0]),
			new TypeBinding("securityType", m_TypeTable[173]),
			new TypeBinding("driveMediaType", m_TypeTable[67]),
			new TypeBinding("onlyProtectionInformationCapable", m_TypeTable[0]),
			new TypeBinding("volumeCandidateRequestData", m_TypeTable[468]),
			new TypeBinding("allocateReservedSpace", m_TypeTable[0]),
			new TypeBinding("securityLevel", m_TypeTable[83])
		}, VolumeCandidateRequest.class, false);

		m_TypeTable[1098] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "data", new ArraySpec(m_TypeTable[1043], 0, true, ThinVolumeRepositoryExpansionHistoryData.class))
		}, ThinVolumeRepositoryExpansionHistoryListReturned.class);

		m_TypeTable[1099] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("viewRef", m_TypeTable[343]),
			new TypeBinding("fullWarnThreshold", m_TypeTable[7]),
			new TypeBinding("viewLabel", m_TypeTable[337])
		}, PITViewParamsUpdateDescriptor.class, false);

		m_TypeTable[1100] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("viewRef", m_TypeTable[343]),
			new TypeBinding("worldWideName", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("baseVol", m_TypeTable[343]),
			new TypeBinding("basePIT", m_TypeTable[343]),
			new TypeBinding("boundToPIT", m_TypeTable[0]),
			new TypeBinding("accessMode", m_TypeTable[13]),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("status", m_TypeTable[232]),
			new TypeBinding("currentManager", m_TypeTable[315]),
			new TypeBinding("preferredManager", m_TypeTable[315]),
			new TypeBinding("repositoryVolume", m_TypeTable[343]),
			new TypeBinding("fullWarnThreshold", m_TypeTable[7]),
			new TypeBinding("viewTime", m_TypeTable[6]),
			new TypeBinding("viewSequenceNumber", m_TypeTable[6]),
			new TypeBinding("perms", m_TypeTable[345]),
			new TypeBinding("volumeHandle", m_TypeTable[7]),
			new TypeBinding("clusterSize", m_TypeTable[7]),
			new TypeBinding("maxRepositoryCapacity", m_TypeTable[6]),
			new TypeBinding("unusableRepositoryCapacity", m_TypeTable[6]),
			new TypeBinding("membership", m_TypeTable[457]),
			new TypeBinding("mgmtClientAttribute", m_TypeTable[7]),
			new TypeBinding("offline", m_TypeTable[0])
		}, PITView.class, false);

		m_TypeTable[1101] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controller", m_TypeTable[315]),
			new TypeBinding("baselinedStats", m_TypeTable[754]),
			new TypeBinding("pitStats", m_TypeTable[1021])
		}, IbStatisticalData.class, false);

		m_TypeTable[1102] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("wwn", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("flashCacheRef", m_TypeTable[343]),
			new TypeBinding("flashCacheBase", m_TypeTable[655]),
			new TypeBinding("fcDriveInfo", m_TypeTable[838])
		}, FlashCache.class, false);

		m_TypeTable[1103] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "statBundle", m_TypeTable[1072])
		}, CumulativeStatisticsBundleReturned.class);

		m_TypeTable[1104] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("itNexus", m_TypeTable[1048]),
			new TypeBinding("registrationKey", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, PRegistrant.class, false);

		m_TypeTable[1105] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("initiatorRef", m_TypeTable[343]),
			new TypeBinding("settings", m_TypeTable[1065])
		}, InitiatorPropertiesUpdateDescriptor.class, false);

		m_TypeTable[1106] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("viewBytesUsed", m_TypeTable[6]),
			new TypeBinding("viewBytesAvailable", m_TypeTable[6]),
			new TypeBinding("viewRef", m_TypeTable[343])
		}, PITViewRepositoryUtilization.class, false);

		m_TypeTable[1107] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("localEndpoint", m_TypeTable[1052]),
			new TypeBinding("remoteEndpoint", m_TypeTable[1052])
		}, IscsiSessionEndpoints.class, false);

		m_TypeTable[1108] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "utilization", m_TypeTable[1092])
		}, AsyncMirrorRepositoryUtilizationListReturned.class);

		m_TypeTable[1109] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("trapDestinationTestDescriptor", new ArraySpec(m_TypeTable[967], 0, true, SNMPTrapDestinationTestDescriptor.class))
		}, SNMPTrapDestinationTestDescriptorList.class, false);

		m_TypeTable[1110] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("details", m_TypeTable[1083]),
			new TypeBinding("controllerRef", m_TypeTable[315])
		}, RawDataRetrieveStartDesc.class, false);

		m_TypeTable[1111] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("nodeName", new ArraySpec(m_TypeTable[648], 1, true, ScsiNodeName.class)),
			new TypeBinding("SCSIInitiatorTargetBaseProperties", m_TypeTable[1015])
		}, InitiatorTargetInitialProperties.class, false);

		m_TypeTable[1112] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("candidate", m_TypeTable[1056]),
			new TypeBinding("label", m_TypeTable[337])
		}, VolumeGroupCreationDescriptor.class, false);

		m_TypeTable[1113] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("syncProgress", new ArraySpec(m_TypeTable[1070], 0, true, AsyncMirrorGroupSyncProgress.class))
		}, AsyncMirrorGroupSyncProgressList.class, false);

		m_TypeTable[1114] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("flashCacheMap", new ArraySpec(m_TypeTable[1074], 0, true, FlashCacheMap.class)),
			new TypeBinding("flashCache", new ArraySpec(m_TypeTable[1102], 0, true, FlashCache.class))
		}, FlashCacheBundle.class, false);

		m_TypeTable[1115] = new UnionSpec(true, "ioInterfaceType", m_TypeTable[276], new AlternateBinding[] {
			new AlternateBinding(2, "fibreEsmAttributes", m_TypeTable[963]),
			new AlternateBinding(4, "sasEsmAttributes", m_TypeTable[634])
		}, EsmInterfaceAttributes.class);

		m_TypeTable[1116] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("flashCacheRef", m_TypeTable[343])
		}, VolumeFlashCacheDescriptor.class, false);

		m_TypeTable[1117] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("percentComplete", m_TypeTable[7]),
			new TypeBinding("timeToCompletion", m_TypeTable[7]),
			new TypeBinding("syncBytes", m_TypeTable[6]),
			new TypeBinding("mirrorMemberRef", m_TypeTable[343])
		}, AsyncMirrorGroupMemberInitialSyncOperation.class, false);

		m_TypeTable[1118] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("settings", m_TypeTable[1065])
		}, InitiatorCreationDescriptor.class, false);

		m_TypeTable[1119] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("viewRef", m_TypeTable[343]),
			new TypeBinding("basePIT", m_TypeTable[343])
		}, PITViewRestartDescriptor.class, false);

		m_TypeTable[1120] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ipv4DefaultRouterAddress", m_TypeTable[560]),
			new TypeBinding("ipv6DefaultRouterAddress", m_TypeTable[649]),
			new TypeBinding("ipv6CandidateDefaultRouterAddresses", new ArraySpec(m_TypeTable[649], 0, true, IpV6AddressData.class)),
			new TypeBinding("remoteAccessEnabled", m_TypeTable[0]),
			new TypeBinding("dnsProperties", m_TypeTable[823]),
			new TypeBinding("ntpProperties", m_TypeTable[1026])
		}, ControllerNetworkSettings.class, false);

		m_TypeTable[1121] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("candidate", m_TypeTable[1056]),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("manager", m_TypeTable[315]),
			new TypeBinding("capacity", m_TypeTable[6]),
			new TypeBinding("segmentSize", m_TypeTable[7]),
			new TypeBinding("readAhead", m_TypeTable[7]),
			new TypeBinding("writeZeros", m_TypeTable[0]),
			new TypeBinding("noMapping", m_TypeTable[0]),
			new TypeBinding("volumeGroupLabel", m_TypeTable[337]),
			new TypeBinding("protectionType", m_TypeTable[136])
		}, VolumeCreationDescriptor.class, false);

		m_TypeTable[1122] = new UnionSpec(true, "interfaceType", m_TypeTable[202], new AlternateBinding[] {
			new AlternateBinding(1, "ethernet", m_TypeTable[1030])
		}, NetInterfaceTypeData.class);

		m_TypeTable[1123] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("syncStats", new ArraySpec(m_TypeTable[997], 0, true, AsyncMirrorSyncStatistics.class))
		}, AsyncMirrorSyncStatisticsList.class, false);

		m_TypeTable[1124] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("esmRef", m_TypeTable[343]),
			new TypeBinding("status", m_TypeTable[267]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("nonRedundantAccess", m_TypeTable[0]),
			new TypeBinding("partNumber", new StringSpec(0)),
			new TypeBinding("serialNumber", new StringSpec(0)),
			new TypeBinding("manufacturerDate", m_TypeTable[6]),
			new TypeBinding("manufacturer", new StringSpec(0)),
			new TypeBinding("fruType", new StringSpec(0)),
			new TypeBinding("softwareVersion", new StringSpec(0)),
			new TypeBinding("esmInterfaceData", m_TypeTable[656]),
			new TypeBinding("productID", new StringSpec(0)),
			new TypeBinding("workingChannel", m_TypeTable[7]),
			new TypeBinding("currentSpeed", m_TypeTable[149]),
			new TypeBinding("maxSpeed", m_TypeTable[149]),
			new TypeBinding("reserved1", new OpaqueSpec(8, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("fibreEsm", m_TypeTable[760]),
			new TypeBinding("rtrAttributes", m_TypeTable[750]),
			new TypeBinding("esmInterfaceAttributes", m_TypeTable[1115]),
			new TypeBinding("boardId", new StringSpec(0)),
			new TypeBinding("factoryDefaultsData", m_TypeTable[551]),
			new TypeBinding("repairPolicy", m_TypeTable[799]),
			new TypeBinding("isTrunkCapable", m_TypeTable[0]),
			new TypeBinding("trunkMiswire", m_TypeTable[0]),
			new TypeBinding("locateInProgress", m_TypeTable[0]),
			new TypeBinding("hasTrayIdentityIndicator", m_TypeTable[0]),
			new TypeBinding("esmType", m_TypeTable[160])
		}, Esm.class, false);

		m_TypeTable[1125] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("statsRequestType", m_TypeTable[32]),
			new TypeBinding("memberList", m_TypeTable[1064]),
			new TypeBinding("sampleLimit", m_TypeTable[7])
		}, AsyncMirrorSyncStatisticsRequestDescriptor.class, false);

		m_TypeTable[1126] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("socConnectedDeviceData", m_TypeTable[985])
		}, SocConnectedDevice.class, false);

		m_TypeTable[1127] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controller", m_TypeTable[315]),
			new TypeBinding("settings", m_TypeTable[1028])
		}, ControllerPropertiesUpdateDescriptor.class, false);

		m_TypeTable[1128] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("label", new ArraySpec(m_TypeTable[337], 1, true, String.class)),
			new TypeBinding("hostRef", new ArraySpec(m_TypeTable[343], 1, true, String.class)),
			new TypeBinding("portId", new ArraySpec(m_TypeTable[1045], 1, true, SCSIInitiatorPortId.class))
		}, HostPortMutableProperties.class, false);

		m_TypeTable[1129] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("socPortMode", m_TypeTable[287]),
			new TypeBinding("device", m_TypeTable[1126]),
			new TypeBinding("socPortDiagData", m_TypeTable[293])
		}, SocPortData.class, false);

		m_TypeTable[1130] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostLabel", m_TypeTable[337]),
			new TypeBinding("hostType", new StringSpec(0)),
			new TypeBinding("hostPortId", new ArraySpec(m_TypeTable[1045], 0, true, SCSIInitiatorPortId.class))
		}, PendingHost.class, false);

		m_TypeTable[1131] = new UnionSpec(true, "candType", m_TypeTable[51], new AlternateBinding[] {
			new AlternateBinding(1, "newVolCandidate", m_TypeTable[1087]),
			new AlternateBinding(2, "existVolCandidate", m_TypeTable[929]),
			new AlternateBinding(3, "expansionDescriptor", m_TypeTable[447])
		}, ConcatVolumeCandidate.class);

		m_TypeTable[1132] = new UnionSpec(true, "commandSet", m_TypeTable[218], new AlternateBinding[] {
			new AlternateBinding(2, "nvmeofProperties", m_TypeTable[1063])
		}, NVMeCommandProtocolProperties.class);
	}

	private static void __init16() {

		m_TypeTable[1133] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("snapshotVol", new ArraySpec(m_TypeTable[943], 0, true, SnapshotVolume.class)),
			new TypeBinding("mirrorVol", new ArraySpec(m_TypeTable[1035], 0, true, MirrorProxyVolume.class)),
			new TypeBinding("metadataVol", new ArraySpec(m_TypeTable[996], 0, true, MetadataVolume.class)),
			new TypeBinding("remoteVol", new ArraySpec(m_TypeTable[893], 0, true, RemoteVolume.class)),
			new TypeBinding("volumeCopy", new ArraySpec(m_TypeTable[1019], 0, true, VolumeCopy.class)),
			new TypeBinding("pitGroup", new ArraySpec(m_TypeTable[995], 0, true, PITGroup.class)),
			new TypeBinding("pit", new ArraySpec(m_TypeTable[822], 0, true, PIT.class)),
			new TypeBinding("pitView", new ArraySpec(m_TypeTable[1100], 0, true, PITView.class)),
			new TypeBinding("pitConsistencyGroup", new ArraySpec(m_TypeTable[764], 0, true, PITConsistencyGroup.class)),
			new TypeBinding("concatVolume", new ArraySpec(m_TypeTable[958], 0, true, ConcatVolume.class)),
			new TypeBinding("concatVolMember", new ArraySpec(m_TypeTable[961], 0, true, ConcatVolumeMember.class)),
			new TypeBinding("pitConsistencyGroupView", new ArraySpec(m_TypeTable[730], 0, true, PITConsistencyGroupView.class)),
			new TypeBinding("thinVolume", new ArraySpec(m_TypeTable[1025], 0, true, ThinVolume.class)),
			new TypeBinding("asyncMirrorGroup", new ArraySpec(m_TypeTable[759], 0, true, AsyncMirrorGroup.class)),
			new TypeBinding("asyncMirrorGroupMember", new ArraySpec(m_TypeTable[1024], 0, true, AsyncMirrorGroupMember.class)),
			new TypeBinding("asyncMirrorGroupIncompleteMember", new ArraySpec(m_TypeTable[940], 0, true, AsyncMirrorGroupIncompleteMember.class))
		}, HLVolumeBundle.class, false);

		m_TypeTable[1134] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("remoteRef", m_TypeTable[343]),
			new TypeBinding("nodeName", m_TypeTable[648]),
			new TypeBinding("SCSIInitiatorTargetBaseProperties", m_TypeTable[1015])
		}, RemoteTarget.class, false);

		m_TypeTable[1135] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("candidate", m_TypeTable[1131]),
			new TypeBinding("mediaScanParams", m_TypeTable[501])
		}, ConcatVolumeCreationDescriptor.class, false);

		m_TypeTable[1136] = new UnionSpec(true, "returnCode", m_TypeTable[152], "thisSequenceNumber", m_TypeTable[7], new AlternateBinding[] {
			new AlternateBinding(1, "info", m_TypeTable[1022])
		}, RawDataRetrieveResult.class);

		m_TypeTable[1137] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeCandidate", new ArraySpec(m_TypeTable[1056], 0, true, VolumeCandidate.class)),
			new TypeBinding("returnCode", m_TypeTable[152])
		}, VolumeCandidateList.class, false);

		m_TypeTable[1138] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("connectionId", m_TypeTable[7]),
			new TypeBinding("iscsiInterface", m_TypeTable[343]),
			new TypeBinding("maxTransmitDataSegmentLength", m_TypeTable[7]),
			new TypeBinding("sendingMarkers", m_TypeTable[0]),
			new TypeBinding("activeIscsiVersion", m_TypeTable[3]),
			new TypeBinding("mutualAuthentication", m_TypeTable[0]),
			new TypeBinding("negotiatedSettings", m_TypeTable[598]),
			new TypeBinding("endpoints", m_TypeTable[1042])
		}, IscsiConnection.class, false);

		m_TypeTable[1139] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("sequenceNumber", m_TypeTable[6]),
			new TypeBinding("eventType", m_TypeTable[7]),
			new TypeBinding("timeStamp", m_TypeTable[6]),
			new TypeBinding("category", m_TypeTable[175]),
			new TypeBinding("componentType", m_TypeTable[165]),
			new TypeBinding("componentLocation", m_TypeTable[1001]),
			new TypeBinding("locationValid", m_TypeTable[0]),
			new TypeBinding("priority", m_TypeTable[55]),
			new TypeBinding("eventSourceController", m_TypeTable[7]),
			new TypeBinding("ASC", m_TypeTable[7]),
			new TypeBinding("ASCQ", m_TypeTable[7]),
			new TypeBinding("senseKey", m_TypeTable[7]),
			new TypeBinding("rawData", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("extComponentLocation", m_TypeTable[664]),
			new TypeBinding("controlParams", m_TypeTable[469])
		}, MelEntry.class, false);

		m_TypeTable[1140] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("scheduleCreationDescriptor", new ArraySpec(m_TypeTable[1093], 0, true, ScheduleCreationDescriptor.class))
		}, ScheduleCreationDescriptorList.class, false);

		m_TypeTable[1141] = new UnionSpec(true, "option", m_TypeTable[50], new AlternateBinding[] {
			new AlternateBinding(1, "descriptor", m_TypeTable[1093])
		}, OptionalScheduleCreationDescriptor.class);

		m_TypeTable[1142] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("viewRef", m_TypeTable[343]),
			new TypeBinding("repositoryCandidate", m_TypeTable[1135]),
			new TypeBinding("fullWarnThreshold", m_TypeTable[7])
		}, PITViewRWConversionDescriptor.class, false);

		m_TypeTable[1143] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controller", m_TypeTable[315]),
			new TypeBinding("baselinedStats", m_TypeTable[1010])
		}, NVMeoFStatisticalData.class, false);

		m_TypeTable[1144] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostPortRef", m_TypeTable[343]),
			new TypeBinding("hostPortName", m_TypeTable[311]),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("hostRef", m_TypeTable[343]),
			new TypeBinding("hostPortTypeIndex", m_TypeTable[7]),
			new TypeBinding("isSAControlled", m_TypeTable[0]),
			new TypeBinding("confirmLUNMappingCreation", m_TypeTable[0]),
			new TypeBinding("portId", m_TypeTable[1045]),
			new TypeBinding("portInactive", m_TypeTable[0])
		}, HostPort.class, false);

		m_TypeTable[1145] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cgRef", m_TypeTable[343]),
			new TypeBinding("baseVolume", m_TypeTable[343]),
			new TypeBinding("repositoryCandidate", m_TypeTable[1135])
		}, PITConsistencyGroupAddMemberDescriptor.class, false);

		m_TypeTable[1146] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("remoteTargetSettings", m_TypeTable[1111])
		}, RemoteTargetCreationDescriptor.class, false);

		m_TypeTable[1147] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaceRef", m_TypeTable[343]),
			new TypeBinding("channelType", m_TypeTable[206]),
			new TypeBinding("netInterfaceTypeData", m_TypeTable[1122])
		}, NetworkInterface.class, false);

		m_TypeTable[1148] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controller", m_TypeTable[315]),
			new TypeBinding("localPort", m_TypeTable[343]),
			new TypeBinding("remoteTargetConnections", m_TypeTable[1094])
		}, ScsiRemoteConnection.class, false);

		m_TypeTable[1149] = new TypedefSpec(new ArraySpec(m_TypeTable[1144], 0, true, HostPort.class), UnlabeledHostPorts.class);

		m_TypeTable[1150] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("valid", m_TypeTable[0]),
			new TypeBinding("socDeviceData", m_TypeTable[611]),
			new TypeBinding("socPortData", new ArraySpec(m_TypeTable[1129], 0, true, SocPortData.class))
		}, SocData.class, false);

		m_TypeTable[1151] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("scheduleUpdateDescriptor", new ArraySpec(m_TypeTable[1073], 0, true, ScheduleUpdateDescriptor.class))
		}, ScheduleUpdateDescriptorList.class, false);

		m_TypeTable[1152] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "syncStats", m_TypeTable[1123])
		}, AsyncMirrorSyncStatisticsListReturned.class);

		m_TypeTable[1153] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("candidate", m_TypeTable[1056]),
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("poolUtilizationWarningThreshold", m_TypeTable[7]),
			new TypeBinding("poolUtilizationCriticalThreshold", m_TypeTable[7]),
			new TypeBinding("degradedReconstructPriority", m_TypeTable[87]),
			new TypeBinding("criticalReconstructPriority", m_TypeTable[87]),
			new TypeBinding("backgroundOperationPriority", m_TypeTable[87])
		}, DiskPoolCreationDescriptor.class, false);

		m_TypeTable[1154] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("statsRequestType", m_TypeTable[32]),
			new TypeBinding("memberList", m_TypeTable[1064])
		}, AsyncMirrorSyncStatisticsResetDescriptor.class, false);

		m_TypeTable[1155] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "statBundle", new ArraySpec(m_TypeTable[1072], 0, true, CumulativeStatisticsBundle.class))
		}, CumulativeStatisticsBundleListReturned.class);

		m_TypeTable[1156] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("channelType", m_TypeTable[206]),
			new TypeBinding("sasAttachedDeviceData", m_TypeTable[1050])
		}, SasAttachedDevice.class, false);

		m_TypeTable[1157] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "envCardLog", m_TypeTable[1079])
		}, EnvCardLogDataReturned.class);

		m_TypeTable[1158] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("baseVolume", m_TypeTable[343]),
			new TypeBinding("snapshotLabel", m_TypeTable[337]),
			new TypeBinding("repositoryLabel", m_TypeTable[337]),
			new TypeBinding("repositoryCapacity", m_TypeTable[6]),
			new TypeBinding("warnThreshold", m_TypeTable[7]),
			new TypeBinding("extentStart", m_TypeTable[6]),
			new TypeBinding("extentSize", m_TypeTable[6]),
			new TypeBinding("repFullPolicy", m_TypeTable[47]),
			new TypeBinding("candidate", m_TypeTable[1056]),
			new TypeBinding("noMapping", m_TypeTable[0]),
			new TypeBinding("volumeGroupLabel", m_TypeTable[337]),
			new TypeBinding("createInStoppedState", m_TypeTable[0]),
			new TypeBinding("snapshotSchedule", m_TypeTable[1141])
		}, SnapshotCreationDescriptor.class, false);

		m_TypeTable[1159] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "ibStatistics", new ArraySpec(m_TypeTable[1101], 0, true, IbStatisticalData.class))
		}, IbStatisticsReturned.class);

		m_TypeTable[1160] = new UnionSpec(true, "candidateType", m_TypeTable[75], new AlternateBinding[] {
			new AlternateBinding(1, "existingRemoteTarget", m_TypeTable[343]),
			new AlternateBinding(2, "newRemoteTarget", m_TypeTable[1146])
		}, AsyncMirrorGroupMirrorConnectionDescriptor.class);

		m_TypeTable[1161] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("registrant", new ArraySpec(m_TypeTable[1104], 0, true, PRegistrant.class))
		}, PRegistrantList.class, false);

		m_TypeTable[1162] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("pendingHost", m_TypeTable[1130]),
			new TypeBinding("matchingConfiguredHost", m_TypeTable[343]),
			new TypeBinding("matchType", m_TypeTable[246]),
			new TypeBinding("hostNameChange", m_TypeTable[0]),
			new TypeBinding("hostTypeChange", m_TypeTable[0]),
			new TypeBinding("unconfiguredPorts", new ArraySpec(m_TypeTable[1045], 0, true, SCSIInitiatorPortId.class)),
			new TypeBinding("matchingPorts", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("conflictingPorts", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("missingPorts", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("matchingInitiators", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("conflictingInitiators", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("missingInitiators", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, MatchedPendingHost.class, false);

		m_TypeTable[1163] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("repositoryUtilization", new ArraySpec(m_TypeTable[1106], 0, true, PITViewRepositoryUtilization.class))
		}, PITViewRepositoryUtilizationList.class, false);

		m_TypeTable[1164] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("incompleteMemberRef", m_TypeTable[343]),
			new TypeBinding("localVolume", m_TypeTable[343]),
			new TypeBinding("repositoryCandidate", m_TypeTable[1135])
		}, AsyncMirrorGroupAddSecondaryMemberDescriptor.class, false);

		m_TypeTable[1165] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "dependency", new ArraySpec(m_TypeTable[1090], 0, true, ExportDependency.class))
		}, ExportDependenciesReturned.class);

		m_TypeTable[1166] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("ethernetPortStats", new ArraySpec(m_TypeTable[569], 0, true, EthernetPortStatistics.class)),
			new TypeBinding("tcpStats", new ArraySpec(m_TypeTable[783], 0, true, TcpStatisticalData.class)),
			new TypeBinding("ipStats", new ArraySpec(m_TypeTable[811], 0, true, IpEndpointStatistics.class)),
			new TypeBinding("enhStats", new ArraySpec(m_TypeTable[1095], 0, true, EnhancedEthernetStatistics.class))
		}, IscsiInterfaceStatistics.class, false);

		m_TypeTable[1167] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("label", m_TypeTable[337]),
			new TypeBinding("repFullPolicy", m_TypeTable[19]),
			new TypeBinding("fullWarnThreshold", m_TypeTable[7]),
			new TypeBinding("autoDeleteLimit", m_TypeTable[7]),
			new TypeBinding("rollbackPriority", m_TypeTable[139]),
			new TypeBinding("cgSchedule", m_TypeTable[1141])
		}, PITConsistencyGroupCreationDescriptor.class, false);

		m_TypeTable[1168] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "progress", m_TypeTable[1113])
		}, AsyncMirrorGroupSyncProgressListReturned.class);

		m_TypeTable[1169] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupPercentComplete", m_TypeTable[7]),
			new TypeBinding("groupTimeToCompletion", m_TypeTable[7]),
			new TypeBinding("groupSyncBytes", m_TypeTable[6]),
			new TypeBinding("groupRef", m_TypeTable[343]),
			new TypeBinding("memberProgress", new ArraySpec(m_TypeTable[1117], 0, true, AsyncMirrorGroupMemberInitialSyncOperation.class))
		}, AsyncMirrorGroupInitialSyncOperation.class, false);

		m_TypeTable[1170] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("addMember", new ArraySpec(m_TypeTable[1145], 0, true, PITConsistencyGroupAddMemberDescriptor.class))
		}, PITConsistencyGroupAddMemberDescriptorList.class, false);

		m_TypeTable[1171] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("socData", new ArraySpec(m_TypeTable[1150], 0, true, SocData.class))
		}, SocStatistics.class, false);

		m_TypeTable[1172] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("rlsData", new ArraySpec(m_TypeTable[790], 0, true, RLSData.class)),
			new TypeBinding("socData", new ArraySpec(m_TypeTable[1150], 0, true, SocData.class))
		}, ChannelDiagFcDependentResults.class, false);

		m_TypeTable[1173] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("pendingHost", m_TypeTable[1130]),
			new TypeBinding("unconfiguredPorts", new ArraySpec(m_TypeTable[1045], 0, true, SCSIInitiatorPortId.class)),
			new TypeBinding("conflictingPorts", new ArraySpec(m_TypeTable[343], 0, true, String.class)),
			new TypeBinding("conflictingInitiators", new ArraySpec(m_TypeTable[343], 0, true, String.class))
		}, UnmatchedPendingHost.class, false);

		m_TypeTable[1174] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "utilization", m_TypeTable[1096])
		}, PITGroupRepositoryUtilizationListReturned.class);

		m_TypeTable[1175] = new UnionSpec(true, "accessMode", m_TypeTable[13], new AlternateBinding[] {
			new AlternateBinding(1, "repositoryCandidate", m_TypeTable[1135])
		}, PITViewRepositoryCreationDescriptor.class);

		m_TypeTable[1176] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("repositoryCreationDescriptor", m_TypeTable[1135]),
			new TypeBinding("volumeLabel", m_TypeTable[337]),
			new TypeBinding("manager", m_TypeTable[315]),
			new TypeBinding("virtualCapacity", m_TypeTable[6]),
			new TypeBinding("provisionedCapacityQuota", m_TypeTable[6]),
			new TypeBinding("readAhead", m_TypeTable[7]),
			new TypeBinding("noMapping", m_TypeTable[0]),
			new TypeBinding("repositoryExpansionPolicy", m_TypeTable[23]),
			new TypeBinding("growthAlertThreshold", m_TypeTable[7]),
			new TypeBinding("protectionType", m_TypeTable[136])
		}, ThinVolumeCreationDescriptor.class, false);

		m_TypeTable[1177] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("hostPortRef", m_TypeTable[343]),
			new TypeBinding("settings", m_TypeTable[1128])
		}, HostPortPropertiesUpdateDescriptor.class, false);

		m_TypeTable[1178] = new UnionSpec(true, "volAction", m_TypeTable[199], new AlternateBinding[] {
			new AlternateBinding(2, "copyback", m_TypeTable[950]),
			new AlternateBinding(4, "reconstruct", m_TypeTable[950]),
			new AlternateBinding(5, "capacityExpansion", m_TypeTable[950]),
			new AlternateBinding(6, "raidMigration", m_TypeTable[950]),
			new AlternateBinding(7, "raidMigrationandExpansion", m_TypeTable[950]),
			new AlternateBinding(8, "segSize", m_TypeTable[950]),
			new AlternateBinding(9, "volExpansion", m_TypeTable[950]),
			new AlternateBinding(10, "volAndCapExpansion", m_TypeTable[950]),
			new AlternateBinding(12, "defrag", m_TypeTable[950]),
			new AlternateBinding(3, "init", m_TypeTable[802]),
			new AlternateBinding(13, "format", m_TypeTable[802]),
			new AlternateBinding(14, "sync", m_TypeTable[965]),
			new AlternateBinding(18, "copy", m_TypeTable[1032]),
			new AlternateBinding(17, "parityScan", m_TypeTable[950]),
			new AlternateBinding(19, "rollback", m_TypeTable[903]),
			new AlternateBinding(20, "pitRollback", m_TypeTable[864]),
			new AlternateBinding(21, "initialSync", m_TypeTable[1169]),
			new AlternateBinding(23, "rebalancing", m_TypeTable[950]),
			new AlternateBinding(24, "copyThenFail", m_TypeTable[950]),
			new AlternateBinding(25, "copyThenFailPending", m_TypeTable[950]),
			new AlternateBinding(26, "copyThenReplace", m_TypeTable[950]),
			new AlternateBinding(27, "copyThenReplaceAndFail", m_TypeTable[950]),
			new AlternateBinding(22, "reconstructCritical", m_TypeTable[950]),
			new AlternateBinding(28, "thinDefrag", m_TypeTable[941]),
			new AlternateBinding(33, "volCreation", m_TypeTable[941]),
			new AlternateBinding(34, "volDeletion", m_TypeTable[941])
		}, LongLivedOperation.class);

		m_TypeTable[1179] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("parent", m_TypeTable[780]),
			new TypeBinding("attachedDevice", m_TypeTable[1156]),
			new TypeBinding("state", m_TypeTable[253]),
			new TypeBinding("miswireType", m_TypeTable[122]),
			new TypeBinding("channelPortRef", m_TypeTable[343]),
			new TypeBinding("sasPhys", new ArraySpec(m_TypeTable[296], 0, true, SasPhy.class)),
			new TypeBinding("portTypeData", m_TypeTable[630]),
			new TypeBinding("portMode", m_TypeTable[80]),
			new TypeBinding("domainNumber", m_TypeTable[7]),
			new TypeBinding("attachedChannelPortRef", m_TypeTable[343]),
			new TypeBinding("discoveryStatus", m_TypeTable[7])
		}, SasPort.class, false);

		m_TypeTable[1180] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("type", m_TypeTable[94]),
			new TypeBinding("tsih", m_TypeTable[7]),
			new TypeBinding("endpoints", m_TypeTable[1107]),
			new TypeBinding("negotiatedSettings", m_TypeTable[301]),
			new TypeBinding("connections", new ArraySpec(m_TypeTable[1138], 0, true, IscsiConnection.class))
		}, IscsiSession.class, false);

		m_TypeTable[1181] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("expanderRef", m_TypeTable[343]),
			new TypeBinding("parent", m_TypeTable[813]),
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("deviceName", m_TypeTable[379]),
			new TypeBinding("vendorId", new StringSpec(0)),
			new TypeBinding("productId", new StringSpec(0)),
			new TypeBinding("fwVersion", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("expanderPorts", new ArraySpec(m_TypeTable[1179], 0, true, SasPort.class)),
			new TypeBinding("domainNumber", m_TypeTable[7])
		}, SasExpander.class, false);

		m_TypeTable[1182] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("volumeRef", m_TypeTable[343]),
			new TypeBinding("lun", m_TypeTable[7]),
			new TypeBinding("reservationTypeID", m_TypeTable[236]),
			new TypeBinding("registrantList", m_TypeTable[1161]),
			new TypeBinding("holdingITNexus", m_TypeTable[1048]),
			new TypeBinding("ptpl_A", m_TypeTable[0])
		}, PRegistration.class, false);

		m_TypeTable[1183] = new UnionSpec(true, "commandProtocol", m_TypeTable[164], new AlternateBinding[] {
			new AlternateBinding(2, "nvmeProperties", m_TypeTable[1132])
		}, CommandProtocolProperties.class);

		m_TypeTable[1184] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "remoteConnections", new ArraySpec(m_TypeTable[1148], 0, true, ScsiRemoteConnection.class))
		}, ScsiRemoteConnectionsReturned.class);

		m_TypeTable[1185] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("events", new ArraySpec(m_TypeTable[1139], 0, true, MelEntry.class))
		}, MelEntryList.class, false);

		m_TypeTable[1186] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("concatVol", m_TypeTable[343]),
			new TypeBinding("expandCandidate", m_TypeTable[1131])
		}, ConcatVolumeExpansionDescriptor.class, false);

		m_TypeTable[1187] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("fan", new ArraySpec(m_TypeTable[1002], 0, true, Fan.class)),
			new TypeBinding("battery", new ArraySpec(m_TypeTable[991], 0, true, Battery.class)),
			new TypeBinding("powerSupply", new ArraySpec(m_TypeTable[1020], 0, true, PowerSupply.class)),
			new TypeBinding("thermalSensor", new ArraySpec(m_TypeTable[1067], 0, true, ThermalSensor.class)),
			new TypeBinding("esm", new ArraySpec(m_TypeTable[1124], 0, true, Esm.class)),
			new TypeBinding("ups", new ArraySpec(m_TypeTable[1055], 0, true, Ups.class)),
			new TypeBinding("minihub", new ArraySpec(m_TypeTable[920], 0, true, Minihub.class)),
			new TypeBinding("gbic", new ArraySpec(m_TypeTable[1009], 0, true, Gbic.class)),
			new TypeBinding("sfp", new ArraySpec(m_TypeTable[1034], 0, true, Sfp.class)),
			new TypeBinding("interconnectCRU", new ArraySpec(m_TypeTable[1089], 0, true, InterconnectCRU.class)),
			new TypeBinding("supportCRU", new ArraySpec(m_TypeTable[974], 0, true, SupportCRU.class)),
			new TypeBinding("alarm", new ArraySpec(m_TypeTable[982], 0, true, Alarm.class)),
			new TypeBinding("hostBoard", new ArraySpec(m_TypeTable[998], 0, true, HostBoard.class)),
			new TypeBinding("sasExpander", new ArraySpec(m_TypeTable[1181], 0, true, SasExpander.class)),
			new TypeBinding("cacheBackupDevice", new ArraySpec(m_TypeTable[911], 0, true, CacheBackupDevice.class)),
			new TypeBinding("cacheMemoryDimm", new ArraySpec(m_TypeTable[898], 0, true, CacheMemoryDimm.class)),
			new TypeBinding("processorMemoryDimm", new ArraySpec(m_TypeTable[1046], 0, true, ProcessorMemoryDimm.class)),
			new TypeBinding("drawer", new ArraySpec(m_TypeTable[908], 0, true, Drawer.class))
		}, ComponentBundle.class, false);

		m_TypeTable[1188] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("settings", m_TypeTable[1128])
		}, HostPortCreateDescriptor.class, false);

		m_TypeTable[1189] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "utilization", m_TypeTable[1163])
		}, PITViewRepositoryUtilizationListReturned.class);

		m_TypeTable[1190] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "nvmeofStatistics", new ArraySpec(m_TypeTable[1143], 0, true, NVMeoFStatisticalData.class))
		}, NVMeoFStatisticsReturned.class);

		m_TypeTable[1191] = new UnionSpec(true, "initAction", m_TypeTable[255], new AlternateBinding[] {
			new AlternateBinding(2, "newProvisionedCapacity", m_TypeTable[6]),
			new AlternateBinding(3, "newRepositoryCandidate", m_TypeTable[1135])
		}, ThinVolumeReinitializeParams.class);

		m_TypeTable[1192] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("attachedDevice", m_TypeTable[1156]),
			new TypeBinding("sasPhyData", new ArraySpec(m_TypeTable[476], 0, true, SasPhyData.class))
		}, SasPortData.class, false);

		m_TypeTable[1193] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("controller", m_TypeTable[315]),
			new TypeBinding("timeData", m_TypeTable[517]),
			new TypeBinding("iscsiInterfaceStatistics", m_TypeTable[1166]),
			new TypeBinding("iscsiTargetStatistics", new ArraySpec(m_TypeTable[556], 0, true, IscsiTargetStatistics.class)),
			new TypeBinding("iscsiInitiatorStatistics", new ArraySpec(m_TypeTable[547], 0, true, IscsiInitiatorStatistics.class))
		}, IscsiStatisticalData.class, false);

		m_TypeTable[1194] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("groupRef", m_TypeTable[343]),
			new TypeBinding("localVolume", m_TypeTable[343]),
			new TypeBinding("remotePassword", m_TypeTable[309]),
			new TypeBinding("repositoryCandidate", m_TypeTable[1135])
		}, AsyncMirrorGroupAddPrimaryMemberDescriptor.class, false);

		m_TypeTable[1195] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("baseVolume", m_TypeTable[343]),
			new TypeBinding("pitGroupLabel", m_TypeTable[337]),
			new TypeBinding("repositoryCandidate", m_TypeTable[1135]),
			new TypeBinding("repFullPolicy", m_TypeTable[19]),
			new TypeBinding("fullWarnThreshold", m_TypeTable[7]),
			new TypeBinding("autoDeleteLimit", m_TypeTable[7]),
			new TypeBinding("rollbackPriority", m_TypeTable[139]),
			new TypeBinding("pitSchedule", m_TypeTable[1141])
		}, PITGroupCreationDescriptor.class, false);

		m_TypeTable[1196] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("saPortGroup", new ArraySpec(m_TypeTable[880], 0, true, SAPortGroup.class)),
			new TypeBinding("saPort", new ArraySpec(m_TypeTable[879], 0, true, SAPort.class)),
			new TypeBinding("cluster", new ArraySpec(m_TypeTable[558], 0, true, Cluster.class)),
			new TypeBinding("host", new ArraySpec(m_TypeTable[699], 0, true, Host.class)),
			new TypeBinding("hostPort", new ArraySpec(m_TypeTable[1144], 0, true, HostPort.class)),
			new TypeBinding("lunMapping", new ArraySpec(m_TypeTable[674], 0, true, LUNMapping.class)),
			new TypeBinding("initiator", new ArraySpec(m_TypeTable[990], 0, true, Initiator.class)),
			new TypeBinding("target", new ArraySpec(m_TypeTable[968], 0, true, Target.class)),
			new TypeBinding("remoteTarget", new ArraySpec(m_TypeTable[1134], 0, true, RemoteTarget.class))
		}, StoragePoolBundle.class, false);

		m_TypeTable[1197] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "longLivedOpsProgress", new ArraySpec(m_TypeTable[1178], 0, true, LongLivedOperation.class))
		}, LongLivedOpsProgressReturn.class);

		m_TypeTable[1198] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "iscsiStatistics", new ArraySpec(m_TypeTable[1193], 0, true, IscsiStatisticalData.class))
		}, IscsiStatisticsReturned.class);

		m_TypeTable[1199] = new UnionSpec(true, "type", m_TypeTable[42], new AlternateBinding[] {
			new AlternateBinding(1, "matchedPendingHost", m_TypeTable[1162]),
			new AlternateBinding(2, "unmatchedPendingHost", m_TypeTable[1173])
		}, CheckedPendingHost.class);

		m_TypeTable[1200] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("connectionDescriptor", m_TypeTable[1160]),
			new TypeBinding("groupLabel", m_TypeTable[337]),
			new TypeBinding("syncIntervalMinutes", m_TypeTable[7]),
			new TypeBinding("syncCompletionTimeAlertThresholdMinutes", m_TypeTable[7]),
			new TypeBinding("recoveryPointAgeAlertThresholdMinutes", m_TypeTable[7]),
			new TypeBinding("repositoryUtilizationWarnThreshold", m_TypeTable[7]),
			new TypeBinding("remotePassword", m_TypeTable[309])
		}, AsyncMirrorGroupCreationDescriptor.class, false);

		m_TypeTable[1201] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "socStatistics", m_TypeTable[1171])
		}, SocStatisticsReturned.class);

		m_TypeTable[1202] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("returnCode", m_TypeTable[152]),
			new TypeBinding("persistentRegistration", new ArraySpec(m_TypeTable[1182], 0, true, PRegistration.class))
		}, PRegistrationList.class, false);

		m_TypeTable[1203] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("basePIT", m_TypeTable[343]),
			new TypeBinding("viewLabel", m_TypeTable[337]),
			new TypeBinding("repositoryDescriptor", m_TypeTable[1175]),
			new TypeBinding("fullWarnThreshold", m_TypeTable[7])
		}, PITViewCreationDescriptor.class, false);

		m_TypeTable[1204] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("channel", m_TypeTable[7]),
			new TypeBinding("currentInterfaceSpeed", m_TypeTable[149]),
			new TypeBinding("maximumInterfaceSpeed", m_TypeTable[149]),
			new TypeBinding("part", new StringSpec(0)),
			new TypeBinding("revision", m_TypeTable[7]),
			new TypeBinding("isDegraded", m_TypeTable[0]),
			new TypeBinding("iocPort", m_TypeTable[1179]),
			new TypeBinding("interfaceRef", m_TypeTable[343]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("protectionInformationCapable", m_TypeTable[0]),
			new TypeBinding("oneWayMaxRate", m_TypeTable[6]),
			new TypeBinding("bidirectionalMaxRate", m_TypeTable[6])
		}, SasInterface.class, false);

		m_TypeTable[1205] = new UnionSpec(true, "componentType", m_TypeTable[118], new AlternateBinding[] {
			new AlternateBinding(12, "alarm", m_TypeTable[982]),
			new AlternateBinding(2, "battery", m_TypeTable[991]),
			new AlternateBinding(16, "cacheBackupDevice", m_TypeTable[911]),
			new AlternateBinding(17, "cacheMemoryDimm", m_TypeTable[898]),
			new AlternateBinding(5, "esm", m_TypeTable[1124]),
			new AlternateBinding(1, "fan", m_TypeTable[1002]),
			new AlternateBinding(8, "gbic", m_TypeTable[1009]),
			new AlternateBinding(13, "hostBoard", m_TypeTable[998]),
			new AlternateBinding(14, "sasExpander", m_TypeTable[1181]),
			new AlternateBinding(10, "interconnectCRU", m_TypeTable[1089]),
			new AlternateBinding(7, "minihub", m_TypeTable[920]),
			new AlternateBinding(3, "powerSupply", m_TypeTable[1020]),
			new AlternateBinding(18, "processorMemoryDimm", m_TypeTable[1046]),
			new AlternateBinding(9, "sfp", m_TypeTable[1034]),
			new AlternateBinding(11, "supportCRU", m_TypeTable[974]),
			new AlternateBinding(4, "thermalSensor", m_TypeTable[1067]),
			new AlternateBinding(6, "ups", m_TypeTable[1055])
		}, ComponentTypeData.class);

		m_TypeTable[1206] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "sessions", new ArraySpec(m_TypeTable[1180], 0, true, IscsiSession.class))
		}, IscsiSessionsReturned.class);
	}

	private static void __init17() {

		m_TypeTable[1207] = new UnionSpec(true, "recFailureType", m_TypeTable[134], new AlternateBinding[] {
			new AlternateBinding(250, "altCtlrBoardIdUnreadable", m_TypeTable[315]),
			new AlternateBinding(390, "baseControllerDiagFailed", m_TypeTable[315]),
			new AlternateBinding(103, "batteryConfigMismatch", m_TypeTable[343]),
			new AlternateBinding(5, "batteryWarn", m_TypeTable[343]),
			new AlternateBinding(261, "batteryTempWarn", m_TypeTable[343]),
			new AlternateBinding(91, "batteryStatUnknown", m_TypeTable[343]),
			new AlternateBinding(176, "batteryCapacityWarn", m_TypeTable[343]),
			new AlternateBinding(251, "failedCacheBackupDevice", m_TypeTable[343]),
			new AlternateBinding(253, "insufficientCacheBackupDeviceCapacity", m_TypeTable[315]),
			new AlternateBinding(252, "writeProtectedCacheBackupDevice", m_TypeTable[343]),
			new AlternateBinding(71, "channelDegradedFailure", m_TypeTable[356]),
			new AlternateBinding(81, "channelFailedFailure", m_TypeTable[302]),
			new AlternateBinding(38, "chanMiswire", m_TypeTable[315]),
			new AlternateBinding(114, "vpdEepromCorrupted", m_TypeTable[343]),
			new AlternateBinding(79, "ctlMismatch", m_TypeTable[315]),
			new AlternateBinding(96, "ctlMiswire", m_TypeTable[955]),
			new AlternateBinding(226, "ddfDriveOtherVendor", m_TypeTable[343]),
			new AlternateBinding(224, "failedDedicatedMirrorChannel", m_TypeTable[315]),
			new AlternateBinding(300, "degradedHostBoard", m_TypeTable[343]),
			new AlternateBinding(13, "volDegraded", m_TypeTable[343]),
			new AlternateBinding(64, "drvBypassCauseUnknown", m_TypeTable[343]),
			new AlternateBinding(119, "driveBypassedSinglePort", m_TypeTable[343]),
			new AlternateBinding(63, "speedMismatchDrive", m_TypeTable[343]),
			new AlternateBinding(205, "incompatibleDownRevDacstoreDriveRef", m_TypeTable[343]),
			new AlternateBinding(335, "mixedDriveEnclosureMiswire", new ArraySpec(m_TypeTable[621], 0, true, MiswiredDriveChannelList.class)),
			new AlternateBinding(211, "incompatibleSectorSizeDriveRef", m_TypeTable[343]),
			new AlternateBinding(204, "incompatibleUpRevDacstoreDriveRef", m_TypeTable[343]),
			new AlternateBinding(109, "driveTrayExpansionFeature", m_TypeTable[866]),
			new AlternateBinding(92, "driveTraysNotGroupedTogether", m_TypeTable[673]),
			new AlternateBinding(117, "misconfiguredEnclosure", m_TypeTable[343]),
			new AlternateBinding(31, "trayCodeMismatch", m_TypeTable[343]),
			new AlternateBinding(120, "esmFactoryDefaultsMismatch", m_TypeTable[343]),
			new AlternateBinding(104, "trayHardwareMismatch", m_TypeTable[343]),
			new AlternateBinding(46, "esmMiswire", m_TypeTable[343]),
			new AlternateBinding(60, "esmStatUnknown", m_TypeTable[343]),
			new AlternateBinding(254, "batteryExpired", m_TypeTable[343]),
			new AlternateBinding(255, "integratedBatteryExpired", m_TypeTable[343]),
			new AlternateBinding(6, "batteryFail", m_TypeTable[343]),
			new AlternateBinding(101, "batterySystemFail", m_TypeTable[784]),
			new AlternateBinding(80, "discreteLineFail", m_TypeTable[315]),
			new AlternateBinding(23, "driveFail", m_TypeTable[343]),
			new AlternateBinding(12, "chFail", m_TypeTable[315]),
			new AlternateBinding(4, "esmFail", m_TypeTable[343]),
			new AlternateBinding(1, "fanFail", m_TypeTable[343]),
			new AlternateBinding(115, "vpdI2cFailure", m_TypeTable[315]),
			new AlternateBinding(89, "iccCruFail", m_TypeTable[343]),
			new AlternateBinding(3, "miniHubFail", m_TypeTable[343]),
			new AlternateBinding(16, "volFailDuringModifyMultiRaid", m_TypeTable[343]),
			new AlternateBinding(15, "volFailDuringModify", m_TypeTable[343]),
			new AlternateBinding(2, "powerSupplyFail", m_TypeTable[343]),
			new AlternateBinding(90, "supportCruFail", m_TypeTable[343]),
			new AlternateBinding(37, "transceiverModuleFailed", m_TypeTable[343]),
			new AlternateBinding(17, "volFail", m_TypeTable[343]),
			new AlternateBinding(20, "volFailAwaitingInit", m_TypeTable[343]),
			new AlternateBinding(14, "volFailInterruptedWrite", m_TypeTable[343]),
			new AlternateBinding(18, "volFailMultiRaid", m_TypeTable[343]),
			new AlternateBinding(58, "fanStatUnknown", m_TypeTable[343]),
			new AlternateBinding(217, "foreignDriveHasInconsistentRole", m_TypeTable[857]),
			new AlternateBinding(212, "foreignDriveInconsistent", m_TypeTable[343]),
			new AlternateBinding(213, "foreignDriveRefersToNativeDrive", m_TypeTable[343]),
			new AlternateBinding(47, "ghostVolume", m_TypeTable[343]),
			new AlternateBinding(93, "goldkeyFeature", m_TypeTable[866]),
			new AlternateBinding(105, "failedHostBoard", m_TypeTable[343]),
			new AlternateBinding(325, "hostBoardIdMismatch", m_TypeTable[343]),
			new AlternateBinding(121, "hostBoardStatUnknown", m_TypeTable[343]),
			new AlternateBinding(203, "missingHotSpareDriveRef", m_TypeTable[343]),
			new AlternateBinding(206, "iccCruStatUnknown", m_TypeTable[343]),
			new AlternateBinding(326, "iccMissing", m_TypeTable[343]),
			new AlternateBinding(19, "volImpaired", m_TypeTable[343]),
			new AlternateBinding(24, "driveFailImpendingHigh", m_TypeTable[343]),
			new AlternateBinding(26, "driveFailImpendingLow", m_TypeTable[343]),
			new AlternateBinding(25, "driveFailImpendingMed", m_TypeTable[343]),
			new AlternateBinding(220, "incompatibleFailedLegacyDrive", m_TypeTable[857]),
			new AlternateBinding(301, "ldFwVersionMismatch", m_TypeTable[369]),
			new AlternateBinding(230, "legacyVgNotOptimal", m_TypeTable[343]),
			new AlternateBinding(82, "linkSpeedDetectionError", m_TypeTable[800]),
			new AlternateBinding(327, "linkSpeedMismatch", m_TypeTable[315]),
			new AlternateBinding(32, "driveRedundancyFailure", m_TypeTable[875]),
			new AlternateBinding(34, "esmRedundancyFailure", m_TypeTable[848]),
			new AlternateBinding(33, "trayRedundancyFailure", m_TypeTable[749]),
			new AlternateBinding(8, "maxTempWarn", m_TypeTable[343]),
			new AlternateBinding(11, "memParityError", m_TypeTable[315]),
			new AlternateBinding(50, "metadataOffline", m_TypeTable[1004]),
			new AlternateBinding(65, "minihubRef", m_TypeTable[343]),
			new AlternateBinding(51, "dualMirrorPrimary", m_TypeTable[1041]),
			new AlternateBinding(52, "dualMirrorSecondary", m_TypeTable[1000]),
			new AlternateBinding(53, "mirrorUnsynchronized", m_TypeTable[901]),
			new AlternateBinding(78, "mixeddrivetypesFeature", m_TypeTable[866]),
			new AlternateBinding(215, "nativeVgForeignDriveMutualRef", m_TypeTable[857]),
			new AlternateBinding(214, "nativeVgRefersToForeignDrive", m_TypeTable[857]),
			new AlternateBinding(77, "networkSetupError", m_TypeTable[315]),
			new AlternateBinding(7, "nominalTempWarn", m_TypeTable[343]),
			new AlternateBinding(39, "nonFruBatteryWarn", m_TypeTable[315]),
			new AlternateBinding(40, "nonFruBatteryFail", m_TypeTable[315]),
			new AlternateBinding(68, "nonFruBatteryRemoved", m_TypeTable[315]),
			new AlternateBinding(10, "nonPreferredPath", m_TypeTable[562]),
			new AlternateBinding(28, "offlineCtl", m_TypeTable[315]),
			new AlternateBinding(22, "volGroupOffline", m_TypeTable[343]),
			new AlternateBinding(30, "spmFeature", m_TypeTable[866]),
			new AlternateBinding(29, "passiveCtl", m_TypeTable[315]),
			new AlternateBinding(76, "pathDegradedFailure", m_TypeTable[906]),
			new AlternateBinding(209, "performanceTierFeature", m_TypeTable[866]),
			new AlternateBinding(59, "powerSupplyStatUnknown", m_TypeTable[343]),
			new AlternateBinding(259, "procMemTooSmallForCache", m_TypeTable[315]),
			new AlternateBinding(210, "raid6Feature", m_TypeTable[866]),
			new AlternateBinding(108, "incorrectSupportCru", m_TypeTable[343]),
			new AlternateBinding(55, "remoteVolNoArray", m_TypeTable[933]),
			new AlternateBinding(56, "remoteVolNoFabric", m_TypeTable[944]),
			new AlternateBinding(54, "remoteVolNoLUN", m_TypeTable[954]),
			new AlternateBinding(57, "remoteVolWWNChangeFailed", m_TypeTable[913]),
			new AlternateBinding(207, "alarmRemoved", m_TypeTable[343]),
			new AlternateBinding(67, "batteryRemoved", m_TypeTable[343]),
			new AlternateBinding(102, "batteryPackRemoved", m_TypeTable[343]),
			new AlternateBinding(66, "esmRemoved", m_TypeTable[343]),
			new AlternateBinding(84, "fanRemoved", m_TypeTable[343]),
			new AlternateBinding(87, "iccCruRemoved", m_TypeTable[343]),
			new AlternateBinding(85, "powerSupplyRemoved", m_TypeTable[343]),
			new AlternateBinding(88, "supportCruRemoved", m_TypeTable[343]),
			new AlternateBinding(86, "tempSensorRemoved", m_TypeTable[343]),
			new AlternateBinding(107, "replacedDriveWrongType", m_TypeTable[343]),
			new AlternateBinding(43, "repositoryFull", m_TypeTable[938]),
			new AlternateBinding(42, "repositoryOverThreshold", m_TypeTable[343]),
			new AlternateBinding(41, "rpaParityError", m_TypeTable[315]),
			new AlternateBinding(49, "rvmFeature", m_TypeTable[866]),
			new AlternateBinding(112, "degradedSasPort", m_TypeTable[1179]),
			new AlternateBinding(113, "failedSasPort", m_TypeTable[1179]),
			new AlternateBinding(111, "miswiredSasPort", m_TypeTable[1179]),
			new AlternateBinding(44, "snapFail", m_TypeTable[1038]),
			new AlternateBinding(48, "snapshotFeature", m_TypeTable[866]),
			new AlternateBinding(73, "speedNegError", m_TypeTable[376]),
			new AlternateBinding(100, "submodelMismatch", m_TypeTable[315]),
			new AlternateBinding(99, "submodelNotSet", m_TypeTable[315]),
			new AlternateBinding(98, "submodelNotSupported", m_TypeTable[315]),
			new AlternateBinding(97, "supportCruNoInput", m_TypeTable[343]),
			new AlternateBinding(208, "supportCruStatUnknown", m_TypeTable[343]),
			new AlternateBinding(61, "tempSensorStatUnknown", m_TypeTable[343]),
			new AlternateBinding(62, "transceiverModuleStatUnknown", m_TypeTable[343]),
			new AlternateBinding(36, "trayIDConflicts", m_TypeTable[673]),
			new AlternateBinding(35, "trayIDMismatch", m_TypeTable[343]),
			new AlternateBinding(27, "driveUncertified", m_TypeTable[343]),
			new AlternateBinding(83, "esmUncertified", m_TypeTable[343]),
			new AlternateBinding(223, "cacheMemorySizeUnsupported", m_TypeTable[315]),
			new AlternateBinding(328, "unsupportedHostBoard", m_TypeTable[343]),
			new AlternateBinding(45, "miniHubUnsupported", m_TypeTable[343]),
			new AlternateBinding(72, "unsupportedTray", m_TypeTable[343]),
			new AlternateBinding(9, "upsOnBattery", m_TypeTable[343]),
			new AlternateBinding(74, "usmDbFullError", m_TypeTable[559]),
			new AlternateBinding(75, "usmExistError", m_TypeTable[559]),
			new AlternateBinding(216, "vgCloned", m_TypeTable[343]),
			new AlternateBinding(218, "vgDrivePartOfMultipleVgs", m_TypeTable[857]),
			new AlternateBinding(225, "vgHasDrivePartOfMultipleVgs", m_TypeTable[857]),
			new AlternateBinding(69, "failedVolumeCopy", m_TypeTable[343]),
			new AlternateBinding(70, "volcopyFeature", m_TypeTable[866]),
			new AlternateBinding(201, "incompleteVolumeGroupRef", m_TypeTable[343]),
			new AlternateBinding(202, "missingVolumeGroupRef", m_TypeTable[343]),
			new AlternateBinding(200, "partialPresentVolumeGroupRef", m_TypeTable[343]),
			new AlternateBinding(21, "volHotSpareInUse", m_TypeTable[343]),
			new AlternateBinding(263, "hostRef", m_TypeTable[343]),
			new AlternateBinding(331, "securityKeyNeeded", m_TypeTable[791]),
			new AlternateBinding(334, "fdeFeature", m_TypeTable[866]),
			new AlternateBinding(266, "removedCtrl", m_TypeTable[315]),
			new AlternateBinding(336, "driveUnsuccessIsolationRedunMismatch", m_TypeTable[343]),
			new AlternateBinding(337, "driveThresExcdedMismatchCorrected", m_TypeTable[343]),
			new AlternateBinding(338, "inactiveHostPort", m_TypeTable[343]),
			new AlternateBinding(339, "inactiveInitiator", m_TypeTable[343]),
			new AlternateBinding(340, "protectionInformationFeature", m_TypeTable[866]),
			new AlternateBinding(341, "protectionInformationNotSupported", m_TypeTable[343]),
			new AlternateBinding(342, "driveCapacityInsufficient", m_TypeTable[343]),
			new AlternateBinding(344, "openDrawerRef", m_TypeTable[343]),
			new AlternateBinding(343, "failedDrawerRef", m_TypeTable[343]),
			new AlternateBinding(349, "driveRef", m_TypeTable[343]),
			new AlternateBinding(347, "solidStateDisksFeature", m_TypeTable[866]),
			new AlternateBinding(364, "fibreTrunkMiswire", m_TypeTable[872]),
			new AlternateBinding(365, "fibreTrunkIncompatibleEsm", m_TypeTable[343]),
			new AlternateBinding(368, "driveSlotLimitFeature", m_TypeTable[866]),
			new AlternateBinding(370, "newKeySequence", m_TypeTable[7]),
			new AlternateBinding(371, "fdeProxyKeyMgmtFeature", m_TypeTable[866]),
			new AlternateBinding(374, "sbbValidationFailure", m_TypeTable[343]),
			new AlternateBinding(376, "powerSupplyInvalid", m_TypeTable[343]),
			new AlternateBinding(377, "enclosureThermalShutdown", m_TypeTable[343]),
			new AlternateBinding(379, "unsupportedProtocolConnection", m_TypeTable[343]),
			new AlternateBinding(380, "twiBusFailed", m_TypeTable[343]),
			new AlternateBinding(381, "mismatchedEepromContents", m_TypeTable[343]),
			new AlternateBinding(384, "unsupportedCapacityDrive", m_TypeTable[343]),
			new AlternateBinding(385, "evalExpirationImminent", m_TypeTable[343]),
			new AlternateBinding(386, "keyInvalid", m_TypeTable[315]),
			new AlternateBinding(387, "multipleMismatchedKeys", m_TypeTable[315]),
			new AlternateBinding(388, "keyValidationLock", m_TypeTable[315]),
			new AlternateBinding(389, "cacheDataLoss", m_TypeTable[795]),
			new AlternateBinding(391, "featureOutOfCompliance", m_TypeTable[343]),
			new AlternateBinding(392, "driveIncompatiblePItype", m_TypeTable[343]),
			new AlternateBinding(393, "degradedDrawerRef", m_TypeTable[343]),
			new AlternateBinding(396, "ctlrIocDiagFailed", m_TypeTable[315]),
			new AlternateBinding(395, "invalidSataFlashConfig", m_TypeTable[315]),
			new AlternateBinding(394, "offlineCtlrIocDiagFailed", m_TypeTable[315]),
			new AlternateBinding(397, "chanSasPhyDisabledLocalWidePortDegraded", m_TypeTable[7]),
			new AlternateBinding(398, "chanSasPhyDisabledSharedWidePortDegraded", m_TypeTable[7]),
			new AlternateBinding(399, "drawerInvalid", m_TypeTable[343]),
			new AlternateBinding(400, "drawerRemoved", m_TypeTable[343]),
			new AlternateBinding(401, "driveUnsupportedInterposerFwVersion", m_TypeTable[343]),
			new AlternateBinding(402, "volumeOfflineDuringReconfig", m_TypeTable[343]),
			new AlternateBinding(403, "snapRollbackPaused", m_TypeTable[343]),
			new AlternateBinding(404, "pitRollbackPaused", m_TypeTable[343]),
			new AlternateBinding(405, "pitGroupOverWarnThreshold", m_TypeTable[343]),
			new AlternateBinding(406, "pitViewOverWarnThreshold", m_TypeTable[343]),
			new AlternateBinding(407, "pitGroupRepositoryFull", m_TypeTable[343]),
			new AlternateBinding(408, "pitViewRepositoryFull", m_TypeTable[343]),
			new AlternateBinding(409, "pitGroupFailed", m_TypeTable[343]),
			new AlternateBinding(410, "pitViewFailed", m_TypeTable[343]),
			new AlternateBinding(411, "pitPurged", m_TypeTable[343]),
			new AlternateBinding(412, "degradedAsyncMirrorGroup", m_TypeTable[834]),
			new AlternateBinding(414, "syncIntervalTimeExceeded", m_TypeTable[834]),
			new AlternateBinding(413, "failedAsyncMirror", m_TypeTable[343]),
			new AlternateBinding(415, "asyncMirrorRepositoryOverWarnThreshold", m_TypeTable[1091]),
			new AlternateBinding(416, "roleConflictMirrorGroup", m_TypeTable[343]),
			new AlternateBinding(420, "recoveryPointLostGroup", m_TypeTable[343]),
			new AlternateBinding(417, "incompatibleVolumeGroupSecurity", m_TypeTable[343]),
			new AlternateBinding(418, "orphanMirrorGroup", m_TypeTable[343]),
			new AlternateBinding(419, "orphanMirrorMember", m_TypeTable[343]),
			new AlternateBinding(421, "diskPoolStatePartial", m_TypeTable[343]),
			new AlternateBinding(422, "diskPoolStateIncomplete", m_TypeTable[343]),
			new AlternateBinding(423, "diskPoolStateMissing", m_TypeTable[343]),
			new AlternateBinding(424, "diskPoolReconstruction", m_TypeTable[343]),
			new AlternateBinding(425, "diskPoolUtilizationWarning", m_TypeTable[343]),
			new AlternateBinding(426, "diskPoolUtilizationCritical", m_TypeTable[343]),
			new AlternateBinding(427, "pitGroupPendingCreateFailed", m_TypeTable[343]),
			new AlternateBinding(428, "cgPendingCreateFailed", m_TypeTable[343]),
			new AlternateBinding(429, "thinVolumeOverThreshold", m_TypeTable[343]),
			new AlternateBinding(430, "thinVolumeRepositoryFull", m_TypeTable[343]),
			new AlternateBinding(431, "thinVolumeFailed", m_TypeTable[343]),
			new AlternateBinding(432, "fullSecondaryRepositoryMirrorMember", m_TypeTable[343]),
			new AlternateBinding(433, "suspendedMirrorGroup", m_TypeTable[343]),
			new AlternateBinding(434, "databaseMetadata", m_TypeTable[671]),
			new AlternateBinding(435, "fullPrimaryRepositoryMirrorMember", m_TypeTable[1091]),
			new AlternateBinding(436, "sataSCTCmndUnsupported", m_TypeTable[343]),
			new AlternateBinding(437, "diskPoolCapacityDepleted", m_TypeTable[343]),
			new AlternateBinding(438, "driveModelNumberUnsupported", m_TypeTable[343]),
			new AlternateBinding(439, "flashCacheNonOptimalDrives", m_TypeTable[1071]),
			new AlternateBinding(440, "flashCacheHotSpareInUse", m_TypeTable[1071]),
			new AlternateBinding(441, "nativeSATAIncompatibleNVSRAM", m_TypeTable[315]),
			new AlternateBinding(443, "diskPoolDriveFailure", m_TypeTable[343]),
			new AlternateBinding(444, "diskPoolInsufficientMemory", m_TypeTable[315]),
			new AlternateBinding(445, "orphanIncompleteMember", m_TypeTable[343]),
			new AlternateBinding(446, "pausedAltStateMirrorGroup", m_TypeTable[343]),
			new AlternateBinding(447, "pausedRoleChangeGroup", m_TypeTable[343]),
			new AlternateBinding(448, "driveEmulationIncompatibleAlignment", m_TypeTable[343]),
			new AlternateBinding(449, "redundancyFail", m_TypeTable[701]),
			new AlternateBinding(450, "mirrorProxyRef", m_TypeTable[343]),
			new AlternateBinding(451, "miswiredSasHost", m_TypeTable[1179]),
			new AlternateBinding(452, "miswiredSasCross", m_TypeTable[1179]),
			new AlternateBinding(453, "miswiredSasLoop", m_TypeTable[1179]),
			new AlternateBinding(454, "volGroupWaitingOnHotSpare", m_TypeTable[343]),
			new AlternateBinding(455, "missingAssignedDrives", new ArraySpec(m_TypeTable[377], 0, true, TraySlot.class)),
			new AlternateBinding(457, "diskPoolWaitingOnHotSpare", m_TypeTable[343]),
			new AlternateBinding(458, "controllerInServiceMode", m_TypeTable[315]),
			new AlternateBinding(459, "controllerInLockdown", m_TypeTable[315]),
			new AlternateBinding(460, "discoveryErrorSasPort", m_TypeTable[1179]),
			new AlternateBinding(465, "ntpResolutionFailure", m_TypeTable[516]),
			new AlternateBinding(466, "ntpQueryFailure", m_TypeTable[516]),
			new AlternateBinding(467, "ntpServiceFailureController", m_TypeTable[315]),
			new AlternateBinding(474, "misconfiguredHost", m_TypeTable[343]),
			new AlternateBinding(475, "hostRedundancyLossDetails", m_TypeTable[539]),
			new AlternateBinding(476, "excessiveRebootsDetected", m_TypeTable[353]),
			new AlternateBinding(477, "ctlrWithDirtyCacheNotFlushed", m_TypeTable[441]),
			new AlternateBinding(481, "kmsExpiringCertificate", m_TypeTable[359]),
			new AlternateBinding(482, "kmsExpiredCertificate", m_TypeTable[359]),
			new AlternateBinding(486, "kmsConnFailureEndpoint", m_TypeTable[861]),
			new AlternateBinding(487, "kmsServerErrorEndpoint", m_TypeTable[861]),
			new AlternateBinding(480, "directoryServicesDomain", m_TypeTable[454]),
			new AlternateBinding(488, "kmsKeyReqEndpoint", m_TypeTable[861])
		}, FailureTypeEntry.class);

		m_TypeTable[1208] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("commandProtocolProperties", new ArraySpec(m_TypeTable[1183], 0, true, CommandProtocolProperties.class))
		}, CommandProtocolPropertiesList.class, false);

		m_TypeTable[1209] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("thinVol", m_TypeTable[343]),
			new TypeBinding("initParams", m_TypeTable[1191])
		}, ThinVolumeReinitializeDescriptor.class, false);

		m_TypeTable[1210] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("portProvider", m_TypeTable[780]),
			new TypeBinding("portData", new ArraySpec(m_TypeTable[1192], 0, true, SasPortData.class))
		}, SasData.class, false);

		m_TypeTable[1211] = new TypedefSpec(new ArraySpec(m_TypeTable[1199], 0, true, CheckedPendingHost.class), CheckedPendingHostList.class);

		m_TypeTable[1212] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("cgRef", m_TypeTable[343]),
			new TypeBinding("pitSequenceNumber", m_TypeTable[6]),
			new TypeBinding("viewCreationDescriptor", new ArraySpec(m_TypeTable[1203], 0, true, PITViewCreationDescriptor.class)),
			new TypeBinding("label", m_TypeTable[337])
		}, PITConsistencyGroupViewCreationDescriptor.class, false);

		m_TypeTable[1213] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("componentData", m_TypeTable[1205]),
			new TypeBinding("reserved1", new OpaqueSpec(12, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, Component.class, false);

		m_TypeTable[1214] = new UnionSpec(true, "interfaceType", m_TypeTable[276], new AlternateBinding[] {
			new AlternateBinding(2, "fibre", m_TypeTable[914]),
			new AlternateBinding(6, "ib", m_TypeTable[994]),
			new AlternateBinding(5, "iscsi", m_TypeTable[1039]),
			new AlternateBinding(4, "sas", m_TypeTable[1204]),
			new AlternateBinding(3, "sata", m_TypeTable[975]),
			new AlternateBinding(1, "scsi", m_TypeTable[391])
		}, IOInterfaceTypeData.class);

		m_TypeTable[1215] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("sasData", new ArraySpec(m_TypeTable[1210], 0, true, SasData.class))
		}, ChannelDiagSasDependentResults.class, false);

		m_TypeTable[1216] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("active", m_TypeTable[0]),
			new TypeBinding("quiesced", m_TypeTable[0]),
			new TypeBinding("status", m_TypeTable[59]),
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("physicalLocation", m_TypeTable[888]),
			new TypeBinding("manufacturer", new StringSpec(0)),
			new TypeBinding("manufacturerDate", m_TypeTable[6]),
			new TypeBinding("appVersion", new StringSpec(0)),
			new TypeBinding("bootVersion", new StringSpec(0)),
			new TypeBinding("productID", new StringSpec(0)),
			new TypeBinding("productRevLevel", new StringSpec(0)),
			new TypeBinding("serialNumber", new StringSpec(0)),
			new TypeBinding("boardID", new StringSpec(0)),
			new TypeBinding("cacheMemorySize", m_TypeTable[7]),
			new TypeBinding("processorMemorySize", m_TypeTable[7]),
			new TypeBinding("hostInterfaces", new ArraySpec(m_TypeTable[1214], 0, true, IOInterfaceTypeData.class)),
			new TypeBinding("driveInterfaces", new ArraySpec(m_TypeTable[1214], 0, true, IOInterfaceTypeData.class)),
			new TypeBinding("netInterfaces", new ArraySpec(m_TypeTable[1122], 0, true, NetInterfaceTypeData.class)),
			new TypeBinding("inventory", new ArraySpec(m_TypeTable[546], 0, true, InventoryItem.class)),
			new TypeBinding("reserved1", new OpaqueSpec(12, false, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("reserved2", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY)),
			new TypeBinding("hostBoardID", new StringSpec(0)),
			new TypeBinding("physicalCacheMemorySize", m_TypeTable[7]),
			new TypeBinding("readyToRemove", m_TypeTable[0]),
			new TypeBinding("boardSubmodelID", new StringSpec(0)),
			new TypeBinding("submodelSupported", m_TypeTable[0]),
			new TypeBinding("oemPartNumber", new StringSpec(0)),
			new TypeBinding("partNumber", new StringSpec(0)),
			new TypeBinding("rtrAttributes", m_TypeTable[750]),
			new TypeBinding("bootTime", m_TypeTable[6]),
			new TypeBinding("modelName", new StringSpec(0)),
			new TypeBinding("networkSettings", m_TypeTable[1120]),
			new TypeBinding("repairPolicy", m_TypeTable[799]),
			new TypeBinding("flashCacheMemorySize", m_TypeTable[7]),
			new TypeBinding("ctrlIocDumpData", m_TypeTable[499]),
			new TypeBinding("locateInProgress", m_TypeTable[0]),
			new TypeBinding("hasTrayIdentityIndicator", m_TypeTable[0]),
			new TypeBinding("controllerErrorMode", m_TypeTable[190]),
			new TypeBinding("codeVersions", new ArraySpec(m_TypeTable[523], 0, true, VersionDescriptor.class))
		}, Controller.class, false);

		m_TypeTable[1217] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("failureList", new ArraySpec(m_TypeTable[1207], 0, true, FailureTypeEntry.class))
		}, FailureTypeList.class, false);

		m_TypeTable[1218] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("collectionElapsedTime", m_TypeTable[7]),
			new TypeBinding("sasData", new ArraySpec(m_TypeTable[1210], 0, true, SasData.class))
		}, SasStatistics.class, false);

		m_TypeTable[1219] = new UnionSpec(true, "interfaceType", m_TypeTable[276], new AlternateBinding[] {
			new AlternateBinding(2, "fcResults", m_TypeTable[1172]),
			new AlternateBinding(4, "sasResults", m_TypeTable[1215])
		}, ChannelDiagInterfaceDepResults.class);

		m_TypeTable[1220] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "checkedPendingHostList", m_TypeTable[1211])
		}, CheckedPendingHostListReturned.class);

		m_TypeTable[1221] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaceRef", m_TypeTable[343]),
			new TypeBinding("channelType", m_TypeTable[206]),
			new TypeBinding("ioInterfaceTypeData", m_TypeTable[1214]),
			new TypeBinding("controllerRef", m_TypeTable[315]),
			new TypeBinding("commandProtocolPropertiesList", m_TypeTable[1208])
		}, IoInterface.class, false);

		m_TypeTable[1222] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("device", m_TypeTable[765]),
			new TypeBinding("status", m_TypeTable[167]),
			new TypeBinding("actualTimeInterval", m_TypeTable[7]),
			new TypeBinding("iterationsAttempted", m_TypeTable[7]),
			new TypeBinding("channelResetsDetected", m_TypeTable[7]),
			new TypeBinding("iterationsPassed", m_TypeTable[7]),
			new TypeBinding("iterationsFailedWithMiscompares", m_TypeTable[7]),
			new TypeBinding("iterationsFailedWithSetupErrors", m_TypeTable[7]),
			new TypeBinding("iterationsFailedWithOutboundTimeouts", m_TypeTable[7]),
			new TypeBinding("iterationsFailedWithOutboundResets", m_TypeTable[7]),
			new TypeBinding("iterationsFailedWithOutboundMiscErrors", m_TypeTable[7]),
			new TypeBinding("iterationsFailedWithInboundTimeouts", m_TypeTable[7]),
			new TypeBinding("iterationsFailedWithInboundResets", m_TypeTable[7]),
			new TypeBinding("iterationsFailedWithInboundMiscErrors", m_TypeTable[7]),
			new TypeBinding("averageElapsedTimeForOutboundPhases", m_TypeTable[7]),
			new TypeBinding("varianceInElapsedTimeForOutboundPhases", m_TypeTable[7]),
			new TypeBinding("averageElapsedTimeForInboundPhases", m_TypeTable[7]),
			new TypeBinding("varianceInElapsedTimeForInboundPhases", m_TypeTable[7]),
			new TypeBinding("interfaceDependentResults", m_TypeTable[1219]),
			new TypeBinding("driveChannel", m_TypeTable[7])
		}, ChannelDiagWrRdVfyResults.class, false);

		m_TypeTable[1223] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "controllerHostIoInterfaces", new ArraySpec(m_TypeTable[1221], 0, true, IoInterface.class))
		}, ControllerHostIoInterfacesReturned.class);

		m_TypeTable[1224] = new UnionSpec(true, "type", m_TypeTable[208], new AlternateBinding[] {
			new AlternateBinding(0, "writeReadVerifyData", new ArraySpec(m_TypeTable[1222], 0, true, ChannelDiagWrRdVfyResults.class))
		}, ChannelDiagResults.class);

		m_TypeTable[1225] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("configGeneration", m_TypeTable[6]),
			new TypeBinding("sa", m_TypeTable[1057]),
			new TypeBinding("tray", new ArraySpec(m_TypeTable[910], 0, true, Tray.class)),
			new TypeBinding("componentBundle", m_TypeTable[1187]),
			new TypeBinding("controller", new ArraySpec(m_TypeTable[1216], 0, true, Controller.class)),
			new TypeBinding("drive", new ArraySpec(m_TypeTable[992], 0, true, Drive.class)),
			new TypeBinding("volumeGroup", new ArraySpec(m_TypeTable[733], 0, true, VolumeGroup.class)),
			new TypeBinding("volume", new ArraySpec(m_TypeTable[986], 0, true, Volume.class)),
			new TypeBinding("freeExtent", new ArraySpec(m_TypeTable[808], 0, true, FreeExtent.class)),
			new TypeBinding("dveVol", new ArraySpec(m_TypeTable[930], 0, true, DVEVolume.class)),
			new TypeBinding("storagePoolBundle", m_TypeTable[1196]),
			new TypeBinding("highLevelVolBundle", m_TypeTable[1133]),
			new TypeBinding("ghostVolBundle", m_TypeTable[936]),
			new TypeBinding("consistencyGroupBundle", m_TypeTable[984]),
			new TypeBinding("ioInterface", new ArraySpec(m_TypeTable[1221], 0, true, IoInterface.class)),
			new TypeBinding("networkInterface", new ArraySpec(m_TypeTable[1147], 0, true, NetworkInterface.class)),
			new TypeBinding("lockKeyIDs", new ArraySpec(m_TypeTable[617], 0, true, LockKeyID.class)),
			new TypeBinding("interposer", new ArraySpec(m_TypeTable[740], 0, true, Interposer.class)),
			new TypeBinding("ioInterfaceHicMap", new ArraySpec(m_TypeTable[707], 0, true, IoInterfaceHicMap.class)),
			new TypeBinding("schedule", new ArraySpec(m_TypeTable[1088], 0, true, ScheduleInstance.class)),
			new TypeBinding("remoteArray", new ArraySpec(m_TypeTable[774], 0, true, RemoteArray.class)),
			new TypeBinding("flashCacheBundle", m_TypeTable[1114]),
			new TypeBinding("snmpBundle", m_TypeTable[715]),
			new TypeBinding("applicationAwarenessBundle", m_TypeTable[1037])
		}, ObjectBundle.class, false);

		m_TypeTable[1226] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("interfaces", new ArraySpec(m_TypeTable[1214], 0, true, IOInterfaceTypeData.class))
		}, IOInterfaceTypeDataList.class, false);

		m_TypeTable[1227] = new UnionSpec(true, "returnCode", m_TypeTable[152], new AlternateBinding[] {
			new AlternateBinding(1, "sasStatistics", m_TypeTable[1218])
		}, SasStatisticsReturned.class);

		m_TypeTable[1228] = new StructSpec(true, new TypeBinding[] {
			new TypeBinding("returnCode", m_TypeTable[152]),
			new TypeBinding("testStartTime", m_TypeTable[6]),
			new TypeBinding("testEndTime", m_TypeTable[6]),
			new TypeBinding("diagResults", m_TypeTable[1224])
		}, ChannelDiagResultsReturned.class, false);
	}

	static
	{
		m_TypeTable = new TypeSpec[1229];

		__init0();
		__init1();
		__init2();
		__init3();
		__init4();
		__init5();
		__init6();
		__init7();
		__init8();
		__init9();
		__init10();
		__init11();
		__init12();
		__init13();
		__init14();
		__init15();
		__init16();
		__init17();
	}

	private static ProcTableEntry[] m_ProcTable;

	private static void __init18() {
		m_ProcTable[0] = new ProcTableEntry("discoverControllers", 1, 40, false, null, m_TypeTable[781],"Returns a DiscoveryResponse object that identifies the storage arrays and controllers known to the RPC server that handles this request. Response also indicates if RPC server is RAID controller or SYMbol RPC UTM agent.","None.","A DiscoveryResponse object that identifies the storage arrays and controllers known to the RPC server that handles this request. The response also indicates if the RPC server is a true RAID controller or a SYMbol RPC/UTM agent. In cases where the response comes from a controller, only one AccessibleController object will be identified, although it will contain the reference values of all controllers present in the storage array. If the response is from an agent, it will contain one AccessibleController for each controller that is accessible through the agent. Furthermore, each such object will identify the storage array to which it belongs, plus all other controllers present in the array.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[1] = new ProcTableEntry("bindToController", 2, 40, false, m_TypeTable[545], m_TypeTable[152],"This function is used to bind a new connection to a particular controller. If the server is actually a controller itself, the controller will just ensure that its CONTROLLER REF is the same as the one passed in as an argument. If the server is an agent, it will use the CONTROLLER REF argument to determine which locally-attached controller should be used for all further interactions over the RPC connection.","A descriptor value that identifies the controller to which all further requests on this RPC connection should be routed.","","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.noHeap));
		m_ProcTable[2] = new ProcTableEntry("assignVolumeGroupOwnership", 3, 300, true, m_TypeTable[917], m_TypeTable[152],"Instructs the SYMbol Server's controller to transfer ownership of a volume group and its associated volumes to another controller.","A descriptor that specifies the volume group being modified, and the controller that is to take ownership of the volume group, and thus all volumes defined on the volume group.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.cacheSyncFailure,ReturnCode.controllerInServiceMode,ReturnCode.iconFailure,ReturnCode.internalError,ReturnCode.invalidControllerref,ReturnCode.invalidRequest,ReturnCode.invalidVolumegroupref,ReturnCode.modesenseError,ReturnCode.notDualActive,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[3] = new ProcTableEntry("assignDrivesAsHotSpares", 4, 40, true, m_TypeTable[7], m_TypeTable[152],"This procedure causes the controller to automatically assign the specified number of drives as hot spares, in addition to any previously assigned hot spares.","The number of new hot spare drives to be added to the array's pool of hot spares.","","Am1base","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.noHeap,ReturnCode.noSparesAssigned,ReturnCode.ok,ReturnCode.someSparesAssigned,ReturnCode.tryAlternate));
		m_ProcTable[4] = new ProcTableEntry("assignSpecificDrivesAsHotSpares", 5, 40, true, m_TypeTable[817], m_TypeTable[152],"Instructs the SYMbol Server's controller to create hot spare drives out of the given drives.","A list of drive reference values, which identifies the drives to be assigned as hot spares.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.noHeap,ReturnCode.noSparesAssigned,ReturnCode.ok,ReturnCode.someSparesAssigned,ReturnCode.sparesSmallUnassigned,ReturnCode.tryAlternate));
		m_ProcTable[5] = new ProcTableEntry("getVolumeCandidates", 6, 60, false, m_TypeTable[1097], m_TypeTable[1137],"This procedure returns a list of volume candidates that can be used in an ensuing volume creation request.","A VolumeCandidateRequest descriptor that specifies the type of volume candidates to be returned to the caller.","A list of volume candidates that conform to the parameters specified in the request. If no such candidates exist, an empty list is returned. Possible return codes are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.invalidSecurity,ReturnCode.noFdeDrives,ReturnCode.volumeGroupSecure));
		m_ProcTable[6] = new ProcTableEntry("createVolume", 7, 540, true, m_TypeTable[1121], m_TypeTable[152],"This procedure causes a new volume to be created based on parameters provided by the caller in the argument structure. Note that a key parameter is a VolumeCandidate object that was previously returned by the controller as the result of a getVolumeCandidates operation. The user must select one such candidate, and then supply further information about the desired attributes of the volume when calling this procedure.","A VolumeCreationDescriptor object that provides attributes and properties of the volume to be created.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.cannotFormatVolume,ReturnCode.controllerInServiceMode,ReturnCode.driveNotExist,ReturnCode.driveNotUnassigned,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidLabel,ReturnCode.invalidSecurity,ReturnCode.invalidSegmentsize,ReturnCode.maxVolumesExceeded,ReturnCode.noFdeDrives,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.raid6FeatureDisabled,ReturnCode.raid6FeatureUnsupported,ReturnCode.tryAlternate,ReturnCode.volumeGroupReconstructing,ReturnCode.volumeGroupSecure,ReturnCode.volumeGroupUndergoingCopyback));
		m_ProcTable[7] = new ProcTableEntry("deassignDrivesAsHotSpares", 8, 40, true, m_TypeTable[817], m_TypeTable[152],"This procedure causes the drives specified by the argument to be deassigned as hot spares. They will be returned to the pool of unassigned drives, and thus be added to the unconfigured capacity pool of the storage array. Note that a hot spare drive cannot be deassigned if it is currently in use, sparing for a failed drive.","A list of DriveRef values that identifies all drives to be affected by this operation.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.noSparesDeassigned,ReturnCode.ok,ReturnCode.someSparesDeassigned,ReturnCode.tryAlternate));
		m_ProcTable[8] = new ProcTableEntry("deleteVolume", 9, 540, true, m_TypeTable[343], m_TypeTable[152],"This procedure is used to delete a Thin Volume. The procedure has been deprecated for deleting RAID Volumes - it has been replaced by the procedure deleteVolumeFromGroup.","The value of the AbstractVolRef for the volume to be deleted.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.repositoryMissing,ReturnCode.repositoryOffline,ReturnCode.repositoryReconfiguring,ReturnCode.reservationConflict,ReturnCode.rollbackInProgress,ReturnCode.volumeFormatting,ReturnCode.volumeHasMirrorRelationship,ReturnCode.volumeInUse,ReturnCode.volumeOffline,ReturnCode.volumeReconfiguring));
		m_ProcTable[9] = new ProcTableEntry("setControllerToFailed", 10, 180, true, m_TypeTable[315], m_TypeTable[152],"This procedure marks the specified controller as being failed. Furthermore, the alternate of the specified controller will force the failed controller into a reset state (if possible).","The value of the controller reference for the controller that is to be marked failed.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.cacheSyncFailure,ReturnCode.controllerInServiceMode,ReturnCode.error,ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidControllerref,ReturnCode.invalidRequest,ReturnCode.modesenseError,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[10] = new ProcTableEntry("setDriveToFailed", 11, 90, true, m_TypeTable[343], m_TypeTable[152],"This procedure marks the specified drive as being failed. In general, this will also impact the operational state of the volume group to which the drive is assigned, plus all volumes defined on that volume group. The precise impact on the states of these other objects may vary, as it depends on the RAID level of the volumes, as well as the states of the other drives in the volume group.","The value of the drive reference for the drive that is to be marked failed.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.databaseError,ReturnCode.driveNotExist,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidDriveref,ReturnCode.invalidDriveState,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.takeRecoveryActionsFirst,ReturnCode.tryAlternate));
		m_ProcTable[11] = new ProcTableEntry("startVolumeFormat", 12, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure causes the specified volume to be formatted. All data that is currently present on the volume will be irretrievably lost as a result of this operation. Once a format operation starts, the volume's action field will be changed to VOL_ACTION_INITIALIZING; the getVolumeActionProgress procedure can then be used to monitor the progress of the operation. Volume format operations are typically required only when reviving a volume that has been marked failed for some reason. Newly-created volumes need not be explicitly formatted using this procedure.","The value of the volume reference for the volume that is to be reformatted.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.busy,ReturnCode.cannotFormatVolume,ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidRequest,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.reservationConflict,ReturnCode.tryAlternate,ReturnCode.volumeNotExist,ReturnCode.volumeOffline,ReturnCode.volumeReconfiguring));
		m_ProcTable[12] = new ProcTableEntry("initializeDrive", 13, 540, true, m_TypeTable[343], m_TypeTable[152],"This procedure causes the specified drive object to be initialized for use in the system. All data on the drive is irretrievably lost as a result of this operation. Only offline drives or drives whose status is DRIVE_STAT_INCOMPATIBLE are candidates for initialization. This procedure implicitly transitions the drive to the online state.","The value of the drive reference for the drive that is to be initialized.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidDriveref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[13] = new ProcTableEntry("loadControllerFirmware", 14, 1200, true, m_TypeTable[308], m_TypeTable[152],"To indicate the end of the iterative download sequence, call this procedure with a zero-length segment size. When the controller receives this end indicator, the controller writes the accumulated firmware image to stable storage (typically flash memory). The controller responds to this procedure call with the appropriate return code, delays for a short period, and then reboots to load and execute the new firmware.","A FirmwareUpdateDescriptor object that indicates, among other things, the offset and size of the firmware segment being transferred.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.busy,ReturnCode.cacheconfigError,ReturnCode.controllerInServiceMode,ReturnCode.downloadInProgress,ReturnCode.downloadNotPermitted,ReturnCode.error,ReturnCode.fileTooLarge,ReturnCode.illegalParam,ReturnCode.imageTransferred,ReturnCode.invalidChunksize,ReturnCode.invalidDlstate,ReturnCode.invalidFile,ReturnCode.invalidOffset,ReturnCode.invalidTotalsize,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.overrun,ReturnCode.spawnError,ReturnCode.voltransferError));
		m_ProcTable[14] = new ProcTableEntry("loadControllerNVSRAM", 15, 360, true, m_TypeTable[308], m_TypeTable[152],"To indicate the end of the iterative download sequence, call this procedure with a zero-length segment size. When the controller receives this end indicator, the controller writes the accumulated NVSRAM image to stable storage (typically flash memory). The controller responds to this procedure call with the appropriate return code, delays for a short period, and then reboots to load and execute the new NVSRAM.","A FirmwareUpdateDescriptor object that specifies the size and content of the NVSRAM data to be loaded by the controller.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.busy,ReturnCode.controllerInServiceMode,ReturnCode.downloadInProgress,ReturnCode.downloadNotPermitted,ReturnCode.error,ReturnCode.fileTooLarge,ReturnCode.flashError,ReturnCode.illegalParam,ReturnCode.invalidChunksize,ReturnCode.invalidFile,ReturnCode.invalidOffset,ReturnCode.invalidTotalsize,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.overrun,ReturnCode.spawnError,ReturnCode.utmConflict));
		m_ProcTable[15] = new ProcTableEntry("resetMel", 16, 40, true, null, m_TypeTable[152],"This procedure clears all entries from the Major Events Log.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[16] = new ProcTableEntry("setVolumeGroupToOffline", 17, 90, true, m_TypeTable[343], m_TypeTable[152],"This procedure marks a volume group offline. When this operation completes, all volumes in the volume group will be inaccessible for I/O operations. The drives that comprise the volume group can be removed from the storage array and, if desired, inserted into a different storage array.","The value of the volume group reference for the volume group to be placed offline.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","VolGrpMgmt","",
			EnumSet.of(ReturnCode.driveNotOptimal,ReturnCode.driveNotUnassigned,ReturnCode.driveRemoved,ReturnCode.duplicateDrives,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.numdrivesAdditional,ReturnCode.numdrivesGroup,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeReconfiguring));
		m_ProcTable[17] = new ProcTableEntry("setVolumeGroupToOnline", 18, 540, true, m_TypeTable[343], m_TypeTable[152],"This procedure marks a volume group online. It is typically used when the drives assigned to a volume group have been transported from one storage array to another. After the last such drive has been inserted into the new storage array, it is necessary to manually mark the volume group online. When this operation completes, assuming the drives are all functioning properly, the volumes defined in the volume group will become accessible for I/O operations.","The value of the volume group reference for the volume group to be placed online.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","VolGrpMgmt","",
			EnumSet.of(ReturnCode.driveNotOptimal,ReturnCode.driveNotUnassigned,ReturnCode.duplicateDrives,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.numdrivesAdditional,ReturnCode.numdrivesGroup,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeReconfiguring));
		m_ProcTable[18] = new ProcTableEntry("startDriveReconstruction", 19, 540, true, m_TypeTable[343], m_TypeTable[152],"This procedure initiates the reconstruction of a failed drive in a degraded RAID volume. The procedure returns once the reconstruction has started. If the indicated failed drive has an integrated hot spare serving in its place, then this procedure will initiate the copyback from the hot spare to the failed drive.","The value of the drive reference for the drive on which reconstruction is to begin.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.copybackInProgress,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidDriveref,ReturnCode.invalidRaidlevel,ReturnCode.invalidRequest,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.reconstructionInProgress,ReturnCode.tryAlternate,ReturnCode.volumeReconfiguring));
		m_ProcTable[19] = new ProcTableEntry("startVolumeGroupDefrag", 20, 540, true, m_TypeTable[343], m_TypeTable[152],"This procedure initiates a long-running operation to defragment a volume group by shifting the physical storage location of each volume in the volume group to eliminate any free extents that reside between defined volumes. Note that all volumes remain fully accessible and online during this transition. While the operation is in progress, the client can make calls to the getVolumeActionProgress procedure to determine how much progress has been made in completing the operation for each affected volume. The end result of a volume group defragment operation is that free extents that existed between defined volumes will be eliminated, and a single large free extent (if any) will appear at the end of the volume group.","The value of a volume group reference for the volume group that is to be defragmented.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.cannotReconfigure,ReturnCode.drivesDacstoresOverlap,ReturnCode.driveNotOptimal,ReturnCode.driveNotUnassigned,ReturnCode.driveTooSmall,ReturnCode.duplicateDrives,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.insufficientCache,ReturnCode.invalidRequest,ReturnCode.invalidVolumegroupref,ReturnCode.noHeap,ReturnCode.numdrivesAdditional,ReturnCode.numdrivesGroup,ReturnCode.ok,ReturnCode.reconfigLogSpaceError,ReturnCode.tryAlternate,ReturnCode.volumeFormatting,ReturnCode.volumeNotOptimal,ReturnCode.volumeOffline,ReturnCode.volumeReconfiguring));
		m_ProcTable[20] = new ProcTableEntry("startVolumeGroupExpansion", 21, 540, true, m_TypeTable[816], m_TypeTable[152],"This procedure initiates a long-running operation to expand the capacity of a volume group by adding one or more drives to it. An expansion of this form requires that the controller transparently move the data of existing volumes within the volume group; volumes remain fully accessible and online during this transition. While the operation is in progress, the client can make calls to the getVolumeActionProgress procedure to determine how much progress has been made in completing the operation for each affected volume. The end result of a volume group expansion is the appearance of a new (or enlarged) free extent at the end of the volume group. The free extent can then be used to create new volumes as desired by the user.","A VolumeGroupExpansionDescriptor object that identifies the volume group to be expanded, plus the drive or drives to be added to the volume group. All drives specified for this operation must be in the unassigned state initially.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.cannotReconfigure,ReturnCode.drivesDacstoresOverlap,ReturnCode.driveNotOptimal,ReturnCode.driveNotUnassigned,ReturnCode.driveTooSmall,ReturnCode.duplicateDrives,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.insufficientCache,ReturnCode.invalidDriveref,ReturnCode.invalidExpansionList,ReturnCode.invalidRequest,ReturnCode.invalidVolumegroupref,ReturnCode.noHeap,ReturnCode.numdrivesAdditional,ReturnCode.numdrivesGroup,ReturnCode.ok,ReturnCode.reconfigLogSpaceError,ReturnCode.tryAlternate,ReturnCode.volumeFormatting,ReturnCode.volumeHasAsyncMirror,ReturnCode.volumeNotOptimal,ReturnCode.volumeOffline,ReturnCode.volumeReconfiguring));
		m_ProcTable[21] = new ProcTableEntry("startVolumeRAIDMigration", 22, 540, true, m_TypeTable[876], m_TypeTable[152],"This procedure initiates a long-running operation to change the RAID level of a volume group (and thus all volumes in the volume group) from one supported value to another. While the operation is in progress, the client can make calls to the getVolumeActionProgress procedure to determine how much progress has been made in completing the operation for each affected volume.","A VolumeRAIDMigrationDescriptor object that identifies the volume group and the new RAID level to be used.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.cannotReconfigure,ReturnCode.drivesDacstoresOverlap,ReturnCode.driveNotOptimal,ReturnCode.driveNotUnassigned,ReturnCode.duplicateDrives,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.insufficientCache,ReturnCode.invalidRaidlevel,ReturnCode.invalidRequest,ReturnCode.invalidVolumegroupref,ReturnCode.noHeap,ReturnCode.numdrivesAdditional,ReturnCode.numdrivesGroup,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeFormatting,ReturnCode.volumeOffline,ReturnCode.volumeReconfiguring));
		m_ProcTable[22] = new ProcTableEntry("startVolumeSegmentSizing", 23, 540, true, m_TypeTable[847], m_TypeTable[152],"This procedure initiates a long-running operation to change the segment size (i.e. stripe depth) of a volume from one supported value to another. While the operation is in progress, the client can make calls to the getVolumeActionProgress procedure to determine how much progress has been made in completing the operation.","A VolumeSegmentSizingDescriptor object that identifies the volume and the new segment size to be used.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.cannotReconfigure,ReturnCode.drivesDacstoresOverlap,ReturnCode.error,ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.insufficientCache,ReturnCode.invalidRequest,ReturnCode.invalidSegmentsize,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.reservationConflict,ReturnCode.tryAlternate,ReturnCode.volumeFormatting,ReturnCode.volumeOffline,ReturnCode.volumeReconfiguring));
		m_ProcTable[23] = new ProcTableEntry("setControllerToPassive", 24, 60, true, m_TypeTable[315], m_TypeTable[152],"This procedure causes the specified controller to be transitioned to the passive state. All volume groups owned by the controller will be transitioned to the alternate controller, which remains in the active state.","The value of the controller reference for the controller that is to be made passive.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","Am1base","",
			EnumSet.of(ReturnCode.obsolete));
		m_ProcTable[24] = new ProcTableEntry("setControllerToActive", 25, 40, true, m_TypeTable[315], m_TypeTable[152],"This procedure causes the specified controller to be transitioned into the active state. If the controller was previously active, no visible changes will occur as a result of this operation. If it was previously passive or in service mode, it will be made active. After this transition occurs, it will be possible to assign ownership of volume groups to the controller so that it may participate in standard I/O operations.","The value of the controller reference for the controller that is to be made active.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.cacheSyncFailure,ReturnCode.error,ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidControllerref,ReturnCode.invalidRequest,ReturnCode.modesenseError,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[25] = new ProcTableEntry("setSACacheParams", 26, 40, true, m_TypeTable[478], m_TypeTable[152],"This procedure updates the cache parameters that are maintained on a per-array basis, across all controllers in the array.","An SACacheParamsUpdateDescriptor object that provides new values for the storage array cache management parameters.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.controllerInServiceMode,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidCacheblksize,ReturnCode.invalidFlushAmount,ReturnCode.invalidFlushThreshold,ReturnCode.noHeap,ReturnCode.noVolumes,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeNotExist,ReturnCode.volumeReconfiguring));
		m_ProcTable[26] = new ProcTableEntry("setSAUserLabel", 27, 40, true, m_TypeTable[337], m_TypeTable[152],"This procedure is used by a client to modify the user-assigned label for the storage array. The label value is stored in non-volatile storage and returned to the client as part of the SAInfo object.","The new user-assigned label for the storage array. This value is presented to the controller as a variable-length opaque byte array. However, the intention is that the byte array will contain a string value in double-byte character set format, with each two bytes representing one character value.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidLabel,ReturnCode.ok));
		m_ProcTable[27] = new ProcTableEntry("setControllerTime", 28, 40, true, m_TypeTable[6], m_TypeTable[152],"This procedure allows the client to set the clock of the controller to the specified value. Note that the clock value is only set on the controller to which this request is directed. If the client wishes to set the clock value on each controller, then an independent request of this form should be directed to each controller.","A 64-bit integer value that represents the new clock value to be set on the controller. The integer specifies the time value as the number of seconds that have elapsed since 12:00AM GMT on January 1, 1970.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.ok));
		m_ProcTable[28] = new ProcTableEntry("setVolumeCacheParams", 29, 40, true, m_TypeTable[830], m_TypeTable[152],"This procedure updates the caching parameters for a particular volume as specified in the argument structure.","A VolumeCacheParamsUpdateDescriptor object that specifies the volume whose cache parameters are to be updated, as well as the new parameter values themselves.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.cacheParametersNotChangeable,ReturnCode.error,ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidCacheModifier,ReturnCode.invalidReadahead,ReturnCode.invalidRequest,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeFormatting,ReturnCode.volumeNotExist,ReturnCode.volumeOffline,ReturnCode.volumeReconfiguring));
		m_ProcTable[29] = new ProcTableEntry("setVolumeParams", 30, 40, true, m_TypeTable[642], m_TypeTable[152],"This procedure updates various parameters (outside of cache-related parameters) for a particular volume as specified in the argument structure.","A VolumeParamsUpdateDescriptor object that specifies the volume whose parameters are to be updated, as well as the new parameter values themselves.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","PreReadRedCheck",
			EnumSet.of(ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.invalidReconpriority,ReturnCode.invalidRequest,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeNotExist,ReturnCode.volumeOffline));
		m_ProcTable[30] = new ProcTableEntry("setVolumeUserLabel", 31, 40, true, m_TypeTable[669], m_TypeTable[152],"This procedure is used by a client to modify the user-assigned label for a volume. The label value is stored in non-volatile storage and returned to the client as part of the Volume or SnapshotVolume object when the client requests this information from the controller.","A VolumeLabelUpdateDescriptor object that contains the new user-assigned label for the volume. This value is presented to the controller as a variable-length opaque byte array. However, the intention is that the byte array will contain a string value in double-byte character set format, with each two bytes representing one character value.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.invalidLabel,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeNotConfigurable,ReturnCode.volumeOffline));
		m_ProcTable[31] = new ProcTableEntry("startSAIdentification", 32, 40, false, null, m_TypeTable[152],"This procedure causes visual indicators to be activated on the physical storage array unit to allow an end-user to visually identify the storage array. The indicators will remain active until the stopIdentification procedure is invoked.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[32] = new ProcTableEntry("startDriveIdentification", 33, 40, false, m_TypeTable[817], m_TypeTable[152],"This procedure causes visual indicators to be activated on the physical drives specified in the argument list to allow an end-user to visually identify the drives. The indicators will remain active until the stopIdentification procedure is invoked.","A list of drive reference objects that specifies the drives whose visual indicators are to be activated.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[33] = new ProcTableEntry("stopIdentification", 34, 90, false, null, m_TypeTable[152],"This procedure cancels the effects of any prior startDriveIdentification, startSAIdentification, startChannelIdentification and/or startTrayIdentification operations by deactivating all visual indicators.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[34] = new ProcTableEntry("setHostInterfaceParams", 35, 40, true, m_TypeTable[406], m_TypeTable[152],"This procedure updates the I/O interface parameters for the controller to which the request is directed.","An InterfaceUpdateDescriptor object that provides new values for the host I/O interface parameters.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.invalidControllerref,ReturnCode.invalidFibreid,ReturnCode.noHeap,ReturnCode.nvramError,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[35] = new ProcTableEntry("setControllerToOptimal", 36, 60, true, m_TypeTable[315], m_TypeTable[152],"This procedure causes the specified controller's state to be set to optimal. If the controller was previously in the failed state, it will be reactivated. If necessary, the alternate controller will also remove any forced reset signal being applied to the specified controller.","The value of the controller reference for the controller to be set to the optimal state.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.cacheSyncFailure,ReturnCode.error,ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidControllerref,ReturnCode.invalidRequest,ReturnCode.modesenseError,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[36] = new ProcTableEntry("setDriveToOptimal", 37, 540, true, m_TypeTable[343], m_TypeTable[152],"This procedure forces the specified drive to the optimal state, including clearing the PFA condition for the drive, if any. Returning the drive to optimal may cause volumes on the associated volume group to be returned to the optimal state as well. This is a potentially dangerous operation, since a failed drive is usually accompanied by some form of parity inconsistency. Forcing a drive from the failed state to the optimal state may disrupt the controller's normal methods of providing availability in a degraded state, and may thus result in corrupted data being returned on ensuing data transfers to the host system.","The value of the drive reference for the drive to be returned to the optimal state.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.background,ReturnCode.illegalParam,ReturnCode.invalidDriveref,ReturnCode.invalidDriveState,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[37] = new ProcTableEntry("forceVolumeGroupToOptimal", 38, 600, true, m_TypeTable[343], m_TypeTable[152],"This is a potentially dangerous operation, since it causes data to be made available to the I/O host even though that data may have become corrupted due to device failures that occurred in the past.","The value of the VolumeGroupRef for the volume group that is being restored to the optimal state.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.background,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidVolumegroupref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeReconfiguring));
		m_ProcTable[38] = new ProcTableEntry("getControllerHostInterfaces", 39, 40, false, null, m_TypeTable[1226],"This procedure is used by clients to query the referenced controller for up-to-date information about its host-side I/O interfaces. Since this interface information is highly volatile, the object graph data contains only a point-in-time snapshot of the interface data. This procedure can be used to obtain current information that may not be reflected in the most recent object graph.","None.","A list of elements that describe each host-side I/O interface for the controller to which the request was directed.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[39] = new ProcTableEntry("getObjectGraph", 40, 60, false, null, m_TypeTable[1225],"This procedure causes all configuration and state information to be returned to the requester. The information is conveyed in the form of an object graph. The ObjectBundle object contains a set of all known logical and physical components. The reference values within these objects can be analyzed to determine the interrelationships and linkages between the key objects, and thus to establish the true graph-oriented image of the storage array state.","None.","An ObjectBundle object that contains all relevant logical and physical objects and their associated state information for the storage array.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[40] = new ProcTableEntry("getVolumeActionProgress", 41, 40, false, m_TypeTable[343], m_TypeTable[439],"This procedure returns an indication of the extent to which a long-running operation on a volume has completed. The set of supported long-running operations is defined by the VolumeAction enumeration. This procedure can also be called for a snapshot volume. The set of supported long-running operations for snapshot volumes is defined by the SnapshotAction enumeration.","The value of the AbstractVolRef for the volume whose long-running operation is being queried.","A VolumeActionProgress object that contains the completion percentage of a long running volume oriented operation as well as the estimated elapsed time to completion in minutes. If no operation is running on the given volume then a -1 will be returned for the completion percentage. Estimated time to completion will be -1 if it is unknown.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[41] = new ProcTableEntry("getRecoveryFailureList", 42, 40, false, null, m_TypeTable[1217],"This procedure is used by clients to obtain information about all component or logic failures on the storage array that require some form of recovery action.","None.","A FailureTypeList object that contains one element for each type of failure that is currently present in the storage array.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[42] = new ProcTableEntry("getSAData", 43, 60, false, null, m_TypeTable[862],"This procedure returns an object that contains high-level status information about the storage array as a whole.","None.","An SAData object that contains general status information about the storage array.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[43] = new ProcTableEntry("getVolumePerformance", 44, 90, false, m_TypeTable[682], m_TypeTable[814],"This procedure is used by the client to retrieve performance monitoring data for one or more volumes.","A list of AbstractVolRef values of the volumes for which the caller wishes to obtain performance monitoring information.","A list of VolumePerformance objects that contain the desired information. The list contains one such object for each valid volume that was specified in the argument object.","Am1base","","SpecCorrection",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[44] = new ProcTableEntry("setSATrayPositions", 45, 40, true, m_TypeTable[601], m_TypeTable[152],"This procedure is used by the client to request that the controller store (in nonvolatile storage) a TrayPositionList object that provides information about the relative physical positions of the storage array's trays within their enclosing rack(s) or container(s).","The TrayPositionList object to be stored for future retrieval.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidTrayposLength,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[45] = new ProcTableEntry("setVolumeMediaScanParams", 46, 40, true, m_TypeTable[698], m_TypeTable[152],"This procedure sets the media scan parameters for a particular volume. Each volume can be configured to either participate in media scans or not. Furthermore, if a volume is configured to participate, it can be further configured so that parity validation either occurs during the media scan or is skipped. The client uses this procedure to set these configuration options on a per-volume basis.","A VolumeMediaScanParamsUpdateDescriptor object that identifies the volume to be modified, as well as the media scan settings to be used for the volume.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.ssdMediaScanNotAllowed,ReturnCode.tryAlternate,ReturnCode.volumeOffline));
		m_ProcTable[46] = new ProcTableEntry("setSAMediaScanPeriod", 47, 40, true, m_TypeTable[7], m_TypeTable[152],"This procedure sets the target media scan period for background media scans to the value specified by the caller. The period is specified in units of days, and governs the approximate time required for a complete media scan of all volumes and drives in the system. The allowed period values can be determined by checking the appropriate fields of the FeatureParameters object for the storage array.","The desired media scan period, expressed in units of days. This value must be within the valid range of media scan periods supported the controller.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.controllerInServiceMode,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidScanperiod,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[47] = new ProcTableEntry("getChangeState", 48, 40, false, m_TypeTable[735], m_TypeTable[529],"This procedure is used by clients to query the controller for indications of state changes that have occurred and which would necessitate that the client refresh its view of the storage array's state. If no state changes need to be reported, the controller will generally hold this request, without responding, for up to the amount of time specified in the argument. If, at any time during the hold period, a state change occurs, the controller will return immediately with the new configuration generation number and/or MEL sequence number. By using this hanging poll approach, the amount of traffic between the client and the server is reduced to an insignificant level, and yet near-immediate notification of changes is still possible.","A ChangeQueryDescriptor object that identifies the caller's current understanding of the storage array's state, along with an indication of the maximum hold time for this request.","A ChangeState object that indicates the current configuration of the storage array by providing the array's current configuration generation number, along with key information about the Major Event Log.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[48] = new ProcTableEntry("clearSAConfiguration", 49, 120, true, null, m_TypeTable[152],"Causes the entire configuration of the storage array to be cleared to an initial state.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","AutomaticConfig",
			EnumSet.of(ReturnCode.controllerInServiceMode,ReturnCode.error,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeReconfiguring));
		m_ProcTable[49] = new ProcTableEntry("autoSAConfiguration", 50, 180, true, null, m_TypeTable[152],"Tells the controller to automatically configure the Storage Array.","","","Am1base","SpecCorrection","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[50] = new ProcTableEntry("getMelExtent", 51, 90, false, null, m_TypeTable[413],"This procedure is used to determine the head and tail sequence numbers of entries in the storage array's Major Event Log. The client can use these values to manage controlled fetching of log entries.","None.","A MelExtent object that contains head and tail sequence numbers of the entries in the storage array's Major Event Log.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[51] = new ProcTableEntry("getMelEntries", 52, 300, false, m_TypeTable[413], m_TypeTable[1185],"This procedure allows a client to fetch a set of entries from the storage array's Major Event Log for analysis or display. Note that the MEL_MAX_XFER_COUNT constant specifies that maximum number of entries that can be requested in one operation. If more entries are needed, the client must fetch them iteratively, ensuring that no single request exceeds the transfer limit.","A MelExtent object that provides the sequence number of the first and last MEL entries to be retrieved. All entries between these two numbers (inclusive) will be transferred to the caller as a result of this operation.","A MelEntryList object containing the desired information.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[52] = new ProcTableEntry("getCriticalMelEntries", 53, 900, false, m_TypeTable[413], m_TypeTable[1185],"This procedure allows a client to fetch a set of entries with a priority value of EVENT_PRIORITY_CRITICAL from the storage array's Major Event Log for analysis or display. If there are less critical MEL events than MEL_MAX_XFER_COUNT, all the critical events will be displayed on the first call. If the client receives a number of critical MEL events that is equal to MEL_MAX_XFER_COUNT, then the user must increment the first sequence number to be the highest sequence number in the list of entries returned and repeat the procedure. This process must be repeated until the number of entries returned is less than MEL_MAX_XFER_COUNT.","A MelExtent object that provides the sequence number of the first and last MEL entries to be retrieved. All critical entries between these two numbers (inclusive) will be transferred to the caller as the result of the operation.","A list of MelEntry objects containing the desired information.","Am1base","","EventLogging",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[53] = new ProcTableEntry("getControllerNVSRAM", 54, 40, false, m_TypeTable[210], m_TypeTable[542],"This procedure allows a client to fetch the data that resides within a designated region of the controller's NVSRAM. Note that the NVSRAM data is obtained only from the controller to which this request is directed.","An NVSRAMRegionId value that identifies the region whose data is to be retrieved. The caller is allowed to specify that all NVSRAM regions be obtained, if desired.","A list of NVSRAMRegion objects containing the desired information.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[54] = new ProcTableEntry("setControllerNVSRAM", 55, 40, true, m_TypeTable[320], m_TypeTable[152],"This procedure is used to modify a portion of the controller's NVSRAM. Note that the NVSRAM data is changed only on the controller to which this request is directed.","An NVSRAMUpdateDescriptor object that specifies the region to be modified, the starting byte offset within the region, and the size and value of the new data to be stored into NVSRAM.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRegionid,ReturnCode.noHeap,ReturnCode.nvramError,ReturnCode.ok));
		m_ProcTable[55] = new ProcTableEntry("setSAPassword", 56, 40, true, m_TypeTable[422], m_TypeTable[152],"This procedure allows a client to change the administrative password that protects the storage array against unauthorized configuration changes.","An EncryptedPassword object that identifies the new password to be used for further management activities for the storage array.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.controllerInServiceMode,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidEncryption,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[56] = new ProcTableEntry("pingController", 57, 40, false, null, m_TypeTable[152],"This procedure simply verifies that the controller is responsive and is operating properly.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[57] = new ProcTableEntry("startVolumeParityCheck", 58, 40, true, m_TypeTable[343], m_TypeTable[152],"Initiates an explicit parity check operation. This is a background task that verifies the correctness of all parity/redundancy data for the volume. Only one such operation may be active at any time on a given controller. After initiating the operation with this procedure, the operation's progress can be checked via the getParityCheckProgress procedure. This procedure is deprecated. The scanVolume procedure should be used instead.","The AbstractVolRef of the volume on which the operation is to be performed.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","Am1base",
			EnumSet.of(ReturnCode.background,ReturnCode.ghostVolume,ReturnCode.invalidRaidlevel,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.parityScanInProgress,ReturnCode.tryAlternate,ReturnCode.volumeNotOptimal,ReturnCode.volumeOffline));
		m_ProcTable[58] = new ProcTableEntry("getParityCheckProgress", 59, 300, false, m_TypeTable[343], m_TypeTable[7],"This procedure returns an indication of the progress of an explicit parity check operation on a particular volume. This procedure is deprecated. The scanVolume procedure should be used instead.","The AbstractVolRef value for the volume whose parity check operation is being queried.","An integer in the range 0-100 that indicates the percentage of the volume that has been checked for parity inconsistencies, or one of the (negative) PARITY_CHK_* constant values to indicate an error condition or a completed parity check result.","Am1base","Am1base","Am1base",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[59] = new ProcTableEntry("getLUNMappings", 61, 40, false, m_TypeTable[343], m_TypeTable[804],"This procedure returns a list of LUN mappings that apply to the object identified by the argument SYMbolRef.","The SYMbolRef value of the entity for which applicable LUN mappings are to be returned. For example, to find all LUN mappings that apply to a particular Cluster object, the associated ClusterRef would be used as the argument.","A LUNMappings object that identifies the mappings that apply to the referenced object.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[60] = new ProcTableEntry("createSAPortGroup", 62, 40, true, m_TypeTable[337], m_TypeTable[360],"Creates a new SAPortGroup & returns its ref. If a group by that name already exists, returns its ref.. OBSOLETE: Any call to createSAPortGroup will get a return status indicating the command is obsolete. No alternative procedure is available.","","","Am1base","Am1base","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[61] = new ProcTableEntry("deleteSAPortGroup", 63, 40, true, m_TypeTable[343], m_TypeTable[152],"Removes all SAPorts from an SAPortGroup, and deletes the group. OBSOLETE: Any call to deleteSAPortGroup will get a return status indicating the command is obsolete. No alternative procedure is available.","","","Am1base","Am1base","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[62] = new ProcTableEntry("moveSAPort", 64, 40, true, m_TypeTable[605], m_TypeTable[152],"Removes the SA Port 'itemRef' from any SA Port Group that it might be in, & moves it to the group 'containerRef'. If this leaves the previous SAPortGroup empty, the previous SAPortGroup is deleted. OBSOLETE: Any call to moveSAPort will get a return status indicating the command is obsolete. No alternative procedure is available.","","","Am1base","Am1base","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[63] = new ProcTableEntry("getSAPort", 65, 40, false, m_TypeTable[607], m_TypeTable[360],"Retrieves a storage array port. OBSOLETE: Any call to getSAPort will get a return status indicating the command is obsolete. No alternative procedure is available.","","","Am1base","Am1base","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[64] = new ProcTableEntry("createHost", 66, 40, true, m_TypeTable[825], m_TypeTable[360],"This procedure causes a new Host object to be created using the parameters in the creation descriptor argument. After creating a host, host ports can be added to it, mappings established, etc.","A HostCreationDescriptor object that contains all required attributes for the new Host object.","A ReturnCodeWithRef object that indicates the outcome of the operation, and also returns the HostRef of the newly-created object. Valid ReturnCode values are:","Am1base","","",
			EnumSet.of(ReturnCode.noHeap,ReturnCode.ok,ReturnCode.partDupId,ReturnCode.partLabelInvalid,ReturnCode.partLunCollision,ReturnCode.partNodeNonexistent));
		m_ProcTable[65] = new ProcTableEntry("createCluster", 67, 40, true, m_TypeTable[337], m_TypeTable[360],"This procedure causes a new Cluster object to be created and assigned the specified label. After creating a cluster, hosts can be added to it, mappings established, etc.","The user-assigned label to be used for the new cluster.","A ReturnCodeWithRef object that indicates the outcome of the operation, and also returns the ClusterRef of the newly-created object. Valid ReturnCode values are:","Am1base","","",
			EnumSet.of(ReturnCode.noHeap,ReturnCode.ok,ReturnCode.partDupId,ReturnCode.partLabelInvalid));
		m_ProcTable[66] = new ProcTableEntry("deleteCluster", 68, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure causes the Cluster object identified by the argument value to be deleted from the Storage Partitions configuration.","The ClusterRef value for the cluster to be deleted.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.partNodeNonexistent));
		m_ProcTable[67] = new ProcTableEntry("renameCluster", 69, 40, true, m_TypeTable[355], m_TypeTable[152],"This procedure changes the user-assigned label for a Cluster object.","A SYMbolRefWithUAL object whose ref field identifies the cluster to be renamed, and whose label field provides the new user-assigned label for the cluster.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.partDupId,ReturnCode.partLabelInvalid,ReturnCode.partNodeNonexistent));
		m_ProcTable[68] = new ProcTableEntry("deleteHost", 70, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure causes the Host object identified by the argument value to be deleted from the Storage Partitions configuration.","The HostRef value for the host to be deleted.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.partNodeNonexistent));
		m_ProcTable[69] = new ProcTableEntry("renameHost", 71, 40, true, m_TypeTable[355], m_TypeTable[152],"This procedure changes the user-assigned label for a Host object.","A SYMbolRefWithUAL object whose ref field identifies the host to be renamed, and whose label field provides the new user-assigned label for the host.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","CoreIscsi",
			EnumSet.of(ReturnCode.ok,ReturnCode.partDupId,ReturnCode.partLabelInvalid,ReturnCode.partNodeNonexistent));
		m_ProcTable[70] = new ProcTableEntry("moveHost", 72, 40, true, m_TypeTable[605], m_TypeTable[152],"Changes the Storage Partitions configuration for a Host object by modifying the host's cluster assignment.","A SYMbolRefPair object. The itemRef field of the argument is a HostRef that identifies the host being modified, and the containerRef field is a ClusterRef that identifies the cluster to which the host is to be moved.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","CoreIscsi",
			EnumSet.of(ReturnCode.ok,ReturnCode.partLunCollision,ReturnCode.partNodeNonexistent,ReturnCode.requestFailedDueToPiRestrictions));
		m_ProcTable[71] = new ProcTableEntry("createHostPort", 73, 60, true, m_TypeTable[854], m_TypeTable[360],"This procedure causes a new HostPort object to be created using the parameters in the creation descriptor argument. After creating a host, host ports can be added to it, mappings established, etc. This procedure does not work for iSCSI.","A HostPortCreationDescriptor object that contains all required attributes for the new HostPort object.","A ReturnCodeWithRef object that indicates the outcome of the operation, and also returns the HostPortRef of the newly-created object. Valid ReturnCode values are:","Am1base","","InfinibandSupport",
			EnumSet.of(ReturnCode.noHeap,ReturnCode.ok,ReturnCode.partDupId,ReturnCode.partLabelInvalid,ReturnCode.partNodeNonexistent,ReturnCode.requestFailedDueToPiRestrictions));
		m_ProcTable[72] = new ProcTableEntry("deleteHostPort", 74, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure causes the HostPort object identified by the argument value to be deleted from the Storage Partitions configuration.","The HostPortRef value for the host port to be deleted.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.partNodeNonexistent));
		m_ProcTable[73] = new ProcTableEntry("renameHostPort", 75, 40, true, m_TypeTable[658], m_TypeTable[152],"This procedure changes the user-assigned label for a HostPort object.","A SYMbolRefWithUAL object whose ref field identifies the host port to be renamed, and whose label field provides the new user-assigned label for the host port. This procedure does not apply to iSCSI.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","InfinibandSupport",
			EnumSet.of(ReturnCode.ok,ReturnCode.partDupId,ReturnCode.partNodeNonexistent));
		m_ProcTable[74] = new ProcTableEntry("moveHostPort", 76, 40, true, m_TypeTable[605], m_TypeTable[152],"Changes the Storage Partitions configuration for a HostPort object by modifying the port's host assignment. This procedure does not apply for iSCSI .","A SYMbolRefPair object. The itemRef field of the argument is a HostPortRef that identifies the host port being modified, and the containerRef field is a HostRef that identifies the host to which the port is to be moved.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","InfinibandSupport",
			EnumSet.of(ReturnCode.ok,ReturnCode.partLunCollision,ReturnCode.partNodeNonexistent,ReturnCode.requestFailedDueToPiRestrictions));
		m_ProcTable[75] = new ProcTableEntry("createLUNMapping", 77, 90, true, m_TypeTable[709], m_TypeTable[360],"This procedure causes a new LUNMapping object to be created using the parameters in the creation descriptor argument. Once this mapping is created, it provides a new LUN-to-volume mapping for I/O accesses from the specified entities to a given volume.","A LUNMappingCreationDescriptor object that contains all required attributes for the new LUNMapping object.","A ReturnCodeWithRef object that indicates the outcome of the operation, and also returns the LUNMappingRef of the newly-created object. Valid ReturnCode values are:","Am1base","","",
			EnumSet.of(ReturnCode.cannotMapVolume,ReturnCode.ghostVolume,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.partIsUtmLun,ReturnCode.partLunCollision,ReturnCode.partMappingNonexistent,ReturnCode.partNoHostports,ReturnCode.partPiIncapable,ReturnCode.partVolumeNonexistent,ReturnCode.tooManyPartitions));
		m_ProcTable[76] = new ProcTableEntry("deleteLUNMapping", 78, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure causes the LUNMapping object identified by the argument value to be deleted from the Storage Partitions configuration.","The LUNMappingRef value for the mapping to be deleted.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.partNodeNonexistent));
		m_ProcTable[77] = new ProcTableEntry("getUnlabeledHostPorts", 79, 40, false, null, m_TypeTable[1149],"This procedure returns information about host ports whose world-wide names are known to the controller, but which have not been defined as full HostPort objects via the SYMbol interface. Note that you only need to send the request to one of the controllers, and that the same list of unlabeled host ports are returned, regardless of which controller receives the request. This procedure does not apply to iSCSI. The getUnconfiguredInitiators procedure should be used instead.","None.","An UnlabeledHostPorts object that identifies the host ports that are known to the referenced controller, but which have not yet been defined as full HostPort entities.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[78] = new ProcTableEntry("setHostPortType", 80, 40, true, m_TypeTable[504], m_TypeTable[152],"Changes the \"host port type\" attribute of a given HostPort object. Changing an individual host port type will cause all host port types to be changed if SPM is not enabled. This procedure does not apply to iSCSI; for iSCSI, the host type is set at the host level.","A HostPortTypeUpdateDescriptor object that identifies the HostPort to be modified, and also provides the new type index value that specifies the type of the host port.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","CR103066",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.ok,ReturnCode.partNodeNonexistent));
		m_ProcTable[79] = new ProcTableEntry("moveLUNMapping", 81, 40, true, m_TypeTable[530], m_TypeTable[152],"Move a LUN mapping.","A LUNMappingUpdateDescriptor that provides the new values for the LUN used to access the mapped value, as well as the host/cluster for which the mapping applies.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.partIsUtmLun,ReturnCode.partLunCollision,ReturnCode.partMappingNonexistent,ReturnCode.partNodeNonexistent,ReturnCode.partNoHostports,ReturnCode.partPiIncapable,ReturnCode.tooManyPartitions));
		m_ProcTable[80] = new ProcTableEntry("enableFeature", 82, 40, true, m_TypeTable[528], m_TypeTable[152],"This procedure causes the \"premium\" features identified in the feature keys of the argument to be enabled.","A key for the \"premium\" feature to be enabled. This key must be obtained from an authorized source in order to be accepted by the array controller.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.featureNotKeyable,ReturnCode.invalidSafeCapability,ReturnCode.invalidSafeId,ReturnCode.invalidSafeKey,ReturnCode.invalidSafeVersion,ReturnCode.ok,ReturnCode.perfTierSafeUpgradeDisabled,ReturnCode.premiumFeatureLimitExceedsMaximum,ReturnCode.previouslyEnabledForEval,ReturnCode.safeControllerNotSubjectToRaid6));
		m_ProcTable[81] = new ProcTableEntry("disableFeature", 83, 40, true, m_TypeTable[153], m_TypeTable[152],"Disable a single add-on(optional feature","The Capability value for the \"premium\" feature to be disabled.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.disableNotPermitted,ReturnCode.error,ReturnCode.invalidSafeCapability,ReturnCode.ok));
		m_ProcTable[82] = new ProcTableEntry("stateCapture", 84, 750, true, new StringSpec(0), m_TypeTable[424],"This procedure is used to capture current controller conditions as specified by the function being passed through the variable string input.","A character string indicating the function being called and up to 2 function arguments. The individual elements of the string are separated by commas.","A pointer to the statePrintBuffer where any output from the function is stored.","Am1base","ObsoleteStateCaptureCommand","CtrlStateCapture",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[83] = new ProcTableEntry("loadDriveFirmware", 85, 300, true, m_TypeTable[624], m_TypeTable[152],"Downloads a portion of a new firmware image to a drive in the SYMbol Server. loadDriveFirmware OBSOLETED by implementation of parallel drive firmware download","","","Am1base","Am1base","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[84] = new ProcTableEntry("loadESMFirmware", 86, 900, true, m_TypeTable[690], m_TypeTable[152],"This procedure is used to download some or all of a new firmware image to the ESM cards in a tray. The argument object specifies tray where the ESMs are located, the size of the firmware segment being downloaded, and the offset of the segment within the overall firmware image. Downloads are accomplished using an iterative approach, where the overall image is segmented and each segment transferred to the controller via a call to this procedure. To indicate the end of the iterative download sequence, this procedure should be called with a zero-length segment size. When this end indicator is received by the controller, the accumulated firmware image will be written to the ESM cards.","An ESMFirmwareUpdateDescriptor object that indicates the tray to receive the firmware, the offset and size of the firmware segment being transferred.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.busy,ReturnCode.cacheconfigError,ReturnCode.controllerInServiceMode,ReturnCode.downloadInProgress,ReturnCode.error,ReturnCode.esmDownloadFailed,ReturnCode.esmPartialUpdate,ReturnCode.fileTooLarge,ReturnCode.invalidChunksize,ReturnCode.invalidOffset,ReturnCode.invalidTotalsize,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.overrun,ReturnCode.spawnError,ReturnCode.tryAlternate));
		m_ProcTable[85] = new ProcTableEntry("getHostSpecificNVSRAM", 87, 40, false, m_TypeTable[426], m_TypeTable[542],"This procedure allows the Host Specific NVSRAM region to be read to obtain information for a specific host.","An NVSRAMRegionIDAndHostIndex object that specifies the region ID (in this case 0xF2) and the host index for a specific host.","The values from the specified region.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[86] = new ProcTableEntry("setHostSpecificNVSRAM", 88, 40, true, m_TypeTable[495], m_TypeTable[152],"This procedure updates the NVSRAM for the Host Specific region.","A HostSpecificNVSRAMUpdateDescriptor object that specifies the region ID (in this case 0xF2), the host index for a specific host, the starting offset within the region, the number of bytes, and the values to be written.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidHostTypeIndex,ReturnCode.invalidRegionid,ReturnCode.noHeap,ReturnCode.nvramError,ReturnCode.ok));
		m_ProcTable[87] = new ProcTableEntry("setBatteryParams", 89, 40, true, m_TypeTable[686], m_TypeTable[152],"This procedure sets the battery parameters for the given battery.","A descriptor object that specifies the battery properties.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.noHeap,ReturnCode.noVolumes,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeNotExist));
		m_ProcTable[88] = new ProcTableEntry("assignVolumeOwnership", 90, 40, true, m_TypeTable[533], m_TypeTable[152],"Instructs the SYMbol Server's controller to transfer ownership of a volume to another controller.","A descriptor that specifies the volume being modified and the controller that is to take ownership of the volume.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.controllerInServiceMode,ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidControllerref,ReturnCode.invalidVolumeref,ReturnCode.modesenseError,ReturnCode.notDualActive,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[89] = new ProcTableEntry("issueRuntimeDiagnostics", 91, 180, true, m_TypeTable[334], m_TypeTable[589],"This procedure is used to start the Runtime Diagnostics.","A descriptor that specifies the Runtime Diagnostics tests to run.","A RuntimeDiagResults object that indicates the results and the return code for the operation. Valid return code values are:","Am1base","","",
			EnumSet.of(ReturnCode.diagConfigErr,ReturnCode.diagDriveErr,ReturnCode.diagIconSendErr,ReturnCode.diagInitErr,ReturnCode.diagInvalidTestId,ReturnCode.diagInProgress,ReturnCode.diagLockErr,ReturnCode.diagLoopbackError,ReturnCode.diagModeErr,ReturnCode.diagNotQuiesced,ReturnCode.diagNoAlt,ReturnCode.diagNoCacheMem,ReturnCode.diagReadFailure,ReturnCode.diagTimeout,ReturnCode.diagUtmNotEnabled,ReturnCode.diagWriteFailure,ReturnCode.illegalParam,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[90] = new ProcTableEntry("resetController", 92, 40, true, m_TypeTable[315], m_TypeTable[152],"This procedure requests a reboot of the given controller.","The value of the controller reference for the controller that is to be rebooted.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.controllerInServiceMode,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidControllerref,ReturnCode.invalidRequest,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[91] = new ProcTableEntry("quiesceController", 93, 40, true, m_TypeTable[315], m_TypeTable[152],"This procedure is used to put the controller in a quiesced state.","The value of the controller that is to be quiesced.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.controllerInServiceMode,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidControllerref,ReturnCode.ok));
		m_ProcTable[92] = new ProcTableEntry("unquiesceController", 94, 40, true, m_TypeTable[315], m_TypeTable[152],"This procedure is used to take a controller out of the quiesced state.","A value of the controller to take out of the quiesced state.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidControllerref,ReturnCode.ok));
		m_ProcTable[93] = new ProcTableEntry("startVolumeExpansion", 95, 540, true, m_TypeTable[777], m_TypeTable[152],"This procedure checks to make sure the additional capacity is available and then starts a DVE or DCE/DVE operation.","A VolumeExpansionDescriptor object that identifies the volume to be expanded, plus the drive or drives to be added to the volume. All drives specified for this operation must be in the unassigned state initially.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.cannotReconfigure,ReturnCode.drivesDacstoresOverlap,ReturnCode.driveNotOptimal,ReturnCode.driveNotUnassigned,ReturnCode.driveTooSmall,ReturnCode.duplicateDrives,ReturnCode.error,ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.insufficientCache,ReturnCode.internalError,ReturnCode.invalidDriveref,ReturnCode.invalidExpansionList,ReturnCode.invalidRequest,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.numdrivesAdditional,ReturnCode.numdrivesGroup,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeFormatting,ReturnCode.volumeHasAsyncMirror,ReturnCode.volumeNotOptimal,ReturnCode.volumeOffline,ReturnCode.volumeReconfiguring));
		m_ProcTable[94] = new ProcTableEntry("createSnapshot", 96, 90, true, m_TypeTable[1158], m_TypeTable[152],"Create a snapshot volume of a given base.","This object contains information about how a new snapshot volume is to be created including the size of the repository, the repository utilization warning threshold and the REPOSITORY full policy.","A ReturnCode object that indicates the outcome of the operation. Valid ReturnCode values are:","Am1base","LancasterBase","",
			EnumSet.of(ReturnCode.baseVolumeFailed,ReturnCode.baseVolumeFormatting,ReturnCode.baseVolumeOffline,ReturnCode.driveNotExist,ReturnCode.driveNotUnassigned,ReturnCode.error,ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.invalidBasevol,ReturnCode.invalidProtection,ReturnCode.invalidRepositoryLabel,ReturnCode.invalidSnapLabel,ReturnCode.invalidWarnThreshold,ReturnCode.maxSnapsExceeded,ReturnCode.maxSnapsPerBaseExceeded,ReturnCode.maxVolumesExceeded,ReturnCode.noHeap,ReturnCode.numVolumesGroup,ReturnCode.ok,ReturnCode.partitionsDisabled,ReturnCode.raid6FeatureDisabled,ReturnCode.raid6FeatureUnsupported,ReturnCode.repositoryTooSmall,ReturnCode.snapshotFeatureDisabled,ReturnCode.tryAlternate));
		m_ProcTable[95] = new ProcTableEntry("disableSnapshot", 97, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure will disable (stop) the indicated snapshot volume.","The SnapshotRef of the snapshot volume on which the operation is to be performed.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","LancasterBase","",
			EnumSet.of(ReturnCode.baseVolumeFailed,ReturnCode.baseVolumeOffline,ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.notDisabled,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.repositoryFailed,ReturnCode.repositoryMissing,ReturnCode.repositoryOffline,ReturnCode.snapNotAvailable,ReturnCode.tryAlternate));
		m_ProcTable[96] = new ProcTableEntry("recreateSnapshot", 98, 40, true, m_TypeTable[960], m_TypeTable[152],"This procedure restarts a snapshot volume that was previously created. The snapshot must have been previously disabled for this procedure to succeed.","A descriptor object that specifies the various snapshot parameters.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","LancasterBase","",
			EnumSet.of(ReturnCode.basevolSizeChanged,ReturnCode.baseVolumeFailed,ReturnCode.baseVolumeOffline,ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.notDisabled,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.repositoryFailed,ReturnCode.repositoryMissing,ReturnCode.repositoryOffline,ReturnCode.snapshotFeatureDisabled,ReturnCode.snapNotAvailable,ReturnCode.tryAlternate));
		m_ProcTable[97] = new ProcTableEntry("setSnapshotParams", 99, 40, true, m_TypeTable[960], m_TypeTable[152],"This procedure is used to set various snapshot parameters including the repository warning threshold, the repository full policy, and the rollback operation priority.","A SnapshotParamsUpdateDescriptor object that specifies the various snapshot parameters.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","LancasterBase","",
			EnumSet.of(ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidRollbackPriority,ReturnCode.invalidVolumeref,ReturnCode.invalidWarnThreshold,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.snapNotAvailable,ReturnCode.tryAlternate));
		m_ProcTable[98] = new ProcTableEntry("getRepositoryUtilization", 100, 40, false, m_TypeTable[829], m_TypeTable[949],"This procedure is used by clients to obtain information about the utilization of the repository volume for selected snapshots.","A list of snapshot volume reference values.","The RepositoryUtilizationList is an array of Repository Utilization objects that contains the number of bytes used in the repository and the associated snapshot volume.","Am1base","LancasterBase","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[99] = new ProcTableEntry("calculateDVECapacity", 101, 40, false, m_TypeTable[777], m_TypeTable[6],"Calculates the volume's maximum capacity after a DVE operation","This object contains information used for a DVE or DCE/DVE combination.","","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[100] = new ProcTableEntry("getReadLinkStatus", 102, 40, false, m_TypeTable[959], m_TypeTable[856],"This procedure returns the Read Link Status information.","A RLS Command Descriptor that provides the type of RLS command.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.dstNotFibre,ReturnCode.ok));
		m_ProcTable[101] = new ProcTableEntry("setRLSBaseline", 103, 40, true, null, m_TypeTable[152],"This procedure sets the RLS baseline for all devices. The baseline is used to indicate the difference in error counts from when the baseline was established and the time at which the RLS data is requested.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.dstNotFibre,ReturnCode.ok));
		m_ProcTable[102] = new ProcTableEntry("getMetadataVolumeCapacity", 104, 40, false, m_TypeTable[111], m_TypeTable[7],"This procedure returns the amount of storage required for a metadata volume.","The metadata volume type e.g. remote volume mirror metadata.","The size of storage required for a metadata volume.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[103] = new ProcTableEntry("createMetadataVolume", 105, 90, true, m_TypeTable[1069], m_TypeTable[152],"Create a metadata volume","A MetadataVolCreationDescriptor object that contains all required attributes for the new MetadataVolume object.","A ReturnCode object that indicates the outcome of the operation, and also returns the MetadataVolRef of the newly-created object. Valid ReturnCode values are:","Am1base","","",
			EnumSet.of(ReturnCode.raid6FeatureDisabled));
		m_ProcTable[104] = new ProcTableEntry("activateMirroring", 106, 40, true, null, m_TypeTable[152],"Activate Remote Mirroring","None","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.maxMirrorsExceeded,ReturnCode.metadataVolNonexistent,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.rvmFeatureDisabled,ReturnCode.rvmFibreError));
		m_ProcTable[105] = new ProcTableEntry("deactivateMirroring", 107, 40, true, null, m_TypeTable[152],"Deactivate Remote Mirroring","None","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.mirrorsPresent,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.rvmFibreError,ReturnCode.tryAlternate));
		m_ProcTable[106] = new ProcTableEntry("changeSynchronizationPriority", 108, 40, true, m_TypeTable[966], m_TypeTable[152],"Change MirrorProxy Synchronization Priority","This object contains information used for changing the synchronization priority level for a mirror volume.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ghostVolume,ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidMirrorvol,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[107] = new ProcTableEntry("getVolumeListForMirroring", 109, 90, false, m_TypeTable[883], m_TypeTable[563],"This procedure returns a list of mirror volume candidates that can be used in an ensuing mirror volume creation request.","A MirrorVolumeCandidateRequest descriptor that specifies the type of mirror volume candidates to be returned to the caller.","A list of mirror volume candidates that conform to the parameters specified in the request.","Am1base","","",
			EnumSet.of(ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidMirrorCandidateVol,ReturnCode.invalidVolumeref,ReturnCode.maxMirrorsExceeded,ReturnCode.metadataVolNonexistent,ReturnCode.noHeap,ReturnCode.noValidMirrorCandidate,ReturnCode.ok,ReturnCode.remoteMaxMirrorsExceeded,ReturnCode.remoteMetadataVolNonexistent,ReturnCode.remoteRvmFeatureDisabled,ReturnCode.rvmCommunicationError,ReturnCode.rvmFeatureDisabled,ReturnCode.rvmRemoteArrayError,ReturnCode.rvmVersionMismatch));
		m_ProcTable[108] = new ProcTableEntry("createMirror", 110, 90, true, m_TypeTable[897], m_TypeTable[152],"Create a Mirror","A MirrorCreationDescriptor object that contains all required attributes for the new Mirror Volume object.","A ReturnCode object that indicates the outcome of the operation, and also returns the MirrorVolRef of the newly-created object. Valid ReturnCode values are:","Am1base","","",
			EnumSet.of(ReturnCode.ghostVolume,ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidMirrorCandidateVol,ReturnCode.invalidVolumeref,ReturnCode.legacyRvmAsyncModeUnsupported,ReturnCode.maxMirrorsExceeded,ReturnCode.metadataVolNonexistent,ReturnCode.mirrorProtocolMismatch,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.remoteAuthFailPassword,ReturnCode.remoteInvalidCfgGen,ReturnCode.remoteMaxMirrorsExceeded,ReturnCode.remoteMaxTotalMirrorsPerArrayExceeded,ReturnCode.remoteMetadataVolNonexistent,ReturnCode.remoteRvmFeatureDisabled,ReturnCode.rvmCommunicationError,ReturnCode.rvmFeatureDisabled,ReturnCode.rvmRemoteArrayError,ReturnCode.rvmSpmError,ReturnCode.rvmVersionMismatch,ReturnCode.tryAlternate,ReturnCode.volumeNotExist));
		m_ProcTable[109] = new ProcTableEntry("roleChange", 111, 40, true, m_TypeTable[993], m_TypeTable[152],"This procedure changes the role of the mirror volume.","The MirrorRoleChangeDescriptor object.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidMirrorvol,ReturnCode.invalidVolumeref,ReturnCode.localRoleChangedNotForced,ReturnCode.localRoleChangeFailed,ReturnCode.localRoleChangeSuccessful,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.priNotDemoteable,ReturnCode.remoteRoleChangedLocalFailed,ReturnCode.remoteRoleChangeFailed,ReturnCode.rvmCommunicationError,ReturnCode.rvmRemoteArrayError,ReturnCode.rvmVersionMismatch,ReturnCode.secNotPromoteable));
		m_ProcTable[110] = new ProcTableEntry("removeMirror", 112, 40, true, m_TypeTable[343], m_TypeTable[152],"Deletes a mirror volume.","A MirrorProxyRef object which identifies the Mirror Proxy Volume to be removed.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ghostVolume,ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidMirrorvol,ReturnCode.invalidVolumeref,ReturnCode.ok,ReturnCode.onlyLocalMirrorDeleted,ReturnCode.rvmSpmError,ReturnCode.volumeNotExist));
		m_ProcTable[111] = new ProcTableEntry("startSyncMirror", 113, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure starts the synchronization process on a mirror.","The value of the mirror that is to be synchronized.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidMirrorvol,ReturnCode.invalidVolumeref,ReturnCode.mirrorVolNotPrimary,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeNotExist));
		m_ProcTable[112] = new ProcTableEntry("startChannelIdentification", 114, 40, false, m_TypeTable[7], m_TypeTable[152],"This procedure causes visual indicators to be activated on the specified channel. The indicators will remain active until the stopIdentification procedure is invoked.","An integer value specifying the channel number.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.noChannel,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[113] = new ProcTableEntry("startTrayIdentification", 115, 40, false, m_TypeTable[673], m_TypeTable[152],"This procedure causes visual indicators to be activated on the physical storage array unit to allow an end-user to visually identify the trays. The indicators will remain active until the stopIdentification procedure is invoked.","A list of the trays.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.invalidTrayref,ReturnCode.ok));
		m_ProcTable[114] = new ProcTableEntry("getDacstoreIncompatibleVolumes", 116, 40, false, m_TypeTable[6], m_TypeTable[682],"This procedure gets a list of volumes encroaching the requested Dacstore area.","A number representing the size of a Dacstore in bytes.","A list of volumeRef objects representing the volumes encroaching on the desired Dacstore area.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[115] = new ProcTableEntry("getControllerTime", 117, 40, false, null, m_TypeTable[613],"This procedure gets the internal clock from the controllers. The time is expressed in seconds since midnight (GMT) on 1/1/1970.","None.","The current value of the controller time-of-day clock.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[116] = new ProcTableEntry("establishVolumeCopy", 118, 40, true, m_TypeTable[945], m_TypeTable[360],"This procedure establishes a volume copy.","The VolumeCopyCreationDescriptor for the volume copy.","A ReturnCodewithRef object that indicates the outcome of the operation, and also returns a reference to the newly created copy. Valid ReturnCode values are:","Am1base","","",
			EnumSet.of(ReturnCode.copyApptagMismatch,ReturnCode.copyGhostSource,ReturnCode.copyGhostTarget,ReturnCode.copyIncompatibleSource,ReturnCode.copyIncompatibleTarget,ReturnCode.copyInvalidSourceRef,ReturnCode.copyInvalidSourceState,ReturnCode.copyInvalidTargetRef,ReturnCode.copyInvalidTargetState,ReturnCode.copySourceFormat,ReturnCode.copySourceReconfig,ReturnCode.copySourceReservation,ReturnCode.copySourceZeroCapacity,ReturnCode.copyTargetFormat,ReturnCode.copyTargetLimit,ReturnCode.copyTargetReconfig,ReturnCode.copyTargetTooSmall,ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidCopyPriority,ReturnCode.maxVolumeCopysExceeded,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volcopyFeatureDisabled));
		m_ProcTable[117] = new ProcTableEntry("removeVolumeCopy", 119, 40, true, m_TypeTable[343], m_TypeTable[152],"Removes a volume copy.","A VolumeCopyRef object that identifies the volume copy to be removed.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[118] = new ProcTableEntry("setVolumeCopyParams", 120, 40, true, m_TypeTable[835], m_TypeTable[152],"This procedure modifies the parameters of a volume copy.","A VolumeCopyParamsUpdateDescriptor object that identifies the copy request and a set of attributes to be used to update the existing attributes.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.copyChangeFailed,ReturnCode.copyGhostTarget,ReturnCode.copyTargetReservation,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidCopyPriority,ReturnCode.invalidVolumecopyref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.volumeNotExist));
		m_ProcTable[119] = new ProcTableEntry("startVolumeCopy", 121, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure takes as its input a VolumeCopyRef and causes a copy operation to be initiated from the beginning of the Source volume. A failure status is returned if the Source and Target volumes do not meet compatibility requirements.","A descriptor object that identifies the volumes to perform the copy operation.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.copyActive,ReturnCode.copyApptagMismatch,ReturnCode.copyGhostSource,ReturnCode.copyGhostTarget,ReturnCode.copyIncompatibleSource,ReturnCode.copyIncompatibleTarget,ReturnCode.copyInvalidSourceState,ReturnCode.copyInvalidTargetState,ReturnCode.copySourceFormat,ReturnCode.copySourceReconfig,ReturnCode.copySourceReservation,ReturnCode.copySourceZeroCapacity,ReturnCode.copyStartFailed,ReturnCode.copyTargetFormat,ReturnCode.copyTargetLimit,ReturnCode.copyTargetReconfig,ReturnCode.copyTargetTooSmall,ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumecopyref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeNotExist));
		m_ProcTable[120] = new ProcTableEntry("stopVolumeCopy", 122, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure halts the active copy.","The VolumeCopyRef object to halt the active copy.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.copyInactive,ReturnCode.copyStopFailed,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumecopyref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeNotExist));
		m_ProcTable[121] = new ProcTableEntry("getVolumeCopyTargetCandidates", 123, 40, false, m_TypeTable[343], m_TypeTable[806],"This procedure returns a list of volume target candidates for creating a volume copy.","An AbstractVolRef descriptor that specifies the source volume for which the target candidates are requested (i.e. the source volume in the candidate copy relationship… the SYMbol client is requesting valid target volumes to use with this source volume).","A list of volumes that are valid target volume candidates.","Am1base","","",
			EnumSet.of(ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.maxVolumeCopysExceeded,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volcopyFeatureDisabled));
		m_ProcTable[122] = new ProcTableEntry("getVolumeCopySourceCandidates", 124, 40, false, null, m_TypeTable[806],"This procedure returns a list of volume source candidates for creating a volume copy.","None.","A list of volumes that are valid source volume candidates.","Am1base","","",
			EnumSet.of(ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.maxVolumeCopysExceeded,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volcopyFeatureDisabled));
		m_ProcTable[123] = new ProcTableEntry("setNetworkParameters", 125, 40, true, m_TypeTable[506], m_TypeTable[152],"This procedure updates the network parameters.","An EthernetParamsUpdateDescriptor object that specifies the controller IP address, the gateway IP address, the network subnet mask, and bootp enable/disable.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","GbEthMgmtPort",
			EnumSet.of(ReturnCode.background,ReturnCode.illegalParam,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[124] = new ProcTableEntry("setRloginCapability", 126, 40, true, m_TypeTable[344], m_TypeTable[152],"This procedure allows rlogin to the controller to be enabled or disabled.","The RloginUpdateDescriptor object is used for specifying the remote login capability of the controller","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","GbEthMgmtPort",
			EnumSet.of(ReturnCode.background,ReturnCode.illegalParam,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[125] = new ProcTableEntry("setVolXferAlertDelayPeriod", 127, 40, true, m_TypeTable[7], m_TypeTable[152],"This procedure is used to set the delay period before a volume transfer alert is issued.","The delay period in seconds from 0 to 3600.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.ok));
		m_ProcTable[126] = new ProcTableEntry("getPersistentRegistrations", 128, 40, false, null, m_TypeTable[921],"Get the list of persistent registrations on the array OBSOLETE: Any call to getPersistantReservations will get a return status indicating the command is obsolete. Please use the new command getPRegistrations.","","","Am1base","Am1base","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[127] = new ProcTableEntry("getPersistentRegistrationsForVolume", 129, 40, false, m_TypeTable[343], m_TypeTable[921],"Get the persistent registrations for the specified volume. The list will contain no more than one PersistentRegistration element. OBSOLETE: Any call to getPersistantReservationsForVolume will get a return status indicating the command is obsolete. Please use the new commands getPRegistrationsForVolume.","","","Am1base","Am1base","Am1base",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[128] = new ProcTableEntry("clearPersistentRegistrations", 130, 240, true, m_TypeTable[682], m_TypeTable[152],"This procedure clears registrations and reservations for specific volumes. A UNIT ATTENTION, RESERVATIONS PREEMPTED condition is established for the former registrants.","The list AbstractVolRefList of volumes to be cleared.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.controllerInServiceMode,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.regDeleteFailed));
		m_ProcTable[129] = new ProcTableEntry("changeMirrorWriteMode", 131, 40, true, m_TypeTable[853], m_TypeTable[152],"Change mirror write mode","This object contains information used for changing the mirror write mode.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ghostVolume,ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidMirrorvol,ReturnCode.invalidVolumeref,ReturnCode.legacyRvmAsyncModeUnsupported,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.rvmOperNotAllowedOnSec,ReturnCode.rvmVersionMismatch));
		m_ProcTable[130] = new ProcTableEntry("suspendMirror", 132, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure suspends the communication between a mirror pair.","This object contains information identifying the Mirror Proxy Volume to be removed.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ghostVolume,ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidMirrorvol,ReturnCode.invalidVolumeref,ReturnCode.mirrorAlreadySuspended,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.rvmOperNotAllowedOnSec,ReturnCode.rvmVersionMismatch,ReturnCode.tryAlternate));
		m_ProcTable[131] = new ProcTableEntry("resumeMirror", 133, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure resumes the communication between a mirror pair.","This object contains information identifying the Mirror Proxy Volume to be removed.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ghostVolume,ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidMirrorvol,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.rvmOperNotAllowedOnSec,ReturnCode.rvmVersionMismatch,ReturnCode.tryAlternate));
		m_ProcTable[132] = new ProcTableEntry("setAutoResync", 134, 40, true, m_TypeTable[932], m_TypeTable[152],"This procedure sets the allowable options for the auto resynchronization.","This object determines whether auto resynchronization is allowed.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ghostVolume,ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidMirrorvol,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.rvmOperNotAllowedOnSec,ReturnCode.rvmVersionMismatch));
		m_ProcTable[133] = new ProcTableEntry("activateStagedControllerFirmware", 135, 480, true, null, m_TypeTable[152],"Activate staged controller firmware","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.busy,ReturnCode.downloadInProgress,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.ok,ReturnCode.voltransferError));
		m_ProcTable[134] = new ProcTableEntry("invalidateStagedControllerFirmware", 136, 240, true, null, m_TypeTable[152],"This procedure invalidates the staged controller firmware.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.downloadInProgress,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.ok));
		m_ProcTable[135] = new ProcTableEntry("getDriveLogData", 137, 40, false, m_TypeTable[343], m_TypeTable[1077],"This procedure gets the drive's log sense pages.","This object contains information identifying all drives that are affected by this operation.","A DriveLogData object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.internalError,ReturnCode.invalidDriveref,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[136] = new ProcTableEntry("getAutoConfigCandidates", 138, 40, false, m_TypeTable[435], m_TypeTable[912],"This procedure automatically gets the configuration candidates.","This object contains a list of automatic configuration templates.","An AutoConfigCandidateList object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.driveNotExist,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidSegmentsize,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.raid6FeatureDisabled,ReturnCode.raid6FeatureUnsupported));
		m_ProcTable[137] = new ProcTableEntry("createAutoConfig", 139, 180, true, m_TypeTable[912], m_TypeTable[152],"Create automatic configuration","This object contains a list of automatic configuration templates.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.tryAlternate));
		m_ProcTable[138] = new ProcTableEntry("autoAssignHotSpares", 140, 40, true, null, m_TypeTable[152],"Automatically assign hot spares","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.noHeap,ReturnCode.noSparesAssigned,ReturnCode.noSparesNeeded,ReturnCode.ok,ReturnCode.someSparesAssigned));
		m_ProcTable[139] = new ProcTableEntry("getHotSpareCoverage", 141, 40, false, null, m_TypeTable[983],"This procedure returns a list of all hot spare drives and their volume groups.","None.","A HotSpareCoverageList object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.noHeap,ReturnCode.ok,ReturnCode.volumeNotExist));
		m_ProcTable[140] = new ProcTableEntry("getHotSpareCandidates", 142, 40, false, m_TypeTable[21], m_TypeTable[1014],"This procedure returns a list of hot spare candidates with the volume groups that they potentially cover.","This object contains information describing the physical drive types supported.","A HotspareCandidateList object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.internalError,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[141] = new ProcTableEntry("readUnreadableSectorDatabase", 143, 600, false, null, m_TypeTable[805],"This procedure returns a list of the known unreadable sectors for the system.","None.","An UnreadableSectorTableInfo object containing the database limit and all known unreadable sectors in the system.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[142] = new ProcTableEntry("clearUnreadableSectors", 144, 600, true, m_TypeTable[343], m_TypeTable[152],"Clears all the unreadable sectors for the given Volume","This object contains information for the specific volume.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.usmClearFailed,ReturnCode.volumeOffline));
		m_ProcTable[143] = new ProcTableEntry("communicationCheck", 145, 600, false, m_TypeTable[824], m_TypeTable[325],"Sending an RVM Communication Check command","This object performs a user requested communication check for a remote volume.","A RemoteCommunicationCheckSampleList object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.rvmCommStatChannelFailure,ReturnCode.rvmCommStatDeviceMissing,ReturnCode.rvmCommStatInvNumSamplesReqd,ReturnCode.rvmCommStatLoginFailure,ReturnCode.rvmCommStatLoginRejected,ReturnCode.rvmCommStatNetworkFailure,ReturnCode.rvmCommStatNotReady,ReturnCode.rvmCommStatRecoveredDelay,ReturnCode.rvmCommStatRecoveredTimeout,ReturnCode.rvmCommStatTimeout,ReturnCode.rvmInvalidRemotevol,ReturnCode.rvmQuiescenceInProgress));
		m_ProcTable[144] = new ProcTableEntry("startDriveFirmwareDownload", 146, 300, true, m_TypeTable[882], m_TypeTable[905],"This procedure starts the parallel drive firmware download process.","This object contains the list of drives to download and an indicator of whether or not to perform the download keeping the volumes online.","A DriveFirmwareStatus object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.busy,ReturnCode.downloadInProgress,ReturnCode.downloadNotPermitted,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidDrives,ReturnCode.invalidSetsize,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.sodInProgress,ReturnCode.spawnError));
		m_ProcTable[145] = new ProcTableEntry("sendDriveFirmware", 147, 40, true, m_TypeTable[459], m_TypeTable[152],"This procedure sends chunks to the parallel drive firmware download process.","This object contains information about the DriveFirmwareChunkDescriptor.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.controllerInServiceMode,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidChunksize,ReturnCode.invalidOffset,ReturnCode.invalidRequest,ReturnCode.invalidSetid,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.overrun,ReturnCode.validationError));
		m_ProcTable[146] = new ProcTableEntry("updateDriveFirmware", 148, 40, true, null, m_TypeTable[152],"This procedure starts the drive download stage of the parallel drive firmware download process.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.ok));
		m_ProcTable[147] = new ProcTableEntry("stopDriveFirmwareDownload", 149, 40, true, null, m_TypeTable[152],"This procedure stops the parallel drive firmware download process.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[148] = new ProcTableEntry("getDriveFirmwareDownloadProgress", 150, 40, false, null, m_TypeTable[905],"This procedure gets the progress of the firmware download.","None.","A DriveFirmwareStatus object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.allFailed,ReturnCode.cacheSyncFailure,ReturnCode.downloadInProgress,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.missingData,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.partialOk,ReturnCode.quiescenceFailed,ReturnCode.tryAlternate));
		m_ProcTable[149] = new ProcTableEntry("recoverVolume", 151, 40, true, m_TypeTable[844], m_TypeTable[152],"This procedure creates a volume using the parameters of a volume that previously existed. Since no data or parity initialization is performed on the volume, the prior data is preserved resulting in a volume that is identical to the previous volume.","This object contains information on how a recovered volume is to be created.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.maxVolumesExceeded,ReturnCode.raid6FeatureDisabled,ReturnCode.raid6FeatureUnsupported));
		m_ProcTable[150] = new ProcTableEntry("setDriveChannelState", 152, 40, true, m_TypeTable[381], m_TypeTable[152],"This procedure sets the drive channel state to either degraded or optimal.","This object contains information on how to request a drive channel state change from the array.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[151] = new ProcTableEntry("getDriveChannelStatistics", 153, 40, false, null, m_TypeTable[922],"This procedure gets statistical information about all of the drive channels.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[152] = new ProcTableEntry("clearDriveChannelStatistics", 154, 40, true, null, m_TypeTable[152],"Clear the drive channel cumulative statistic information","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.ok));
		m_ProcTable[153] = new ProcTableEntry("suspendConsistencyGroup", 155, 120, true, m_TypeTable[343], m_TypeTable[152],"This procedure suspends the communications for all mirrors in a Write Consistency group with a specified group number.","This object contains information about the write consistency group object.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.iconFailure,ReturnCode.internalError,ReturnCode.legacyRvmAsyncModeUnsupported,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.rvmQuiescenceInProgress));
		m_ProcTable[154] = new ProcTableEntry("resumeConsistencyGroup", 156, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure resumes the communication for all mirrors in a Write Consistency group with a specified group number.","This object contains information about the write consistency group object.","A ReturnCode object that indicates the outcome of the operation. Valid values are: ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.iconFailure,ReturnCode.internalError,ReturnCode.legacyRvmAsyncModeUnsupported,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[155] = new ProcTableEntry("setControllerServiceMode", 157, 180, true, m_TypeTable[315], m_TypeTable[152],"This procedure places a controller in Service Mode. It replaces the obsolete setControllerToPassive procedure. The command is serviced by the controller opposite to controllerRef.","The value of the controller reference for the controller to be placed in service mode.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.modesenseError,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[156] = new ProcTableEntry("scanVolume", 158, 60, true, m_TypeTable[739], m_TypeTable[574],"This procedure causes a scan of the specified volume over the specified extent. The scan stops on any media or parity error encountered and reports the error. The procedure can also be used to repair media errors and parity errors.","A VolumeScanDescriptor that specifies the volume and extent to be scanned and contains indicators to enable repairing of media and parity errors.","A ParityScanResponse that contains a ReturnCode indicating the status of the scan/repair. If the return code indicates a media error or parity error was encountered the EndingLBA fields specify the location of the error. Valid values for the return code are:","Am1base","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.invalidVolumeref,ReturnCode.mediaRepairFailed,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.parityRepairFailed,ReturnCode.parityScanFailed,ReturnCode.tryAlternate,ReturnCode.volumeNotOptimal,ReturnCode.volumeOffline));
		m_ProcTable[157] = new ProcTableEntry("updateVolumeAttribute", 159, 40, true, m_TypeTable[585], m_TypeTable[152],"This procedure changes the mgmtClientAttribute for a volume.","The VolumeAttributeUpdateDescriptor object.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.databaseError,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.volumeNotExist));
		m_ProcTable[158] = new ProcTableEntry("writeMgmtClientRecords", 160, 40, true, m_TypeTable[645], m_TypeTable[152],"This procedure saves a new value of the specified MgmtClientRecord.","The MgmtClientRecordWriteDescriptor object.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.databaseError,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.volumeNotExist));
		m_ProcTable[159] = new ProcTableEntry("readMgmtClientRecords", 161, 40, false, m_TypeTable[494], m_TypeTable[638],"This procedure reads a range of (i.e. one or more) MgmtClient Record objects.","The MgmtClientRecordReadDescriptor value.","The MgmtClientRecordReadResult object.","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[160] = new ProcTableEntry("deleteMgmtClientRecords", 162, 40, true, m_TypeTable[681], m_TypeTable[152],"This procedure deletes a range of (i.e. one or more) specified MgmtCleintRecords.","The MgmtClientRecordDeleteDescriptor value.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.databaseError,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.volumeNotExist));
		m_ProcTable[161] = new ProcTableEntry("suspendMirrorList", 163, 40, true, m_TypeTable[1053], m_TypeTable[152],"This procedure suspends the communication between all mirrored pairs specified in the MirrorVolumeList.","This object contains information identifying the list of Mirror Volumes to suspend.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.iconFailure,ReturnCode.internalError,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.rvmQuiescenceInProgress));
		m_ProcTable[162] = new ProcTableEntry("resumeMirrorList", 164, 40, true, m_TypeTable[1053], m_TypeTable[152],"This procedure resumes the communication between all mirrored pairs specified in the MirrorVolumeList.","This object contains information identifying the list of mirrored pairs on which to perform the resume operation.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.iconFailure,ReturnCode.internalError,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[163] = new ProcTableEntry("getPRegistrations", 165, 40, false, null, m_TypeTable[1202],"This procedure returns a list of persistent registrations on the array.","None.","A list of all volumes for which initiators have registered. Each entry in the list has a reservation type, an indication of whether the reservation, if any, persists through power loss, and a list of registrants. Each registrant contains (a) the port identifier, (b) the name of the host containing the port, if available, (c) a list of target ports, and (d) the target port through which the reservation is held, which can be a single port, \"All\", or \"None.\"","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[164] = new ProcTableEntry("updateTray", 166, 40, true, m_TypeTable[615], m_TypeTable[152],"Updates the Tray ID of a tray.","A reference to the physical tray and the ID value to set for the tray.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[165] = new ProcTableEntry("setAlarm", 167, 40, true, m_TypeTable[776], m_TypeTable[152],"This procedure sets the allowed alarm controls.","An AlarmUpdateDescriptor object that indicates the alarm to modify and the alarm control to activate.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.ok));
	}

	private static void __init19() {
		m_ProcTable[166] = new ProcTableEntry("issueDiscreteLinesTest", 168, 40, false, null, m_TypeTable[152],"This procedure executes the inter-controller discrete line diagnostics test.","None.","A ReturnCode object that indicates the outcome of the operation . Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.dltNotCompleted,ReturnCode.error,ReturnCode.ok));
		m_ProcTable[167] = new ProcTableEntry("requestToRemove", 169, 40, true, m_TypeTable[927], m_TypeTable[152],"This procedure turns the Ready to Remove indicator light on or off or puts the Ready to Remove indicator into automatic mode, for the component specified in the RTRUpdateDescriptor. This procedure is deprecated. The requestRemoval procedure should be used instead.","An RTRUpdateDescriptor object that indicates the component to modify and the control to execute.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","Am1base",
			EnumSet.of(ReturnCode.downloadInProgress,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.ok));
		m_ProcTable[168] = new ProcTableEntry("setSimplexMode", 170, 40, true, m_TypeTable[35], m_TypeTable[152],"This procedure is used to enable and disable Simplex mode.","An enumeration object that describes the controller's redundancy mode. Use CTRL_REDUNDANCY_MODE_DUPLEX to set the redundancy mode to duplex and CTRL_REDUNDANCY_MODE_SIMPLEX to set the redundancy mode to simplex.","","Am1base","","",
			EnumSet.of(ReturnCode.iconFailure,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.mirrorsPresent,ReturnCode.notImplemented,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[169] = new ProcTableEntry("getPRegistrationsForVolume", 171, 40, false, m_TypeTable[343], m_TypeTable[1202],"This procedure returns a list of the persistent registrations for the specified volume.","The AbstractVolRef object for the specific volume.","An indication of whether the reservation, if any, persists through power loss, and a list of registrants. Each registrant contains (a) the port identifier, (b) the name of the host containing the port, if available, (c) a list of target ports, and (d) the target port through which the reservation is held, which can be a single port, \"All\", or \"None.\"","Am1base","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[170] = new ProcTableEntry("requestRemoval", 172, 40, true, m_TypeTable[758], m_TypeTable[152],"This procedure turns the Ready to Remove indicator light on or off or puts the Ready to Remove indicator into automatic mode, for the component specified in the RTRUpdateDescriptor.","An RTRUpdateDescription object that indicates the component to modify and the control to execute.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Am1base","","",
			EnumSet.of(ReturnCode.downloadInProgress,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.ok));
		m_ProcTable[171] = new ProcTableEntry("getSocErrorStatistics", 173, 40, false, m_TypeTable[538], m_TypeTable[1201],"This procedure returns SOC error statistics.","A SOC command descriptor that indicates the devices for which statistics should be returned.","A SocStatisticsReturned structure containing a return code indicating the outcome of the operation and, if the return code is RETCODE_OK, a SocStatistics structure. Valid return code values are:","SocStatistics","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[172] = new ProcTableEntry("clearSocErrorStatistics", 174, 40, true, m_TypeTable[315], m_TypeTable[152],"Set SOC error statistics baseline information","A reference to the controller for which statistics are to be cleared on all accessible SOC devices.","A return code object that indicates the outcome of the operation. Valid values are:","SocStatistics","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[173] = new ProcTableEntry("getDdcLog", 175, 40, false, m_TypeTable[595], m_TypeTable[650],"This procedure allows a client to retrieve diagnostic information from the storage array's diagnostic data capture. The client must specify a correct tag and appropriate chunk number. In case of failure, the client must either (1) retry the current chunk number or (2) discard any partially-received log data and retry from the first chunk number (which is one - zero is not a valid chunk number).","A DdcExtent structure specifying the chunk to be retrieved.","A DdcLogDataReturned structure containing the procedure return code and the log data. Valid return codes are:","DiagDataCapture","","",
			EnumSet.of(ReturnCode.ddcUnavail,ReturnCode.illegalParam,ReturnCode.invalidDdcTag,ReturnCode.ok));
		m_ProcTable[174] = new ProcTableEntry("clearDdcNeedsAttention", 176, 40, false, m_TypeTable[7], m_TypeTable[152],"This procedure clears the Needs Attention signifying the availability of diagnostic data. The client must specify a correct tag. This procedure does not clears the DDC logs in the controller.","A DdcTag value identifying the DDC data set that triggered the Needs Attention.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","DiagDataCapture","","",
			EnumSet.of(ReturnCode.ddcUnavail,ReturnCode.invalidDdcTag,ReturnCode.ok));
		m_ProcTable[175] = new ProcTableEntry("powerDownArray", 177, 40, true, null, m_TypeTable[152],"This command provides a programmatic means of powering off a storage array The operation is performed as gracefully as possible. Once this command is received, all open sockets, except for those that have in-process commands, are closed, meaning that any new SYMbol commands attempted will receive an RPC error. SYMbol commands that are in-process when this command is received are allowed to continue execution. In-process SYMbol commands in the \"active\" category are guaranteed to complete; In-process commands in the \"passive\" category may complete, but there is no guarantee. This command returns and reports status just prior to the actual power down event. Authentication is required for this command.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","PowerDownCommand","","",
			EnumSet.of(ReturnCode.background,ReturnCode.cacheSyncFailure,ReturnCode.controllerInServiceMode,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.quiescenceFailed));
		m_ProcTable[176] = new ProcTableEntry("loadEsmFirmwareOnMismatch", 178, 900, false, m_TypeTable[690], m_TypeTable[152],"This procedure is used to download a new firmware image to the ESM cards in a tray. This procedure is identical in behavior to loadESMFirmware. with respect to interpretation of the argument and performing the download process. It differs from that command with respect to certain pre-validation checks it performs. In particular, it requires that an ESM firmware mismatch condition exist on the indicated tray before it will proceed with the download.","An ESMFirmwareUpdateDescriptor object that indicates the tray to receive the firmware, the offset and size of the firmware segment being transferred.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","EsmAutoSync","","",
			EnumSet.of(ReturnCode.busy,ReturnCode.cacheconfigError,ReturnCode.controllerInServiceMode,ReturnCode.downloadInProgress,ReturnCode.error,ReturnCode.esmDownloadFailed,ReturnCode.esmPartialUpdate,ReturnCode.fileTooLarge,ReturnCode.invalidChunksize,ReturnCode.invalidOffset,ReturnCode.invalidTotalsize,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.overrun,ReturnCode.requiredConditionNotPresent,ReturnCode.spawnError,ReturnCode.tryAlternate));
		m_ProcTable[177] = new ProcTableEntry("addPendingHost", 179, 40, false, m_TypeTable[1130], m_TypeTable[152],"This procedure causes the controller to store some or all of the information contained in the PendingHost argument. The information is simply stored and made available for later retrieval (see getPendingHosts procedure); it is not incorporated into the configured topology, and it is not persisted to disk. If the controller determines that the pending definition is an exact match of configured topology elements, it does not store it. It bears pointing out that, for iSCSI, multiple ports belonging to the same initiator may be present in the pending host information - when this happens, the controller creates only a single initiator, no matter how many ports for that initiator are presented. No authentication is performed on this command.","A PendingHost structure that describes the host to be added to the pending topology. It is not considered an error for the PendingHost structure to have a zero-length host label.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","HostContextAgent","ImmediateHostTopology","HostContextAgent",
			EnumSet.of(ReturnCode.internalError,ReturnCode.invalidHosttypeString,ReturnCode.invalidProtocol,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[178] = new ProcTableEntry("configurePendingHost", 180, 40, true, m_TypeTable[1130], m_TypeTable[152],"This procedure is subject to SYMbol authentication.","A PendngHost structure describing a host and its related objects.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","HostContextAgent","ImmediateHostTopology","HostContextAgent",
			EnumSet.of(ReturnCode.hosttypeConflict,ReturnCode.initiatorConflict,ReturnCode.initiatorRemoved,ReturnCode.internalError,ReturnCode.invalidHosttypeString,ReturnCode.invalidProtocol,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.portConflict,ReturnCode.portRemoved));
		m_ProcTable[179] = new ProcTableEntry("getPendingHosts", 181, 40, false, null, m_TypeTable[1220],"","","","HostContextAgent","ImmediateHostTopology","HostContextAgent",
			EnumSet.of(ReturnCode.internalError,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[180] = new ProcTableEntry("setTrayAttributes", 182, 40, true, m_TypeTable[778], m_TypeTable[152],"This procedure sets arbitrary \"attribute data\" for a specified tray enclosure. Only the attributes specified in the argument are affected by this operation. The old data in an affected attribute is completely overwritten by the new attribute data.","A TrayAttributeUpdateDescriptor indicating which tray is to receive the attribute data, along with a list of elements defining new attribute data to be written.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","MercurySupport","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.invalidRequestForEnclosure,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[181] = new ProcTableEntry("getEnvCardLogData", 183, 40, false, m_TypeTable[343], m_TypeTable[1157],"This procedure gets the log data for the indicated environmental card.","The argument is a component reference indicating the environmental card which is to have its log data returned.","An EnvCardLogDataReturned object containing a return code and the log data itself, if available. Valid values for the return code are:","MercurySupport","","",
			EnumSet.of(ReturnCode.internalError,ReturnCode.invalidEsmref,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[182] = new ProcTableEntry("getSasErrorStatistics", 184, 40, false, null, m_TypeTable[1227],"This procedure returns the SAS PHY error statistics for all SAS devices in the storage array.","None.","A SasStatisticsReturned structure containing a return code indicating the outcome of the operation and, if the return code is RETCODE_OK, a SasStatistics structure. Valid return code values are:","SasSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[183] = new ProcTableEntry("clearSasErrorStatistics", 185, 40, true, null, m_TypeTable[152],"Clears SAS PHY error statistics for SAS I/O controller and expander devices in the array","None.","A return code object that indicates the outcome of the operation. Valid values are:","SasSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[184] = new ProcTableEntry("applyBundleKey", 186, 40, true, m_TypeTable[663], m_TypeTable[152],"This procedure causes the storage array to be migrated from one feature bundle definition to another, as specified in the BundleKey argument.","A key that defines and enables the bundle migration. This key must be obtained from an authorized source in order to be accepted by the array controller.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","SimplBundleMigrate","","",
			EnumSet.of(ReturnCode.controllerInServiceMode,ReturnCode.databaseError,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidBundleKey,ReturnCode.invalidSafeId,ReturnCode.tryAlternate));
		m_ProcTable[185] = new ProcTableEntry("removeBundleKeys", 187, 40, true, null, m_TypeTable[152],"Removes all bundle keys that have been applied to change feature bundles.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","SimplBundleMigrate","","",
			EnumSet.of(ReturnCode.controllerInServiceMode,ReturnCode.error,ReturnCode.ok));
		m_ProcTable[186] = new ProcTableEntry("createInitiator", 188, 40, true, m_TypeTable[1118], m_TypeTable[409],"This procedure creates a new initiator object.","An InitiatorCreationDescriptor object that contains all required properties for the new Initiator object.","An InstanceReturned object that indicates the outcome of the operation, and also returns the InitiatortRef of the newly-created object if the return code is RETCODE_OK. Valid ReturnCode values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.requestFailedDueToPiRestrictions));
		m_ProcTable[187] = new ProcTableEntry("deleteInitiator", 189, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure deletes an initiator object.","A ScsiNodeRef object that identifies the initiator to delete.","An ReturnCode object that indicates the outcome of the operation. Valid ReturnCode values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[188] = new ProcTableEntry("getIscsiSessions", 190, 40, false, m_TypeTable[820], m_TypeTable[1206],"This procedure returns data about active iSCSI sessions.","A GetIscsiSessionsFilter object that indicates that either all or a subset of the session data should be returned.","An IscsiSessionsReturned object containing a return code and the session data, if the return code is RETCODE_OK.. Note that the case of no sessions to report is handled as a normal (RETCODE_OK) condition with the list of sessions just being an empty list. Valid ReturnCode values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[189] = new ProcTableEntry("getIscsiNegotiationDefaults", 191, 40, false, null, m_TypeTable[1061],"This procedure returns the default values for negotiable settings for sessions and connections. These represent the storage array's starting point for negotiations.","None","An IscsiNegotiationDefaultsReturned object containing a return code and the default negotiable settings, if the return code is RETCODE_OK.. Valid ReturnCode values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[190] = new ProcTableEntry("getUnconfiguredInitiators", 192, 40, false, null, m_TypeTable[687],"This procedure returns a list of initiators that have been detected by the storage array, but which are not configured into the storage array topology. An initiator is considered unconfigured if it is not associated with a host.","None","An UnconfiguredInitiatorsReturned object containing a return code and an array of ScsiNodeName that identifies the unconfigured initiators, if the return code is RETCODE_OK.. Valid ReturnCode values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[191] = new ProcTableEntry("setHostProperties", 193, 40, true, m_TypeTable[988], m_TypeTable[152],"This procedure sets selected host properties as indicated by the input argument. It is a replacement for the deprecated moveHost, renameHost.","A HostPropertiesUpdateDescriptor, indicating the affected Host, which properties to set, and what values to set them to.","An ReturnCode object indicating the outcome of the procedure Valid ReturnCode values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[192] = new ProcTableEntry("setInitiatorProperties", 194, 40, true, m_TypeTable[1105], m_TypeTable[152],"This procedure sets selected Initiator properties as indicated by the input argument.","An InitiatorPropertiesUpdateDescriptor, indicating which Initiator properties to set and what values to set them to.","An ReturnCode object indicating the outcome of the procedure. Valid ReturnCode values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.invalidAuthMethod,ReturnCode.invalidSecret,ReturnCode.ok,ReturnCode.requestFailedDueToPiRestrictions,ReturnCode.secretAlreadyInUse));
		m_ProcTable[193] = new ProcTableEntry("setIscsiEntityProperties", 195, 180, true, m_TypeTable[909], m_TypeTable[152],"This procedure sets selected iSCSI entity properties for the storage array as indicated by the input argument.","An IscsiEntityPropertiesUpdateDescriptor, indicating which iSCSI entity properties to set and what values to set them to.","An ReturnCode object indicating the outcome of the procedure Valid ReturnCode values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.isnsDhcpNotSupported,ReturnCode.ok));
		m_ProcTable[194] = new ProcTableEntry("setIscsiInterfaceProperties", 196, 240, true, m_TypeTable[887], m_TypeTable[152],"This procedure sets selected properties of a controller iSCSI interface, as indicated by the input argument.","An IscsiInterfacePropertiesUpdateDescriptor, indicating the affected iSCSI interface, which properties to set, and what values to set them to.","An ReturnCode object indicating the outcome of the procedure Valid ReturnCode values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.duplicateIscsiIpAddress,ReturnCode.invalidInterfaceref,ReturnCode.ok,ReturnCode.portSpeedConflict));
		m_ProcTable[195] = new ProcTableEntry("setTargetProperties", 197, 40, true, m_TypeTable[1076], m_TypeTable[152],"This procedure sets selected Target properties as indicated by the input argument.","A TargetPropertiesUpdateDescriptor, indicating the affected Target, which properties to set and what values to set them to.","An ReturnCode object indicating the outcome of the procedure Valid ReturnCode values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.invalidAuthMethod,ReturnCode.invalidSecret,ReturnCode.ok,ReturnCode.secretAlreadyInUse));
		m_ProcTable[196] = new ProcTableEntry("stopIscsiSession", 198, 40, true, m_TypeTable[7], m_TypeTable[152],"This procedure forcibly terminates an iSCSI session.","An TargetSessionIdentifyingHandle object indicating which session to terminate.","An ReturnCode object indicating the outcome of the procedure Valid ReturnCode values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[197] = new ProcTableEntry("getIscsiStatistics", 199, 40, false, m_TypeTable[176], m_TypeTable[1198],"This procedure returns iSCSI statistical data collected by the storage array. The caller may request either the \"raw\" counts, which are relative to controller start-of-day, or baseline-relative counters, which are relative to the baseline which was last set using the setIscsiStatisticsBaselilne procedure. If the user has not set a baseline since controller start-of-day, then the time at start-of-day is the default baseline time.","An IscsiStatisticsReportType object that indicates if the reported statistics should be the raw or baseline-relative counters.","An IscsiStatisticsReturned object containing a return code and the statistical data, if the return code is RETCODE_OK.. The reported statistics and time references are broken out by controller. The time references reported for the two controllers should be the same, unless, over the collection interval, one controller was reset without the other being reset. Valid ReturnCode values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[198] = new ProcTableEntry("setIscsiStatisticsBaseline", 200, 40, true, null, m_TypeTable[152],"This procedure, from the client's perspective, resets the iSCSI statistical counters to zero. It is a logical reset in the sense that the raw counts maintained in hardware and firmware are not actually reset; instead the firmware makes a snapshot of the current counter values and uses that to report deltas in counts when the statistics are fetched. The new baseline time is applied to both controllers, so that their counts are in sync with one another. If one controller resets without the other resetting, the counters become effectively out of sync and the client is made aware of this fact by the timestamp data reported along with the statistics.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[199] = new ProcTableEntry("setStorageArrayProperties", 201, 40, true, m_TypeTable[884], m_TypeTable[152],"This procedure sets selected properties for the storage array that is the recipient of the call.","A StorageArrayPropertiesUpdateDescriptor, indicating which properties to set and what values to set them to.","An ReturnCode object indicating the outcome of the procedure Valid ReturnCode values are:","CR103066","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.ok));
		m_ProcTable[200] = new ProcTableEntry("validatePassword", 202, 40, true, null, m_TypeTable[152],"This procedure validates the clients storage array password and reports a return code indicating whether or not the password is valid. Even though it does not modify the state of the array, this procedure behaves the same and has the same setup requirements as a procedure that does modify the state of the array.","None","A ReturnCode object indicating the validity of the password. Valid values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.authFailPassword,ReturnCode.authFailReadpassword,ReturnCode.ok));
		m_ProcTable[201] = new ProcTableEntry("refreshIscsiDhcpParameters", 203, 210, true, m_TypeTable[343], m_TypeTable[152],"This procedure performs a refresh of the DHCP parameters for the iSCSI interface specified by the input argument. The affected parameters are port IP address, subnet mask, and gateway IP address.","An Interface reference that identifies the iSCSI interface on which the operation is to be performed.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.manualConfigModeSet,ReturnCode.ok));
		m_ProcTable[202] = new ProcTableEntry("refreshIsnsServerLocation", 204, 180, true, null, m_TypeTable[152],"This procedure causes the storage array to refresh its idea of the network address information for the iSNS server","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","CoreIscsi","","",
			EnumSet.of(ReturnCode.background,ReturnCode.manualConfigModeSet));
		m_ProcTable[203] = new ProcTableEntry("disableSnapshotCollection", 225, 180, true, m_TypeTable[829], m_TypeTable[152],"This procedure will disable (stop) each snapshot volume identified in the argument list. Validation checks for necessary snapshot-disable preconditions are performed prior to disabling any snapshot; if any of the requested snapshots do not meet the preconditions to be disabled, the entire command will be failed and no snapshots will be disabled. If command validation succeeds for all snapshots in the list, but one or more of the snapshots in the list fails to be disabled, the entire command will be failed and no snapshots will be disabled. Requests to disable an already-disabled Snapshot will be treated as no-ops and will be considered successful.","A SnapshotRefList structure identifying the snapshot volume that are to be disabled. The list may contain as few as one snapshot reference or up to MAX_SNAPSHOT_COLLECTION_SIZE references.","A ReturnCode object that indicates either good status or the first error encountered. Valid values are:","SnapshotCopy","LancasterBase","",
			EnumSet.of(ReturnCode.baseVolumeFailed,ReturnCode.baseVolumeOffline,ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.notDisabled,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.repositoryFailed,ReturnCode.repositoryMissing,ReturnCode.repositoryOffline,ReturnCode.snapNotAvailable));
		m_ProcTable[204] = new ProcTableEntry("recreateSnapshotCollection", 226, 40, true, m_TypeTable[829], m_TypeTable[152],"During snapshot recreation, all affected volumes (snapshots, base, and repository) will be appropriately quiesced; I/O will be resumed to all affected volumes once all snapshots have been successfully restarted.","A SnapshotRefList structure identifying the snapshot volume that are to be restarted. The list may contain as few as one snapshot reference or up to MAX_SNAPSHOT_COLLECTION_SIZE references.","A ReturnCode object that indicates either good status or the first error encountered. Valid values are:","SnapshotCopy","LancasterBase","",
			EnumSet.of(ReturnCode.basevolSizeChanged,ReturnCode.baseVolumeFailed,ReturnCode.baseVolumeOffline,ReturnCode.ghostVolume,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.notDisabled,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.repositoryFailed,ReturnCode.repositoryMissing,ReturnCode.repositoryOffline,ReturnCode.snapshotFeatureDisabled,ReturnCode.snapNotAvailable));
		m_ProcTable[205] = new ProcTableEntry("createVolumeGroup", 235, 40, true, m_TypeTable[1112], m_TypeTable[152],"Create an empty VolumeGroup","A VolumeGroupCreationDescriptor structure containing the volume group creation parameters. The information about the volume group drive composition, RAID level, etc. is conveyed in an embedded VolumeCandidate structure.","A return code indicating the outcome of the procedure. Valid values are:","VolGrpMgmt","","",
			EnumSet.of(ReturnCode.invalidSecurity,ReturnCode.noFdeDrives,ReturnCode.ok));
		m_ProcTable[206] = new ProcTableEntry("deleteVolumeGroup", 236, 120, true, m_TypeTable[343], m_TypeTable[152],"Delete VolumeGroup and all Volumes in that group","A reference to the volume group that is to be deleted.","A return code that indicates the outcome of the operation. Valid values are:","VolGrpMgmt","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.volumeInUse));
		m_ProcTable[207] = new ProcTableEntry("resetSAConfiguration", 237, 120, true, m_TypeTable[82], m_TypeTable[152],"This procedure provides a way to clear the storage array configuration without bringing it all the way back to its initial state. Core security and identification may be retained, if desired.","A ResetConfigType object that indicates which parts of the array configuration are to be cleared.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","AutomaticConfig","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[208] = new ProcTableEntry("setVolumeGroupUserLabel", 238, 40, true, m_TypeTable[809], m_TypeTable[152],"Sets the user assigned label for the volume group specified in the VolumeGroupLabelUpdate structure.","A VolumeGroupUserLabelUpdateDescriptor structure that contains the user label and a reference to the volume group to update.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","VolGrpMgmt","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.ok));
		m_ProcTable[209] = new ProcTableEntry("replaceDrive", 239, 240, true, m_TypeTable[840], m_TypeTable[152],"This procedure causes a drive, A, that is not part of a volume group to replace a drive, B, that is part of a volume group. The end result is that the volume group drive composition is redefined to include A, and exclude B. The only candidate drives for being replaced are those that belong to a volume group and are either not-present or are failed. The only candidate drives for replacing a drive are those that are either unassigned or are a fully-integrated hot spare.","A DriveReplacementDescriptor structure that identifies the drive to replace and the replacement drive.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","DriveMgmt","","",
			EnumSet.of(ReturnCode.driveTypeMismatch,ReturnCode.ok));
		m_ProcTable[210] = new ProcTableEntry("getVolumeGroupExpansionCandidates", 240, 40, false, m_TypeTable[343], m_TypeTable[1068],"The firmware prioritizes the properties of candidates for constructing the return list, subject to the volume group having a given property in the first place. The prioritization and ordering of the list is as follows:","A reference to the volume group to which the candidates are to apply.","An ExpansionCandidatesReturned data type containing both a return code and the list of candidates. Possible return codes are:","GrpExpCandidates","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[211] = new ProcTableEntry("exportVolumeGroup", 241, 180, true, m_TypeTable[343], m_TypeTable[152],"This procedure places the identified volume group in an \"exported\" state so that its drives may be removed and installed into another array.","A SYMbol VolumeGroupRef identifying the volume group to export.","A return code indicating the outcome of the operation. The list below identifies the possible return codes for this procedure:","PortableVolGrps","","",
			EnumSet.of(ReturnCode.exportingDrivesDatabaseFailed,ReturnCode.exportingDrivesDatabaseResynchronizing,ReturnCode.noNativeSstor,ReturnCode.ok,ReturnCode.volumeGroupHasArvmRelationship,ReturnCode.volumeGroupHasCloneOpportunity,ReturnCode.volumeGroupHasConcatRelationship,ReturnCode.volumeGroupHasFailedDrives,ReturnCode.volumeGroupHasFailedVols,ReturnCode.volumeGroupHasHotspare,ReturnCode.volumeGroupHasIncompatibleDacstores,ReturnCode.volumeGroupHasInsufficientDrives,ReturnCode.volumeGroupHasMappedVols,ReturnCode.volumeGroupHasMirroringMetadata,ReturnCode.volumeGroupHasMirrorRelationship,ReturnCode.volumeGroupHasNonOptimalVols,ReturnCode.volumeGroupHasPitgroupRelationship,ReturnCode.volumeGroupHasPitviewRelationship,ReturnCode.volumeGroupHasReservations,ReturnCode.volumeGroupHasSnapshotRelationship,ReturnCode.volumeGroupHasUnknownRaidLevel,ReturnCode.volumeGroupHasUnsupportedRaidLevel,ReturnCode.volumeGroupHasVolcopyRelationship,ReturnCode.volumeGroupNotComplete,ReturnCode.volumeGroupReconfiguring,ReturnCode.volumeGroupReconstructing,ReturnCode.volumeInitializing,ReturnCode.volumeLimitExceeded));
		m_ProcTable[212] = new ProcTableEntry("forceVolumeGroup", 242, 540, true, m_TypeTable[343], m_TypeTable[152],"This procedure applies to a volume group for which successful migration of drives from the source array to the target array could not be completed due to hardware errors. It causes the identified volume group to move to a state called the \"forced\" state, from which it is still permissible to perform an import operation on the volume group.","A SYMbol VolumeGroupRef identifying the volume group to export.","A return code indicating the outcome of the operation. The list below identifies the possible return codes for this procedure:","PortableVolGrps","","",
			EnumSet.of(ReturnCode.driveSpinUpError,ReturnCode.legacyVg,ReturnCode.ok,ReturnCode.vgNotForceable,ReturnCode.volumeGroupHasCloneOpportunity,ReturnCode.volumeGroupHasFailedDrives,ReturnCode.volumeGroupHasFailedVols,ReturnCode.volumeGroupHasHotspare,ReturnCode.volumeGroupHasIncompatibleDacstores,ReturnCode.volumeGroupHasIncompatibleDrive,ReturnCode.volumeGroupHasInsufficientDrives,ReturnCode.volumeGroupHasMappedVols,ReturnCode.volumeGroupHasMirroringMetadata,ReturnCode.volumeGroupHasMirrorRelationship,ReturnCode.volumeGroupHasNonOptimalVols,ReturnCode.volumeGroupHasReservations,ReturnCode.volumeGroupHasUnknownRaidLevel,ReturnCode.volumeGroupHasUnsupportedRaidLevel,ReturnCode.volumeGroupHasVolcopyRelationship,ReturnCode.volumeGroupNotContingent,ReturnCode.volumeGroupReconfiguring,ReturnCode.volumeGroupReconstructing,ReturnCode.volumeLimitExceeded));
		m_ProcTable[213] = new ProcTableEntry("importVolumeGroup", 243, 540, true, m_TypeTable[343], m_TypeTable[152],"This procedure causes the identified volume group to be imported, which move it from either the \"exported\" state or the \"forced\" state to the \"complete\" state in which it is fully operable and available for use. Note that \"higher-level\" volumes (SnapshotVolume, MetadataVolume, VolumeCopy, and MirrorProxyVolume) - but not their underlying RAID volumes - are removed as part of the import.","A SYMbol VolumeGroupRef identifying the volume group to export.","A return code indicating the outcome of the operation. The list below identifies the possible return codes for this procedure:","PortableVolGrps","","",
			EnumSet.of(ReturnCode.drivesNeedToBeSpunUp,ReturnCode.driveSpinUpError,ReturnCode.noNativeSstor,ReturnCode.ok,ReturnCode.volumeGroupHasCloneOpportunity,ReturnCode.volumeGroupHasFailedDrives,ReturnCode.volumeGroupHasFailedVols,ReturnCode.volumeGroupHasHotspare,ReturnCode.volumeGroupHasIncompatibleDacstores,ReturnCode.volumeGroupHasIncompatibleDrive,ReturnCode.volumeGroupHasInsufficientDrives,ReturnCode.volumeGroupHasMappedVols,ReturnCode.volumeGroupHasMirroringMetadata,ReturnCode.volumeGroupHasMirrorRelationship,ReturnCode.volumeGroupHasNonOptimalVols,ReturnCode.volumeGroupHasReservations,ReturnCode.volumeGroupHasUnknownRaidLevel,ReturnCode.volumeGroupHasUnsupportedRaidLevel,ReturnCode.volumeGroupHasVolcopyRelationship,ReturnCode.volumeGroupImportInProgress,ReturnCode.volumeGroupNotComplete,ReturnCode.volumeGroupReconfiguring,ReturnCode.volumeGroupReconstructing,ReturnCode.volumeGroupVolumeEncroachesOnDacstore,ReturnCode.volumeLimitExceeded));
		m_ProcTable[214] = new ProcTableEntry("activateDiscreteTimeSeries", 244, 40, true, m_TypeTable[894], m_TypeTable[515],"This procedure activates the collection of a set of statistics known as a \"discrete time series\" (discrete time) on each control of the array. A discrete time is a time-ordered sequence of observations of a single statistic, sampled at regular intervals.","A DiscreteTimeSeriesDescriptor structure containing the arguments for the procedure call.","A StatStreamIdReturned structure containing a return code, and, if the return code is RETCODE_OK, a StatStreamId object for identifying the statistics stream in other related procedure calls. The possible return code values are:","ArrayStatistics","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.ok));
		m_ProcTable[215] = new ProcTableEntry("deactivateDiscreteTimeSeries", 245, 40, true, m_TypeTable[7], m_TypeTable[152],"This procedure deactivates the discrete time series statistical streams","A StatStreamId object that identifies the discrete time series to deactivate.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","ArrayStatistics","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.ok));
		m_ProcTable[216] = new ProcTableEntry("getDiscreteTimeSeriesBundle", 246, 40, false, m_TypeTable[7], m_TypeTable[1007],"This returns up to two groups of discrete time series statistics, one per controller","A StatStreamId object that identifies the discrete time series statistics to return.","A DiscreteTimeSeriesBundleReturned structure containing a return code, and, if the return code value is RETCODE_OK, the discrete time series statistics. The possible return codes for this procedure are","ArrayStatistics","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.ok));
		m_ProcTable[217] = new ProcTableEntry("resetDiscreteTimeSeries", 247, 40, true, m_TypeTable[7], m_TypeTable[152],"This procedure resets the related discrete time series statistical streams on both controller, i.e., it sets the number of observations for the series back to zero.","A StatStreamId object that identifies the discrete time series to reset.","A return code that indicates the outcome of the operation. Possible return codes for this procedure are:","ArrayStatistics","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.ok));
		m_ProcTable[218] = new ProcTableEntry("getHistogramBundle", 248, 40, false, m_TypeTable[7], m_TypeTable[695],"This procedure returns up to two groups of histogram statistics, one per controller,","A StatStreamId object that identifies the histogram statistics to return.","A HistogramBundleReturned structure containing a return code, and, if the return code value is RETCODE_OK, the histogram statistics. The possible return codes for this procedure are","ArrayStatistics","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.ok));
		m_ProcTable[219] = new ProcTableEntry("activateHistogram", 249, 40, true, m_TypeTable[745], m_TypeTable[515],"This procedure activates a type of statistics stream known as a histogram on each controller of the array. A histogram is a set of observations of a single statistic, organized into categories based on user criteria, with observation counts per category identified.","A HistogramDescriptor structure containing the arguments for the procedure call.","A StatStreamIdReturned structure containing a return code, and, if the return code is RETCODE_OK, a StatStreamId object for identifying the activated statistics set in other related procedure calls. The possible return code values are:","ArrayStatistics","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.ok));
		m_ProcTable[220] = new ProcTableEntry("deactivateHistogram", 250, 40, true, m_TypeTable[7], m_TypeTable[152],"This procedure deactivates a histogram statistics set, given a stream ID.","A StatStreamId object that identifies the histogram set to deactivate.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","ArrayStatistics","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.ok));
		m_ProcTable[221] = new ProcTableEntry("resetHistogram", 251, 40, true, m_TypeTable[7], m_TypeTable[152],"This procedure resets the related histograms both controllers, i.e., it sets the number of entries in each category and all observation tallies back to zero.","A StatStreamId object that identifies the histograms to reset.","A return code that indicates the outcome of the operation. Possible return codes for this procedure are:","ArrayStatistics","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.ok));
		m_ProcTable[222] = new ProcTableEntry("getCumulativeStatisticsBundle", 252, 40, false, m_TypeTable[720], m_TypeTable[1103],"This procedure returns up to two groups of statistical counters, one per controller, bundled together. A counter group is a set of related statistical counters, accumulated over a period of time, along with the associated base time.","A CumulativeStatisticsDescriptor structure describing the statistics of interest.","A CumulativeStatisticsBundleReturned structure containing a return code, and, if the return code value is RETCODE_OK, the counter bundle statistical data. Possible return codes for this procedure are:","ArrayStatistics","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.ok));
		m_ProcTable[223] = new ProcTableEntry("resetCumulativeStatistics", 253, 40, true, null, m_TypeTable[152],"This procedure sets all cumulative statistics on each controller back to zero and sets a new base time equal to the current time.","None.","A return code that indicates the outcome of the operation. Possible return codes for this procedure are:","ArrayStatistics","","",
			EnumSet.of(ReturnCode.error,ReturnCode.invalidRequest,ReturnCode.ok));
		m_ProcTable[224] = new ProcTableEntry("getExportDependencies", 254, 40, false, m_TypeTable[343], m_TypeTable[1165],"This procedure returns a list of volume group export dependencies for the identified volume group. The returned list consists of the input volume group's immediate export dependencies only. The procedure does not return transitive dependencies. It is up to the caller to create the complete dependency graph through successive calls to this procedure.","A SYMbol VolumeGroupRef identifying the volume group for which export dependencies are to be reported.","An ExportDependenciesReturned structure containing a return code and, provided the return code is RETCODE_OK, a list of volume group export dependencies. The list below identifies the return codes for this procedure:","PortableVolGrps","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[225] = new ProcTableEntry("deleteSnapshot", 255, 40, true, m_TypeTable[343], m_TypeTable[152],"Deletes the snapshot volume identified by the input argument. All data on the volume is lost and all resources associated with maintaining the snapshot are released.","A SYMbol reference to the snapshot volume that is to be deleted.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","VolumeManagement","LancasterBase","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[226] = new ProcTableEntry("deleteVolumeFromGroup", 256, 540, true, m_TypeTable[541], m_TypeTable[152],"This procedure deletes the volume referenced by the input argument. The procedure allows the caller to specify which behavior is desired for the case of deleting the last volume in the volume group - either delete or retain the volume group.","A VolumeDeletionDescriptor which contains (1) a reference to the volume to delete and (2) a boolean indicator, which indicates whether to delete or retain the volume group when the last volume in the group is deleted.","A return code that indicates the outcome of the operation. Valid values are:","VolumeManagement","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[227] = new ProcTableEntry("cancelImport", 257, 40, false, m_TypeTable[343], m_TypeTable[152],"This procedure indicates to the storage array firmware that the client does not want to proceed with a volume group import operation, and therefore the firmware may spin down the drives that were spun up by the get- ImportDependencies procedure.","A reference to the volume group for which the import is to be canceled.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","PortableVolGrps","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.volumeGroupStateNotValid));
		m_ProcTable[228] = new ProcTableEntry("getImportDependencies", 258, 600, false, m_TypeTable[343], m_TypeTable[414],"This procedure returns a list of volume group import dependencies for the identified volume group. The reported information identifies the types of dependencies that exist for the volume group. It is necessary for this procedure to spin up the drives in the volume group so that their configuration databases can be read. An error is returned if the volume group is not in the exported or forced state.","A SYMbol VolumeGroupRef identifying the volume group for which import dependencies are to be reported.","An ImportDependenciesReturned structure containing a return code and, provided the return code is RETCODE_OK, a list of volume group import dependencies. The list below identifies the return codes for this procedure:","PortableVolGrps","","",
			EnumSet.of(ReturnCode.driveSpinUpError,ReturnCode.ok,ReturnCode.volumeGroupStateNotValid));
		m_ProcTable[229] = new ProcTableEntry("setVolumeProperties", 259, 40, true, m_TypeTable[831], m_TypeTable[152],"This procedure is used for setting new values of certain volume properties. It supports setting some properties while leaving others unchanged.","A VolumePropertiesUpdateDescriptor structure specifying which properties to change and what their new values should be.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","PreReadRedCheck","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidReconpriority,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeNotConfigurable,ReturnCode.volumeNotExist,ReturnCode.volumeNotOptimal,ReturnCode.volumeOffline));
		m_ProcTable[230] = new ProcTableEntry("adoptAllDrives", 260, 540, true, null, m_TypeTable[152],"This procedure caused the storage array to \"adopt\" all foreign drives that are eligible to be adopted. Adoption means accepting or incorporating elements of a foreign drive's configuration database into that of the recipient array. It must be possible for the storage array to match the adoption-candidate drives with ones that are currently being tracked as \"not present.\" In addition, several other technical criteria must be met in order for the adoption to succeed.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","CfgDbAdoption","","",
			EnumSet.of(ReturnCode.error,ReturnCode.noDrivesAdopted,ReturnCode.ok,ReturnCode.someDrivesAdopted));
		m_ProcTable[231] = new ProcTableEntry("adoptDrive", 261, 180, true, m_TypeTable[343], m_TypeTable[152],"This procedure caused the storage array to \"adopt\" a foreign drive that is eligible to be adopted. Adoption means accepting or incorporating elements of a foreign drive's configuration database into that of the recipient array. It must be possible for the storage array to match the adoption-candidate drive with one that is currently being tracked as \"not present.\" In addition, several other technical criteria must be met in order for the adoption to succeed.","A SYMbol reference to the drive that is to be adopted.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","CfgDbAdoption","","",
			EnumSet.of(ReturnCode.error,ReturnCode.ok));
		m_ProcTable[232] = new ProcTableEntry("getControllerDebugInformation", 262, 120, false, m_TypeTable[603], m_TypeTable[670],"This procedure replaces the deprecated stateCapture procedure. It returns a single \"chunk\" of debug information and must be used in a series of like calls in order to retrieve the complete set of debug information.","A DebugInfoExtent structure containing three pieces of information: a reference to the controller that is to return the data, a \"handle\" identifying a single mutually-consistent set of chunks, and a chunk number that identifies the specific chunk to be returned. On the request for the initial chunk (chunk zero), the handle is not significant.","A DebuginfoReturned union consisting of a return code, and, if the code is equal to RETCODE_OK, a structure containing the handle to use on subsequent calls, a count of the total number of chunks, and a block (i.e., \"chunk\") of display-able debug data.","CtrlStateCapture","","",
			EnumSet.of(ReturnCode.debugInfoConfigChanged,ReturnCode.illegalParam,ReturnCode.noSuchDebugChunk,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[233] = new ProcTableEntry("getIbIocAttributes", 400, 40, false, null, m_TypeTable[818],"This procedure returns attribute information for each InfiniBand I/O controller that is part of the Infiniband I/O Unit. An InfiniBand I/O Controller is a logical entity defined in the InfiniBand Architecture. It does not correlate one-to-one with a storage array controller","None.","A union containing a return code and, if the call succeeded, an array holding a set of InfiniBand IOC attributes for each InfiniBand IOC in the array. The list below identifies the return codes for this procedure.","InfinibandSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[234] = new ProcTableEntry("getIbPortPartitionTables", 401, 40, false, null, m_TypeTable[832],"This procedure returns a group of InfiniBand port partition tables, one table for each InfiniBand port of the Infiniband I/O Unit (i.e., storage array).","None","A union containing a return code and, if the call succeeded, an array of PortPartitionTable elements, one for each InfiniBand port of the storage array. The list below identifies the return codes for this procedure.","InfinibandSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[235] = new ProcTableEntry("getIbRdmaChannels", 402, 40, false, null, m_TypeTable[886],"This procedure returns various items of information about InfiniBand RDMA channels that are presently active in the Infiniband I/O Unit (i.e., storage array).","None","A union containing a return code and, if the call succeeded, an array of informational elements, one for each currently-active RDMA channel. The list below identifies the return codes for this procedure.","InfinibandSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[236] = new ProcTableEntry("getIbStatistics", 403, 40, false, null, m_TypeTable[1159],"This procedure returns the InfiniBand statistics, which consist of start-of-day-relative interface statistics, baseline-relative interface statistics, target channel adapter statistics, and RDMA channel statistics.","None.","An IbStatisticsReturned structure containing the InfiniBand statistics. The list below identifies the return codes for this procedure.","InfinibandSupport","","Denali2HIC",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[237] = new ProcTableEntry("setIbStatisticsBaseline", 404, 40, true, null, m_TypeTable[152],"This procedure, from the client's perspective, resets the InfiniBand baselined statistical counters to zero. It is a logical reset in the sense that the raw counts maintained in hardware and firmware are not actually reset; instead the firmware makes a snapshot of the current counter values and uses that to report deltas in counts when the statistics are fetched. The new baseline time is applied to both controllers, so that their counts are in sync with one another. If one controller resets without the other resetting, the counters become effectively out of sync and the client is made aware of this fact by the timestamp data reported along with the statistics.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","InfinibandSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[238] = new ProcTableEntry("createAHostPort", 405, 60, true, m_TypeTable[1188], m_TypeTable[409],"This procedure creates a new host port having the attributes specified in the input argument. It is a replacement for the deprecated createHostPort procedure.","A HostPortCreateDescriptor object containing a set of attributes to assign to the new host port.","","InfinibandSupport","","",
			EnumSet.of(ReturnCode.noHeap,ReturnCode.ok,ReturnCode.partDupId,ReturnCode.partLabelInvalid,ReturnCode.partNodeNonexistent,ReturnCode.requestFailedDueToPiRestrictions));
		m_ProcTable[239] = new ProcTableEntry("setEthernetInterfaceProperties", 407, 40, true, m_TypeTable[939], m_TypeTable[152],"When this command is issued directly to the controller for which the Ethernet properties will change, controller firmware will issue a return code of RETCODE_BACKGROUND to the storage management software before resetting the Ethernet properties and stopping communication. Storage management software developers should maintain both old and new Ethernet properties for the controller in case the procedure fails (if the procedure fails at this point status will not be able to be returned and the storage management software should reestablish communication with the controller using the old Ethernet properties).","An EthernetInterfacePropertiesUpdateDescriptor, indicating the affected Ethernet interface, which properties to set, and what values to set them to.","An ReturnCode object indicating the outcome of the procedure Valid ReturnCode values are:","GbEthMgmtPort","","",
			EnumSet.of(ReturnCode.background,ReturnCode.invalidInterfaceref,ReturnCode.ok,ReturnCode.snmpCannotDisableIpv4,ReturnCode.snmpCannotDisableIpv6,ReturnCode.snmpIpv4ConfigError));
		m_ProcTable[240] = new ProcTableEntry("setHostPortProperties", 408, 40, true, m_TypeTable[1177], m_TypeTable[152],"This procedure sets selected HostPort properties, as specified by the input argument. It is a replacement for the deprecated moveHostPort, renameHostPort.","A HostPortPropertiesUpdateDescriptor structure which indicates the affected host port, which properties to set, and what values to set for them.","","InfinibandSupport","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.requestFailedDueToPiRestrictions));
		m_ProcTable[241] = new ProcTableEntry("setControllerProperties", 409, 40, true, m_TypeTable[1127], m_TypeTable[152],"This procedure is for setting certain changeable properties of an individual controller. The procedure works in such a way that specific properties can be changed while leaving others unchanged.","A ControllerPropertiesUpdateDescriptor structure that indicates to which controller the operation applies and the new settings for that controller.","","MgmtPortIpV6","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.snmpIpv4ConfigError));
		m_ProcTable[242] = new ProcTableEntry("startChannelDiagnostics", 410, 40, true, m_TypeTable[892], m_TypeTable[152],"This procedure initiates a drive channel fault isolation diagnostic test. It returns a status code immediately and the requested tests proceed asynchronously. Any SYMbol request, other than getChannelDiagnosticsResults, cancelChannelDiagnostics, bindToController, and getSAData that is received while the test is running is rejected immediately. Since some SYMbol procedures do not provide a return code, the method of indicating the request rejection is specialized and entails the following: The RPC header that is returned to the client will consist of an RPC response of type \"reply message.\" The reply will have a general status of \"accepted,\" indicating the request was accepted by the controller for processing. The specific \"accepted request status\" value will be 0x80000001, which is an indication that the request could not be processed due to a diagnostic activity.","A ChannelDiagnosticDescriptor structure that contains all of the arguments needed to define the test to perform.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","DrvChannelDiags","","",
			EnumSet.of(ReturnCode.channelDiagsAltCommFailed,ReturnCode.channelDiagsChanSetupFailed,ReturnCode.channelDiagsDeviceBypassFailed,ReturnCode.channelDiagsLockErr,ReturnCode.channelDiagsNotQuiesced,ReturnCode.invalidRequest,ReturnCode.ok));
		m_ProcTable[243] = new ProcTableEntry("stopChannelDiagnostics", 411, 40, false, null, m_TypeTable[152],"This procedure cancels a running channel diagnostic test sequence that was initiated by the startChannelDiagnostics procedure. It is possible to retrieve the (partial) results of a canceled test by calling getChannelDiagnosticsResults.","None.","A return code that indicates the outcome of the operation. Valid values are:","DrvChannelDiags","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[244] = new ProcTableEntry("getChannelDiagnosticsResults", 412, 40, false, null, m_TypeTable[1228],"This procedure reports the results of drive channel fault isolation diagnostic tests that were initiated by the startChannelDIagnostics procedure.","None","A ChannelDiagResultsReturned structure containing a return code along with the results of the channel diagnostic tests. The results may indicate that the tests are still running.","DrvChannelDiags","","",
			EnumSet.of(ReturnCode.channelDiagsResultsNotAvailable,ReturnCode.channelDiagsResultsPartial,ReturnCode.channelDiagsRunning,ReturnCode.ok));
		m_ProcTable[245] = new ProcTableEntry("getControllerHostIoInterfaces", 413, 40, false, m_TypeTable[315], m_TypeTable[1223],"NOTE: object graph data may not be the most recent.","A reference to the controller for which the I/O interface information is desired.","The procedure return code plus the returned I/O interface data, provided the return code is RETCODE_OK.","ParentRelativeLocation","EmeraldObsolete","EmeraldObsolete",
			EnumSet.of(ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[246] = new ProcTableEntry("getCtlLockDownInfo", 414, 40, false, null, m_TypeTable[691],"Returns a structure containing information about the controller if it is locked down.","None.","If getCtlLockDownInfo() returned successfully, then this union will contain information about the locked down controller.","CtrlLockdown","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[247] = new ProcTableEntry("loadControllerFirmwareOnLockdown", 415, 1200, true, m_TypeTable[308], m_TypeTable[152],"To indicate the end of the iterative download sequence, call this procedure with a zero-length segment size. When the controller receives this end indicator, the controller writes the accumulated firmware image to stable storage (typically flash memory). The controller responds to this procedure call with the appropriate return code, delays for a short period, and then reboots to load and execute the new firmware.","A FirmwareUpdateDescriptor object that indicates, among other things, the offset and size of the firmware segment being transferred.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","CtrlLockdown","","",
			EnumSet.of(ReturnCode.busy,ReturnCode.cacheconfigError,ReturnCode.controllerInServiceMode,ReturnCode.downloadInProgress,ReturnCode.downloadNotPermitted,ReturnCode.error,ReturnCode.fileTooLarge,ReturnCode.illegalParam,ReturnCode.imageTransferred,ReturnCode.invalidChunksize,ReturnCode.invalidDlstate,ReturnCode.invalidFile,ReturnCode.invalidOffset,ReturnCode.invalidTotalsize,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.overrun,ReturnCode.spawnError,ReturnCode.voltransferError));
		m_ProcTable[248] = new ProcTableEntry("disableVolumeProtectionInformation", 416, 40, true, m_TypeTable[343], m_TypeTable[152],"Disables protection information (PI) usage for the specified volume.","","A ReturnCode object that indicates the outcome of the operation. Valid values are:","T10ProtectionInformation","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.volumeHasMirrorRelationship,ReturnCode.volumeHasSnapshotRelationship,ReturnCode.volumeHasVolcopyRelationship));
		m_ProcTable[249] = new ProcTableEntry("setLockKey", 504, 40, true, null, m_TypeTable[152],"This procedure is used in conjunction with the createLockKey procedure. This request may be issued to change the existing array lock key or to set an array lock key after a database adoption. The procedure commits the lock key generated by the createLockKey procedure to the drives and to the controllers.","None.","Returns a Return Code indicating if the lockKey was set","FDEDriveSupport","","",
			EnumSet.of(ReturnCode.driveSecurityEnabledFailed,ReturnCode.keyDoesNotExist,ReturnCode.lockkeyFailed,ReturnCode.noFdeDrives,ReturnCode.ok,ReturnCode.volumeNotOptimal));
		m_ProcTable[250] = new ProcTableEntry("importLockKey", 505, 600, false, m_TypeTable[471], m_TypeTable[152],"This procedure allows a security locked drive to be unlocked. An archived, wrapped and encrypted lock key is imported into the array. In response, the controller attempts to unlock all security-locked drives that have a matching lock key ID. The imported lock key and lock key id become the new array lock key and lock key ID.","A LockKeyBlob structure that contains the wrapped lock key and the pass phrase used to encrypt the lock key.","Returns a Return Code indicating if the operation was successful.","FDEDriveSupport","","",
			EnumSet.of(ReturnCode.invalidBlob,ReturnCode.notImplemented,ReturnCode.noKeySet,ReturnCode.noLockedDrives,ReturnCode.ok,ReturnCode.unlockFailed));
		m_ProcTable[251] = new ProcTableEntry("exportLockKey", 506, 40, true, m_TypeTable[380], m_TypeTable[453],"This procedure returns the WrappedLockKeyReturn union for the array.The WrappedLockKeyReturn contains the WrappedLockKey structure for the array it was exported from.","The wrapped pass phrase used to encrypt the lock key.","A wrapped lock key in the WrappedLockKeyReturn union. See the WrappedLockKeyReturn union and the WrappedLockKey structure for more information.","FDEDriveSupport","","",
			java.util.Collections.EMPTY_SET);
		m_ProcTable[252] = new ProcTableEntry("reprovisionDrive", 507, 600, true, m_TypeTable[817], m_TypeTable[152],"This procedure resets each drive's lock key to a new, random value and disables each drive's security system.","A list of drive reference values, which identifies the drives to be re-provisioned.","A return code that indicates the outcome of the operation.","FDEDriveSupport","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.notImplemented,ReturnCode.ok));
		m_ProcTable[253] = new ProcTableEntry("secureVolumeGroup", 508, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure converts the specified volume group to a secure volume group.","The VolumeGroupRef identifier for the volume to be secured.","A return code that indicates the outcome of the operation.","FDEDriveSupport","","",
			EnumSet.of(ReturnCode.invalidVolumegroupref,ReturnCode.notImplemented,ReturnCode.ok,ReturnCode.volsInVgUsingNonSecureCapableFlashcache,ReturnCode.volsInVgUsingSecureDisabledFlashcache));
		m_ProcTable[254] = new ProcTableEntry("createLockKey", 509, 120, true, m_TypeTable[352], m_TypeTable[453],"This procedure creates a new lock key for the array, but does not commit the key to the drives. There must be at least one FDE capable drive present on the array.","This is used to generate the WrappedLockKey that this procedure returns.","This structure contains the return data for this procedure. It contains a return code, and, provided that code is RETCODE_OK, the wrapped lock key in a wrappedLockKey structure.","FDEDriveSupport","","",
			EnumSet.of(ReturnCode.noFdeDrives,ReturnCode.ok,ReturnCode.rekeyInProgress));
		m_ProcTable[255] = new ProcTableEntry("activateHostPort", 510, 40, true, m_TypeTable[343], m_TypeTable[152],"Activates an inactive host port.","","A ReturnCode object that indicates the outcome of the operation. Valid values are:","ImmediateHostTopology","","ImmediateHostTopology",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[256] = new ProcTableEntry("activateInitiator", 511, 40, true, m_TypeTable[343], m_TypeTable[152],"Activates inactive iSCSI initiator.","","A ReturnCode object that indicates the outcome of the operation. Valid values are:","ImmediateHostTopology","","ImmediateHostTopology",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[257] = new ProcTableEntry("getProductCapabilities", 513, 40, false, null, m_TypeTable[571],"This procedure retrieves a list of product capabilities supported by the array.","This procedure retrieves a list of product capabilities supported by the array.","A list of product capabilities supported by the array.","ProductVariation","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[258] = new ProcTableEntry("disableExternalKMS", 516, 40, true, m_TypeTable[380], m_TypeTable[453],"Disables external KMS.","","A WrappedLockKey object that indicates the outcome of the operation.","FDEProxyKeyMgmt","","",
			EnumSet.of(ReturnCode.cannotDisableNoKey,ReturnCode.externalKmsDisabledNoKey,ReturnCode.externalKmsNotEnabled,ReturnCode.ok));
		m_ProcTable[259] = new ProcTableEntry("enableExternalKMS", 517, 300, true, m_TypeTable[380], m_TypeTable[453],"Enables external KMS.","","A wrapped lock key object that indicates the outcome of the operation. Valid values are:","FDEProxyKeyMgmt","","",
			EnumSet.of(ReturnCode.externalKmsEnabled,ReturnCode.externalKmsFailed,ReturnCode.externalKmsNotCompliant,ReturnCode.externalKmsTimeout,ReturnCode.ok));
		m_ProcTable[260] = new ProcTableEntry("installLockKey", 518, 600, false, m_TypeTable[768], m_TypeTable[152],"Passes an existing lock key for the array and unlocks the disks.","","A return code that indicates the outcome of the operation. Valid values are:","FDEProxyKeyMgmt","","",
			EnumSet.of(ReturnCode.invalidBlob,ReturnCode.ok));
		m_ProcTable[261] = new ProcTableEntry("installNewLockKey", 519, 255, true, m_TypeTable[492], m_TypeTable[152],"Passes a new lock key for the array and commits the key to the disks.","","A return code that indicates the outcome of the operation. Valid values are:","FDEProxyKeyMgmt","","",
			EnumSet.of(ReturnCode.externalKmsNotCompliant,ReturnCode.externalKmsNotEnabled,ReturnCode.invalidBlob,ReturnCode.invalidLockKeyId,ReturnCode.keyInvalidSequence,ReturnCode.keyNotNeeded,ReturnCode.ok));
		m_ProcTable[262] = new ProcTableEntry("startCacheMemoryDiagnostic", 520, 40, true, m_TypeTable[580], m_TypeTable[152],"Starts a cache memory diagnostic test on the controller","A structure containing the test type for the controller.","A return code that indicates the outcome of the operation. Valid values are:","CacheMemoryDiags","","",
			EnumSet.of(ReturnCode.ctrlNotInServiceMode,ReturnCode.diagInProgress,ReturnCode.illegalParam,ReturnCode.ok));
		m_ProcTable[263] = new ProcTableEntry("getCacheMemoryDiagnosticStatus", 521, 40, false, null, m_TypeTable[692],"Retrieves the status of a running, interrupted, or completed cache memory diagnostic test.","None.","A FruDiagReturn object that indicates the outcome of the operation. Valid values are:","CacheMemoryDiags","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[264] = new ProcTableEntry("cancelCacheMemoryDiagnostic", 522, 40, true, null, m_TypeTable[692],"Cancels a running cache memory diagnostic test and returns the test status.","None.","A FruDiagReturn object that indicates the outcome of the operation. Valid values are:","CacheMemoryDiags","","",
			EnumSet.of(ReturnCode.authFailParam,ReturnCode.diagNotRunning,ReturnCode.ok));
		m_ProcTable[265] = new ProcTableEntry("startCacheBackupDeviceDiagnostic", 523, 40, true, m_TypeTable[580], m_TypeTable[152],"Starts a cache backup device diagnostic test on the controller","A structure containing the test type and slot number for the procedure call.","A return code that indicates the outcome of the operation. Valid values are:","CacheBackupDeviceDiags","","",
			EnumSet.of(ReturnCode.cacheBackupDevNotExist,ReturnCode.ctrlNotInServiceMode,ReturnCode.diagInProgress,ReturnCode.illegalParam,ReturnCode.ok));
		m_ProcTable[266] = new ProcTableEntry("getCacheBackupDeviceDiagnosticStatus", 524, 40, false, null, m_TypeTable[692],"Retrieves the status of a running, interrupted, or completed cache backup device diagnostic test.","None.","A FruDiagReturn object that indicates the outcome of the operation. Valid values are:","CacheBackupDeviceDiags","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[267] = new ProcTableEntry("cancelCacheBackupDeviceDiagnostic", 525, 40, true, null, m_TypeTable[692],"Cancels a running cache backup device diagnostic test and returns the test status.","None.","A FruDiagReturn object that indicates the outcome of the operation. Valid values are:","CacheBackupDeviceDiags","","",
			EnumSet.of(ReturnCode.authFailParam,ReturnCode.diagNotRunning,ReturnCode.ok));
		m_ProcTable[268] = new ProcTableEntry("startHostCardDiagnostic", 526, 40, true, m_TypeTable[580], m_TypeTable[152],"Starts a host card diagnostic test on the controller","A structure containing the test type and slot number for the procedure call.","A return code that indicates the outcome of the operation. Valid values are:","HICDiags","","",
			EnumSet.of(ReturnCode.ctrlNotInServiceMode,ReturnCode.diagInProgress,ReturnCode.illegalParam,ReturnCode.ok));
		m_ProcTable[269] = new ProcTableEntry("getHostCardDiagnosticStatus", 527, 40, false, null, m_TypeTable[692],"Retrieves the status of a running, interrupted, or completed host card diagnostic test.","None.","A FruDiagReturn object that indicates the outcome of the operation. Valid values are:","HICDiags","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[270] = new ProcTableEntry("cancelHostCardDiagnostic", 528, 90, true, null, m_TypeTable[692],"Cancels a running host card diagnostic test and returns the test status","None.","A FruDiagReturn object that indicates the outcome of the operation. Valid values are:","HICDiags","","",
			EnumSet.of(ReturnCode.authFailParam,ReturnCode.diagNotRunning,ReturnCode.ok));
		m_ProcTable[271] = new ProcTableEntry("startBaseControllerDiagnostic", 529, 40, true, m_TypeTable[580], m_TypeTable[152],"Starts a base controller diagnostic test on the controller.","A structure containing the test type for the procedure call.","A return code that indicates the outcome of the operation. Valid values are:","BaseControllerDiags","","",
			EnumSet.of(ReturnCode.ctrlNotInServiceMode,ReturnCode.diagInProgress,ReturnCode.illegalParam,ReturnCode.ok));
		m_ProcTable[272] = new ProcTableEntry("getBaseControllerDiagnosticStatus", 530, 40, false, null, m_TypeTable[692],"Retrieves the status of a running, interrupted, or completed base controller diagnostic test.","None.","A FruDiagReturn object that indicates the outcome of the operation. Valid values are:","BaseControllerDiags","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[273] = new ProcTableEntry("cancelBaseControllerDiagnostic", 531, 40, true, null, m_TypeTable[692],"Cancels a running base controller diagnostic test and returns the test status.","None.","A FruDiagReturn object that indicates the outcome of the operation. Valid values are:","BaseControllerDiags","","",
			EnumSet.of(ReturnCode.authFailParam,ReturnCode.diagNotRunning,ReturnCode.ok));
		m_ProcTable[274] = new ProcTableEntry("loadControllerFirmwareNoPassword", 541, 1200, false, m_TypeTable[308], m_TypeTable[152],"Used to download some or all of a new firmware image file to a controller when the authentication password is unavailable.","","A return code that indicates the outcome of the operation. Valid values are:","LoadCfwNoPassword","","",
			EnumSet.of(ReturnCode.busy,ReturnCode.cacheconfigError,ReturnCode.controllerInServiceMode,ReturnCode.downloadInProgress,ReturnCode.downloadNotPermitted,ReturnCode.error,ReturnCode.fileTooLarge,ReturnCode.illegalParam,ReturnCode.imageTransferred,ReturnCode.invalidChunksize,ReturnCode.invalidDlstate,ReturnCode.invalidFile,ReturnCode.invalidOffset,ReturnCode.invalidTotalsize,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.overrun,ReturnCode.spawnError,ReturnCode.voltransferError));
		m_ProcTable[275] = new ProcTableEntry("enableFeatureEvaluation", 542, 40, true, m_TypeTable[153], m_TypeTable[152],"Used to start an evaluation of a specified feature using the duration specified for the sub-model ID in the FBDT.","","A return code that indicates the outcome of the operation. Valid values are:","Type2LicenseKeys","","",
			EnumSet.of(ReturnCode.evalNotSupported,ReturnCode.invalidCapability,ReturnCode.invalidSafeCapability,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.previouslyEnabledForEval));
		m_ProcTable[276] = new ProcTableEntry("externalKMSReKey", 543, 300, true, m_TypeTable[380], m_TypeTable[453],"Used to re-key the array with a new lock key.","The wrapped pass phrase used to encrypt the lock key.","A wrapped lock key in the WrappedLockKeyReturn union. See the WrappedLockKeyReturn union and the WrappedLockKey structure for more information.","FDEProxyKeyMgmt","","",
			EnumSet.of(ReturnCode.externalKmsFailed,ReturnCode.externalKmsNotCompliant,ReturnCode.externalKmsNotEnabled,ReturnCode.externalKmsTimeout,ReturnCode.ok));
		m_ProcTable[277] = new ProcTableEntry("validateLockKey", 544, 40, true, m_TypeTable[471], m_TypeTable[152],"Used to validate the supplied key with one currently on the controller.","A LockKeyBlob structure that contains the wrapped lock key and the pass phrase used to encrypt the lock key.","A return code that indicates the outcome of the operation. Valid values are:","FDELockKeyValidation","","",
			EnumSet.of(ReturnCode.externalKeyNotInMemory,ReturnCode.invalidBlob,ReturnCode.lockKeyValidationDisabled,ReturnCode.lockKeyValidationFailed,ReturnCode.noMatchingLockKeyIdFound,ReturnCode.ok));
		m_ProcTable[278] = new ProcTableEntry("setVolumeListOnline", 548, 40, true, m_TypeTable[682], m_TypeTable[1075],"Places the set of volumes online.","The list AbstractVolRefList of volumes to be placed online.","A list of responses from each volume and a return code that indicates the outcome of the operation. Valid values for the return code are:","AlignRemoteNotifications","","",
			EnumSet.of(ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.volumeNotExist,ReturnCode.volumeNotOptimal));
		m_ProcTable[279] = new ProcTableEntry("startRawDataRetrieve", 549, 2400, false, m_TypeTable[1110], m_TypeTable[553],"This procedure starts a raw data retrieval operation.","The controller ref and transfer-type-specific details of the retrieval.","This data will contain both a return code and a raw data transfer type.","DataRetrievalRestore","","",
			EnumSet.of(ReturnCode.busy,ReturnCode.coredumpBackupInProgress,ReturnCode.dplCoreDumpInvalidTag,ReturnCode.dqRetrieveNothingToTransfer,ReturnCode.invalidControllerref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.rawdataTransferAlreadyStarted,ReturnCode.rawdataTransferBadType,ReturnCode.rawdataTransferNoDrives));
		m_ProcTable[280] = new ProcTableEntry("continueRawDataRetrieve", 550, 2400, false, m_TypeTable[474], m_TypeTable[1136],"This procedure is called for each chunk of raw data to be transferred to the host. The first call must be preceded by a call to startRawDataRetrieve().","The controller ref, raw data transfer type and the sequence number for this chunk.","This data will contain a return code, a raw data transfer type, this sequence number, the final sequence number for the data retrieve, and the chunk details for this chunk.","DQRetrieve","","",
			EnumSet.of(ReturnCode.flashError,ReturnCode.invalidControllerref,ReturnCode.invalidFile,ReturnCode.invalidTotalsize,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.rawdataBadSeqNum,ReturnCode.rawdataTransferBadType,ReturnCode.rawdataTransferNotStarted,ReturnCode.rawdataTransferReadError,ReturnCode.rawdataTransferUserCancelled));
		m_ProcTable[281] = new ProcTableEntry("cancelRawDataRetrieve", 551, 40, false, m_TypeTable[388], m_TypeTable[152],"This procedure cancels a raw data retrieve operation.","The raw data transfer type and controller reference.","A return code that indicates the outcome of the operation. Valid values are:","DQRetrieve","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.rawdataTransferNotStarted));
		m_ProcTable[282] = new ProcTableEntry("startRawDataRestore", 552, 40, true, m_TypeTable[969], m_TypeTable[312],"starts a raw data restore operation.","Specifies the controller ref, data transfer type and transfer-type-specific parameters for the restore operation.","This data will contain both a return code and a raw data transfer type.","DBMRetrieveRestore","","",
			EnumSet.of(ReturnCode.busy,ReturnCode.dbmDbSourceUnavailable,ReturnCode.dbmRestoreSourceMismatch,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.rawdataTransferAlreadyStarted,ReturnCode.rawdataTransferBadType,ReturnCode.rawdataTransferInvalidImage,ReturnCode.rawdataTransferNoDrives,ReturnCode.rawdataTransferReadError,ReturnCode.tryAlternate));
		m_ProcTable[283] = new ProcTableEntry("continueRawDataRestore", 553, 1200, true, m_TypeTable[785], m_TypeTable[312],"This procedure is called once to restore each chunk of data, after first calling a startRawDataRestore to notify the controller that it needs to prepare for the restore. On the first call to this procedure, a return code of RETCODE_RAWDATA_TRANSFER_PREPARING indicates that the controller has not completed the preparation, and the first call should be retried. Upon successful completion of the first call (RETCODE_OK), subsequent calls should be made to transfer additional chunks of data, incrementing the sequence number by one for each call.","The controller ref, type of transfer, final sequence number of the transfer, the sequence number of the chunk currently being delivered, and the restore details for the chunk.","This data will contain both a return code and a raw data transfer type.","DBMRetrieveRestore","","",
			EnumSet.of(ReturnCode.dbmDbSourceUnavailable,ReturnCode.dbmRestoreSourceMismatch,ReturnCode.dbmRestoreWriteError,ReturnCode.flashError,ReturnCode.invalidFile,ReturnCode.invalidTotalsize,ReturnCode.ok,ReturnCode.rawdataBadSeqNum,ReturnCode.rawdataTransferCrcError,ReturnCode.rawdataTransferInvalidImage,ReturnCode.rawdataTransferNotStarted,ReturnCode.rawdataTransferPreparing,ReturnCode.rawdataTransferReadError));
		m_ProcTable[284] = new ProcTableEntry("cancelRawDataRestore", 554, 40, true, m_TypeTable[388], m_TypeTable[152],"This procedure cancels a raw data restore operation.","The transfer type and controller reference.","A return code that indicates the outcome of the operation. Valid values are:","DBMRetrieveRestore","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.rawdataTransferNotStarted));
		m_ProcTable[285] = new ProcTableEntry("setRemoteTargetProperties", 556, 40, true, m_TypeTable[981], m_TypeTable[152],"This procedure sets the selected remote target properties as indicated by the input arguments.","The updated settings for the new target initiator identified in the descriptor.","A return code that indicates the outcome of the operation. Valid values are:","iSCSIMultiMirrorCopyServices","","",
			EnumSet.of(ReturnCode.invalidAuthMethod,ReturnCode.invalidSecret,ReturnCode.ok,ReturnCode.secretAlreadyInUse));
		m_ProcTable[286] = new ProcTableEntry("writeClientMgmtRecordsNoPassword", 559, 40, false, m_TypeTable[645], m_TypeTable[152],"This procedure saves a new value of the specified MgmtClientRecords.","The MgmtClientRecordWriteDescriptor object.","A return code that indicates the outcome of the operation. Valid values are:","ClientDataNoPassword","","",
			EnumSet.of(ReturnCode.databaseError,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.volumeNotExist));
		m_ProcTable[287] = new ProcTableEntry("deleteClientMgmtRecordsNoPassword", 560, 40, false, m_TypeTable[681], m_TypeTable[152],"This procedure deletes a range of (i.e. one or more) specified MgmtClientRecords.","The MgmtClientRecordDeleteDescriptor value.","A return code that indicates the outcome of the operation. Valid values are:","ClientDataNoPassword","","",
			EnumSet.of(ReturnCode.databaseError,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.volumeNotExist));
		m_ProcTable[288] = new ProcTableEntry("loadFactoryDefaults", 562, 200, true, m_TypeTable[398], m_TypeTable[152],"This procedure is used to download factory default information to a controller or expansion enclosure.","The factory default data.","A return code that indicates the outcome of the operation. Valid values are:","WembleySASEnclosure","","",
			EnumSet.of(ReturnCode.error,ReturnCode.errorWritingToEeprom,ReturnCode.factoryDefaultDownloadFailed,ReturnCode.factoryDefaultPartialUpdate,ReturnCode.ok));
		m_ProcTable[289] = new ProcTableEntry("getEnclosureStateCaptureData", 563, 40, false, m_TypeTable[343], m_TypeTable[424],"This procedure will retrieve state capture information from controller and expansion enclosures, including DCMs, if any. Send the command to both controllers if the tray is an RBOD.","The ref corresponding to the enclosure for which the data is requested.","A pointer to the statePrintBuffer where any output from the function is stored.","WembleySASEnclosure","","WembleySAS60RBODSupport",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[290] = new ProcTableEntry("getAlertableMelEntries", 565, 900, false, m_TypeTable[413], m_TypeTable[1185],"Allows a client to fetch a set of entries that have the alertable, needs attention, or collect support bundle flag set from the array's MEL for analysis or display.","The range of MEL entries.","Information associated with the MEL entries in the set.","EventLogging","","",
			EnumSet.of(ReturnCode.error,ReturnCode.ok));
		m_ProcTable[291] = new ProcTableEntry("getLongLivedOpsProgress", 566, 40, false, null, m_TypeTable[1197],"This procedure will report progress on each actively running long-lived operation.","","Information about the progress of long lived operations.","LongLivedOpsProgressReportingSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[292] = new ProcTableEntry("startSnapshotRollback", 567, 40, true, m_TypeTable[829], m_TypeTable[152],"This procedure is used to initiate a snapshot rollback (to base) on one or more snapshots.","A reference to the snapshots to roll back.","A return code that indicates the outcome of the operation. Valid values are:","SnapshotRollback","LancasterBase","",
			EnumSet.of(ReturnCode.ok,ReturnCode.rollbackStartFailure));
		m_ProcTable[293] = new ProcTableEntry("cancelSnapshotRollback", 568, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure is used to cancel a snapshot rollback operation.","A reference to the snapshot on which to cancel the rollback.","A return code that indicates the outcome of the operation. Valid values are:","SnapshotRollback","LancasterBase","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[294] = new ProcTableEntry("resumeSnapshotRollback", 569, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure is used to resume suspended snapshot rollback operations.","A reference to the snapshot for which to resume the snapshot rollback operation.","A return code that indicates the outcome of the operation. Valid values are:","SnapshotRollback","LancasterBase","",
			EnumSet.of(ReturnCode.ok,ReturnCode.rollbackStartFailure));
		m_ProcTable[295] = new ProcTableEntry("createScheduleList", 570, 40, true, m_TypeTable[1140], m_TypeTable[535],"This procedure is used to create a list of schedules.","A list of schedule creation descriptors.","A list of refs and status.","SnapshotScheduler","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[296] = new ProcTableEntry("modifyScheduleList", 571, 40, true, m_TypeTable[1151], m_TypeTable[152],"This procedure is used to modify a list of schedules.","A list of schedule update descriptors.","A return code that indicates the outcome of the operation. Valid values are:","SnapshotScheduler","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[297] = new ProcTableEntry("deleteScheduleList", 572, 40, true, m_TypeTable[837], m_TypeTable[152],"This procedure will delete a list of schedules.","A list of schedule references.","A return code that indicates the outcome of the operation. Valid values are:","SnapshotScheduler","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[298] = new ProcTableEntry("getIscsiCopperCableDiagnostics", 573, 40, false, m_TypeTable[612], m_TypeTable[858],"This procedure will perform diagnostic tests on all channels of a given iSCSI HIC. These diagnostics are dependent on the PHY used on a particular HIC, so they may not be available on all ports of the controller.","Information used to start iSCSI cable diagnostics.","A return code is returned, and if it is RETCODE_OK, additional diagnostic information from the procedure is returned as well.","SolarFlarePhyDiagsSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[299] = new ProcTableEntry("updatePSUFirmware", 574, 40, true, m_TypeTable[676], m_TypeTable[152],"This procedure is used to update the firmware on one or more power supplies.","A PSUFirmwareUpdateDescriptor object that contains all the attributes required to update the firmware on the power supplies.","A return code that indicates the outcome of the operation. Valid values are:","PowerSupplyUpdateSupport","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.psuFirmwareDownloadFailed,ReturnCode.psuFirmwareUpdateMfgDeviceCodeMismatch,ReturnCode.psuFirmwareUpdateNotAllOptimal,ReturnCode.psuFirmwareUpdateNotAllRedundant));
		m_ProcTable[300] = new ProcTableEntry("getPSUFirmwareUpdateProgress", 575, 40, false, null, m_TypeTable[942],"This procedure is used to check the progress of a power supply firmware update operation.","","A return code is returned, and if it is RETCODE_OK, additional diagnostic information from the procedure is returned as well.","PowerSupplyUpdateSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[301] = new ProcTableEntry("getEnclosureTemperatures", 576, 40, false, null, m_TypeTable[1054],"This procedure retrieves temperature data for each thermal sensor in each enclosure in the storage array.","","A return code is returned, and if it is RETCODE_OK, additional diagnostic information from the procedure is returned as well.","EnclTempReporting","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[302] = new ProcTableEntry("getDriveTemperatures", 577, 40, false, null, m_TypeTable[957],"This procedure retrieves temperature data for drives in the storage array.","","A return code is returned, and if it is RETCODE_OK, additional diagnostic information from the procedure is returned as well.","DriveTempRetrieval","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[303] = new ProcTableEntry("setDriveTemperaturePollingInterval", 578, 40, false, m_TypeTable[7], m_TypeTable[152],"This procedure set the interval in minutes between automatic polls of drive temperatures. For interval > 0, automatic polling is enabled at the specified interval. For interval == 0, automatic polling is disabled. Each polling event will update the driveTemperature field in each Drive structure in the ObjectBundle.","Polling interval in minutes.","A return code that indicates the outcome of the operation. Valid values are:","DriveTempRetrieval","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[304] = new ProcTableEntry("reserveSupportData", 579, 40, false, null, m_TypeTable[567],"This procedure attempts to acquire the Customer Support Bundle lock. If the lock is successfully acquired the procedure returns success and the lock key. If another client owns the lock a failure indication is returned along with an integer indicating the suggested number of seconds to wait before retrying the reservation.","","The return data from the procedure call. If the value of returnCode is RETCODE_OK, then the lock key to be used when later releasing the reservation is returned. Valid values for a return code are:","ConcurrentCSBPrevention","","",
			EnumSet.of(ReturnCode.csbReserveFailed,ReturnCode.ok));
		m_ProcTable[305] = new ProcTableEntry("releaseSupportData", 580, 40, false, m_TypeTable[7], m_TypeTable[152],"This procedure attempts to release a previously acquired Customer Support Bundle (CSB) lock once the CSB retrieval is complete. If the provided lock key matches the current value of the lock, the lock is released and the procedure returns success. If the lock key does not match the current value of the lock or if the lock is not active, the procedure returns an error.","The key returned by reserveSupportData.","A return code that indicates the outcome of the operation. Valid values are:","ConcurrentCSBPrevention","","",
			EnumSet.of(ReturnCode.csbReleaseFailedInvalidKey,ReturnCode.csbReleaseFailedNoLock,ReturnCode.ok));
		m_ProcTable[306] = new ProcTableEntry("createDiskPool", 581, 540, true, m_TypeTable[1153], m_TypeTable[152],"This procedure is used to create an empty disk pool.","Information about the intended disk pool.","A return code that indicates the outcome of the operation. Valid values are:","DiskPools","","",
			EnumSet.of(ReturnCode.driveNotExist,ReturnCode.error,ReturnCode.exceedDiskPoolCapacity,ReturnCode.exceedDiskPoolLimit,ReturnCode.exceedMaxVolumeCapacity,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidCriticalThreshold,ReturnCode.invalidDriveState,ReturnCode.invalidLabel,ReturnCode.invalidSecurity,ReturnCode.noFdeDrives,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.prohibitedByMdtRestrictions,ReturnCode.raid6FeatureDisabled,ReturnCode.raid6FeatureUnsupported));
		m_ProcTable[307] = new ProcTableEntry("deleteDiskPool", 582, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure is used to delete a disk pool and all volumes in that pool.","A reference to the volume group to be deleted.","A return code that indicates the outcome of the operation. Valid values are:","DiskPools","","",
			EnumSet.of(ReturnCode.diskPoolNotEmpty,ReturnCode.ok));
		m_ProcTable[308] = new ProcTableEntry("assignDiskPoolOwnership", 583, 40, true, m_TypeTable[917], m_TypeTable[152],"This procedure is used to instruct the controller to transfer ownership of a disk pool and its associated volumes to another controller.","A descriptor that specifies the volume group being modified, and the controller that is to take ownership of the volume group, and thus all volumes defined on the volume group.","A return code that indicates the outcome of the operation. Valid values are:","DiskPools","","",
			EnumSet.of(ReturnCode.cacheSyncFailure,ReturnCode.controllerInServiceMode,ReturnCode.iconFailure,ReturnCode.internalError,ReturnCode.invalidControllerref,ReturnCode.invalidRequest,ReturnCode.invalidVolumegroupref,ReturnCode.modesenseError,ReturnCode.notDualActive,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[309] = new ProcTableEntry("setDiskPoolUserLabel", 584, 40, true, m_TypeTable[809], m_TypeTable[152],"This procedure is used to set the user assigned label for the disk pool.","A DiskPoolLabelUpdateDescriptor structure that contains the user label and a reference to the volume group to update.","A return code that indicates the outcome of the operation. Valid values are:","DiskPools","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.ok));
		m_ProcTable[310] = new ProcTableEntry("createFlashCache", 585, 40, true, m_TypeTable[1066], m_TypeTable[152],"This procedure creates a Volume Group and two RAID Volumes to be used for flash cache. Uses the VolumeCandidate for the RAID Volume creation and assigns labels as given. The capacity in the VolumeCandidate is split between the two RAID Volumes. A High Level Volume is also created to reference the RAID Volumes.","The attributes for creation of a flash cache object.","A return code that indicates the outcome of the operation. Valid values are:","FlashReadCache","","",
			EnumSet.of(ReturnCode.driveNotExist,ReturnCode.driveNotUnassigned,ReturnCode.driveTypeMismatch,ReturnCode.error,ReturnCode.flashcacheAlreadyExists,ReturnCode.flashcacheFeatureDisabled,ReturnCode.flashcacheMaxCapacityExceeded,ReturnCode.flashcacheMaxLimitExceeded,ReturnCode.flashCacheFdeEnablementDisallowed,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidLabel,ReturnCode.maxVolumesExceeded,ReturnCode.noHeap,ReturnCode.numVolumesGroup,ReturnCode.ok));
		m_ProcTable[311] = new ProcTableEntry("deleteFlashCache", 586, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure deletes the High Level Volume, the RAID Volumes on the SSD, and disables flash caching on any associated user volumes.","A reference to the flash cache object to delete.","A return code that indicates the outcome of the operation. Valid values are:","FlashReadCache","","",
			EnumSet.of(ReturnCode.error,ReturnCode.flashcacheDeleted,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.notFlashcacheVol,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[312] = new ProcTableEntry("enableFlashCacheVolume", 587, 40, true, m_TypeTable[1116], m_TypeTable[152],"This procedure creates a flash cache proxy linked to the referenced user RAID Volume and the flash cache High Level Volume. The flash cache attribute on the RAID Volume will be turned on.","A reference to the user volume to link to the flash cache proxy, and a reference to the flash cache volume.","A return code that indicates the outcome of the operation. Valid values are:","FlashReadCache","","",
			EnumSet.of(ReturnCode.error,ReturnCode.flashcacheDeleted,ReturnCode.flashCacheInvalidBaseVol,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.notFlashcacheVol,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeFormatting,ReturnCode.volumeNotExist,ReturnCode.volumeOffline,ReturnCode.volumeReconfiguring));
		m_ProcTable[313] = new ProcTableEntry("disableFlashCacheVolume", 588, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure deletes the proxy and turns off flash cache volume attributes on the referenced user volume.","A reference to the volume to disable.","A return code that indicates the outcome of the operation. Valid values are:","FlashReadCache","","",
			EnumSet.of(ReturnCode.error,ReturnCode.flashcacheDeleted,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.notFlashcacheVol,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.volumeNotExist));
		m_ProcTable[314] = new ProcTableEntry("suspendFlashCache", 589, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure suspends caching on the specified flash cache.","The flash cache reference.","A return code that indicates the outcome of the operation. Valid values are:","FlashReadCache","","",
			EnumSet.of(ReturnCode.error,ReturnCode.flashcacheAlreadySuspended,ReturnCode.flashcacheDeleted,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.notFlashcacheVol,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.volumeNotExist));
		m_ProcTable[315] = new ProcTableEntry("addDrivesToFlashCache", 590, 40, true, m_TypeTable[1049], m_TypeTable[152],"This procedure reconfigures the flash cache volume group to add additional drives.","A FlashCacheReconfigureDrivesDescriptor object that identifies the volume group to be expanded, plus the drive or drives to be added to the volume group. All drives specified for this operation must be in the unassigned state initially.","A return code that indicates the outcome of the operation. Valid values are:","FlashReadCache","","",
			EnumSet.of(ReturnCode.capacityConstrained,ReturnCode.driveNotOptimal,ReturnCode.driveNotUnassigned,ReturnCode.duplicateDrives,ReturnCode.error,ReturnCode.flashcacheDegradedState,ReturnCode.flashcacheDeleted,ReturnCode.flashcacheFailed,ReturnCode.flashcacheMaxCapacityExceeded,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidDriveref,ReturnCode.invalidDriveState,ReturnCode.invalidExpansionList,ReturnCode.invalidVolumegroupref,ReturnCode.notFlashcacheVol,ReturnCode.noHeap,ReturnCode.numdrivesGroup,ReturnCode.ok));
		m_ProcTable[316] = new ProcTableEntry("removeDrivesFromFlashCache", 591, 40, true, m_TypeTable[1049], m_TypeTable[152],"This procedure reconfigures the flash cache volume group to remove drives.","The flash cache reference and list of drive references to be removed.","A return code that indicates the outcome of the operation. Valid values are:","FlashReadCache","","",
			EnumSet.of(ReturnCode.duplicateDrives,ReturnCode.error,ReturnCode.flashcacheDeleted,ReturnCode.flashcacheFailed,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidDriveref,ReturnCode.invalidDriveState,ReturnCode.notFlashcacheVol,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[317] = new ProcTableEntry("setFlashCacheParams", 592, 40, true, m_TypeTable[1059], m_TypeTable[152],"This procedure sets the parameters on a given flash cache.","A flash cache reference, configuration type, and whether or not flash cache should be enabled on new volumes.","A return code that indicates the outcome of the operation. Valid values are:","FlashReadCache","","",
			EnumSet.of(ReturnCode.flashcacheDegradedState,ReturnCode.flashcacheDeleted,ReturnCode.flashcacheFailed,ReturnCode.flashcacheInvalidConfigType,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.notFlashcacheVol,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[318] = new ProcTableEntry("resumeFlashCache", 593, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure resumes a previously suspended flash cache.","A reference to the flash cache object.","A return code that indicates the outcome of the operation. Valid values are:","FlashReadCache","","",
			EnumSet.of(ReturnCode.error,ReturnCode.flashcacheDegradedState,ReturnCode.flashcacheDeleted,ReturnCode.flashcacheFailed,ReturnCode.flashcacheNotSuspended,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.notFlashcacheVol,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.volumeNotExist));
		m_ProcTable[319] = new ProcTableEntry("createPITGroup", 594, 40, true, m_TypeTable[1195], m_TypeTable[360],"This procedure will create a new PiT Group.","Structure containing Pit group creation data.","A ReturnCodeWithRef object that indicates the outcome of the operation, and also returns the PiT ref of the newly-created object. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.baseVolumeFailed,ReturnCode.concatVolMemberTooSmall,ReturnCode.incompatibleMemberVol,ReturnCode.incompatibleRepositorySecurity,ReturnCode.invalidBasevol,ReturnCode.invalidConcatVolMemberLabel,ReturnCode.invalidPitAutoDeleteLimit,ReturnCode.invalidPitGroupLabel,ReturnCode.invalidPitRepositoryFullPolicy,ReturnCode.invalidProtection,ReturnCode.invalidRollbackPriority,ReturnCode.invalidWarnThreshold,ReturnCode.maxPitGroupsExceeded,ReturnCode.maxPitGroupsPerBaseExceeded,ReturnCode.ok,ReturnCode.pitGroupsFeatureDisabled));
		m_ProcTable[320] = new ProcTableEntry("deletePITGroup", 595, 40, true, m_TypeTable[860], m_TypeTable[152],"This procedure will delete a PiT Group.","Structure containing PiT group reference data.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.invalidPitGroupRef,ReturnCode.ok,ReturnCode.operationFailedVolumeCopyClone,ReturnCode.pitGroupInConsistencyGroup,ReturnCode.rollbackInProgress));
		m_ProcTable[321] = new ProcTableEntry("setPITGroupParams", 596, 40, true, m_TypeTable[839], m_TypeTable[152],"This procedure will update the changeable parameters of a PiT Group.","Structure containing PiT parameter data.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.attributeFixedByArvm,ReturnCode.baseVolumeFailed,ReturnCode.invalidBasevol,ReturnCode.invalidPitAutoDeleteLimit,ReturnCode.invalidPitGroupLabel,ReturnCode.invalidPitGroupRef,ReturnCode.invalidPitRepositoryFullPolicy,ReturnCode.invalidRollbackPriority,ReturnCode.invalidWarnThreshold,ReturnCode.ok,ReturnCode.pitGroupsFeatureDisabled,ReturnCode.pitGroupInConsistencyGroup));
		m_ProcTable[322] = new ProcTableEntry("createPIT", 597, 40, true, m_TypeTable[1023], m_TypeTable[535],"This procedure will create a new PiT in one or more existing PiT Group(s). Max list size is 64 PiT Groups.","Structure containing a list of PiT groups.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.alternateRequiredForOperation,ReturnCode.invalidPitGroupRef,ReturnCode.maxPitsExceeded,ReturnCode.maxPitsPerGroupExceeded,ReturnCode.ok,ReturnCode.pitCreatePending,ReturnCode.pitGroupsFeatureDisabled,ReturnCode.pitGroupInConsistencyGroup));
		m_ProcTable[323] = new ProcTableEntry("deletePIT", 598, 40, true, m_TypeTable[846], m_TypeTable[152],"This procedure will delete one or more PiTs.","Structure containing a list of PiTs.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.invalidPitRef,ReturnCode.notOldestPit,ReturnCode.ok,ReturnCode.pitInConsistencyGroup,ReturnCode.rollbackInProgress));
		m_ProcTable[324] = new ProcTableEntry("createCGPIT", 599, 40, true, m_TypeTable[343], m_TypeTable[535],"This procedure will create a new PiT in a consistency group (a PiT of all members in the group).","Reference to consistency group.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.pitCreatePending,ReturnCode.pitGroupsFeatureDisabled));
		m_ProcTable[325] = new ProcTableEntry("deleteCGPIT", 600, 40, true, m_TypeTable[488], m_TypeTable[152],"This procedure will delete a PiT in one or more members of a consistency group.","Structure containing information about the consistency group PiT to delete.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[326] = new ProcTableEntry("createPITView", 601, 40, true, m_TypeTable[1203], m_TypeTable[360],"This procedure will create a new PiT View.","Structure containing information about the PiT View to create.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.concatVolMemberTooSmall,ReturnCode.incompatibleMemberVol,ReturnCode.incompatibleRepositorySecurity,ReturnCode.invalidConcatVolMemberLabel,ReturnCode.invalidPitRef,ReturnCode.invalidProtection,ReturnCode.invalidWarnThreshold,ReturnCode.maxMappableVolumesExceeded,ReturnCode.maxViewsExceeded,ReturnCode.maxViewsPerPitExceeded,ReturnCode.ok,ReturnCode.pitGroupsFeatureDisabled,ReturnCode.pitInConsistencyGroup));
		m_ProcTable[327] = new ProcTableEntry("deletePITView", 602, 40, true, m_TypeTable[1084], m_TypeTable[152],"This procedure will delete an existing PiT View.","Structure containing information about the PiT View to delete.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.operationFailedVolumeCopyClone));
		m_ProcTable[328] = new ProcTableEntry("stopPITView", 603, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure will stop an existing PiT View.","Reference to PiT View to be stopped.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.operationFailedVolumeCopyClone));
		m_ProcTable[329] = new ProcTableEntry("setPITViewParams", 604, 40, true, m_TypeTable[1099], m_TypeTable[152],"This procedure will change the attributes of an existing PiT View.","Descriptor for the PiT View parameters to be updated.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.invalidWarnThreshold,ReturnCode.ok,ReturnCode.pitGroupsFeatureDisabled,ReturnCode.pitViewInConsistencyGroup));
		m_ProcTable[330] = new ProcTableEntry("createPITConsistencyGroup", 605, 40, true, m_TypeTable[1167], m_TypeTable[360],"This procedure will create a new PiT consistency group.","Descriptor for the consistency group to be created.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.invalidPitAutoDeleteLimit,ReturnCode.invalidPitConsistencyGroupLabel,ReturnCode.invalidPitRepositoryFullPolicy,ReturnCode.invalidRollbackPriority,ReturnCode.invalidWarnThreshold,ReturnCode.maxConsistencyGroupsExceeded,ReturnCode.ok,ReturnCode.pitGroupsFeatureDisabled));
		m_ProcTable[331] = new ProcTableEntry("deletePITConsistencyGroup", 606, 40, true, m_TypeTable[493], m_TypeTable[152],"This procedure will delete an existing PiT consistency group, all of the child PiT groups and their PiTs and associated ERVs. All associated views are stopped.","Descriptor for the consistency group to be deleted.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok));
	}

	private static void __init20() {
		m_ProcTable[332] = new ProcTableEntry("addPITConsistencyGroupMember", 607, 40, true, m_TypeTable[1170], m_TypeTable[535],"This procedure will add a new member to a PiT consistency group (create a new PiT group for the member volume to add and add that PiT group to the consistency group). Returns the ref of the new PiT group created and added to the PCG.","Descriptor for the consistency group member to be added.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.concatVolMemberTooSmall,ReturnCode.consistencyGroupArvmBindingConflict,ReturnCode.incompatibleRepositorySecurity,ReturnCode.invalidConcatVolMemberLabel,ReturnCode.invalidProtection,ReturnCode.maxConsistencyGroupMembersExceeded,ReturnCode.ok,ReturnCode.pitGroupsFeatureDisabled));
		m_ProcTable[333] = new ProcTableEntry("removePITConsistencyGroupMember", 608, 40, true, m_TypeTable[979], m_TypeTable[152],"This procedure will remove a member from a PiT consistency group.","Descriptor for the consistency group member to be removed.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.invalidPitGroupRef,ReturnCode.ok));
		m_ProcTable[334] = new ProcTableEntry("setPITConsistencyGroupParams", 609, 40, true, m_TypeTable[577], m_TypeTable[152],"This procedure will modify the attributes of a PiT consistency group.","Descriptor for the consistency group parameters to be updated.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.attributeFixedByArvm,ReturnCode.invalidPitAutoDeleteLimit,ReturnCode.invalidPitConsistencyGroupLabel,ReturnCode.invalidPitRepositoryFullPolicy,ReturnCode.invalidRollbackPriority,ReturnCode.invalidWarnThreshold,ReturnCode.ok,ReturnCode.pitGroupsFeatureDisabled));
		m_ProcTable[335] = new ProcTableEntry("startPITRollback", 610, 40, true, m_TypeTable[846], m_TypeTable[152],"This procedure will initiate a rollback on a specified list of PiTs. Note that this list could be a subset of a set of consistency group PiTs.","A list of references to PiTs for which to start the rollback.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.invalidPitRef,ReturnCode.ok,ReturnCode.pitGroupsFeatureDisabled,ReturnCode.repositoryOffline));
		m_ProcTable[336] = new ProcTableEntry("startCGRollback", 611, 40, true, m_TypeTable[660], m_TypeTable[152],"This procedure will initiate a rollback on a specified PiT on all members of a consistency group (all members that have the specified PiT may not necessarily be all of them).","Descriptor for the consistency group rollback to be started.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.pitGroupsFeatureDisabled,ReturnCode.repositoryOffline));
		m_ProcTable[337] = new ProcTableEntry("resumePITRollback", 612, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure will resume a paused rollback on the specified PiT.","A reference to the PiT rollback to be resumed.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.invalidPitRef,ReturnCode.ok,ReturnCode.pitGroupsFeatureDisabled,ReturnCode.repositoryOffline));
		m_ProcTable[338] = new ProcTableEntry("cancelPITRollback", 613, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure will cancel a rollback on the specified PiT.","A reference to the PiT rollback to be canceled.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.invalidPitRef,ReturnCode.ok,ReturnCode.repositoryOffline));
		m_ProcTable[339] = new ProcTableEntry("expandConcatVolume", 614, 40, true, m_TypeTable[1186], m_TypeTable[360],"This procedure will expand a concatenated volume by adding another member RAID volume. Returns the ref for the new ConcatVolMember added.","A descriptor of the concat volume to be expanded.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.cannotExpandConcatMember,ReturnCode.concatMemberLimitExceeded,ReturnCode.concatVolumeFailed,ReturnCode.concatVolMemberTooSmall,ReturnCode.incompatibleMemberVol,ReturnCode.incompatibleRepositorySecurity,ReturnCode.insufficientExpansionSpace,ReturnCode.invalidConcatVolMemberLabel,ReturnCode.invalidExpansionSize,ReturnCode.invalidMemberVol,ReturnCode.invalidMemberVolState,ReturnCode.invalidProtection,ReturnCode.memberVolMapped,ReturnCode.ok,ReturnCode.repositoryFull));
		m_ProcTable[340] = new ProcTableEntry("trimConcatVolume", 615, 40, true, m_TypeTable[987], m_TypeTable[152],"This procedure will trim a concatenated volume by removing one or more member RAID volumes. Note this can only be done in cases where the ConcatVolume is not being used (definition of \"used\" depends on parent object usage).","A descriptor of the concat volume to be trimmed.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.invalidTrimCount,ReturnCode.ok,ReturnCode.volumeInUse));
		m_ProcTable[341] = new ProcTableEntry("getPITGroupRepositoryUtilization", 617, 40, false, m_TypeTable[1023], m_TypeTable[1174],"This procedure will return repository utilization information for PiT groups.","A list of PiT groups for which to return repository utilization.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.invalidPitGroupRef,ReturnCode.ok));
		m_ProcTable[342] = new ProcTableEntry("getPITViewRepositoryUtilization", 618, 40, false, m_TypeTable[1085], m_TypeTable[1189],"This procedure will return repository utilization information for PiT Views.","A list of PiT Views for which to return repository utilization.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[343] = new ProcTableEntry("estimatePITRollbackRepositoryUtilization", 619, 40, false, m_TypeTable[343], m_TypeTable[770],"This procedure will return the amount of repository capacity necessary to perform a rollback operation.","A reference to a PiT","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.invalidPitRef,ReturnCode.ok));
		m_ProcTable[344] = new ProcTableEntry("convertReadOnlyPITViewToReadWrite", 620, 40, true, m_TypeTable[1142], m_TypeTable[152],"This procedure will convert a read-only view to a read-write view.","Descriptor to PiT View to be converted.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.viewStopped));
		m_ProcTable[345] = new ProcTableEntry("createPITConsistencyGroupView", 621, 40, true, m_TypeTable[1212], m_TypeTable[360],"This procedure will create a View on the specified PiTs in a Consistency Group.","An object containing all of the attributes required to create a PiT Consistency Group View.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.alternateRequiredForOperation,ReturnCode.incompatibleMemberVol,ReturnCode.mustSpecifyExistingVolumes,ReturnCode.ok,ReturnCode.pitGroupsFeatureDisabled));
		m_ProcTable[346] = new ProcTableEntry("deletePITConsistencyGroupView", 622, 40, true, m_TypeTable[685], m_TypeTable[152],"This procedure will delete the specified PITConsistencyGroupView.","An object containing all of the attributes required to delete a PiT Consistency Group View.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.operationFailedVolumeCopyClone));
		m_ProcTable[347] = new ProcTableEntry("stopPITConsistencyGroupView", 623, 40, true, m_TypeTable[678], m_TypeTable[152],"This procedure will stop the specified PITConsistencyGroupView (and thus all of its associated member views).","An object containing all of the attributes required to stop a PiT Consistency Group View.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.operationFailedVolumeCopyClone));
		m_ProcTable[348] = new ProcTableEntry("setDiskPoolReservedDriveCount", 624, 40, true, m_TypeTable[962], m_TypeTable[152],"This procedure will set the Disk Pool Reserved Drive Count value.","An object containing all of the attributes required to set a reserved drive count value on a disk pool.","A return code that indicates the outcome of the operation. Valid values are:","DiskPools","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[349] = new ProcTableEntry("setDiskPoolThreshold", 625, 40, true, m_TypeTable[716], m_TypeTable[152],"This procedure will set the Disk Pool Utilization Threshold values.","An object containing all of the attributes required to set utilization threshold values for a Disk Pool.","A return code that indicates the outcome of the operation. Valid values are:","DiskPools","","",
			EnumSet.of(ReturnCode.invalidCriticalThreshold,ReturnCode.ok));
		m_ProcTable[350] = new ProcTableEntry("setDiskPoolPriority", 626, 40, true, m_TypeTable[722], m_TypeTable[152],"This procedure will set the Disk Pool Reconstruction and Background Operation priorities.","An object containing all of the attributes required to set priorities for a Disk Pool.","A return code that indicates the outcome of the operation. Valid values are:","DiskPools","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[351] = new ProcTableEntry("setDiskPoolToComplete", 627, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure forces the Disk Pool to a complete (optimal) state. This may be necessary if a drive is missing and the drive is not going to be replaced.","A reference to the Disk Pool to complete.","A return code that indicates the outcome of the operation. Valid values are:","DiskPools","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[352] = new ProcTableEntry("getDiskPoolExpansionCandidates", 628, 40, true, m_TypeTable[343], m_TypeTable[1068],"This procedure returns a list of drive sets that are candidates for use in expanding the given Disk Pool.","A reference to the Disk Pool to be expanded.","","DiskPools","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[353] = new ProcTableEntry("startDiskPoolExpansion", 629, 540, true, m_TypeTable[867], m_TypeTable[152],"This procedure initiates a long-running operation to expand the capacity of a Disk Pool by adding one or more drives to it.","A reference to the Disk Pool to expand and the drives to use for the expansion.","A return code that indicates the outcome of the operation. Valid values are:","DiskPools","","",
			EnumSet.of(ReturnCode.exceedDiskPoolCapacity,ReturnCode.exceedMaxVolumeCapacity,ReturnCode.ok));
		m_ProcTable[354] = new ProcTableEntry("triggerDPLCoreDumpOnDemand", 633, 40, true, null, m_TypeTable[443],"This procedure is used to manually trigger a DPL Core Dump.","","","DPLCoreDump","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[355] = new ProcTableEntry("getDPLCoreDumpInformation", 634, 40, false, m_TypeTable[7], m_TypeTable[1033],"This procedure is used to request the information about a DPL core dump. The parameter is a DPL Core Dump Tag. The value of the tag is unique for each core dump and may be obtained from the DPLCoreDumpData structure in StorageArray.","The integer value of the dplCoreDumpTag for which you are requesting information.","","DPLCoreDump","","",
			EnumSet.of(ReturnCode.dplCoreDumpInvalidTag,ReturnCode.ok));
		m_ProcTable[356] = new ProcTableEntry("clearDPLCoreDumpNeedsRetrieved", 635, 40, true, null, m_TypeTable[152],"This procedure is used to clear the flag indicating that a DPL core dump needs to be retrieved without offloading it. Otherwise, the available DPL core dump will remain in controller memory until overwritten by a new DPL core dump.","","A return code that indicates the outcome of the operation. Valid values are:","DPLCoreDump","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[357] = new ProcTableEntry("restartPITView", 636, 40, true, m_TypeTable[1119], m_TypeTable[152],"This procedure will restart a PiT View.","An object containing all of the attributes required to restart a PiT View.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.invalidPitForView,ReturnCode.ok));
		m_ProcTable[358] = new ProcTableEntry("restartPITConsistencyGroupView", 637, 40, true, m_TypeTable[637], m_TypeTable[152],"This procedure will restart a Consistency Group View (restart all of its associated member Views).","An object containing all of the attributes required to restart a Consistency Group View.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.invalidPitForView,ReturnCode.ok));
		m_ProcTable[359] = new ProcTableEntry("disableFeatureByRef", 638, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure disables a feature.","A reference to the feature to disable.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Type2LicenseKeys","","",
			EnumSet.of(ReturnCode.disableEvaluationFeatureNotPermitted,ReturnCode.disableNotPermitted,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidFeatureref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.uninitialized));
		m_ProcTable[360] = new ProcTableEntry("addAsyncMirrorGroupPrimaryMember", 639, 150, true, m_TypeTable[1194], m_TypeTable[152],"This procedure will add a member to an Async Mirror Group on the primary array. This is step 1 of the add member process.","An object containing all of the attributes required to add a member to an Asynchronous Mirror Group on the primary array.","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmGroupDoesNotExist,ReturnCode.arvmGroupNotPrimary,ReturnCode.arvmMemberLimitExceeded,ReturnCode.arvmOrphanGroup,ReturnCode.arvmRemoteGroupDoesNotExist,ReturnCode.arvmRemoteGroupNotSecondary,ReturnCode.arvmRemoteMaxMirrorsPerArrayExceeded,ReturnCode.arvmRemoteThinNotSupported,ReturnCode.arvmVolumeAlreadyInMirrorRelationship,ReturnCode.incompatibleRepositorySecurity,ReturnCode.invalidProtection,ReturnCode.ok,ReturnCode.remoteDatabaseError,ReturnCode.remoteInternalError,ReturnCode.remoteInvalidProtection,ReturnCode.remoteMaxTotalMirrorsPerArrayExceeded,ReturnCode.remoteNoHeap));
		m_ProcTable[361] = new ProcTableEntry("addAsyncMirrorGroupSecondaryMember", 640, 120, true, m_TypeTable[1164], m_TypeTable[152],"This procedure will add a member to an Async Mirror Group on the secondary array. This is step 2 of the add member process.","An object containing all of the attributes required to add a member to an Asynchronous Mirror Group on the secondary array.","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmGroupNotSecondary,ReturnCode.arvmIncorrectVolumeType,ReturnCode.arvmInvalidMirrorState,ReturnCode.arvmInvalidSecondaryCapacity,ReturnCode.arvmOrphanGroup,ReturnCode.arvmRemoteGroupDoesNotExist,ReturnCode.arvmRemoteMirrorMemberDoesNotExist,ReturnCode.arvmThinVolInitError,ReturnCode.arvmVolumeAlreadyInMirrorRelationship,ReturnCode.incompatibleRepositorySecurity,ReturnCode.incompatibleSecondarySecurity,ReturnCode.invalidIncompleteMemberRef,ReturnCode.invalidProtection,ReturnCode.ok,ReturnCode.remoteDatabaseError,ReturnCode.remoteInternalError,ReturnCode.remoteRvmSpmError));
		m_ProcTable[362] = new ProcTableEntry("changeAsyncMirrorGroupRole", 642, 150, true, m_TypeTable[581], m_TypeTable[152],"This procedure will change roles on an Async Mirror Group.","A reference to the Asynchronous Mirror Group on which to change roles and some change attributes.","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmExpansionSynchronizationInProgress,ReturnCode.arvmGroupHasIncompleteMember,ReturnCode.arvmMemberStopped,ReturnCode.arvmOrphanGroup,ReturnCode.arvmRemoteGroupDoesNotExist,ReturnCode.arvmRemoteGroupNotSecondary,ReturnCode.arvmRoleChangeInProgress,ReturnCode.arvmRoleChangePending,ReturnCode.ok,ReturnCode.remoteDatabaseError,ReturnCode.remoteInternalError,ReturnCode.rollbackInProgress));
		m_ProcTable[363] = new ProcTableEntry("clearAsyncMirrorGroupFaultIndication", 643, 40, true, m_TypeTable[554], m_TypeTable[152],"This procedure will clear a recovery failure posted for a given Async Mirror Group (AMG). Since some AMG needs attention / recovery failure conditions are \"sticky\" the user has to acknowledge the condition before it is cleared.","A reference to the Asynchronous Mirror Group with the condition to acknowledge/clear and the type of indication to clear.","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmOrphanGroup,ReturnCode.arvmOrphanMember,ReturnCode.faultConditionStillExists,ReturnCode.ok));
		m_ProcTable[364] = new ProcTableEntry("clearAsyncMirrorGroupMemberFaultIndication", 644, 40, true, m_TypeTable[1062], m_TypeTable[152],"This procedure will clear a recovery failure posted for a given Async Mirror Group member. Since some mirror member needs attention / recovery failure conditions are \"sticky\" the user has to acknowledge the condition before it is cleared.","A reference to the Asynchronous Mirror Group member with the condition to acknowledge/clear and the type of indication to clear.","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM","","",
			EnumSet.of(ReturnCode.faultConditionStillExists,ReturnCode.ok));
		m_ProcTable[365] = new ProcTableEntry("createAsyncMirrorGroup", 645, 180, true, m_TypeTable[1200], m_TypeTable[152],"This procedure will create an Async Mirror Group (AMG).","An object that contains all of the required attributes for the new mirror group.","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmFeatureDeactivated,ReturnCode.arvmGroupUserLabelExists,ReturnCode.arvmInvalidSyncInterval,ReturnCode.arvmRemoteGroupUserLabelExists,ReturnCode.arvmRemoteMaxAsyncMirrorGroupsExceeded,ReturnCode.invalidRecoveryPointAlertThreshold,ReturnCode.invalidSyncAlertThreshold,ReturnCode.invalidSyncPriority,ReturnCode.invalidWarnThreshold,ReturnCode.mirrorProtocolMismatch,ReturnCode.ok,ReturnCode.remoteArvmFeatureDeactivated,ReturnCode.remoteArvmFeatureDisabled,ReturnCode.remoteDatabaseError,ReturnCode.remoteInternalError,ReturnCode.remoteNoHeap,ReturnCode.remoteTargetNotFound));
		m_ProcTable[366] = new ProcTableEntry("deleteAsyncMirrorGroup", 646, 150, true, m_TypeTable[828], m_TypeTable[152],"This procedure will delete an Async Mirror Group (AMG).","An object containing all of the required attributes to delete an Asynchronous Mirror Group.","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmGroupDoesNotExist,ReturnCode.arvmGroupNotEmpty,ReturnCode.arvmOnlyLocalAmgDeleted,ReturnCode.arvmRemoteGroupNotEmpty,ReturnCode.ok,ReturnCode.remoteDatabaseError,ReturnCode.remoteInternalError,ReturnCode.remoteTryAlternate));
		m_ProcTable[367] = new ProcTableEntry("deleteAsyncMirrorGroupIncompleteMember", 647, 120, true, m_TypeTable[343], m_TypeTable[152],"This procedure is used to clean up a mirror \"place holder.\"","An object with all of the required attributes to delete an incomplete member of an Asynchronous Mirror Group.","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmGroupNotSecondary,ReturnCode.arvmRemoteGroupDoesNotExist,ReturnCode.arvmRemoteMirrorMemberDoesNotExist,ReturnCode.invalidIncompleteMemberRef,ReturnCode.ok,ReturnCode.remoteDatabaseError,ReturnCode.remoteInternalError));
		m_ProcTable[368] = new ProcTableEntry("deactivateFibreChannelCheckPointBasedAsyncMirroring", 648, 40, true, null, m_TypeTable[152],"This procedure will disable mirroring over Fibre Channel (freeing up dedicated channel).","","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmAsyncMirrorGroupPresent,ReturnCode.ok));
		m_ProcTable[369] = new ProcTableEntry("activateFibreChannelCheckPointBasedAsyncMirroring", 649, 40, true, null, m_TypeTable[152],"This procedure will enable mirroring over Fibre Channel (setup dedicated channel).","","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[370] = new ProcTableEntry("getAsyncMirrorGroupSyncProgress", 650, 40, true, m_TypeTable[683], m_TypeTable[1168],"This procedure will return sync progress information for Async Mirror Groups and their associated members. Calls to this procedure are valid even when a sync is not running.","A list of Asynchronous Mirror Group references.","Information about progress of a sync operation on an Asynchronous Mirror Group.","AsyncRVM","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[371] = new ProcTableEntry("getAsyncMirrorRepositoryUtilization", 651, 40, false, m_TypeTable[1064], m_TypeTable[1108],"This procedure will return repository utilization information for async mirror members.","A list of Asynchronous Mirror Group member references.","Information about an async mirror repository utilization","AsyncRVM","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[372] = new ProcTableEntry("removeAsyncMirrorGroupMember", 654, 180, true, m_TypeTable[1016], m_TypeTable[152],"This procedure will remove a member from an Async Mirror Group.","An object containing all of the required attributes to remove an Asynchronous Mirror Group member.","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmGroupDoesNotExist,ReturnCode.arvmMirrorMemberDoesNotExist,ReturnCode.arvmRemoteMirrorMemberDoesNotExist,ReturnCode.ok,ReturnCode.remoteDatabaseError,ReturnCode.remoteInternalError));
		m_ProcTable[373] = new ProcTableEntry("resumeAsyncMirrorGroup", 655, 90, true, m_TypeTable[579], m_TypeTable[1078],"Resume an Async Mirror Group.","A descriptor containing a reference to the Asynchronous Mirror Group to resume.","The result of the procedure action.","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmGroupDoesNotExist,ReturnCode.arvmGroupHasIncompleteMember,ReturnCode.arvmGroupNotPrimary,ReturnCode.arvmGroupNotSuspended,ReturnCode.arvmRecoveryPointDeletionRequired,ReturnCode.arvmRemoteGroupDoesNotExist,ReturnCode.arvmRemoteResumeFailure,ReturnCode.arvmResumeFailure,ReturnCode.ok,ReturnCode.remoteDatabaseError,ReturnCode.remoteInternalError));
		m_ProcTable[374] = new ProcTableEntry("setAsyncMirrorGroupParams", 656, 90, true, m_TypeTable[713], m_TypeTable[152],"This procedure will change the parameters of an Async Mirror Group.","An object containing the Asynchronous Mirror Group parameters.","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmGroupHasIncompleteMember,ReturnCode.arvmGroupUserLabelExists,ReturnCode.arvmInvalidSyncInterval,ReturnCode.arvmOrphanGroup,ReturnCode.arvmOrphanMember,ReturnCode.arvmRemoteGroupDoesNotExist,ReturnCode.arvmRemoteGroupUserLabelExists,ReturnCode.invalidRecoveryPointAlertThreshold,ReturnCode.invalidSyncAlertThreshold,ReturnCode.invalidSyncPriority,ReturnCode.invalidWarnThreshold,ReturnCode.ok,ReturnCode.remoteDatabaseError,ReturnCode.remoteInternalError));
		m_ProcTable[375] = new ProcTableEntry("suspendAsyncMirrorGroup", 657, 90, true, m_TypeTable[871], m_TypeTable[1078],"This procedure will suspend an Async Mirror Group.","A descriptor that lists the AMG on which the synchronization is to be suspended.","A return code is returned, and if it is RETCODE_ARVM_RECOVERY_POINT_DELETION_REQUIRED, a list of members that triggered a fault and require deletion is also returned.","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmGroupDoesNotExist,ReturnCode.arvmGroupNotPrimary,ReturnCode.arvmMemberFailed,ReturnCode.arvmOrphanGroup,ReturnCode.arvmRecoveryPointDeletionRequired,ReturnCode.arvmRemoteGroupDoesNotExist,ReturnCode.arvmRemoteSuspendFailure,ReturnCode.arvmSuspendFailure,ReturnCode.ok,ReturnCode.remoteDatabaseError,ReturnCode.remoteInternalError));
		m_ProcTable[376] = new ProcTableEntry("synchronizeAsyncMirrorGroup", 658, 180, true, m_TypeTable[646], m_TypeTable[1078],"This procedure will start a manual resynchronization on an Async Mirror Group.","A reference to the Asynchronous Mirror Group to synchronize.","A list of async mirror group members that triggered a fault and require deletion.","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmExpansionSynchronizationInProgress,ReturnCode.arvmGroupDoesNotExist,ReturnCode.arvmGroupNotPrimary,ReturnCode.arvmInvalidAmgRequestWhileSuspended,ReturnCode.arvmManualSyncAlreadyInProgress,ReturnCode.arvmManualSyncRetryTooSoon,ReturnCode.arvmOrphanGroup,ReturnCode.arvmRecoveryPointDeletionRequired,ReturnCode.arvmRemoteGroupDoesNotExist,ReturnCode.arvmRemoteSynchronizeFailure,ReturnCode.arvmSynchronizeFailure,ReturnCode.ok,ReturnCode.remoteDatabaseError,ReturnCode.remoteInternalError));
		m_ProcTable[377] = new ProcTableEntry("getDiskPoolMaxReservedDriveCount", 659, 40, true, m_TypeTable[343], m_TypeTable[417],"This procedure will return the maximum Reserved Drive Count possible on a disk pool.","A reference to the Disk Pool for which you want the maximum reserved drive count.","The maximum Reserved Drive Count possible on a disk pool.","DiskPools","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[378] = new ProcTableEntry("cancelPendingCGPITCreation", 660, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure cancels a Pending PiT Creation for a PiT Consistency Group.","A reference to the PiT Consistency Group for which you want to cancel a pending creation.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[379] = new ProcTableEntry("cancelPendingPITCreation", 661, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure cancels a Pending PiT Creation for a PiT Group. This returns the pending PiT creation state back to \"none\" from either \"waiting\" or \"failed\".","A reference to the PiT Group for which you want to cancel a pending creation.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[380] = new ProcTableEntry("revivePITGroup", 662, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure revives a failed PiT Group.","A reference to the PiT Group you want to revive.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.repositoryOffline,ReturnCode.rollbackInProgress));
		m_ProcTable[381] = new ProcTableEntry("revivePITView", 663, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure revives a failed PiT View.","A reference to the PiT View you want to revive.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.repositoryOffline));
		m_ProcTable[382] = new ProcTableEntry("setPITConsistencyGroupViewParams", 664, 40, true, m_TypeTable[496], m_TypeTable[152],"This procedure changes the user-settable parameters on a PITConsistencyGroupView.","An object containing the required user-settable attributes to set on a PiT Consistency Group View.","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[383] = new ProcTableEntry("createThinVolume", 665, 40, true, m_TypeTable[1176], m_TypeTable[152],"This procedure creates a new Thin Provisioned Volume.","An object containing all of the required attributes for a Thin Provisioned Volume.","A return code that indicates the outcome of the operation. Valid values are:","ThinProvisioningSupport","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.illegalVolume,ReturnCode.internalError,ReturnCode.invalidConcatVolMemberLabel,ReturnCode.invalidExpansionPolicy,ReturnCode.invalidLabel,ReturnCode.invalidProvisionedCapacityQuota,ReturnCode.invalidRepositoryCapacity,ReturnCode.invalidVirtualCapacity,ReturnCode.invalidVolumeref,ReturnCode.invalidWarnThreshold,ReturnCode.maxThinVolumesExceeded,ReturnCode.maxVolumesExceeded,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.repositoryTooSmall,ReturnCode.volumeNotExist));
		m_ProcTable[384] = new ProcTableEntry("expandThinVolumeVirtualCapacity", 666, 40, true, m_TypeTable[1017], m_TypeTable[152],"This procedure will expand a thin volume's virtual capacity. It does not affect the repository volume's capacity.","An object containing all of the attributes necessary to expand a thin volume's virtual capacity.","A return code that indicates the outcome of the operation. Valid values are:","ThinProvisioningSupport","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.illegalVolume,ReturnCode.internalError,ReturnCode.invalidVirtualCapacity,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[385] = new ProcTableEntry("getThinVolumeConsumedCapacity", 667, 40, false, m_TypeTable[1058], m_TypeTable[1081],"This procedure will retrieve a thin volume's Expandable Repository Volume consumed capacity.","A reference to the thin volume for which you want the consumed capacity.","","ThinProvisioningSupport","","",
			EnumSet.of(ReturnCode.alternateRequiredForOperation,ReturnCode.illegalVolume,ReturnCode.invalidVolumeref,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[386] = new ProcTableEntry("getThinVolumeExpansionHistory", 668, 40, false, m_TypeTable[343], m_TypeTable[1098],"This procedure will retrieve a thin volume's repository expansion history.","A reference to the thin volume for which you want the repository expansion history.","","ThinProvisioningSupport","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.invalidVolumeref,ReturnCode.ok));
		m_ProcTable[387] = new ProcTableEntry("reinitializeThinVolume", 669, 40, true, m_TypeTable[1209], m_TypeTable[152],"This procedure causes the referenced thin volume to be reinitialized to have no content.","An object containing all of the required attributes for reinitializing a thin volume.","A return code that indicates the outcome of the operation. Valid values are:","ThinProvisioningSupport","","",
			EnumSet.of(ReturnCode.illegalParam,ReturnCode.illegalVolume,ReturnCode.internalError,ReturnCode.invalidConcatVolMemberLabel,ReturnCode.invalidProvisionedCapacityQuota,ReturnCode.invalidReinitAction,ReturnCode.invalidReinitCapacity,ReturnCode.invalidRepositoryCapacity,ReturnCode.invalidVolumeref,ReturnCode.notImplemented,ReturnCode.ok,ReturnCode.repositoryTooSmall,ReturnCode.tryAlternate));
		m_ProcTable[388] = new ProcTableEntry("setThinVolumeCapacityThreshold", 670, 40, true, m_TypeTable[1011], m_TypeTable[152],"This procedure will set a thin volume's capacity threshold warning level.","An object containing all of the required attributes for setting the capacity threshold warning level on a thin volume.","A return code that indicates the outcome of the operation. Valid values are:","ThinProvisioningSupport","","",
			EnumSet.of(ReturnCode.illegalVolume,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.invalidWarnThreshold,ReturnCode.ok,ReturnCode.thinVolumeParametersCannotBeModified,ReturnCode.thresholdBelowUsedCapacity));
		m_ProcTable[389] = new ProcTableEntry("setThinVolumeExpansionPolicy", 671, 40, true, m_TypeTable[833], m_TypeTable[152],"This procedure will set a thin volume's repository volume expansion policy.","An object containing all of the required attributes needed to set the repository volume expansion policy for a thin volume.","A return code that indicates the outcome of the operation. Valid values are:","ThinProvisioningSupport","","",
			EnumSet.of(ReturnCode.illegalVolume,ReturnCode.internalError,ReturnCode.invalidExpansionPolicy,ReturnCode.invalidVolumeref,ReturnCode.ok,ReturnCode.thinVolumeParametersCannotBeModified));
		m_ProcTable[390] = new ProcTableEntry("setThinVolumeProvisionedCapacityQuota", 672, 40, true, m_TypeTable[977], m_TypeTable[152],"This procedure will set a thin volume's provisioned capacity quota. This is the maximum value to which a thin volume's repository can grow.","An object containing all of the required attributes needed to set a thin volume's provisioned capacity quota.","A return code that indicates the outcome of the operation. Valid values are:","ThinProvisioningSupport","","",
			EnumSet.of(ReturnCode.illegalVolume,ReturnCode.internalError,ReturnCode.invalidExpansionOperation,ReturnCode.invalidExpansionPolicy,ReturnCode.invalidProvisionedCapacityQuota,ReturnCode.invalidVolumeref,ReturnCode.ok,ReturnCode.thinVolumeParametersCannotBeModified,ReturnCode.tryAlternate));
		m_ProcTable[391] = new ProcTableEntry("getSystemAttributeDefaults", 673, 40, false, null, m_TypeTable[779],"This procedure returns the default values for system attributes.","","The system default attributes are returned.","DiskPools","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[392] = new ProcTableEntry("getCumulativeStatisticsBundles", 674, 40, false, m_TypeTable[697], m_TypeTable[1155],"This procedure is used to request a list of bundles of statistical data. The argument describes the statistics being requested.","An object containing all of the required elements for the procedure.","The list of bundles of statistical data are returned (when the procedure return code is RETCODE_OK).","ArrayStatisticsGiants","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.invalidRequest,ReturnCode.ok));
		m_ProcTable[393] = new ProcTableEntry("createFlashCacheAnalytics", 675, 40, true, m_TypeTable[490], m_TypeTable[152],"This procedure creates a zero size FlashCache for performing analytics. It creates a flashcache with no repository to allow collection of projected cache hits during I/O.","","A return code that indicates the outcome of the operation. Valid values are:","FlashReadCache","","",
			EnumSet.of(ReturnCode.error,ReturnCode.flashcacheAlreadyExists,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidLabel,ReturnCode.ok));
		m_ProcTable[394] = new ProcTableEntry("startFlashCacheAnalytics", 676, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure starts collecting analytics data for flash cache. It resets analytics counters and begins capturing cache data.","","A return code that indicates the outcome of the operation. Valid values are:","FlashReadCache","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.notFlashcacheVol,ReturnCode.ok));
		m_ProcTable[395] = new ProcTableEntry("stopFlashCacheAnalytics", 677, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure stops the collection of analytics data for flash cache. It disables the collection of cache hits.","","A return code that indicates the outcome of the operation. Valid values are:","FlashReadCache","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.notFlashcacheVol,ReturnCode.ok));
		m_ProcTable[396] = new ProcTableEntry("getFlashCacheAnalytics", 678, 40, false, m_TypeTable[343], m_TypeTable[797],"This procedure retrieves analytics data from the last capture period. It returns the cache hits for various sizes of flash cache.","","Data collected for flash cache analytics.","FlashReadCache","","",
			EnumSet.of(ReturnCode.error,ReturnCode.flashcacheInvalidAnalyticsState,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidVolumeref,ReturnCode.notFlashcacheVol,ReturnCode.ok));
		m_ProcTable[397] = new ProcTableEntry("convertSnapshotsToPITGroups", 679, 40, true, m_TypeTable[736], m_TypeTable[152],"This procedure will convert all snapshots of a given base volume to PiT groups.","","A return code that indicates the outcome of the operation. Valid values are:","PITGroupSupport","LancasterBase","",
			EnumSet.of(ReturnCode.notDisabled,ReturnCode.ok,ReturnCode.snapConversionMissingLabel,ReturnCode.snapConversionTooManySnaps,ReturnCode.volumeHasVolcopyRelationship));
		m_ProcTable[398] = new ProcTableEntry("analyzeCopyOnWriteRepository", 680, 1200, false, m_TypeTable[640], m_TypeTable[407],"This procedure will run an analysis on the metadata contained in a copy-on-write repository to identify possible causes for failure.","","The analysis results are returned.","PITGroupSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[399] = new ProcTableEntry("getDatabaseMetadata", 681, 40, false, null, m_TypeTable[741],"This procedure is used to retrieve stable store database metadata.","","The database metadata is returned.","BackupDatabaseSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[400] = new ProcTableEntry("cancelDatabaseRecoveryMode", 682, 40, false, null, m_TypeTable[152],"This procedure is used to cancel stable store database recovery.","","A return code that indicates the outcome of the operation. Valid values are:","BackupDatabaseSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[401] = new ProcTableEntry("cancelAsyncMirrorGroupRoleChange", 683, 90, true, m_TypeTable[566], m_TypeTable[152],"This procedure is used to cancel an Async Mirror Group role change operation.","","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmRemoteGroupDoesNotExist,ReturnCode.ok,ReturnCode.remoteDatabaseError,ReturnCode.remoteInternalError));
		m_ProcTable[402] = new ProcTableEntry("testAsyncMirrorGroupConnectivity", 684, 300, false, m_TypeTable[812], m_TypeTable[863],"This procedure is used to initiate an Async Mirror Group link connectivity test.","","The connectivity test results are returned.","AsyncRVM","","",
			EnumSet.of(ReturnCode.arvmConnectivityTestAmgMemberMismatch,ReturnCode.arvmConnectivityTestLoginFailure,ReturnCode.arvmConnectivityTestMissingRemoteAmg,ReturnCode.arvmConnectivityTestNameServiceError,ReturnCode.arvmConnectivityTestNetworkError,ReturnCode.arvmConnectivityTestRemoteTimeout,ReturnCode.arvmConnectivityTestTimeoutExceeded,ReturnCode.arvmConnectivityTestTurError,ReturnCode.arvmRemoteGroupDoesNotExist,ReturnCode.ok,ReturnCode.remoteNoHeap));
		m_ProcTable[403] = new ProcTableEntry("getFlashCacheStatistics", 685, 40, false, m_TypeTable[343], m_TypeTable[448],"This procedure is used to retrieve flash cache statistics.","","The flash cache statistics are returned.","FlashReadCache","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[404] = new ProcTableEntry("loadControllerNVSRAMNoPassword", 686, 1200, false, m_TypeTable[308], m_TypeTable[152],"This procedure is used to download a NVSRAM image file to a controller when the duplex setting gets erroneously inserted into a Native SATA array. In such a situation, none of the native SATA drives will be recognized by the firmware since the IOC will be set to enable the STP (SATA) layer only if the setting is Simplex. The Recovery Action in such a scenario is to download new NVSRAM using this command and boot with it.","","","NativeSATA","","",
			EnumSet.of(ReturnCode.controllerInServiceMode,ReturnCode.downloadInProgress,ReturnCode.error,ReturnCode.fileTooLarge,ReturnCode.illegalParam,ReturnCode.imageTransferred,ReturnCode.invalidChunksize,ReturnCode.ok));
		m_ProcTable[405] = new ProcTableEntry("recoverAsyncMirrorGroupMember", 687, 90, true, m_TypeTable[343], m_TypeTable[152],"This procedure is used to recover a stopped or failed Async Mirror Group Member.","An object containing all of the required attributes to recover an Asynchronous Mirror Group member.","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM","","ThinToThinARVM",
			EnumSet.of(ReturnCode.arvmOnlyPrimaryMemberRemoved,ReturnCode.arvmOnlySecondaryMemberRemoved,ReturnCode.arvmOrphanGroup,ReturnCode.arvmRecoveryPointDeletionRequired,ReturnCode.arvmRemoteMirrorMemberDoesNotExist,ReturnCode.remoteDatabaseError,ReturnCode.remoteInternalError,ReturnCode.volumeHasUnreadableSectors,ReturnCode.volumeNotAvailable));
		m_ProcTable[406] = new ProcTableEntry("forceDiskPoolToOptimal", 688, 540, true, m_TypeTable[343], m_TypeTable[152],"This procedure attempts to revive the given disk pool.","An object containing all of the required attributes to revive the given disk pool.","A return code that indicates the outcome of the operation. Valid values are:","DiskPools","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[407] = new ProcTableEntry("secureDiskPool", 689, 40, true, m_TypeTable[343], m_TypeTable[152],"This procedure converts the specified disk pool to a secure volume group.","An object containing all of the required attributes to convert the specified disk pool to a secure volume group.","A return code that indicates the outcome of the operation. Valid values are:","DiskPools","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[408] = new ProcTableEntry("enableASUP", 690, 40, true, null, m_TypeTable[152],"This procedure is used to enable Autosupport.","An object containing all of the required attributes to enable ASUP support.","A return code that indicates the outcome of the operation. Valid values are:","SupportsASUP","","",
			EnumSet.of(ReturnCode.notImplemented,ReturnCode.ok));
		m_ProcTable[409] = new ProcTableEntry("disableASUP", 691, 40, true, null, m_TypeTable[152],"This procedure is used to disable Autosupport.","An object containing all of the required attributes to disable ASUP support.","A return code that indicates the outcome of the operation. Valid values are:","SupportsASUP","","",
			EnumSet.of(ReturnCode.notImplemented,ReturnCode.ok));
		m_ProcTable[410] = new ProcTableEntry("getAsyncMirrorGroupRemoteConnections", 692, 40, false, m_TypeTable[343], m_TypeTable[1184],"This procedure returns information on the connections established to a remote array for an existing AsyncMirrorGroup. This will return connection information for both controllers.","","Remote connection information is returned.","AsyncRVM1","","",
			EnumSet.of(ReturnCode.notImplemented,ReturnCode.ok));
		m_ProcTable[411] = new ProcTableEntry("getAsyncMirrorSyncStatistics", 693, 40, false, m_TypeTable[1125], m_TypeTable[1152],"This procedure will return synchronization time statistics for a list of mirror members.","","Synchronization time statistics are returned.","AsyncRVM1","","",
			EnumSet.of(ReturnCode.notImplemented,ReturnCode.ok));
		m_ProcTable[412] = new ProcTableEntry("getRemoteConnections", 694, 600, false, m_TypeTable[1111], m_TypeTable[1184],"This procedure returns information on the available connections between two arrays. This can be used prior to creation of an AsyncMirrorGroup to determine if there are wiring or other connection configuration issues between the two arrays. A call to this procedure acts like a ping test between the arrays and returns back information on the connections that succeed. This must be issued to each controller independently and should be called in fibre channel environments after activation of fibre channel remote mirroring.","","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM1","","",
			EnumSet.of(ReturnCode.notImplemented,ReturnCode.ok));
		m_ProcTable[413] = new ProcTableEntry("resetAsyncMirrorSyncStatistics", 695, 40, true, m_TypeTable[1154], m_TypeTable[152],"This procedure will reset (clear) synchronization time statistics for a list of mirror members.","","A return code that indicates the outcome of the operation. Valid values are:","AsyncRVM1","","",
			EnumSet.of(ReturnCode.notImplemented,ReturnCode.ok));
		m_ProcTable[414] = new ProcTableEntry("setSAViewPassword", 696, 40, true, m_TypeTable[422], m_TypeTable[152],"This procedure is used to set the initial view array password or change an existing view array password.","","A return code that indicates the outcome of the operation. Valid values are:","ViewOnlyPasswordMgmt","","",
			EnumSet.of(ReturnCode.adminPasswordNotSet,ReturnCode.authFailPassword,ReturnCode.ok));
		m_ProcTable[415] = new ProcTableEntry("getSAViewPasswordDigest", 697, 40, false, null, m_TypeTable[743],"This procedure is used to retrieve the digest of the view array password and its associated salt value which are saved in the array by the setViewPassword procedure. If the view array password isn't set, the procedure returns a random salt value and the digest of the salt value message.","","A return code that indicates the outcome of the operation. Valid values are:","ViewOnlyPasswordMgmt","","",
			EnumSet.of(ReturnCode.adminPasswordNotSet,ReturnCode.ok));
		m_ProcTable[416] = new ProcTableEntry("addSNMPCommunity", 698, 40, true, m_TypeTable[639], m_TypeTable[535],"This procedure is used to add a known SNMP community string. SNMP GET/SET requests are only allowed for known communities.","","A return code that indicates the outcome of the operation. Valid values are:","EmbeddedSNMPAgent","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[417] = new ProcTableEntry("addSNMPTrapDestination", 699, 40, true, m_TypeTable[1005], m_TypeTable[535],"This procedure is used to add an SNMP trap destination.","","A return code that indicates the outcome of the operation. Valid values are:","EmbeddedSNMPAgent","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.snmpIncompatibleIpv4Address,ReturnCode.snmpIncompatibleIpv6Address));
		m_ProcTable[418] = new ProcTableEntry("removeSNMPCommunity", 700, 40, true, m_TypeTable[657], m_TypeTable[152],"This procedure is used to remove a previous configured SNMP community from the list of known community strings.","","A return code that indicates the outcome of the operation. Valid values are:","EmbeddedSNMPAgent","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[419] = new ProcTableEntry("removeSNMPTrapDestination", 701, 40, true, m_TypeTable[684], m_TypeTable[152],"This procedure is used to remove a previously configured SNMP trap destination.","","A return code that indicates the outcome of the operation. Valid values are:","EmbeddedSNMPAgent","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[420] = new ProcTableEntry("setSNMPCommunityParams", 702, 40, true, m_TypeTable[738], m_TypeTable[152],"This procedure is used to modify an existing SNMP community.","","A return code that indicates the outcome of the operation. Valid values are:","EmbeddedSNMPAgent","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[421] = new ProcTableEntry("setSNMPSystemVariables", 703, 40, true, m_TypeTable[702], m_TypeTable[152],"This procedure is used to set values of user-settable SNMP system variables.","","A return code that indicates the outcome of the operation. Valid values are:","EmbeddedSNMPAgent","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[422] = new ProcTableEntry("setSNMPTrapDestinationParams", 704, 40, true, m_TypeTable[918], m_TypeTable[152],"This procedure is used to modify an existing SNMP trap destination.","","A return code that indicates the outcome of the operation. Valid values are:","EmbeddedSNMPAgent","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[423] = new ProcTableEntry("startDiskPoolReduction", 705, 40, true, m_TypeTable[952], m_TypeTable[152],"This procedure initiates a long-running operation to reduce the capacity of a Disk Pool by removing one or more drives from it.","","A return code that indicates the outcome of the operation. Valid values are:","DynamicCapacityReduction","","",
			EnumSet.of(ReturnCode.drivesNotAvailableForRemoval,ReturnCode.ok));
		m_ProcTable[424] = new ProcTableEntry("getDiskPoolReductionDriveCount", 706, 40, false, m_TypeTable[343], m_TypeTable[393],"This procedure calculates the maximum number of drives that can be removed from a disk pool.","","The maximum number of drives that can be removed from a disk pool.","DynamicCapacityReduction","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[425] = new ProcTableEntry("testSNMPTrapDestination", 707, 40, false, m_TypeTable[1109], m_TypeTable[152],"This procedure is used to test SNMP trap destinations (generate test trap).","","","EmbeddedSNMPAgent","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[426] = new ProcTableEntry("recoverAsyncMirrorGroupMemberDeleteRecoveryPoint", 708, 90, true, m_TypeTable[1029], m_TypeTable[152],"This procedure is used to recover a stopped or failed asynchronous mirror group member.","","","ThinToThinARVM","","",
			EnumSet.of(ReturnCode.arvmOnlyPrimaryMemberRemoved,ReturnCode.arvmOnlySecondaryMemberRemoved,ReturnCode.arvmOrphanGroup,ReturnCode.arvmRecoveryPointDeletionRequired,ReturnCode.arvmRemoteMirrorMemberDoesNotExist,ReturnCode.arvmRemoteThinVolInitError,ReturnCode.arvmThinVolInitError,ReturnCode.ok,ReturnCode.remoteDatabaseError,ReturnCode.remoteInternalError,ReturnCode.volumeHasUnreadableSectors,ReturnCode.volumeNotAvailable));
		m_ProcTable[427] = new ProcTableEntry("getAsupStatus", 709, 90, false, null, m_TypeTable[444],"This procedure is used to get the current Autosupport status values.","","","ASUPPhase2","","ASUPPhase2Cleanup",
			EnumSet.of(ReturnCode.notImplemented,ReturnCode.ok));
		m_ProcTable[428] = new ProcTableEntry("setAsupStatus", 710, 90, true, m_TypeTable[437], m_TypeTable[152],"This procedure is used to set the current Autosupport status values.","","","ASUPPhase2","","ASUPPhase2Cleanup",
			EnumSet.of(ReturnCode.notImplemented,ReturnCode.ok));
		m_ProcTable[429] = new ProcTableEntry("triggerIOCDumpOnDemand", 711, 40, true, m_TypeTable[432], m_TypeTable[549],"This procedure is used to manually trigger an IOC Dump on the specified channel.","","","IOCDump","","",
			EnumSet.of(ReturnCode.iocDumpInProgress,ReturnCode.iocRestoreInProgress,ReturnCode.ok));
		m_ProcTable[430] = new ProcTableEntry("getIOCDumpInformation", 712, 40, false, m_TypeTable[7], m_TypeTable[513],"This procedure is used to request information about an IOC Dump. The parameter is an IOC Dump Tag. The value of the tag is unique for each dump and may be obtained from the IOCDumpData structure in StorageArray.","","","IOCDump","","",
			EnumSet.of(ReturnCode.iocDumpInvalidTag,ReturnCode.ok));
		m_ProcTable[431] = new ProcTableEntry("recoverFromMiswire", 713, 60, true, null, m_TypeTable[152],"This procedure is used to tell the controller that corrective action has been taken to recover from a mis-wire condition. The controller will re-enable any SAS Ports that were disabled when a mis-wire was detected.","","","SASMultiPortSwitchedExpansion","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[432] = new ProcTableEntry("getEnergyStarData", 714, 40, false, null, m_TypeTable[725],"This procedure is used to request Energy Star data from all power supplies.","","","EnergyStarSupport","","",
			EnumSet.of(ReturnCode.ok,ReturnCode.unsupportedEsmRequest));
		m_ProcTable[433] = new ProcTableEntry("setFunctionState", 715, 40, true, m_TypeTable[395], m_TypeTable[481],"This procedure is used to get the state of a function, enable or disable the function, or revert the function back to its default value.","The function ID and the action to be performed.","The outcome of the get/set operation.","WindowsODX","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[434] = new ProcTableEntry("powerCyclePhysicalDrive", 716, 40, true, m_TypeTable[885], m_TypeTable[710],"This procedure is used to power cycle an individual physical drive.","The descriptor for the drive to be power cycled.","A structure that includes the return code of the operation, the drive ref of the drive for which the command was sent, and the power state of the drive.","MisbehavingDrivesPhase2","","",
			EnumSet.of(ReturnCode.downloadInProgress,ReturnCode.dpcEnclosureFwDownlevel,ReturnCode.dpcEnclosureHardwareUnsupported,ReturnCode.dpcExclusiveOperationActive,ReturnCode.dpcFormatActive,ReturnCode.dpcPowerCycleAlreadyInProgress,ReturnCode.dpcUnreadableSectorsPresent,ReturnCode.dpcVolumeGroupNotRedundant,ReturnCode.dpcVolumeNotInitialized,ReturnCode.driveNotUnassigned,ReturnCode.ok,ReturnCode.parityScanInProgress,ReturnCode.volumeGroupNotComplete,ReturnCode.volumeNotOptimal,ReturnCode.volumeReconfiguring));
		m_ProcTable[435] = new ProcTableEntry("cancelEvacuation", 717, 40, true, m_TypeTable[343], m_TypeTable[152],"This command cancels an evacuation on the referenced drive.","The drive on which to cancel an evacuation.","The return code from the operation.","LSIP200306014","","",
			EnumSet.of(ReturnCode.driveNotExist,ReturnCode.error,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidDriveref,ReturnCode.noEvacFound,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.tryAlternate));
		m_ProcTable[436] = new ProcTableEntry("copyDriveThenFail", 718, 540, true, m_TypeTable[343], m_TypeTable[152],"This procedure triggers the copy of an assigned volume group drive to a standby hot spare. Upon successful completion of the copy, the assigned drive is failed and the hot spare becomes an active drive in the volume group, sparing for the failed drive.","The drive on which to perform the operation.","The return code from the operation.","LSIP200306014","","",
			EnumSet.of(ReturnCode.drivesNotAvailableForRemoval,ReturnCode.driveNotExist,ReturnCode.driveNotOptimal,ReturnCode.driveServiceInProgress,ReturnCode.error,ReturnCode.evacInProgress,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidDriveref,ReturnCode.invalidDriveState,ReturnCode.invalidRaidlevel,ReturnCode.noHeap,ReturnCode.noHotspareAvailable,ReturnCode.noVolumes,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeGroupHasNonOptimalVols,ReturnCode.volumeGroupNotConfigurable,ReturnCode.volumeGroupNotExist,ReturnCode.volumeGroupReconfiguring,ReturnCode.volumeGroupReconstructing,ReturnCode.volumeGroupStateNotValid,ReturnCode.volumeGroupUndergoingCopyback));
		m_ProcTable[437] = new ProcTableEntry("copyDriveThenReplace", 719, 540, true, m_TypeTable[753], m_TypeTable[152],"This command will trigger an evacuation from an assigned volume group drive to an unassigned drive and replace the original drive in the volume group with the new one.","Indicates both the drive to replace and the replacement drive.","The return code from the operation.","LSIP200306014","","",
			EnumSet.of(ReturnCode.drivesNotAvailableForRemoval,ReturnCode.driveNotExist,ReturnCode.driveNotOptimal,ReturnCode.driveServiceInProgress,ReturnCode.error,ReturnCode.evacInProgress,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidDriveref,ReturnCode.invalidDriveState,ReturnCode.invalidRaidlevel,ReturnCode.noHeap,ReturnCode.noVolumes,ReturnCode.ok,ReturnCode.tryAlternate,ReturnCode.volumeGroupHasNonOptimalVols,ReturnCode.volumeGroupNotConfigurable,ReturnCode.volumeGroupNotExist,ReturnCode.volumeGroupReconfiguring,ReturnCode.volumeGroupReconstructing,ReturnCode.volumeGroupStateNotValid,ReturnCode.volumeGroupUndergoingCopyback));
		m_ProcTable[438] = new ProcTableEntry("getEnhancedIbStatistics", 720, 40, false, null, m_TypeTable[1060],"This procedure returns the InfiniBand statistics, which consists of start-of-day-relative interface statistics and baseline-relative statistics. It supersedes the deprecated getIbStatistics () routine.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","Denali2HIC","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[439] = new ProcTableEntry("startPerformanceMonitor", 721, 40, true, null, m_TypeTable[152],"This procedure returns the success of starting statistic data collection.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","PerformanceRingBuffer","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[440] = new ProcTableEntry("stopPerformanceMonitor", 722, 40, true, null, m_TypeTable[152],"This procedure returns the success of stopping statistic data collection.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","PerformanceRingBuffer","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[441] = new ProcTableEntry("setHighResolutionSampling", 728, 40, true, m_TypeTable[338], m_TypeTable[586],"This procedure enables or disables high resolution statistics gathering.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","SamPerformanceMonitoringSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[442] = new ProcTableEntry("setAutoLoadBalancing", 751, 40, true, m_TypeTable[387], m_TypeTable[152],"This procedure enables or disables the auto load balancing capability on this array.","Input descriptor indicating whether auto load balancing is to be enabled or disabled","ReturnCode indicating success or failure of request","AutoLoadBalancing","","",
			EnumSet.of(ReturnCode.databaseError,ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[443] = new ProcTableEntry("failBackVolumeOwnership", 755, 40, true, m_TypeTable[351], m_TypeTable[152],"This procedure will perform an immediate fail-back of volume current ownership to the preferred owner.","Descriptor containing input parameters for fail back request operation.","ReturnCode from result of the operation.","AutoLoadBalancing","","",
			EnumSet.of(ReturnCode.noHeap,ReturnCode.ok));
		m_ProcTable[444] = new ProcTableEntry("autoLoadBalanceRequest", 756, 40, true, m_TypeTable[429], m_TypeTable[152],"This procedure requests an on-demand volume ownership redistribution for load balancing purposes.","Request descriptor specifying details of the load balance request.","Return code from result of requested operation.","AutoLoadBalancing","","",
			EnumSet.of(ReturnCode.autoLoadBalanceInsufficientStatistics,ReturnCode.autoLoadBalanceUserDisabled,ReturnCode.ok));
		m_ProcTable[445] = new ProcTableEntry("setDrivePhysicalSecurityID", 760, 90, true, m_TypeTable[1031], m_TypeTable[152],"This procedure is used to set the Physical Security ID for a drive. The PSID is required in order to set a FIPS drive back to factory settings if the previous PSID is lost. In that case, the drive must be set back to factory settings in order to be used.","The input structure contains a reference to the drive and the Physical Security ID string.","The procedure returns a return code, indicating the success or failure of the command. If the command works, RETCODE_OK will be returned. If the drive reference is invalid, RETCODE_INVALID_DRIVE will be returned. If the PSID is not accepted by the drive, RETCODE_INVALID_PSID will be returned.","FIPSDriveSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[446] = new ProcTableEntry("setThinVolumeReportingPolicy", 761, 40, true, m_TypeTable[1040], m_TypeTable[152],"This procedure changes the reporting policy of a thin volume. The reporting policy controls how a thin volume is reported to the host on the SCSI interface, i.e., as a thin volume that supports unmap commands or as a thick volume.","A ThinVolumeReportingPolicyUpdateDescriptor structure containing the arguments for the procedure call.","A return code that indicates the output of the operation.","UnmapSupport","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[447] = new ProcTableEntry("setClusterPerformanceLimitationValues", 763, 40, true, m_TypeTable[763], m_TypeTable[152],"This procedure allows the user to limit the performance of a host cluster. The limitations that can be set are throughput (MB/s) and IOPs.","The procedure takes as input a structure containing the limitations on the performance of the cluster.","The procedure returns a return code.","ClusterQoSParameters","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[448] = new ProcTableEntry("getClusterPerformanceLimitationValues", 764, 40, false, m_TypeTable[343], m_TypeTable[851],"This procedures returns the performance limitation values for a host cluster. Those values include the limits on the IOPs and throughput (MB/s). The number of IOPs impacted by the performance limits is also returned.","This procedure takes a cluster reference as an input parameter.","This procedures returns the performance limitation values for a host cluster.","ClusterQoSParameters","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[449] = new ProcTableEntry("createKeyValueTag", 765, 40, true, m_TypeTable[717], m_TypeTable[535],"This procedure is utilized to add new key-value tags to the persistent memory so they can be used for application awareness.","The input is an array of key-value descriptors. The content of each is two opaque, fixed length byte arrays.","The response is a return code indicating overall status. If the return is successful, it also includes a list of the KeyValueTagRef objects, in the same order as the request descriptor.","ApplicationAwareness","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[450] = new ProcTableEntry("deleteKeyValueTag", 766, 40, true, m_TypeTable[677], m_TypeTable[152],"This procedure removes from the array the specified key-value tags. It is an error to remove in-use key-value tags.","The input identifies the key-value pairs to be deleted from the array. Unknown references are ignored.","A return code indicates the success or failure (with reason).","ApplicationAwareness","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[451] = new ProcTableEntry("setKeyValueTagMapping", 768, 40, true, m_TypeTable[1082], m_TypeTable[152],"This procedure persists the association between the Key-Value tags and the Volumes (or Workloads). This procedure is used both for creating the initial mappings and to update. Each execution will remove any existing mappings and replace them with the mappings defined within the argument list.","The input is a list of mappings, each mapping consists of a Volume Reference and a Key-Value Pair reference. This method will create the initial associations and can be used to perform a replacement of those associations.","Reports the success or failure of the procedure. It is an error if the input descriptor contains invalid references or duplicate entries.","ApplicationAwareness","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[452] = new ProcTableEntry("deleteKeyValueTagMapping", 769, 40, true, m_TypeTable[999], m_TypeTable[152],"This procedure removes from the specified volumes all references to specific Key-Value tags.","The input is a list of references to Volumes (or Workloads). For each in the list, all references to Key-Value tags are deleted.","A return value that indicates the success or failure of the procedure.","ApplicationAwareness","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[453] = new ProcTableEntry("createWorkload", 770, 40, true, m_TypeTable[704], m_TypeTable[535],"This procedure is utilized to add new application awareness workloads to persistent memory. The workload objects are created but do not as yet have Key-Value Tags associated to them. That requires calling the setKeyValueTagMapping procedure.","A list of the WorkloadCreationDescriptors used as an input to the createWorkload procedure.","The returned structure allows this function to return a list of workload references and a return status.","ApplicationAwareness","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[454] = new ProcTableEntry("deleteWorkload", 771, 40, true, m_TypeTable[788], m_TypeTable[152],"This procedure removes the specified application awareness workloads. It is not an error to remove in-use (association mapped) workloads. All association mappings for the workload are removed including any KeyValueTag mappings. The actual KeyValueTag records are not deleted.","A list of SYMbol application awareness workload references.","A return code indicates the success or failure (with reason).","ApplicationAwareness","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[455] = new ProcTableEntry("createWorkloadVolumeMapping", 772, 40, false, m_TypeTable[836], m_TypeTable[152],"This procedure creates the mappings between the list of workloads and volumes specified by the input descriptor.","The input descriptor is a list of workload and volume pairs, each pair is to be mapped.","The return code specifies the success or failure of the procedure.","ApplicationAwareness","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[456] = new ProcTableEntry("deleteWorkloadVolumeMapping", 773, 40, false, m_TypeTable[801], m_TypeTable[152],"This procedure deletes the specified workload to volume mappings.","A list of unique identifiers to the workload to volume mappings to be deleted.","A return code that indicates the success or failure of the procedure.","ApplicationAwareness","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[457] = new ProcTableEntry("generateCertificateSigningRequest", 774, 40, true, m_TypeTable[386], m_TypeTable[317],"Generates a Key Management Server (KMS) Client Certificate Signing Request (CSR) that needs to be signed by a Certificate Authority (CA). The resulting signed certificate or client certificate is installed on the storage array for authenticating with the KMIP server.","","","EmbeddedExternalKeyMgmt","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[458] = new ProcTableEntry("installKMSCertificateFile", 775, 40, true, m_TypeTable[316], m_TypeTable[152],"Installs a Key Management Server (KMS) Certificate File on the storage array. In addition to the contents of the certificate file, the type of certificate must be specified. If a certificate of the type specified already exists on the storage array, it will be overwritten by the new certificate.","","","EmbeddedExternalKeyMgmt","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[459] = new ProcTableEntry("retrieveKMSCertificateFile", 776, 40, true, m_TypeTable[564], m_TypeTable[317],"Retrieves a specified Key Management Server (KMS) ertificate currently installed on the storage array so that information about the certifiacte such as date of expiration can be extracted and displayed. This allows the storage administrator to know what is installed on the system and used for authentication with the KMIP server.","","","EmbeddedExternalKeyMgmt","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[460] = new ProcTableEntry("removeInstalledKMSCertificateFiles", 778, 40, true, m_TypeTable[265], m_TypeTable[152],"This procedure will remove a specified installed KMS certificate from the storage array.","","","EmbeddedExternalKeyMgmt","","",
			EnumSet.of(ReturnCode.embeddedExternalKeyManagementEnabled,ReturnCode.ok));
		m_ProcTable[461] = new ProcTableEntry("setHostPortsAttributes", 779, 40, true, m_TypeTable[947], m_TypeTable[152],"This procedure sets selected HostPorts attributes, as specified by the input argument. It is meant to operate on a group of ports, for example all the ports on a host interface card or base board.","A HostPortsAttributesUpdateDescriptor structure containing the arguments for the procedure call.","A return code that indicates the outcome of the operation.","SetIscsiHostPortAttributes","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[462] = new ProcTableEntry("setExternalKMSParameters", 780, 40, true, m_TypeTable[1044], m_TypeTable[152],"Sets parameters necessary to communicate with an external key management server.","","","EmbeddedExternalKeyMgmt","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[463] = new ProcTableEntry("verifyExternalKMSCommunication", 781, 40, true, null, m_TypeTable[152],"Uses the credentials (certificates, address of the KMIP server, and the KMIP port number) provided to verify that the storage array is able to communicate with the external KMIP server.","","","EmbeddedExternalKeyMgmt","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[464] = new ProcTableEntry("tunnelHttpCall", 782, 300, false, m_TypeTable[543], m_TypeTable[711],"A procedure that provides a means to tunnel HTTP calls through the UTM Lun. The HTTP call is executed against the embedded web server.","A SymbolTunnelRequest structure that provides the input data for an HTTP call against an embedded web server.","A SymbolTunnelReply object that describes the Symbol return value as well as the results of the HTTP request executed against the embedded web server.","MadridBase","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[465] = new ProcTableEntry("setNVMeHostInterfaceProperties", 783, 40, true, m_TypeTable[902], m_TypeTable[152],"This procedure sets the properties of a NVMe over Fabrics Host Interface port.","NVMe over Fabrics Host Interface Properties","RETCODE value","NVMeOverInfinibandRedwoodHIC","","",
			EnumSet.of(ReturnCode.invalidInterfaceref,ReturnCode.invalidIpAddress,ReturnCode.ok));
		m_ProcTable[466] = new ProcTableEntry("handleInternalMessage", 784, 40, true, m_TypeTable[1086], m_TypeTable[449],"Intended to allow processes external to EOS to send messages and events into EOS. This is primarily to allow non-EOS processes (like the WebServices Proxy) to generate MEL and Needs Attention conditions, but is extensible to allow other types of messages as well","Describes the type and details of the internal message being sent to the EOS process","Returns RETCODE_OK on success. Will return an appropriate error code for all failures","DirectoryServicesSecurityEnhancements","","",
			EnumSet.of(ReturnCode.error,ReturnCode.illegalParam,ReturnCode.internalError,ReturnCode.invalidRequest,ReturnCode.notImplemented,ReturnCode.noHeap,ReturnCode.ok,ReturnCode.uninitialized));
		m_ProcTable[467] = new ProcTableEntry("getNVMeoFStatistics", 785, 40, false, null, m_TypeTable[1190],"This procedure returns the NVMeoF statistics, which consist of start-of-day-relative interface/queue statistics and baseline-relative interface/queue statistics.","None.","An NvmeofStatisticsReturned structure containing the list of NVMeoF statistics. The list below identifies the return codes for this procedure.","NVMeOverInfinibandRedwoodHIC","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[468] = new ProcTableEntry("setNVMeoFStatisticsBaseline", 786, 40, true, null, m_TypeTable[152],"This procedure, from the client's perspective, resets the NVMe over Fabrics baselined statistical counters to zero. It is a logical reset in the sense that the raw counts maintained in hardware and firmware are not actually reset; instead the firmware makes a snapshot of the current counter values and uses that to report deltas in counts when the statistics are fetched. The new baseline time is applied to both storage controllers, so that their counts are in sync with one another. If one storage controller resets without the other resetting, the counters become effectively out of sync and the client is made aware of this fact by the timestamp data reported along with the statistics.","None.","A ReturnCode object that indicates the outcome of the operation. Valid values are:","NVMeOverInfinibandRedwoodHIC","","",
			EnumSet.of(ReturnCode.ok));
		m_ProcTable[469] = new ProcTableEntry("setCacheMirroringProtectionInformation", 787, 40, true, m_TypeTable[314], m_TypeTable[152],"This procedure allows checking of protection information of cache mirroring to be enabled or disabled, if this feature is supported. There is a capability enumeration that indicates whether or not this feature is supported.","A CacheMirroringProtectionInformationDescriptor containing the arguments for the call.","A return code that indicates the status of the operation.","PICheckForMirroring","","",
			EnumSet.of(ReturnCode.ok));
	}

	static
	{
		m_ProcTable = new ProcTableEntry[470];

		__init18();
		__init19();
		__init20();
	}
}
